@@ -1,6 +1,6 @@
 /* airpcap_loader.c
  *
- * $Id$
+ * $Id: airpcap_loader.c 50896 2013-07-25 23:49:47Z gerald $
  *
  * Giorgio Tino <giorgio.tino@cacetech.com>
  * Copyright (c) CACE Technologies, LLC 2006
@@ -163,7 +163,7 @@ get_wep_key(pref_t *pref, gpointer ud)
 
     if (g_ascii_strcasecmp(pref->name, "wep_key_table") == 0 && pref->type == PREF_UAT)
     {
-        uat = (uat_t *)pref->varp.uat;
+        uat = pref->varp.uat;
         /* This is just a sanity check.  UAT should be loaded */
         if (!uat->loaded)
         {
@@ -259,7 +259,7 @@ set_wep_key(pref_t *pref, gpointer ud _U_)
 
     if (g_ascii_strcasecmp(pref->name, "wep_key_table") == 0 && pref->type == PREF_UAT)
     {
-        uat = (uat_t *)pref->varp.uat;
+        uat = pref->varp.uat;
         if (!uat->loaded)
         {
             /* UAT will only be loaded if previous keys exist, so it may need
