@@ -1,8 +1,8 @@
 /* packet-c1222.c
  * Routines for ANSI C12.22 packet dissection
- * Copyright 2010, Edward J. Beroset, edward.j.beroset@us.elster.com
+ * Copyright 2010, Edward J. Beroset, edward.beroset@elster.com
  *
- * $Id$
+ * $Id: packet-c1222-template.c 52503 2013-10-10 17:44:55Z eapache $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,6 +26,9 @@
 #include "config.h"
 
 #include <glib.h>
+
+#include <wsutil/eax.h>
+
 #include <epan/conversation.h>
 #include <epan/expert.h>
 #include <epan/packet.h>
@@ -34,7 +37,7 @@
 #include <epan/dissectors/packet-ber.h>
 #include <epan/dissectors/packet-tcp.h>
 #include <epan/uat.h>
-#include <epan/crypt/eax.h>
+#include <epan/oids.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -86,6 +89,9 @@ static int proto_c1222 = -1;
 static int global_c1222_port = C1222_PORT;
 static gboolean c1222_desegment = TRUE;
 static gboolean c1222_decrypt = TRUE;
+static const gchar *c1222_baseoid_str = NULL;
+static guint8 *c1222_baseoid = NULL;
+static guint c1222_baseoid_len = 0;
 
 #include "packet-c1222-hf.c"
 /* These are the EPSEM pieces */
@@ -128,6 +134,7 @@ static int hf_c1222_write_table = -1;
 static int hf_c1222_write_offset = -1;
 static int hf_c1222_write_size = -1;
 static int hf_c1222_write_data = -1;
+static int hf_c1222_procedure_num = -1;
 static int hf_c1222_write_chksum = -1;
 static int hf_c1222_wait_secs = -1;
 static int hf_c1222_neg_pkt_size = -1;
@@ -181,6 +188,19 @@ static guint32 iv_element_len = 0;
 
 #include "packet-c1222-ett.c"
 
+static expert_field ei_c1222_command_truncated = EI_INIT;
+static expert_field ei_c1222_bad_checksum = EI_INIT;
+static expert_field ei_c1222_epsem_missing = EI_INIT;
+#ifdef HAVE_LIBGCRYPT
+static expert_field ei_c1222_epsem_failed_authentication = EI_INIT;
+#else
+static expert_field ei_c1222_epsem_not_authenticated = EI_INIT;
+#endif
+static expert_field ei_c1222_epsem_not_decryped = EI_INIT;
+static expert_field ei_c1222_ed_class_missing = EI_INIT;
+static expert_field ei_c1222_epsem_ber_length_error = EI_INIT;
+static expert_field ei_c1222_epsem_field_length_error = EI_INIT;
+static expert_field ei_c1222_mac_missing = EI_INIT;
 
 /*------------------------------
  * Data Structures
@@ -216,7 +236,7 @@ static const value_string tableflags[] = {
 
 static const value_string procflags[] = {
   { 0x00, "SF" },
-  { 0x01, "MF" },
+  { 0x08, "MF" },
   { 0, NULL }
 };
 
@@ -285,15 +305,34 @@ static uat_t *c1222_uat;
 #define FILL_START int length, start_offset = offset;
 #define FILL_TABLE(fieldname)  \
   length = offset - start_offset; \
-  fieldname = (guint8 *)tvb_memdup(tvb, start_offset, length); \
+  fieldname = (guint8 *)tvb_memdup(wmem_packet_scope(), tvb, start_offset, length); \
   fieldname##_len = length;
 #define FILL_TABLE_TRUNCATE(fieldname, len)  \
   length = 1 + 2*(offset - start_offset); \
-  fieldname = (guint8 *)tvb_memdup(tvb, start_offset, length); \
+  fieldname = (guint8 *)tvb_memdup(wmem_packet_scope(), tvb, start_offset, length); \
   fieldname##_len = len;
+#define FILL_TABLE_APTITLE(fieldname) \
+  length = offset - start_offset; \
+  switch (tvb_get_guint8(tvb, start_offset)) { \
+    case 0x80: /* relative OID */ \
+      tvb_ensure_bytes_exist(tvb, start_offset, length); \
+      fieldname##_len = length + c1222_baseoid_len; \
+      fieldname = (guint8 *)wmem_alloc(wmem_packet_scope(), fieldname##_len); \
+      fieldname[0] = 0x06;  /* create absolute OID tag */ \
+      fieldname[1] = (fieldname##_len - 2) & 0xff;  \
+      memcpy(&(fieldname[2]), c1222_baseoid, c1222_baseoid_len); \
+      tvb_memcpy(tvb, &(fieldname[c1222_baseoid_len+2]), start_offset+2, length-2); \
+      break; \
+    case 0x06:  /* absolute OID */ \
+    default: \
+      fieldname = (guint8 *)tvb_memdup(wmem_packet_scope(), tvb, start_offset, length); \
+      fieldname##_len = length; \
+      break; \
+  }
 #else /* HAVE_LIBGCRYPT */
 #define FILL_TABLE(fieldname)
 #define FILL_TABLE_TRUNCATE(fieldname, len)
+#define FILL_TABLE_APTITLE(fieldname)
 #define FILL_START
 #endif /* HAVE_LIBGCRYPT */
 
@@ -329,10 +368,10 @@ c1222_cksum(tvbuff_t *tvb, gint offset, int len)
  * Dissects C12.22 packet in detail (with a tree).
  *
  * \param tvb input buffer containing packet to be dissected
- * \param pinfo
- * \param tree
- * \param length
- * \param offset
+ * \param pinfo the packet info of the current data
+ * \param tree the tree to append this item to
+ * \param length length of data
+ * \param offset the offset in the tvb
  */
 static void
 parse_c1222_detailed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int cmd, guint32 *length, int *offset)
@@ -349,6 +388,7 @@ parse_c1222_detailed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int cm
   guint8 wait_seconds = 0;
   int numrates = 0;
   guint16 packet_size;
+  guint16 procedure_num = 0;
   guint8 nbr_packet;
   /* timing setup parameters */
   guint8 traffic;
@@ -371,19 +411,19 @@ parse_c1222_detailed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int cm
 	    user_id = tvb_get_ntohs(tvb, *offset);
 	    proto_tree_add_uint(tree, hf_c1222_logon_id, tvb, *offset, 2, user_id);
 	    *offset += 2;
-	    user_name = tvb_get_ephemeral_string(tvb, *offset, 10);
+	    user_name = tvb_get_string(wmem_packet_scope(),tvb, *offset, 10);
 	    proto_tree_add_string(tree, hf_c1222_logon_user, tvb, *offset, 10, user_name);
 	    *offset += 10;
 	    *length -= 12;
 	    proto_item_set_text(tree, "C12.22 EPSEM: %s (id %d, user \"%s\")",
 		    val_to_str(cmd,commandnames,"Unknown (0x%02x)"), user_id, user_name);
 	} else {
-	    expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 LOGON command truncated");
+	    expert_add_info_format(pinfo, tree, &ei_c1222_command_truncated, "C12.22 LOGON command truncated");
 	}
 	break;
     case C1222_CMD_SECURITY:
 	if (*length >= 20) {
-	    password = tvb_get_ephemeral_string(tvb, *offset, 20);
+	    password = tvb_get_string(wmem_packet_scope(),tvb, *offset, 20);
 	    proto_tree_add_string(tree, hf_c1222_security_password, tvb, *offset, 20, password);
 	    *offset += 20;
 	    *length -= 20;
@@ -399,7 +439,7 @@ parse_c1222_detailed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int cm
 		      val_to_str(cmd,commandnames,"Unknown (0x%02x)"), password);
 	    }
 	} else {
-	    expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 SECURITY command truncated");
+	    expert_add_info_format(pinfo, tree, &ei_c1222_command_truncated, "C12.22 SECURITY command truncated");
 	}
 	break;
     case C1222_CMD_AUTHENTICATE:
@@ -415,10 +455,10 @@ parse_c1222_detailed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int cm
 		proto_item_set_text(tree, "C12.22 EPSEM: %s (%d bytes: %s)",
 		    val_to_str(cmd,commandnames,"Unknown (0x%02x)"), auth_len, auth_req);
 	    } else {
-		expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 AUTHENTICATE command truncated");
+		expert_add_info_format(pinfo, tree, &ei_c1222_command_truncated, "C12.22 AUTHENTICATE command truncated");
 	    }
 	} else {
-	    expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 AUTHENTICATE command truncated");
+	    expert_add_info_format(pinfo, tree, &ei_c1222_command_truncated, "C12.22 AUTHENTICATE command truncated");
 	}
 	break;
     case C1222_CMD_FULL_READ:
@@ -431,7 +471,7 @@ parse_c1222_detailed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int cm
 	    *offset += 2;
 	    *length -= 2;
 	} else {
-	    expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 READ command truncated");
+	    expert_add_info_format(pinfo, tree, &ei_c1222_command_truncated, "C12.22 READ command truncated");
 	}
 	break;
     case C1222_CMD_PARTIAL_READ_OFFSET:
@@ -450,7 +490,7 @@ parse_c1222_detailed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int cm
 		    val_to_str(cmd,commandnames,"Unknown (0x%02x)"),
 		    val_to_str((table >> 8) & 0xF8, tableflags,"Unknown (0x%04x)"), table & 0x7FF);
 	} else {
-	    expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 READ command truncated");
+	    expert_add_info_format(pinfo, tree, &ei_c1222_command_truncated, "C12.22 READ command truncated");
 	}
 	break;
     case C1222_CMD_FULL_WRITE:
@@ -464,25 +504,43 @@ parse_c1222_detailed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int cm
 	    *offset += 2;
 	    *length -= 2;
 	    if (*length >= tblsize+1U) {
+		if (table == 7) {/* is it a procedure call? */
+		    procedure_num = tvb_get_letohs(tvb, *offset);
+		    proto_tree_add_uint(tree, hf_c1222_procedure_num, tvb, *offset, 2, procedure_num);
+		    *offset += 2;
+		    *length -= 2;
+		    tblsize -= 2;
+		}
 		proto_tree_add_item(tree, hf_c1222_write_data, tvb, *offset, tblsize, ENC_NA);
 		*offset += tblsize;
 		*length -= tblsize;
 		chksum = tvb_get_guint8(tvb, *offset);
 		item = proto_tree_add_uint(tree, hf_c1222_write_chksum, tvb, *offset, 1, chksum);
-		calcsum = c1222_cksum(tvb, (*offset)-tblsize, tblsize);
+		if (table == 7) {/* is it a procedure call? */
+		    calcsum = c1222_cksum(tvb, (*offset)-tblsize-2, tblsize+2);
+		} else {
+		    calcsum = c1222_cksum(tvb, (*offset)-tblsize, tblsize);
+		}
 		if (chksum != calcsum) {
-		  expert_add_info_format(pinfo, item, PI_CHECKSUM, PI_ERROR, "Bad checksum [should be 0x%02x]", calcsum);
+		  expert_add_info_format(pinfo, item, &ei_c1222_bad_checksum, "Bad checksum [should be 0x%02x]", calcsum);
+		}
+		if (table == 7) {/* is it a procedure call? */
+		    proto_item_set_text(tree, "C12.22 EPSEM: %s (%s-%d, %s-%d)",
+			    val_to_str(cmd,commandnames,"Unknown (0x%02x)"),
+			    val_to_str((table >> 8) & 0xF8, tableflags,"Unknown (0x%04x)"), table & 0x7FF,
+			    val_to_str((procedure_num >> 8) & 0xF8, procflags,"Unknown (0x%04x)"), procedure_num & 0x7FF);
+		} else {
+		    proto_item_set_text(tree, "C12.22 EPSEM: %s (%s-%d)",
+			    val_to_str(cmd,commandnames,"Unknown (0x%02x)"),
+			    val_to_str((table >> 8) & 0xF8, tableflags,"Unknown (0x%04x)"), table & 0x7FF);
 		}
-		proto_item_set_text(tree, "C12.22 EPSEM: %s (%s-%d)",
-			val_to_str(cmd,commandnames,"Unknown (0x%02x)"),
-			val_to_str((table >> 8) & 0xF8, tableflags,"Unknown (0x%04x)"), table & 0x7FF);
 		*offset += 1;
 		*length -= 1;
 	    } else {
-		expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 WRITE command truncated");
+		expert_add_info_format(pinfo, tree, &ei_c1222_command_truncated, "C12.22 WRITE command truncated");
 	    }
 	} else {
-	    expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 WRITE command truncated");
+	    expert_add_info_format(pinfo, tree, &ei_c1222_command_truncated, "C12.22 WRITE command truncated");
 	}
 	break;
     case C1222_CMD_PARTIAL_WRITE_OFFSET:
@@ -506,7 +564,7 @@ parse_c1222_detailed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int cm
 		item = proto_tree_add_uint(tree, hf_c1222_write_chksum, tvb, *offset, 1, chksum);
 		calcsum = c1222_cksum(tvb, (*offset)-tblsize, tblsize);
 		if (chksum != calcsum) {
-		  expert_add_info_format(pinfo, item, PI_CHECKSUM, PI_ERROR, "Bad checksum [should be 0x%02x]", calcsum);
+		  expert_add_info_format(pinfo, item, &ei_c1222_bad_checksum, "Bad checksum [should be 0x%02x]", calcsum);
 		}
 		proto_item_set_text(tree, "C12.22 EPSEM: %s (%s-%d)",
 			val_to_str(cmd,commandnames,"Unknown (0x%02x)"),
@@ -514,10 +572,10 @@ parse_c1222_detailed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int cm
 		*offset += 1;
 		*length -= 1;
 	    } else {
-		expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 WRITE command truncated");
+		expert_add_info_format(pinfo, tree, &ei_c1222_command_truncated, "C12.22 WRITE command truncated");
 	    }
 	} else {
-	    expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 WRITE command truncated");
+	    expert_add_info_format(pinfo, tree, &ei_c1222_command_truncated, "C12.22 WRITE command truncated");
 	}
 	break;
     case C1222_CMD_WAIT:
@@ -529,7 +587,7 @@ parse_c1222_detailed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int cm
 	    proto_item_set_text(tree, "C12.22 EPSEM: %s (%d seconds)",
 		val_to_str(cmd,commandnames,"Unknown (0x%02x)"), wait_seconds);
 	} else {
-	    expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 WAIT command truncated");
+	    expert_add_info_format(pinfo, tree, &ei_c1222_command_truncated, "C12.22 WAIT command truncated");
 	}
 	break;
     case C1222_CMD_NEGOTIATE:
@@ -545,7 +603,7 @@ parse_c1222_detailed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int cm
 	    proto_item_set_text(tree, "C12.22 EPSEM: %s (pkt size %d, num pkts %d, with %d baud rates)",
 		    val_to_str(cmd,commandnames,"Unknown (0x%02x)"), packet_size, nbr_packet, numrates);
 	} else {
-	    expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 NEGOTIATE command truncated");
+	    expert_add_info_format(pinfo, tree, &ei_c1222_command_truncated, "C12.22 NEGOTIATE command truncated");
 	}
 	break;
     case C1222_CMD_TIMING_SETUP:
@@ -569,7 +627,7 @@ parse_c1222_detailed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int cm
 	    proto_item_set_text(tree, "C12.22 EPSEM: %s (traffic to %d s, inter-char to %d s, response to %d s, %d retries)",
 		    val_to_str(cmd,commandnames,"Unknown (0x%02x)"), traffic, inter_char, resp_to, nbr_retries);
 	} else {
-	    expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 NEGOTIATE command truncated");
+	    expert_add_info_format(pinfo, tree, &ei_c1222_command_truncated, "C12.22 NEGOTIATE command truncated");
 	}
 	break;
 
@@ -577,11 +635,7 @@ parse_c1222_detailed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int cm
 	/* don't do anything */
 	proto_item_set_text(tree, "C12.22 EPSEM: %s", val_to_str(cmd, commandnames, "Unknown (0x%02x)"));
 	if (*length) {
-	    if (*length >= *length) {
-	      proto_tree_add_item(tree, hf_c1222_data, tvb, *offset, *length, ENC_NA);
-	    } else {
-		expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 unknown command truncated");
-	    }
+	  proto_tree_add_item(tree, hf_c1222_data, tvb, *offset, *length, ENC_NA);
 	}
 	break;
   }
@@ -608,7 +662,7 @@ static const TOP_ELEMENT_CONTROL canonifyTable[] = {
   { FALSE, FALSE, 0xA1, TRUE, &aSO_context, &aSO_context_len },
   { TRUE , FALSE, 0xA2, TRUE, &called_AP_title, &called_AP_title_len },
   { FALSE, FALSE, 0xA4, TRUE, &called_AP_invocation_id, &called_AP_invocation_id_len },
-  { FALSE, FALSE, 0xA3, TRUE, &calling_AE_qualifier, &calling_AE_qualifier_len },
+  { FALSE, FALSE, 0xA7, TRUE, &calling_AE_qualifier, &calling_AE_qualifier_len },
   { TRUE,  FALSE, 0xA8, TRUE, &calling_AP_invocation_id, &calling_AP_invocation_id_len },
   { FALSE, FALSE, 0x8B, TRUE, &mechanism_name, &mechanism_name_len },
   { FALSE, FALSE, 0xAC, TRUE, &calling_authentication_value, &calling_authentication_value_len },
@@ -619,6 +673,17 @@ static const TOP_ELEMENT_CONTROL canonifyTable[] = {
   { FALSE, FALSE, 0x0,  TRUE, NULL, NULL }
 };
 
+static void 
+clear_canon(void)
+{
+  const TOP_ELEMENT_CONTROL *t = canonifyTable;
+
+  for (t = canonifyTable; t->element != NULL; t++) {
+    *(t->length) = 0;
+    *(t->element) = NULL;
+  }
+}
+
 /**
  * Calculates the size of the passed number n as encoded as a BER length field.
  *
@@ -714,8 +779,9 @@ canonify_unencrypted_header(guchar *buff, guint32 *offset, guint32 buffsize)
       }
       memcpy(&buff[*offset], *(t->element), len);
       (*offset) += len;
-      g_free(*(t->element));
-      *(t->element) = NULL;
+      if (t->addtag) {
+	  *(t->element) = NULL;
+      }
     }
   }
   return TRUE;
@@ -724,7 +790,7 @@ canonify_unencrypted_header(guchar *buff, guint32 *offset, guint32 buffsize)
 /**
  * Looks up the required key in the key table.
  *
- * \param keybuf is updated with a copy of the key data if successful lookup.
+ * \param keybuff is updated with a copy of the key data if successful lookup.
  * \param keyid is the ID number of the desired key
  * \returns TRUE if key was found; otherwise FALSE
  */
@@ -845,11 +911,11 @@ ber_len_ok(tvbuff_t *tvb, int offset)
 /**
  * Dissects the EPSEM portion of the User-information part of a C12.22 message.
  *
- * \param tvb
- * \param offset
- * \param len
- * \param pinfo
- * \param tree
+ * \param tvb the tv buffer of the current data
+ * \param offset the offset in the tvb
+ * \param len length of data
+ * \param pinfo the packet info of the current data
+ * \param tree the tree to append this item to
  */
 static int
 dissect_epsem(tvbuff_t *tvb, int offset, guint32 len, packet_info *pinfo, proto_tree *tree)
@@ -872,7 +938,7 @@ dissect_epsem(tvbuff_t *tvb, int offset, guint32 len, packet_info *pinfo, proto_
   gboolean encrypted = FALSE;
 
   if ((tvb == NULL) && (len == 0)) {
-      expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 EPSEM missing");
+      expert_add_info(pinfo, tree, &ei_c1222_epsem_missing);
       return offset;
   }
   /* parse the flags byte which is always unencrypted */
@@ -888,9 +954,8 @@ dissect_epsem(tvbuff_t *tvb, int offset, guint32 len, packet_info *pinfo, proto_
         return offset;
       encrypted = TRUE;
       if (c1222_decrypt) {
-	buffer = (guchar *)tvb_memdup(tvb, offset, len2);
+	buffer = (guchar *)tvb_memdup(wmem_packet_scope(), tvb, offset, len2);
 	if (!decrypt_packet(buffer, len2, TRUE)) {
-	  g_free(buffer);
 	  crypto_bad = TRUE;
 	} else {
 	  epsem_buffer = tvb_new_real_data(buffer, len2, len2);
@@ -907,15 +972,15 @@ dissect_epsem(tvbuff_t *tvb, int offset, guint32 len, packet_info *pinfo, proto_
       len2 = tvb_length_remaining(tvb, offset);
       if (len2 <= 0)
         return offset;
-      buffer = (guchar *)tvb_memdup(tvb, offset, len2);
+      buffer = (guchar *)tvb_memdup(wmem_packet_scope(), tvb, offset, len2);
       epsem_buffer = tvb_new_subset_remaining(tvb, offset);
       if (c1222_decrypt) {
 	if (!decrypt_packet(buffer, len2, FALSE)) {
 #ifdef HAVE_LIBGCRYPT
 	  crypto_bad = TRUE;
-	  expert_add_info_format(pinfo, tree, PI_SECURITY, PI_ERROR, "C12.22 EPSEM failed authentication");
+	  expert_add_info(pinfo, tree, &ei_c1222_epsem_failed_authentication);
 #else /* HAVE_LIBGCRYPT */
-	  expert_add_info_format(pinfo, tree, PI_SECURITY, PI_WARN, "C12.22 EPSEM could not be authenticated");
+	  expert_add_info(pinfo, tree, &ei_c1222_epsem_not_authenticated);
 #endif /* HAVE_LIBGCRYPT */
 	} else {
 	  crypto_good = TRUE;
@@ -929,7 +994,7 @@ dissect_epsem(tvbuff_t *tvb, int offset, guint32 len, packet_info *pinfo, proto_
   /* it's only encrypted if we have an undecrypted payload */
   if (encrypted) {
     proto_tree_add_item(tree, hf_c1222_epsem_total, tvb, offset, -1, ENC_NA);
-    expert_add_info_format(pinfo, tree, PI_UNDECODED, PI_WARN, "C12.22 EPSEM could not be decrypted");
+    expert_add_info(pinfo, tree, &ei_c1222_epsem_not_decryped);
     local_offset = offset+len2-4;
     epsem_buffer = tvb;
   } else {  /* it's not (now) encrypted */
@@ -940,7 +1005,7 @@ dissect_epsem(tvbuff_t *tvb, int offset, guint32 len, packet_info *pinfo, proto_
 	proto_tree_add_item(tree, hf_c1222_epsem_ed_class, epsem_buffer, local_offset, 4, ENC_NA);
 	local_offset += 4;
       } else {
-	expert_add_info_format(pinfo, tree, PI_SECURITY, PI_ERROR, "C12.22 ED Class missing");
+	expert_add_info(pinfo, tree, &ei_c1222_ed_class_missing);
       }
     }
     /* what follows are one or more <epsem-data> elements possibly followed by
@@ -952,7 +1017,7 @@ dissect_epsem(tvbuff_t *tvb, int offset, guint32 len, packet_info *pinfo, proto_
       if (ber_len_ok(epsem_buffer, local_offset)) {
 	local_offset = dissect_ber_length(pinfo, tree, epsem_buffer, local_offset, (guint32 *)&len2, &ind);
       } else {
-	expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 EPSEM BER length error");
+	expert_add_info(pinfo, tree, &ei_c1222_epsem_ber_length_error);
 	return offset+len;
       }
       if (tvb_offset_exists(epsem_buffer, local_offset+len2-1)) {
@@ -962,7 +1027,7 @@ dissect_epsem(tvbuff_t *tvb, int offset, guint32 len, packet_info *pinfo, proto_
 	parse_c1222_detailed(epsem_buffer, pinfo, cmd_tree, cmd_err, (guint32 *)&len2, &local_offset);
 	local_offset += len2;
       } else {
-	expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 EPSEM field length error");
+	expert_add_info(pinfo, tree, &ei_c1222_epsem_field_length_error);
 	return offset+len;
       }
     }
@@ -977,7 +1042,7 @@ dissect_epsem(tvbuff_t *tvb, int offset, guint32 len, packet_info *pinfo, proto_
       item = proto_tree_add_boolean(crypto_tree, hf_c1222_epsem_crypto_bad, tvb, local_offset, 4, crypto_bad);
       PROTO_ITEM_SET_GENERATED(item);
     } else {
-      expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR, "C12.22 MAC missing");
+      expert_add_info(pinfo, tree, &ei_c1222_mac_missing);
       return offset+len;
     }
   }
@@ -989,15 +1054,15 @@ dissect_epsem(tvbuff_t *tvb, int offset, guint32 len, packet_info *pinfo, proto_
 /**
  * Dissects a a full (reassembled) C12.22 message.
  *
- * \param tvb
- * \param pinfo
- * \param tree
+ * \param tvb the tv buffer of the current data
+ * \param pinfo the packet info of the current data
+ * \param tree the tree to append this item to
  */
 static void
 dissect_c1222_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     proto_item      *c1222_item = NULL;
-    proto_tree	    *c1222_tree = NULL;
+    proto_tree      *c1222_tree = NULL;
 
     /* make entry in the Protocol column on summary display */
     col_set_str(pinfo->cinfo, COL_PROTOCOL, PNAME);
@@ -1006,16 +1071,16 @@ dissect_c1222_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     if (tree) {
         c1222_item = proto_tree_add_item(tree, proto_c1222, tvb, 0, -1, ENC_NA);
         c1222_tree = proto_item_add_subtree(c1222_item, ett_c1222);
-        dissect_C1222_MESSAGE_PDU(tvb, pinfo, c1222_tree);
+        dissect_MESSAGE_PDU(tvb, pinfo, c1222_tree);
     }
 }
 
 /**
  * Fetches the length of an entire C12.22 message to assist in reassembly.
  *
- * \param pinfo
- * \param tvb
- * \param offset
+ * \param pinfo the packet info of the current data
+ * \param tvb the tv buffer of the current data
+ * \param offset the offset in the tvb
  * \returns length of entire C12.22 message
  */
 static guint
@@ -1034,9 +1099,9 @@ get_c1222_message_len(packet_info *pinfo, tvbuff_t *tvb, int offset)
 /**
  * Reassembles and dissects C12.22 messages.
  *
- * \param tvb
- * \param pinfo
- * \param tree
+ * \param tvb the tv buffer of the current data
+ * \param pinfo the packet info of the current data
+ * \param tree the tree to append this item to
  */
 static void
 dissect_c1222(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
@@ -1200,6 +1265,12 @@ void proto_register_c1222(void) {
     NULL, 0x0,
     NULL, HFILL }
    },
+   { &hf_c1222_procedure_num,
+    { "C12.22 Procedure Number", "c1222.procedure.num",
+    FT_UINT16, BASE_DEC,
+    NULL, 0x7ff,
+    NULL, HFILL }
+   },
    { &hf_c1222_neg_pkt_size,
     { "C12.22 Negotiate Packet Size", "c1222.negotiate.pktsize",
     FT_UINT16, BASE_DEC,
@@ -1273,6 +1344,23 @@ void proto_register_c1222(void) {
 #include "packet-c1222-ettarr.c"
   };
 
+  static ei_register_info ei[] = {
+     { &ei_c1222_command_truncated, { "c1222.command_truncated", PI_MALFORMED, PI_ERROR, "C12.22 command truncated", EXPFILL }},
+     { &ei_c1222_bad_checksum, { "c1222.bad_checksum", PI_CHECKSUM, PI_ERROR, "Bad checksum", EXPFILL }},
+     { &ei_c1222_epsem_missing, { "c1222.epsem.missing", PI_MALFORMED, PI_ERROR, "C12.22 EPSEM missing", EXPFILL }},
+#ifdef HAVE_LIBGCRYPT
+     { &ei_c1222_epsem_failed_authentication, { "c1222.epsem.failed_authentication", PI_SECURITY, PI_ERROR, "C12.22 EPSEM failed authentication", EXPFILL }},
+#else
+     { &ei_c1222_epsem_not_authenticated, { "c1222.epsem.not_authenticated", PI_SECURITY, PI_WARN, "C12.22 EPSEM could not be authenticated", EXPFILL }},
+#endif
+     { &ei_c1222_epsem_not_decryped, { "c1222.epsem.not_decryped", PI_UNDECODED, PI_WARN, "C12.22 EPSEM could not be decrypted", EXPFILL }},
+     { &ei_c1222_ed_class_missing, { "c1222.ed_class_missing", PI_SECURITY, PI_ERROR, "C12.22 ED Class missing", EXPFILL }},
+     { &ei_c1222_epsem_ber_length_error, { "c1222.epsem.ber_length_error", PI_MALFORMED, PI_ERROR, "C12.22 EPSEM BER length error", EXPFILL }},
+     { &ei_c1222_epsem_field_length_error, { "c1222.epsem.field_length_error", PI_MALFORMED, PI_ERROR, "C12.22 EPSEM field length error", EXPFILL }},
+     { &ei_c1222_mac_missing, { "c1222.mac_missing", PI_MALFORMED, PI_ERROR, "C12.22 MAC missing", EXPFILL }},
+  };
+
+  expert_module_t* expert_c1222;
   module_t *c1222_module;
 
 #ifdef HAVE_LIBGCRYPT
@@ -1288,11 +1376,16 @@ void proto_register_c1222(void) {
   /* Register fields and subtrees */
   proto_register_field_array(proto_c1222, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
+  expert_c1222 = expert_register_protocol(proto_c1222);
+  expert_register_field_array(expert_c1222, ei, array_length(ei));
   c1222_module = prefs_register_protocol(proto_c1222, proto_reg_handoff_c1222);
   prefs_register_bool_preference(c1222_module, "desegment",
 	"Reassemble all C12.22 messages spanning multiple TCP segments",
 	"Whether the C12.22 dissector should reassemble all messages spanning multiple TCP segments",
 	&c1222_desegment);
+  prefs_register_string_preference(c1222_module, "baseoid", "Base OID to use for relative OIDs", 
+	"Base object identifier for use in resolving relative object identifiers",
+	&c1222_baseoid_str);
 #ifdef HAVE_LIBGCRYPT
   prefs_register_bool_preference(c1222_module, "decrypt",
 	"Verify crypto for all applicable C12.22 messages",
@@ -1326,12 +1419,16 @@ void
 proto_reg_handoff_c1222(void)
 {
     static gboolean initialized = FALSE;
+    guint8 *temp = NULL;
 
     if( !initialized ) {
         c1222_handle = create_dissector_handle(dissect_c1222, proto_c1222);
-		c1222_udp_handle = create_dissector_handle(dissect_c1222_common, proto_c1222);
+	c1222_udp_handle = create_dissector_handle(dissect_c1222_common, proto_c1222);
         dissector_add_uint("tcp.port", global_c1222_port, c1222_handle);
         dissector_add_uint("udp.port", global_c1222_port, c1222_udp_handle);
         initialized = TRUE;
     }
+    c1222_baseoid_len = oid_string2encoded(c1222_baseoid_str, &temp);
+    c1222_baseoid = (guint8 *)wmem_realloc(wmem_epan_scope(), c1222_baseoid, c1222_baseoid_len);
+    memcpy(c1222_baseoid, temp, c1222_baseoid_len);
 }
