@@ -5,7 +5,7 @@
  * Updated to RFC4210 CMPv2 and associated "Transport Protocols for CMP" draft
  *   Martin Peylo 2008
  *
- * $Id$
+ * $Id: packet-cmp-template.c 50154 2013-06-25 22:02:20Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -41,7 +41,6 @@
 #include "packet-tcp.h"
 #include "packet-http.h"
 #include <epan/prefs.h>
-#include <epan/nstime.h>
 
 #define PNAME  "Certificate Management Protocol"
 #define PSNAME "CMP"
@@ -71,10 +70,6 @@ static int hf_cmp_tcptrans10_flags = -1;
 /* Initialize the subtree pointers */
 static gint ett_cmp = -1;
 #include "packet-cmp-ett.c"
-
-static const char *object_identifier_id;
-
-
 #include "packet-cmp-fn.c"
 
 static int
