@@ -3,7 +3,7 @@
  *   Ronnie Sahlberg 2004
  *   Stig Bjorlykke 2010
  *
- * $Id$
+ * $Id: packet-cms-template.c 51100 2013-08-01 23:34:47Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,6 +27,10 @@
 #include "config.h"
 
 #include <glib.h>
+
+#include <wsutil/sha1.h>
+#include <wsutil/md5.h>
+
 #include <epan/packet.h>
 #include <epan/oids.h>
 #include <epan/asn1.h>
@@ -41,9 +45,6 @@
 #include "packet-x509sat.h"
 #include "packet-pkcs12.h"
 
-#include <epan/crypt/sha1.h>
-#include <epan/crypt/md5.h>
-
 #define PNAME  "Cryptographic Message Syntax"
 #define PSNAME "CMS"
 #define PFNAME "cms"
