@@ -1,10 +1,9 @@
 /* packet-ess.c
- * Routines for RFC 2634 and RFC 5035 Extended Security Services packet
- * dissection
+ * Routines for RFC5035 Extended Security Services packet dissection
  *   Ronnie Sahlberg 2004
  *   Stig Bjorlykke 2010
  *
- * $Id$
+ * $Id: packet-ess-template.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -70,9 +69,9 @@ static gint ett_Category_attributes = -1;
 
 static const char *object_identifier_id;
 
-UAT_CSTRING_CB_DEF(ess_category_attributes, oid, ess_category_attributes_t);
-UAT_DEC_CB_DEF(ess_category_attributes, lacv, ess_category_attributes_t);
-UAT_CSTRING_CB_DEF(ess_category_attributes, name, ess_category_attributes_t);
+UAT_CSTRING_CB_DEF(ess_category_attributes, oid, ess_category_attributes_t)
+UAT_DEC_CB_DEF(ess_category_attributes, lacv, ess_category_attributes_t)
+UAT_CSTRING_CB_DEF(ess_category_attributes, name, ess_category_attributes_t)
 
 static void *
 ess_copy_cb(void *dest, const void *orig, size_t len _U_)
@@ -100,7 +99,7 @@ static void
 ess_dissect_attribute (guint32 value, asn1_ctx_t *actx)
 {
   guint i;
-   
+
   for (i = 0; i < num_ess_category_attributes; i++) {
     ess_category_attributes_t *u = &(ess_category_attributes[i]);
 
@@ -119,10 +118,10 @@ ess_dissect_attribute_flags (tvbuff_t *tvb, asn1_ctx_t *actx)
   proto_tree *tree;
   guint8 *value;
   guint i;
-   
+
   tree = proto_item_add_subtree (actx->created_item, ett_Category_attributes);
-  value = (guint8 *)ep_tvb_memdup (tvb, 0, tvb_length (tvb));
-  
+  value = tvb_get_string (wmem_packet_scope(), tvb, 0, tvb_length (tvb));
+
   for (i = 0; i < num_ess_category_attributes; i++) {
     ess_category_attributes_t *u = &(ess_category_attributes[i]);
 
@@ -144,10 +143,10 @@ void proto_register_ess(void) {
 
   /* List of fields */
   static hf_register_info hf[] = {
-    { &hf_ess_SecurityCategory_type_OID, 
+    { &hf_ess_SecurityCategory_type_OID,
       { "type", "ess.type_OID", FT_STRING, BASE_NONE, NULL, 0,
 	"Type of Security Category", HFILL }},
-    { &hf_ess_Category_attribute, 
+    { &hf_ess_Category_attribute,
       { "Attribute", "ess.attribute", FT_STRING, BASE_NONE, NULL, 0,
 	NULL, HFILL }},
 #include "packet-ess-hfarr.c"
@@ -158,7 +157,7 @@ void proto_register_ess(void) {
      &ett_Category_attributes,
 #include "packet-ess-ettarr.c"
   };
-  
+
   static uat_field_t attributes_flds[] = {
     UAT_FLD_CSTRING(ess_category_attributes,oid, "Tag Set", "Category Tag Set (Object Identifier)"),
     UAT_FLD_DEC(ess_category_attributes,lacv, "Value", "Label And Cert Value"),
@@ -188,7 +187,7 @@ void proto_register_ess(void) {
   /* Register fields and subtrees */
   proto_register_field_array(proto_ess, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
-  
+
   ess_module = prefs_register_protocol(proto_ess, NULL);
 
   prefs_register_uat_preference(ess_module, "attributes_table",
