@@ -5,7 +5,7 @@
  *
  * Luis Ontanon 2005 - Context and Transaction Tracing
  *
- * $Id$
+ * $Id: packet-h248-template.c 51792 2013-09-05 20:55:59Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -54,7 +54,6 @@ static int hf_h248_pkg_bcp_BNCChar_PDU  = -1;
 
 
 static int hf_h248_context_id = -1;
-static int hf_h248_error_code = -1;
 static int hf_h248_term_wild_type = -1;
 static int hf_h248_term_wild_level = -1;
 static int hf_h248_term_wild_position = -1;
@@ -65,6 +64,8 @@ static int hf_h248_no_evt = -1;
 static int hf_h248_param = -1;
 
 static int hf_h248_serviceChangeReasonStr = -1;
+static int hf_h248_transactionId64 = -1;
+static int hf_h248_context_id64 = -1;
 
 /* h248v1 support */
 static int hf_h248_auditValueReplyV1 = -1;
@@ -88,12 +89,16 @@ static gcp_hf_ett_t h248_arrel = {{-1,-1,-1,-1,-1,-1},{-1,-1,-1,-1}};
 
 #include "packet-h248-ett.c"
 
+static expert_field ei_h248_errored_command = EI_INIT;
+static expert_field ei_h248_transactionId64 = EI_INIT;
+static expert_field ei_h248_context_id64 = EI_INIT;
+
 static dissector_table_t subdissector_table;
 
-static emem_tree_t* msgs = NULL;
-static emem_tree_t* trxs = NULL;
-static emem_tree_t* ctxs_by_trx = NULL;
-static emem_tree_t* ctxs = NULL;
+static wmem_tree_t* msgs = NULL;
+static wmem_tree_t* trxs = NULL;
+static wmem_tree_t* ctxs_by_trx = NULL;
+static wmem_tree_t* ctxs = NULL;
 
 static gboolean keep_persistent_data = FALSE;
 static guint    global_udp_port = 2945;
@@ -118,7 +123,7 @@ static int dissect_h248_AuditReplyV1(gboolean implicit_tag, tvbuff_t *tvb, int o
 static int dissect_h248_EventParameterV1(gboolean implicit_tag, tvbuff_t *tvb, int offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index);
 static int dissect_h248_SigParameterV1(gboolean implicit_tag, tvbuff_t *tvb, int offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index);
 static int dissect_h248_SigParamValueV1(gboolean implicit_tag, tvbuff_t *tvb, int offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index);
-
+static int dissect_h248_ValueV1(gboolean implicit_tag, tvbuff_t *tvb, int offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index);
 #if 0
 static const value_string context_id_type[] = {
     {NULL_CONTEXT,"0 (Null Context)"},
@@ -775,9 +780,9 @@ extern void h248_param_PkgdName(proto_tree* tree, tvbuff_t* tvb, packet_info* pi
             pi = proto_tree_add_uint(package_tree, hf_248_pkg_param, tvb, offset-2, 2, name_minor);
 
             if (pkg->signal_names && ( strval = try_val_to_str(name_minor, pkg->signal_names) )) {
-                strval = ep_strdup_printf("%s (%d)",strval,name_minor);
+                strval = wmem_strdup_printf(wmem_packet_scope(), "%s (%d)",strval,name_minor);
             } else {
-                strval = ep_strdup_printf("Unknown (%d)",name_minor);
+                strval = wmem_strdup_printf(wmem_packet_scope(), "Unknown (%d)",name_minor);
             }
 
             proto_item_set_text(pi,"Signal ID: %s", strval);
@@ -811,8 +816,8 @@ static int dissect_h248_trx_id(gboolean implicit_tag, packet_info *pinfo, proto_
             offset++;
         }
         if (trx_id > 0xffffffff) {
-            proto_item* pi = proto_tree_add_text(tree, tvb, offset-len, len,"transactionId %" G_GINT64_MODIFIER "u", trx_id);
-            proto_item_set_expert_flags(pi, PI_MALFORMED, PI_WARN);
+            proto_item* pi = proto_tree_add_uint64(tree, hf_h248_transactionId64, tvb, offset-len, len, trx_id);
+            expert_add_info(pinfo, pi, &ei_h248_transactionId64);
 
             *trx_id_p = 0;
 
@@ -850,9 +855,8 @@ static int dissect_h248_ctx_id(gboolean implicit_tag, packet_info *pinfo, proto_
         }
 
         if (ctx_id > 0xffffffff) {
-            proto_item* pi = proto_tree_add_text(tree, tvb, offset-len, len,
-                                                 "contextId: %" G_GINT64_MODIFIER "u", ctx_id);
-            proto_item_set_expert_flags(pi, PI_MALFORMED, PI_WARN);
+            proto_item* pi = proto_tree_add_uint64(tree, hf_h248_context_id64, tvb, offset-len, len, ctx_id);
+            expert_add_info(pinfo, pi, &ei_h248_context_id64);
 
             *ctx_id_p = 0xfffffffd;
 
@@ -909,7 +913,7 @@ void h248_register_package(const h248_package_t* pkg, pkg_reg_action reg_action)
          */
         packages = g_tree_new(comparePkgID); /* init tree if no entries */
         while (base_package_name_vals[i].strptr != NULL) {
-            pkg_found = g_new0(h248_package_t, 1); /* create a h248 package structure */
+            pkg_found = wmem_new0(wmem_epan_scope(), h248_package_t); /* create a h248 package structure */
             pkg_found->id = base_package_name_vals[i].value;
             vst = (value_string *)wmem_alloc0(wmem_epan_scope(), sizeof(value_string)*2);
             vst[0].strptr = base_package_name_vals[i].strptr;
@@ -959,7 +963,7 @@ void h248_register_package(const h248_package_t* pkg, pkg_reg_action reg_action)
     pkg_default = is_pkg_default(pkg->id);
     if (((reg_action==REPLACE_PKG) || (reg_action==ADD_PKG)) && pkg_default) {
         /* add/replace in tree */
-        s_pkg = g_new0(s_h248_package_t,1);
+        s_pkg = wmem_new0(wmem_epan_scope(), s_h248_package_t);
         s_pkg->is_default = FALSE;
         s_pkg->pkg = (h248_package_t *)pkg;
         g_tree_replace(packages, GINT_TO_POINTER(pkg->id), (gpointer)s_pkg);
@@ -968,7 +972,7 @@ void h248_register_package(const h248_package_t* pkg, pkg_reg_action reg_action)
     if(pkg_default) reg_action = MERGE_PKG_HIGH; /* always make new package overide default */
     s_pkg = s_find_package_id(pkg->id);
     if (s_pkg == NULL) { /* no need to merge - package not in tree */
-        s_pkg = g_new0(s_h248_package_t,1);
+        s_pkg = wmem_new0(wmem_epan_scope(), s_h248_package_t);
         s_pkg->is_default = FALSE;
         s_pkg->pkg = (h248_package_t *)pkg;
         g_tree_insert(packages, GINT_TO_POINTER(pkg->id), (gpointer)s_pkg);
@@ -1032,9 +1036,9 @@ static int dissect_h248_PkgdName(gboolean implicit_tag, tvbuff_t *tvb, int offse
             const gchar* strval;
 
             if (pkg->param_names && ( strval = try_val_to_str(name_minor, pkg->param_names) )) {
-                strval = ep_strdup_printf("%s (%d)",strval,name_minor);
+                strval = wmem_strdup_printf(wmem_packet_scope(), "%s (%d)",strval,name_minor);
             } else {
-                strval = ep_strdup_printf("Unknown (%d)",name_minor);
+                strval = wmem_strdup_printf(wmem_packet_scope(), "Unknown (%d)",name_minor);
             }
 
             proto_item_set_text(pi,"Parameter: %s", strval);
@@ -1095,9 +1099,9 @@ static int dissect_h248_EventName(gboolean implicit_tag, tvbuff_t *tvb, int offs
             const gchar* strval;
 
             if (pkg->event_names && ( strval = try_val_to_str(name_minor, pkg->event_names) )) {
-                strval = ep_strdup_printf("%s (%d)",strval,name_minor);
+                strval = wmem_strdup_printf(wmem_packet_scope(), "%s (%d)",strval,name_minor);
             } else {
-                strval = ep_strdup_printf("Unknown (%d)",name_minor);
+                strval = wmem_strdup_printf(wmem_packet_scope(), "Unknown (%d)",name_minor);
             }
 
             proto_item_set_text(pi,"Event ID: %s", strval);
@@ -1160,9 +1164,9 @@ static int dissect_h248_SignalName(gboolean implicit_tag , tvbuff_t *tvb, int of
             const gchar* strval;
 
             if (pkg->signal_names && ( strval = try_val_to_str(name_minor, pkg->signal_names) )) {
-                strval = ep_strdup_printf("%s (%d)",strval,name_minor);
+                strval = wmem_strdup_printf(wmem_packet_scope(), "%s (%d)",strval,name_minor);
             } else {
-                strval = ep_strdup_printf("Unknown (%d)",name_minor);
+                strval = wmem_strdup_printf(wmem_packet_scope(), "Unknown (%d)",name_minor);
             }
 
             proto_item_set_text(pi,"Signal ID: %s", strval);
@@ -1253,9 +1257,9 @@ static int dissect_h248_SigParameterName(gboolean implicit_tag _U_, tvbuff_t *tv
     }
 
     if (curr_info.sig && curr_info.sig->param_names && ( strval = try_val_to_str(param_id, curr_info.sig->param_names) )) {
-        strval = ep_strdup_printf("%s (%d)",strval,param_id);
+        strval = wmem_strdup_printf(wmem_packet_scope(), "%s (%d)",strval,param_id);
     } else {
-        strval = ep_strdup_printf("Unknown (%d)",param_id);
+        strval = wmem_strdup_printf(wmem_packet_scope(), "Unknown (%d)",param_id);
     }
 
     proto_item_set_text(pi,"Parameter: %s", strval);
@@ -1330,9 +1334,9 @@ static int dissect_h248_EventParameterName(gboolean implicit_tag _U_, tvbuff_t *
     }
 
     if (curr_info.evt && curr_info.evt->param_names && ( strval = try_val_to_str(param_id, curr_info.evt->param_names) )) {
-        strval = ep_strdup_printf("%s (%d)",strval,param_id);
+        strval = wmem_strdup_printf(wmem_packet_scope(), "%s (%d)",strval,param_id);
     } else {
-        strval = ep_strdup_printf("Unknown (%d)",param_id);
+        strval = wmem_strdup_printf(wmem_packet_scope(), "Unknown (%d)",param_id);
     }
 
     proto_item_set_text(pi,"Parameter: %s", strval);
@@ -1517,11 +1521,6 @@ void proto_register_h248(void) {
           { "BNCChar", "h248.package_bcp.BNCChar",
             FT_UINT32, BASE_DEC, VALS(gcp_term_types), 0,
             NULL, HFILL }},
-
-        { &hf_h248_error_code,
-          { "errorCode", "h248.errorCode",
-            FT_UINT32, BASE_DEC|BASE_EXT_STRING, &h248_reasons_ext, 0,
-            "ErrorDescriptor/errorCode", HFILL }},
         { &hf_h248_context_id,
           { "contextId", "h248.contextId",
             FT_UINT32, BASE_HEX, NULL, 0,
@@ -1559,6 +1558,14 @@ void proto_register_h248(void) {
           { "ServiceChangeReasonStr", "h248.serviceChangeReasonstr",
             FT_STRING, BASE_NONE, NULL, 0,
             "h248.IA5String", HFILL }},
+        { &hf_h248_context_id64,
+          { "contextId", "h248.contextId",
+            FT_UINT64, BASE_HEX, NULL, 0,
+            "Context ID", HFILL }},
+        { &hf_h248_transactionId64,
+          { "transactionId", "h248.transactionId",
+            FT_UINT64, BASE_DEC, NULL, 0,
+            NULL, HFILL }},
 
 /* h248v1 support */
         { &hf_h248_auditValueReplyV1,
@@ -1587,8 +1594,14 @@ void proto_register_h248(void) {
 #include "packet-h248-ettarr.c"
     };
 
-    module_t *h248_module;
+    static ei_register_info ei[] = {
+        { &ei_h248_errored_command, { "h248.errored_command", PI_RESPONSE_CODE, PI_WARN, "Errored Command", EXPFILL }},
+        { &ei_h248_transactionId64, { "h248.transactionId.error", PI_MALFORMED, PI_WARN, "Transaction ID invalid", EXPFILL }},
+        { &ei_h248_context_id64, { "h248.contextId.error", PI_MALFORMED, PI_WARN, "Context ID invalid", EXPFILL }},
+    };
 
+    expert_module_t* expert_h248;
+    module_t *h248_module;
 
     /* Register protocol */
     proto_h248 = proto_register_protocol(PNAME, PSNAME, PFNAME);
@@ -1598,6 +1611,8 @@ void proto_register_h248(void) {
     /* Register fields and subtrees */
     proto_register_field_array(proto_h248, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_h248 = expert_register_protocol(proto_h248);
+    expert_register_field_array(expert_h248, ei, array_length(ei));
     
     subdissector_table = register_dissector_table("h248.magic_num", "H248 Magic Num", FT_UINT32, BASE_HEX);
 
@@ -1621,10 +1636,10 @@ void proto_register_h248(void) {
                                    "Desegment H.248 messages that span more TCP segments",
                                    &h248_desegment);
 
-    msgs = se_tree_create(EMEM_TREE_TYPE_RED_BLACK, "h248_msgs");
-    trxs = se_tree_create(EMEM_TREE_TYPE_RED_BLACK, "h248_trxs");
-    ctxs_by_trx = se_tree_create(EMEM_TREE_TYPE_RED_BLACK, "h248_ctxs_by_trx");
-    ctxs = se_tree_create(EMEM_TREE_TYPE_RED_BLACK, "h248_ctxs");
+    msgs        = wmem_tree_new_autoreset(wmem_epan_scope(), wmem_file_scope());
+    trxs        = wmem_tree_new_autoreset(wmem_epan_scope(), wmem_file_scope());
+    ctxs_by_trx = wmem_tree_new_autoreset(wmem_epan_scope(), wmem_file_scope());
+    ctxs        = wmem_tree_new_autoreset(wmem_epan_scope(), wmem_file_scope());
 
     h248_tap = register_tap("h248");
 
