@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2011 by Spenser Sheng <spenser.sheng@ericsson.com>
  *
- * $Id$
+ * $Id: packet-lcsap-template.c 51373 2013-08-15 03:55:09Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -148,7 +148,8 @@ static const value_string lcsap_pos_usage_vals[] = {
  	{ 0x01, "Attempted successfully: results not used to generate location - not used." },
  	{ 0x02, "Attempted successfully: results used to verify but not generate location - not used." },
  	{ 0x03, "Attempted successfully: results used to generate location" },
- 	{ 0x04, "Attempted successfully: case where UE supports multiple mobile based positioning methods and the actual method or methods used by the UE cannot be determined." },
+ 	{ 0x04, "Attempted successfully: case where UE supports multiple mobile based positioning methods \n"
+	        "and the actual method or methods used by the UE cannot be determined." },
  	{ 0x05, "Reserved" },
  	{ 0x06, "Reserved" },
  	{ 0x07, "Reserved" },
@@ -183,7 +184,8 @@ static const value_string lcsap_gnss_pos_usage_vals[] = {
  	{ 0x01, "Attempted successfully: results not used to generate location" },
  	{ 0x02, "Attempted successfully: results used to verify but not generate location" },
  	{ 0x03, "Attempted successfully: results used to generate location" },
- 	{ 0x04, "Attempted successfully: case where UE supports multiple mobile based positioning methods and the actual method or methods used by the UE cannot be determined." },
+ 	{ 0x04, "Attempted successfully: case where UE supports multiple mobile based positioning methods \n"
+	        "and the actual method or methods used by the UE cannot be determined." },
  	{ 0x05, "Reserved" },
  	{ 0x06, "Reserved" },
  	{ 0x07, "Reserved" },
@@ -227,8 +229,7 @@ dissect_lcsap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_tree	*lcsap_tree = NULL;
 
 	/* make entry in the Protocol column on summary display */
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "LCSAP");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "LCSAP");
 
 	/* create the lcsap protocol tree */
 	lcsap_item = proto_tree_add_item(tree, proto_lcsap, tvb, 0, -1, ENC_NA);
