@@ -2,7 +2,7 @@
  * Routines for X.411 (X.400 Message Transfer)  packet dissection
  * Graeme Lunt 2005
  *
- * $Id$
+ * $Id: packet-p1-template.c 52058 2013-09-15 14:33:38Z jmayer $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,6 +31,7 @@
 #include <epan/oids.h>
 #include <epan/asn1.h>
 #include <epan/expert.h>
+#include <epan/wmem/wmem.h>
 
 #include "packet-ber.h"
 #include "packet-acse.h"
@@ -57,21 +58,6 @@ static void prefs_register_p1(void); /* forward declaration for use in preferenc
 static int proto_p1 = -1;
 static int proto_p3 = -1;
 
-static struct SESSION_DATA_STRUCTURE* session = NULL;
-static int extension_id = -1; /* integer extension id */
-static const char *object_identifier_id = NULL; /* extensions identifier */
-static const char *content_type_id = NULL; /* content type identifier */
-static gboolean report_unknown_content_type = FALSE;
-
-#define MAX_ORA_STR_LEN     256
-static char *oraddress = NULL;
-static char *ddatype = NULL;
-static gboolean doing_address=FALSE;
-static gboolean doing_subjectid=FALSE;
-static proto_item *address_item = NULL;
-
-static proto_tree *top_tree=NULL;
-
 static int hf_p1_MTS_APDU_PDU = -1;
 static int hf_p1_MTABindArgument_PDU = -1;
 static int hf_p1_MTABindResult_PDU = -1;
@@ -90,6 +76,11 @@ static gint ett_p1_unknown_extension_attribute_type = -1;
 static gint ett_p1_unknown_tokendata_type = -1;
 #include "packet-p1-ett.c"
 
+static expert_field ei_p1_unknown_extension_attribute_type = EI_INIT;
+static expert_field ei_p1_unknown_standard_extension = EI_INIT;
+static expert_field ei_p1_unknown_built_in_content_type = EI_INIT;
+static expert_field ei_p1_unknown_tokendata_type = EI_INIT;
+
 /* Dissector tables */
 static dissector_table_t p1_extension_dissector_table;
 static dissector_table_t p1_extension_attribute_dissector_table;
@@ -97,6 +88,65 @@ static dissector_table_t p1_tokendata_dissector_table;
 
 #include "packet-p1-table.c"   /* operation and error codes */
 
+typedef struct p1_address_ctx {
+	gboolean do_address;
+	const char *content_type_id;
+	gboolean report_unknown_content_type;
+	wmem_strbuf_t* oraddress;
+} p1_address_ctx_t;
+
+static void set_do_address(asn1_ctx_t* actx, gboolean do_address)
+{
+	p1_address_ctx_t* ctx;
+
+	if (actx->subtree.tree_ctx == NULL) {
+		actx->subtree.tree_ctx = wmem_new0(wmem_packet_scope(), p1_address_ctx_t);
+	}
+
+	ctx = (p1_address_ctx_t*)actx->subtree.tree_ctx;
+	ctx->do_address = do_address;
+}
+
+static void do_address(const char* addr, tvbuff_t* tvb_string, asn1_ctx_t* actx)
+{
+	p1_address_ctx_t* ctx = (p1_address_ctx_t*)actx->subtree.tree_ctx;
+
+	if (ctx && ctx->do_address) {
+		if (addr) {
+			wmem_strbuf_append(ctx->oraddress, addr);
+		}
+		if (tvb_string) {
+			wmem_strbuf_append(ctx->oraddress, tvb_format_text(tvb_string, 0, tvb_length(tvb_string)));
+		}
+	}
+
+}
+
+static void do_address_str(const char* addr, tvbuff_t* tvb_string, asn1_ctx_t* actx)
+{
+	wmem_strbuf_t *ddatype = (wmem_strbuf_t *)actx->value_ptr;
+	p1_address_ctx_t* ctx = (p1_address_ctx_t*)actx->subtree.tree_ctx;
+
+	do_address(addr, tvb_string, actx);
+
+	if (ctx && ctx->do_address && ddatype && tvb_string)
+		wmem_strbuf_append(ddatype, tvb_format_text(tvb_string, 0, tvb_length(tvb_string)));
+}
+
+static void do_address_str_tree(const char* addr, tvbuff_t* tvb_string, asn1_ctx_t* actx, proto_tree* tree)
+{
+	wmem_strbuf_t *ddatype = (wmem_strbuf_t *)actx->value_ptr;
+	p1_address_ctx_t* ctx = (p1_address_ctx_t*)actx->subtree.tree_ctx;
+
+	do_address(addr, tvb_string, actx);
+
+	if (ctx && ctx->do_address && tvb_string && ddatype) {
+		if (wmem_strbuf_get_len(ddatype) > 0) {
+			proto_item_append_text (tree, " (%s=%s)", wmem_strbuf_get_str(ddatype), tvb_format_text(tvb_string, 0, tvb_length(tvb_string)));
+		}
+	}
+}
+
 #include "packet-p1-fn.c"
 
 #include "packet-p1-table11.c" /* operation argument/result dissectors */
@@ -112,17 +162,34 @@ static const ros_info_t p3_ros_info = {
   p3_err_tab
 };
 
-void p1_initialize_content_globals (proto_tree *tree, gboolean report_unknown_cont_type)
+void p1_initialize_content_globals (asn1_ctx_t* actx, proto_tree *tree, gboolean report_unknown_cont_type)
 {
-	top_tree = tree;
-	content_type_id = NULL;
-	report_unknown_content_type = report_unknown_cont_type;
-	address_item = NULL;
+	p1_address_ctx_t* ctx;
+
+	if (actx->subtree.tree_ctx == NULL) {
+		actx->subtree.tree_ctx = wmem_new0(wmem_packet_scope(), p1_address_ctx_t);
+	}
+
+	ctx = (p1_address_ctx_t*)actx->subtree.tree_ctx;
+
+	actx->subtree.top_tree = tree;
+	actx->external.direct_reference = NULL;
+	ctx->content_type_id = NULL;
+	ctx->report_unknown_content_type = report_unknown_cont_type;
 }
 
-char* p1_get_last_oraddress (void) 
-{ 
-	return oraddress;
+const char* p1_get_last_oraddress (asn1_ctx_t* actx)
+{
+	p1_address_ctx_t* ctx;
+
+	if ((actx == NULL) || (actx->subtree.tree_ctx == NULL))
+		return "";
+
+	ctx = (p1_address_ctx_t*)actx->subtree.tree_ctx;
+	if (wmem_strbuf_get_len(ctx->oraddress) <= 0)
+		return "";
+
+	return wmem_strbuf_get_str(ctx->oraddress);
 }
 
 /*
@@ -137,7 +204,7 @@ dissect_p1_mts_apdu (tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
 
 	/* save parent_tree so subdissectors can create new top nodes */
-	p1_initialize_content_globals (parent_tree, TRUE);
+	p1_initialize_content_globals (&asn1_ctx, parent_tree, TRUE);
 
 	if(parent_tree){
 		item = proto_tree_add_item(parent_tree, proto_p1, tvb, 0, -1, ENC_NA);
@@ -148,7 +215,7 @@ dissect_p1_mts_apdu (tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
   	col_set_str(pinfo->cinfo, COL_INFO, "Transfer");
 
 	dissect_p1_MTS_APDU (FALSE, tvb, 0, &asn1_ctx, tree, hf_p1_MTS_APDU_PDU);
-	p1_initialize_content_globals (NULL, FALSE);
+	p1_initialize_content_globals (&asn1_ctx, NULL, FALSE);
 }
 
 /*
@@ -161,6 +228,7 @@ dissect_p1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	int old_offset;
 	proto_item *item=NULL;
 	proto_tree *tree=NULL;
+	struct SESSION_DATA_STRUCTURE* session;
 	int (*p1_dissector)(gboolean implicit_tag _U_, tvbuff_t *tvb, int offset, asn1_ctx_t *actx _U_, proto_tree *tree, int hf_index _U_) = NULL;
 	const char *p1_op_name;
 	int hf_p1_index = -1;
@@ -168,7 +236,7 @@ dissect_p1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
 
 	/* save parent_tree so subdissectors can create new top nodes */
-	p1_initialize_content_globals (parent_tree, TRUE);
+	p1_initialize_content_globals (&asn1_ctx, parent_tree, TRUE);
 
 	/* do we have operation information from the ROS dissector?  */
 	if( !pinfo->private_data ){
@@ -176,17 +244,17 @@ dissect_p1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 			proto_tree_add_text(parent_tree, tvb, offset, -1,
 				"Internal error: can't get operation information from ROS dissector.");
 		}
-		return  ;
-	} else {
-		session  = ( (struct SESSION_DATA_STRUCTURE*)(pinfo->private_data) );
+		return;
 	}
 
+	session  = ( (struct SESSION_DATA_STRUCTURE*)(pinfo->private_data) );
+
 	if(parent_tree){
 		item = proto_tree_add_item(parent_tree, proto_p1, tvb, 0, -1, ENC_NA);
 		tree = proto_item_add_subtree(item, ett_p1);
 	}
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "P1");
-  	col_clear(pinfo->cinfo, COL_INFO);
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	switch(session->ros_op & ROS_OP_MASK) {
 	case (ROS_OP_BIND | ROS_OP_ARGUMENT):	/*  BindInvoke */
@@ -214,8 +282,7 @@ dissect_p1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	  return;
 	}
 
-	if (check_col(pinfo->cinfo, COL_INFO))
-	  col_set_str(pinfo->cinfo, COL_INFO, p1_op_name);
+	col_set_str(pinfo->cinfo, COL_INFO, p1_op_name);
 
 	while (tvb_reported_length_remaining(tvb, offset) > 0){
 		old_offset=offset;
@@ -225,7 +292,7 @@ dissect_p1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 			break;
 		}
 	}
-	p1_initialize_content_globals (NULL, FALSE);
+	p1_initialize_content_globals (&asn1_ctx, NULL, FALSE);
 }
 
 
@@ -235,7 +302,7 @@ void proto_register_p1(void) {
   /* List of fields */
   static hf_register_info hf[] =
   {
-	  /* "Created by defining PDU in .cnf */
+      /* "Created by defining PDU in .cnf */
     { &hf_p1_MTABindArgument_PDU,
       { "MTABindArgument", "p1.MTABindArgument",
         FT_UINT32, BASE_DEC, VALS(p1_MTABindArgument_vals), 0,
@@ -269,6 +336,14 @@ void proto_register_p1(void) {
 #include "packet-p1-ettarr.c"
   };
 
+  static ei_register_info ei[] = {
+     { &ei_p1_unknown_extension_attribute_type, { "p1.unknown.extension_attribute_type", PI_UNDECODED, PI_WARN, "Unknown extension-attribute-type", EXPFILL }},
+     { &ei_p1_unknown_standard_extension, { "p1.unknown.standard_extension", PI_UNDECODED, PI_WARN, "Unknown standard-extension", EXPFILL }},
+     { &ei_p1_unknown_built_in_content_type, { "p1.unknown.built_in_content_type", PI_UNDECODED, PI_WARN, "P1 Unknown Content (unknown built-in content-type)", EXPFILL }},
+     { &ei_p1_unknown_tokendata_type, { "p1.unknown.tokendata_type", PI_UNDECODED, PI_WARN, "Unknown tokendata-type", EXPFILL }},
+  };
+
+  expert_module_t* expert_p1;
   module_t *p1_module;
 
   /* Register protocol */
@@ -280,6 +355,8 @@ void proto_register_p1(void) {
   /* Register fields and subtrees */
   proto_register_field_array(proto_p1, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
+  expert_p1 = expert_register_protocol(proto_p1);
+  expert_register_field_array(expert_p1, ei, array_length(ei));
 
   p1_extension_dissector_table = register_dissector_table("p1.extension", "P1-EXTENSION", FT_UINT32, BASE_DEC);
   p1_extension_attribute_dissector_table = register_dissector_table("p1.extension-attribute", "P1-EXTENSION-ATTRIBUTE", FT_UINT32, BASE_DEC);
