@@ -2,7 +2,7 @@
  * Routines for X.411 (X.400 Message Transfer) packet dissection
  * Graeme Lunt 2005
  *
- * $Id$
+ * $Id: packet-p1-template.h 50286 2013-07-01 06:13:21Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,8 +28,8 @@
 
 #include "packet-p1-val.h"
 
-void p1_initialize_content_globals (proto_tree *tree, gboolean report_unknown_cont_type);
-char* p1_get_last_oraddress(void);
+void p1_initialize_content_globals (asn1_ctx_t* actx, proto_tree *tree, gboolean report_unknown_cont_type);
+const char* p1_get_last_oraddress(asn1_ctx_t* actx);
 void dissect_p1_mts_apdu (tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree);
 #include "packet-p1-exp.h"
 
