@@ -2,7 +2,7 @@
  * Routines for PKCS#1/RFC2313 packet dissection
  *  Ronnie Sahlberg 2004
  *
- * $Id$
+ * $Id: packet-pkcs1-template.c 50066 2013-06-19 23:08:58Z eapache $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,6 +29,7 @@
 #include <epan/packet.h>
 #include <epan/oids.h>
 #include <epan/asn1.h>
+#include <epan/wmem/wmem.h>
 
 #include "packet-ber.h"
 #include "packet-pkcs1.h"
@@ -102,8 +103,8 @@ void proto_reg_handoff_pkcs1(void) {
 	oid_add_from_string("secp384r1","1.3.132.0.34");
 	oid_add_from_string("sect409k1","1.3.132.0.36");
 	oid_add_from_string("sect409r1","1.3.132.0.37");
-	oid_add_from_string("secp521r1","1.3.132.0.35");
-	oid_add_from_string("sect571k1","1.3.132.0.38");
+	oid_add_from_string("sect521r1","1.3.132.0.35")
+;	oid_add_from_string("sect571k1","1.3.132.0.38");
 	oid_add_from_string("sect571r1","1.3.132.0.39");
 
 	/* sha2 family, see RFC3447 and http://www.oid-info.com/get/2.16.840.1.101.3.4.2 */
