@@ -2,7 +2,7 @@
  * Routines for Q.932 packet dissection
  * 2007  Tomas Kukosa
  *
- * $Id$
+ * $Id: packet-q932-ros-template.c 50066 2013-06-19 23:08:58Z eapache $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,6 +29,7 @@
 #include <epan/strutil.h>
 #include <epan/asn1.h>
 #include <epan/expert.h>
+#include <epan/wmem/wmem.h>
 
 #include "packet-ber.h"
 
@@ -43,6 +44,8 @@ static int proto_q932_ros = -1;
 /* Initialize the subtree pointers */
 #include "packet-q932-ros-ett.c" 
 
+static expert_field ei_ros_undecoded = EI_INIT;
+
 /* Preferences */
 
 /* Subdissectors */
@@ -78,6 +81,12 @@ void proto_register_q932_ros(void) {
 #include "packet-q932-ros-ettarr.c" 
   };
 
+  static ei_register_info ei[] = {
+     { &ei_ros_undecoded, { "q932.ros.undecoded", PI_UNDECODED, PI_WARN, "Undecoded", EXPFILL }},
+  };
+
+  expert_module_t* expert_q932_ros;
+
   /* Register protocol and dissector */
   proto_q932_ros = proto_register_protocol(PNAME, PSNAME, PFNAME);
   proto_set_cant_toggle(proto_q932_ros);
@@ -85,6 +94,8 @@ void proto_register_q932_ros(void) {
   /* Register fields and subtrees */
   proto_register_field_array(proto_q932_ros, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
+  expert_q932_ros = expert_register_protocol(proto_q932_ros);
+  expert_register_field_array(expert_q932_ros, ei, array_length(ei));
 
   new_register_dissector(PFNAME, dissect_q932_ros, proto_q932_ros);
 }
