@@ -2,7 +2,7 @@
  * Routines for UMTS Node B Application Part(RANAP) packet dissection
  * Copyright 2005 - 2010, Anders Broman <anders.broman[AT]ericsson.com>
  *
- * $Id$
+ * $Id: packet-ranap-template.c 50130 2013-06-24 21:31:25Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,7 +30,7 @@
 #include <glib.h>
 #include <epan/packet.h>
 
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/strutil.h>
 #include <epan/asn1.h>
 #include <epan/prefs.h>
@@ -247,7 +247,7 @@ dissect_ranap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		if (! sccp_msg_lcl->data.co.label && ProcedureCode != 0xFFFFFFFF) {
 			const gchar* str = val_to_str(ProcedureCode, ranap_ProcedureCode_vals,"Unknown RANAP");
-			sccp_msg_lcl->data.co.label = se_strdup(str);
+			sccp_msg_lcl->data.co.label = wmem_strdup(wmem_file_scope(), str);
 		}
 	}
 }
@@ -352,6 +352,10 @@ void proto_register_ranap(void) {
   prefs_register_uint_preference(ranap_module, "sccp_ssn", "SCCP SSN for RANAP",
 				 "The SCCP SubSystem Number for RANAP (default 142)", 10,
 				 &global_ranap_sccp_ssn);
+  prefs_register_bool_preference(ranap_module, "dissect_rrc_container",
+                                 "Attempt to dissect RRC-Container",
+                                 "Attempt to dissect RRC message embedded in RRC-Container IE",
+                                 &glbl_dissect_container);
 }
 
 
