@@ -4,7 +4,7 @@
  * (3GPP TS 25.331  packet dissection
  * Copyright 2006-2010, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id$
+ * $Id: packet-rrc-template.c 52202 2013-09-24 17:56:17Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -24,7 +24,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * Ref: 3GPP TS 25.331 V11.5.0 (2013-03)
+ * Ref: 3GPP TS 25.331 V11.7.0 (2013-09)
  */
 
 /**
@@ -38,6 +38,7 @@
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/asn1.h>
+#include <epan/wmem/wmem.h>
 #include <epan/conversation.h>
 #include <epan/expert.h>
 
@@ -82,8 +83,6 @@ enum nas_sys_info_gsm_map {
   RRC_NAS_SYS_INFO_CN_COMMON
 };
 
-static guint32 rrc_nas_sys_info_gsm_map_type = RRC_NAS_SYS_INFO_CN_COMMON;
-
 /* Forward declarations */
 void proto_register_rrc(void);
 void proto_reg_handoff_rrc(void);
@@ -111,6 +110,8 @@ static int ett_rrc = -1;
 static gint ett_rrc_eutraFeatureGroupIndicators = -1;
 static gint ett_rrc_cn_CommonGSM_MAP_NAS_SysInfo = -1;
 
+static expert_field ei_rrc_no_hrnti = EI_INIT;
+
 /* Global variables */
 static proto_tree *top_tree;
 
@@ -292,12 +293,19 @@ void proto_register_rrc(void) {
     &ett_rrc_cn_CommonGSM_MAP_NAS_SysInfo,
   };
 
+  static ei_register_info ei[] = {
+     { &ei_rrc_no_hrnti, { "rrc.no_hrnti", PI_SEQUENCE, PI_NOTE, "Did not detect any H-RNTI", EXPFILL }},
+  };
+
+  expert_module_t* expert_rrc;
 
   /* Register protocol */
   proto_rrc = proto_register_protocol(PNAME, PSNAME, PFNAME);
   /* Register fields and subtrees */
   proto_register_field_array(proto_rrc, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
+  expert_rrc = expert_register_protocol(proto_rrc);
+  expert_register_field_array(expert_rrc, ei, array_length(ei));
 
   register_dissector("rrc", dissect_rrc, proto_rrc);
 
