@@ -2,7 +2,7 @@
  * Routines for IEC 61850 Sampled Vales packet dissection
  * Michael Bernhard 2008
  *
- * $Id$
+ * $Id: packet-sv-template.c 50154 2013-06-25 22:02:20Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,7 +30,6 @@
 #include <epan/asn1.h>
 #include <epan/etypes.h>
 #include <epan/expert.h>
-#include <epan/nstime.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -110,6 +109,8 @@ static int ett_phsmeas_q = -1;
 
 #include "packet-sv-ett.c"
 
+static expert_field ei_sv_mal_utctime = EI_INIT;
+
 #if 0
 static const value_string sv_q_validity_vals[] = {
   {   0, "good" },
@@ -317,6 +318,12 @@ void proto_register_sv(void) {
 #include "packet-sv-ettarr.c"
 	};
 
+	static ei_register_info ei[] = {
+		{ &ei_sv_mal_utctime, { "sv.malformed.utctime", PI_MALFORMED, PI_WARN, "BER Error: malformed UTCTime encoding", EXPFILL }},
+	};
+
+	expert_module_t* expert_sv;
+
 	/* Register protocol */
 	proto_sv = proto_register_protocol(PNAME, PSNAME, PFNAME);
 	register_dissector("sv", dissect_sv, proto_sv);
@@ -324,6 +331,8 @@ void proto_register_sv(void) {
 	/* Register fields and subtrees */
 	proto_register_field_array(proto_sv, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	expert_sv = expert_register_protocol(proto_sv);
+	expert_register_field_array(expert_sv, ei, array_length(ei));
 
 	/* Register tap */
 	sv_tap = register_tap("sv");
