@@ -4,7 +4,7 @@
  * 2004  Alejandro Vaquero, add support Conversations for SDP
  * 2006  Alejandro Vaquero, add T30 reassemble and dissection
  *
- * $Id$
+ * $Id: packet-t38-template.c 50708 2013-07-17 21:12:24Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -61,7 +61,7 @@
 #include <epan/asn1.h>
 #include "packet-per.h"
 #include "packet-tpkt.h"
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/strutil.h>
 
 void proto_register_t38(void);
@@ -263,7 +263,7 @@ void t38_add_address(packet_info *pinfo,
          */
         if ( ! p_conversation_data ) {
                 /* Create conversation data */
-                p_conversation_data = se_new(t38_conv);
+                p_conversation_data = wmem_new(wmem_file_scope(), t38_conv);
 
                 conversation_add_proto_data(p_conversation, proto_t38, p_conversation_data);
         }
@@ -292,13 +292,14 @@ void t38_add_address(packet_info *pinfo,
 }
 
 
-fragment_data *
+fragment_head *
 force_reassemble_seq(reassembly_table *table, packet_info *pinfo, guint32 id)
 {
-	fragment_data *fd_head;
-	fragment_data *fd_i;
-	fragment_data *last_fd;
+	fragment_head *fd_head;
+	fragment_item *fd_i;
+	fragment_item *last_fd;
 	guint32 dfpos, size, packet_lost, burst_lost, seq_num;
+	guint8 *data;
 
 	fd_head = fragment_get(table, pinfo, id, NULL);
 
@@ -341,7 +342,9 @@ force_reassemble_seq(reassembly_table *table, packet_info *pinfo, guint32 id)
 	  }
 	  last_fd=fd_i;
 	}
-	fd_head->data = (char *)g_malloc(size);
+
+	data = (guint8 *) g_malloc(size);
+	fd_head->tvb_data = tvb_new_real_data(data, size, size);
 	fd_head->len = size;		/* record size for caller	*/
 
 	/* add all data fragments */
@@ -350,14 +353,14 @@ force_reassemble_seq(reassembly_table *table, packet_info *pinfo, guint32 id)
 	for (fd_i=fd_head->next;fd_i && fd_i->len + dfpos <= size;fd_i=fd_i->next) {
 	  if (fd_i->len) {
 	    if(!last_fd || last_fd->offset!=fd_i->offset){
-	      memcpy(fd_head->data+dfpos,fd_i->data,fd_i->len);
+	      memcpy(data+dfpos,tvb_get_ptr(fd_i->tvb_data,0,fd_i->len),fd_i->len);
 	      dfpos += fd_i->len;
 	    } else {
 	      /* duplicate/retransmission/overlap */
 	      fd_i->flags    |= FD_OVERLAP;
 	      fd_head->flags |= FD_OVERLAP;
 	      if( (last_fd->len!=fd_i->datalen)
-		  || memcmp(last_fd->data, fd_i->data, last_fd->len) ){
+		  || tvb_memeql(last_fd->tvb_data, 0, tvb_get_ptr(fd_i->tvb_data, 0, last_fd->len), last_fd->len) ){
 			fd_i->flags    |= FD_OVERLAPCONFLICT;
 			fd_head->flags |= FD_OVERLAPCONFLICT;
 	      }
@@ -368,9 +371,9 @@ force_reassemble_seq(reassembly_table *table, packet_info *pinfo, guint32 id)
 
 	/* we have defragmented the pdu, now free all fragments*/
 	for (fd_i=fd_head->next;fd_i;fd_i=fd_i->next) {
-	  if(fd_i->data){
-	    g_free(fd_i->data);
-	    fd_i->data=NULL;
+	  if(fd_i->tvb_data){
+	    tvb_free(fd_i->tvb_data);
+	    fd_i->tvb_data=NULL;
 	  }
 	}
 
@@ -444,7 +447,7 @@ init_t38_info_conv(packet_info *pinfo)
 
 		/* create the conversation if it doen't exist */
 		if (!p_t38_conv) {
-			p_t38_conv = se_new(t38_conv);
+			p_t38_conv = wmem_new(wmem_file_scope(), t38_conv);
 			p_t38_conv->setup_method[0] = '\0';
 			p_t38_conv->setup_frame_number = 0;
 
@@ -472,7 +475,7 @@ init_t38_info_conv(packet_info *pinfo)
 		}
 
 		/* copy the t38 conversation info to the packet t38 conversation */
-		p_t38_packet_conv = se_new(t38_conv);
+		p_t38_packet_conv = wmem_new(wmem_file_scope(), t38_conv);
 		g_strlcpy(p_t38_packet_conv->setup_method, p_t38_conv->setup_method, MAX_T38_SETUP_METHOD_SIZE);
 		p_t38_packet_conv->setup_frame_number = p_t38_conv->setup_frame_number;
 
