@@ -3,7 +3,7 @@
  *
  * Copyright 2004 Ian Schorr
  *
- * $Id$
+ * $Id: capinfos.c 51011 2013-07-29 15:43:37Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -85,14 +85,13 @@
  */
 #define WS_BUILD_DLL
 #define RESET_SYMBOL_EXPORT
-#include <epan/packet.h>
 #include <epan/filesystem.h>
 #include <epan/plugins.h>
-#include <epan/report_err.h>
 #undef WS_BUILD_DLL
 #define RESET_SYMBOL_EXPORT
 
 #include "wtap.h"
+#include <wsutil/report_err.h>
 #include <wsutil/privileges.h>
 #include <wsutil/str_util.h>
 
@@ -109,7 +108,7 @@
 #include <wsutil/unicode-utils.h>
 #endif /* _WIN32 */
 
-#include "version.h"
+#include "svnversion.h"
 
 /*
  * By default capinfos now continues processing
@@ -1019,8 +1018,8 @@ usage(gboolean is_error)
   }
 
   fprintf(output, "Capinfos %s"
-#ifdef GITVERSION
-      " (" GITVERSION " from " GITBRANCH ")"
+#ifdef SVNVERSION
+      " (" SVNVERSION " from " SVNPATH ")"
 #endif
       "\n", VERSION);
   fprintf(output, "Prints various information (infos) about capture files.\n");
@@ -1077,7 +1076,7 @@ usage(gboolean is_error)
   fprintf(output, "  -C cancel processing if file open fails (default is to continue)\n");
   fprintf(output, "  -A generate all infos (default)\n");
   fprintf(output, "\n");
-  fprintf(output, "Options are processed from left to right order with later options superceeding\n");
+  fprintf(output, "Options are processed from left to right order with later options superceding\n");
   fprintf(output, "or adding to earlier options.\n");
   fprintf(output, "\n");
   fprintf(output, "If no options are given the default is to display all infos in long report\n");
@@ -1419,7 +1418,6 @@ main(int argc, char *argv[])
         case WTAP_ERR_UNSUPPORTED:
         case WTAP_ERR_UNSUPPORTED_ENCAP:
         case WTAP_ERR_BAD_FILE:
-        case WTAP_ERR_DECOMPRESS:
           fprintf(stderr, "(%s)\n", err_info);
           g_free(err_info);
           break;
