@@ -1,7 +1,7 @@
 /* capture.c
  * Routines for packet capture
  *
- * $Id$
+ * $Id: capture.c 52553 2013-10-11 21:29:12Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -130,19 +130,45 @@ capture_callback_remove(capture_callback_t func)
  * @return TRUE if the capture starts successfully, FALSE otherwise.
  */
 gboolean
-capture_start(capture_options *capture_opts, capture_session *cap_session)
+capture_start(capture_options *capture_opts, capture_session *cap_session, void(*update_cb)(void))
 {
   gboolean ret;
-  GString *source;
+  guint i;
+  GString *source = g_string_new("");
 
   cap_session->state = CAPTURE_PREPARING;
-  cap_session->count = 0;
   g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_MESSAGE, "Capture Start ...");
-  source = get_iface_list_string(capture_opts, IFLIST_SHOW_FILTER);
+#ifdef _WIN32
+  if (capture_opts->ifaces->len < 2) {
+#else
+  if (capture_opts->ifaces->len < 4) {
+#endif
+    for (i = 0; i < capture_opts->ifaces->len; i++) {
+      interface_options interface_opts;
+
+      interface_opts = g_array_index(capture_opts->ifaces, interface_options, i);
+      if (i > 0) {
+          if (capture_opts->ifaces->len > 2) {
+              g_string_append_printf(source, ",");
+          }
+          g_string_append_printf(source, " ");
+          if (i == capture_opts->ifaces->len - 1) {
+              g_string_append_printf(source, "and ");
+          }
+      }
+      g_string_append_printf(source, "%s", get_iface_description_for_interface(capture_opts, i));
+      if ((interface_opts.cfilter != NULL) &&
+          (strlen(interface_opts.cfilter) > 0)) {
+        g_string_append_printf(source, " (%s)", interface_opts.cfilter);
+      }
+    }
+  } else {
+    g_string_append_printf(source, "%u interfaces", capture_opts->ifaces->len);
+  }
   cf_set_tempfile_source((capture_file *)cap_session->cf, source->str);
   g_string_free(source, TRUE);
   /* try to start the capture child process */
-  ret = sync_pipe_start(capture_opts, cap_session);
+  ret = sync_pipe_start(capture_opts, cap_session, update_cb);
   if(!ret) {
       if(capture_opts->save_file != NULL) {
           g_free(capture_opts->save_file);
@@ -268,7 +294,7 @@ capture_input_read_all(capture_session *cap_session, gboolean is_tempfile,
   }
 
   /* if we didn't capture even a single packet, close the file again */
-  if(cap_session->count == 0 && !capture_opts->restart) {
+  if(cf_get_packet_count((capture_file *)cap_session->cf) == 0 && !capture_opts->restart) {
     simple_dialog(ESD_TYPE_INFO, ESD_BTN_OK,
 "%sNo packets captured!%s\n"
 "\n"
@@ -335,7 +361,7 @@ capture_input_new_file(capture_session *cap_session, gchar *new_file)
   /* if we are in real-time mode, open the new file now */
   if(capture_opts->real_time_mode) {
     /* Attempt to open the capture file and set up to read from it. */
-    switch(cf_start_tail((capture_file *)cap_session->cf, capture_opts->save_file, is_tempfile, &err)) {
+    switch(cf_open((capture_file *)cap_session->cf, capture_opts->save_file, is_tempfile, &err)) {
     case CF_OK:
       break;
     case CF_ERROR:
@@ -395,6 +421,9 @@ capture_input_new_packets(capture_session *cap_session, int to_read)
       break;
     }
   } else {
+    /* increase the capture file packet counter by the number of incoming packets */
+    cf_set_packet_count((capture_file *)cap_session->cf,
+        cf_get_packet_count((capture_file *)cap_session->cf) + to_read);
     cf_fake_continue_tail((capture_file *)cap_session->cf);
 
     capture_callback_invoke(capture_cb_capture_fixed_continue, cap_session);
@@ -522,6 +551,7 @@ capture_input_closed(capture_session *cap_session, gchar *msg)
 {
   capture_options *capture_opts = cap_session->capture_opts;
   int  err;
+  int  packet_count_save;
 
   g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_MESSAGE, "Capture stopped!");
   g_assert(cap_session->state == CAPTURE_PREPARING || cap_session->state == CAPTURE_RUNNING);
@@ -543,6 +573,8 @@ capture_input_closed(capture_session *cap_session, gchar *msg)
       /* Read what remains of the capture file. */
       status = cf_finish_tail((capture_file *)cap_session->cf, &err);
 
+      /* XXX: If -Q (quit-after-cap) then cf->count clr'd below so save it first */
+      packet_count_save = cf_get_packet_count((capture_file *)cap_session->cf);
       /* Tell the GUI we are not doing a capture any more.
          Must be done after the cf_finish_tail(), so file lengths are
          correctly displayed */
@@ -552,7 +584,7 @@ capture_input_closed(capture_session *cap_session, gchar *msg)
       switch (status) {
 
       case CF_READ_OK:
-        if (cap_session->count == 0 && !capture_opts->restart) {
+        if ((packet_count_save == 0) && !capture_opts->restart) {
           simple_dialog(ESD_TYPE_INFO, ESD_BTN_OK,
             "%sNo packets captured!%s\n"
             "\n"
@@ -628,7 +660,7 @@ capture_input_closed(capture_session *cap_session, gchar *msg)
     /* close the currently loaded capture file */
     cf_close((capture_file *)cap_session->cf);
 
-    capture_start(capture_opts, cap_session);
+    capture_start(capture_opts, cap_session,NULL); /*XXX is this NULL ok or we need an update_cb???*/
   } else {
     /* We're not doing a capture any more, so we don't have a save file. */
     g_free(capture_opts->save_file);
@@ -664,7 +696,7 @@ capture_stat_start(capture_options *capture_opts) {
    * mechanism, so opening all the devices and presenting packet
    * counts might not always be a good idea.
    */
-  if (sync_interface_stats_open(&stat_fd, &fork_child, &msg) == 0) {
+  if (sync_interface_stats_open(&stat_fd, &fork_child, &msg, NULL) == 0) {
     sc = (if_stat_cache_t *)g_malloc(sizeof(if_stat_cache_t));
     sc->stat_fd = stat_fd;
     sc->fork_child = fork_child;
