@@ -1,7 +1,7 @@
 /* capture_opts.c
  * Routines for capture options setting
  *
- * $Id$
+ * $Id: capture_opts.c 51576 2013-08-29 18:15:13Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,6 +29,7 @@
 #ifdef HAVE_LIBPCAP
 
 #include <string.h>
+#include <ctype.h>
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -108,9 +109,10 @@ capture_opts_init(capture_options *capture_opts)
   capture_opts->has_autostop_packets            = FALSE;
   capture_opts->autostop_packets                = 0;
   capture_opts->has_autostop_filesize           = FALSE;
-  capture_opts->autostop_filesize               = 1000;             /* 1 MB */
+  capture_opts->autostop_filesize               = 1024;             /* 1 MiB */
   capture_opts->has_autostop_duration           = FALSE;
   capture_opts->autostop_duration               = 60;               /* 1 min */
+  capture_opts->capture_comment                 = NULL;
 
   capture_opts->output_to_pipe                  = FALSE;
   capture_opts->capture_child                   = FALSE;
@@ -214,7 +216,7 @@ capture_opts_log(const char *log_domain, GLogLevelFlags log_level, capture_optio
 
     g_log(log_domain, log_level, "AutostopFiles   (%u) : %u", capture_opts->has_autostop_files, capture_opts->autostop_files);
     g_log(log_domain, log_level, "AutostopPackets (%u) : %u", capture_opts->has_autostop_packets, capture_opts->autostop_packets);
-    g_log(log_domain, log_level, "AutostopFilesize(%u) : %u (KB)", capture_opts->has_autostop_filesize, capture_opts->autostop_filesize);
+    g_log(log_domain, log_level, "AutostopFilesize(%u) : %u (KiB)", capture_opts->has_autostop_filesize, capture_opts->autostop_filesize);
     g_log(log_domain, log_level, "AutostopDuration(%u) : %u", capture_opts->has_autostop_duration, capture_opts->autostop_duration);
 }
 
@@ -241,7 +243,7 @@ set_autostop_criterion(capture_options *capture_opts, const char *autostoparg)
    * as we allow it in the preferences file, we might as well
    * allow it here).
    */
-  while (g_ascii_isspace(*p))
+  while (isspace((guchar)*p))
     p++;
   if (*p == '\0') {
     /*
@@ -292,7 +294,7 @@ get_ring_arguments(capture_options *capture_opts, const char *arg)
    * as we allow it in the preferences file, we might as well
    * allow it here).
    */
-  while (g_ascii_isspace(*p))
+  while (isspace((guchar)*p))
     p++;
   if (*p == '\0') {
     /*
@@ -338,7 +340,7 @@ get_sampling_arguments(capture_options *capture_opts, const char *arg)
     p = colonp;
     *p++ = '\0';
 
-    while (g_ascii_isspace(*p))
+    while (isspace((guchar)*p))
         p++;
     if (*p == '\0') {
         *colonp = ':';
@@ -396,7 +398,7 @@ get_auth_arguments(capture_options *capture_opts, const char *arg)
     p = colonp;
     *p++ = '\0';
 
-    while (g_ascii_isspace(*p))
+    while (isspace((guchar)*p))
         p++;
 
     if (capture_opts->ifaces->len > 0) {
@@ -452,7 +454,7 @@ capture_opts_add_iface_opt(capture_options *capture_opts, const char *optarg_str
             cmdarg_err("There is no interface with that adapter index");
             return 1;
         }
-        if_list = capture_interface_list(&err, &err_str);
+        if_list = capture_interface_list(&err, &err_str, NULL);
         if (if_list == NULL) {
             switch (err) {
 
@@ -504,7 +506,7 @@ capture_opts_add_iface_opt(capture_options *capture_opts, const char *optarg_str
          * the interface name, so that the user can try specifying an
          * interface explicitly for testing purposes.
          */
-        if_list = capture_interface_list(&err, NULL);
+        if_list = capture_interface_list(&err, NULL, NULL);
         if (if_list != NULL) {
             /* try and do an exact match (case insensitive) */
             GList   *if_entry;
@@ -625,6 +627,13 @@ capture_opts_add_opt(capture_options *capture_opts, int opt, const char *optarg_
     int status, snaplen;
 
     switch(opt) {
+    case LONGOPT_NUM_CAP_COMMENT:  /* capture comment */
+        if (capture_opts->capture_comment) {
+            cmdarg_err("--capture-comment can be set only once per file");
+            return 1;
+        }
+        capture_opts->capture_comment = g_strdup(optarg_str_p);
+        break;
     case 'a':        /* autostop criteria */
         if (set_autostop_criterion(capture_opts, optarg_str_p) == FALSE) {
             cmdarg_err("Invalid or unknown -a flag \"%s\"", optarg_str_p);
