@@ -1,7 +1,7 @@
 /* capture_opts.h
  * Capture options (all parameters needed to do the actual capture)
  *
- * $Id$
+ * $Id: capture_opts.h 51576 2013-08-29 18:15:13Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -42,6 +42,16 @@
 extern "C" {
 #endif /* __cplusplus */
 
+/* Attention:
+   for tshark, we're using a leading - in the optstring to prevent getopt()
+   from permuting the argv[] entries, in this case, unknown argv[] entries
+   will be returned as parameters to a dummy-option 1
+   in short: we must not use 1 here */
+
+/* this does not clash with tshark's -2 option which returns '2' */
+#define LONGOPT_NUM_CAP_COMMENT 2
+
+
 #ifdef HAVE_PCAP_REMOTE
 /* Type of capture source */
 typedef enum {
@@ -200,9 +210,12 @@ typedef struct capture_options_tag {
                                          is specified */
     gint32 autostop_duration;       /**< Maximum capture duration */
 
+    gchar *capture_comment;         /** capture comment to write to the
+                                        output file */
+
     /* internally used (don't touch from outside) */
     gboolean output_to_pipe;        /**< save_file is a pipe (named or stdout) */
-	gboolean capture_child;         /**< hidden option: Wireshark child mode */
+    gboolean capture_child;         /**< hidden option: Wireshark child mode */
 } capture_options;
 
 /* initialize the capture_options with some reasonable values */
