@@ -1,7 +1,7 @@
 /* capture_session.h
  * State of a capture session
  *
- * $Id$
+ * $Id: capture_session.h 52552 2013-10-11 21:26:26Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,6 +29,7 @@
 extern "C" {
 #endif /* __cplusplus */
 
+#ifdef HAVE_LIBPCAP
 /* Current state of capture engine. XXX - differentiate states */
 typedef enum {
     CAPTURE_STOPPED,        /**< stopped */
@@ -51,13 +52,17 @@ typedef struct {
     gid_t group;                    /**< group of the cfile */
 #endif
     gboolean session_started;
-    guint32 count;                  /**< Total number of frames captured */
     capture_options *capture_opts;  /**< options for this capture */
     void *cf;                       /**< handle to cfile (note: untyped handle) */
 } capture_session;
 
 extern void
 capture_session_init(capture_session *cap_session, void *cf);
+#else
+
+typedef struct {} capture_session;
+
+#endif /* HAVE_LIBPCAP */
 
 #ifdef __cplusplus
 }
