@@ -2,7 +2,7 @@
  * capture_file GUI-independent manipulation
  * Vassilii Khachaturov <vassilii@tarunz.org>
  *
- * $Id$
+ * $Id: cfile.c 50794 2013-07-22 19:38:38Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,6 +31,29 @@
 
 #include "cfile.h"
 
+const char *
+cap_file_get_interface_name(void *data, guint32 interface_id)
+{
+  capture_file *cf = (capture_file *) data;
+  wtapng_iface_descriptions_t *idb_info;
+  const wtapng_if_descr_t *wtapng_if_descr = NULL;
+
+  idb_info = wtap_file_get_idb_info(cf->wth);
+
+  if (interface_id < idb_info->number_of_interfaces)
+    wtapng_if_descr = &g_array_index(idb_info->interface_data, wtapng_if_descr_t, interface_id);
+
+  g_free(idb_info);
+
+  if (wtapng_if_descr) {
+    if (wtapng_if_descr->if_name)
+      return wtapng_if_descr->if_name;
+    else if (wtapng_if_descr->if_description)
+      return wtapng_if_descr->if_description;
+  }
+  return "unknown";
+}
+
 void
 cap_file_init(capture_file *cf)
 {
