@@ -9,7 +9,27 @@
 #      will be replaced by the pod-formatted glossary
 # STDOUT is the output
 #
-# $Id$
+# Gilbert Ramirez <gram [AT] alumni.rice.edu>
+#
+# $Id: dfilter2pod.pl 52471 2013-10-09 17:30:50Z eapache $
+#
+# Wireshark - Network traffic analyzer
+# By Gerald Combs <gerald@wireshark.org>
+# Copyright 1998 Gerald Combs
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 use Getopt::Std;
 
@@ -45,6 +65,7 @@ use Getopt::Std;
 	'FT_PCRE',		'Perl Compatible Regular Expression',
 	'FT_GUID',		'Globally Unique Identifier',
 	'FT_OID',		'Object Identifier',
+	'FT_REL_OID',		'Relative Object Identifier',
 );
 
 getopts('e');
