@@ -1,7 +1,7 @@
 /* addr_resolv.h
  * Definitions for network object lookup
  *
- * $Id$
+ * $Id: addr_resolv.h 52505 2013-10-10 19:30:29Z etxrab $
  *
  * Laurent Deniel <laurent.deniel@free.fr>
  *
@@ -36,6 +36,8 @@
 
 #include <epan/address.h>
 #include <epan/tvbuff.h>
+#include <epan/to_str.h>
+#include <wiretap/wtap.h>
 #include "ws_symbol_export.h"
 
 #ifdef __cplusplus
@@ -55,6 +57,44 @@ typedef struct _e_addr_resolve {
   gboolean load_hosts_file_from_profile_only;
 } e_addr_resolve;
 
+
+typedef struct hashether {
+  guint             status;  /* (See above) */
+  guint8            addr[6];
+  char              hexaddr[6*3];
+  char              resolved_name[MAXNAMELEN];
+} hashether_t;
+
+typedef struct serv_port {
+  gchar            *udp_name;
+  gchar            *tcp_name;
+  gchar            *sctp_name;
+  gchar            *dccp_name;
+} serv_port_t;
+
+/*
+ * 
+ */
+#define DUMMY_ADDRESS_ENTRY      1<<0
+#define TRIED_RESOLVE_ADDRESS    1<<1
+#define RESOLVED_ADDRESS_USED    1<<2
+
+#define DUMMY_AND_RESOLVE_FLGS   3
+#define USED_AND_RESOLVED_MASK   (1+4)
+typedef struct hashipv4 {
+    guint             addr;
+    guint8            flags;          /* B0 dummy_entry, B1 resolve, B2 If the address is used in the trace */
+    gchar             ip[16];
+    gchar             name[MAXNAMELEN];
+} hashipv4_t;
+
+
+typedef struct hashipv6 {
+    struct e_in6_addr addr;
+    guint8            flags;          /* B0 dummy_entry, B1 resolve, B2 If the address is used in the trace */
+    gchar             ip6[MAX_IP6_STR_LEN]; /* XX */
+    gchar             name[MAXNAMELEN];
+} hashipv6_t;
 /*
  * Flag controlling what names to resolve.
  */
@@ -122,9 +162,6 @@ void get_addr_name_buf(const address *addr, gchar *buf, gsize size);
 struct pref_module;
 extern void addr_resolve_pref_init(struct pref_module *nameres);
 
-/* host_name_lookup_init fires up an ADNS socket if we're using ADNS */
-extern void host_name_lookup_init(void);
-
 /** If we're using c-ares or ADNS, process outstanding host name lookups.
  *  This is called from a GLIB timeout in Wireshark and before processing
  *  each packet in TShark.
@@ -134,9 +171,6 @@ extern void host_name_lookup_init(void);
  */
 WS_DLL_PUBLIC gboolean host_name_lookup_process(void);
 
-/* host_name_lookup_cleanup cleans up an ADNS socket if we're using ADNS */
-extern void host_name_lookup_cleanup(void);
-
 /* get_hostname returns the host name or "%d.%d.%d.%d" if not found */
 WS_DLL_PUBLIC const gchar *get_hostname(const guint addr);
 
@@ -221,7 +255,7 @@ WS_DLL_PUBLIC void add_ipv6_name(const struct e_in6_addr *addr, const gchar *nam
  * The file can be added before host_name_lookup_init() is called and
  * will be re-read each time host_name_lookup_init() is called.
  *
- * @param hostspath Absolute path to the hosts file.
+ * @param hosts_file Absolute path to the hosts file.
  *
  * @return TRUE if the hosts file can be read.
  */
@@ -230,33 +264,14 @@ WS_DLL_PUBLIC gboolean add_hosts_file (const char *hosts_file);
 /* adds a hostname in the hash table */
 WS_DLL_PUBLIC gboolean add_ip_name_from_string (const char *addr, const char *name);
 
-/** Get a list of host name to address mappings we know about.
+
+/** Get lists of host name to address mappings we know about.
  *
- * Each list element is an addrinfo struct with the following fields defined:
- *   - ai_family: 0, AF_INET or AF_INET6
- *   - ai_addrlen: Length of ai_addr
- *   - ai_canonname: Host name or NULL
- *   - ai_addr: Pointer to a struct sockaddr or NULL (see below)
- *   - ai_next: Next element or NULL
- * All other fields are zero-filled.
+ * The struct contains two g_lists one with hashipv4_t entries and one with hashipv6_t entries.
  *
- * If ai_family is 0, this is a dummy entry which should only appear at the beginning of the list.
- *
- * If ai_family is AF_INET, ai_addr points to a struct sockaddr_in with the following fields defined:
- *   - sin_family: AF_INET
- *   - sin_addr: Host IPv4 address
- * All other fields are zero-filled.
- *
- * If ai_family is AF_INET6, ai_addr points to a struct sockaddr_in6 with the following fields defined:
- *   - sin6_family: AF_INET6
- *   - sin6_addr: Host IPv6 address
- * All other fields are zero-filled.
- *
- * The list and its elements MUST NOT be modified or freed.
- *
- * @return The first element in our list of known addresses. May be NULL.
+ * @return a struct with lists of known addresses(IPv4 and IPv6). May be NULL.
  */
-WS_DLL_PUBLIC struct addrinfo *get_addrinfo_list(void);
+WS_DLL_PUBLIC addrinfo_lists_t *get_addrinfo_list(void);
 
 /* add ethernet address / name corresponding to IP address  */
 extern void add_ether_byip(const guint ip, const guint8 *eth);
@@ -297,6 +312,50 @@ gboolean get_host_ipaddr6(const char *host, struct e_in6_addr *addrp);
 WS_DLL_PUBLIC
 const char* host_ip_af(const char *host);
 
+WS_DLL_PUBLIC
+GHashTable *get_manuf_hashtable(void);
+
+WS_DLL_PUBLIC
+GHashTable *get_wka_hashtable(void);
+
+WS_DLL_PUBLIC
+GHashTable *get_eth_hashtable(void);
+
+WS_DLL_PUBLIC
+GHashTable *get_serv_port_hashtable(void);
+
+WS_DLL_PUBLIC
+GHashTable *get_ipxnet_table(void);
+
+WS_DLL_PUBLIC
+GHashTable *get_ipv4_hash_table(void);
+
+WS_DLL_PUBLIC
+GHashTable *get_ipv6_hash_table(void);
+
+/*
+ * private functions (should only be called by epan directly)
+ */
+
+WS_DLL_LOCAL
+void name_resolver_init(void);
+
+/* (Re)Initialize hostname resolution subsystem */
+WS_DLL_LOCAL
+void host_name_lookup_init(void);
+
+/* Clean up only hostname resolutions (so they don't "leak" from one
+ * file to the next).
+ */
+WS_DLL_LOCAL
+void host_name_lookup_cleanup(void);
+
+WS_DLL_LOCAL
+void addr_resolv_init(void);
+
+WS_DLL_LOCAL
+void addr_resolv_cleanup(void);
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
