@@ -1,7 +1,7 @@
 /* column-utils.h
  * Definitions for column utility structures and routines
  *
- * $Id$
+ * $Id: column-utils.h 52317 2013-10-01 15:30:22Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -58,7 +58,7 @@ WS_DLL_PUBLIC void	col_cleanup(column_info *cinfo);
  *
  * Internal, don't use this in dissectors!
  */
-extern void	col_init(column_info *cinfo);
+extern void	col_init(column_info *cinfo, const struct epan_session *epan);
 
 /** Fill in all columns of the given packet which are based on values from frame_data.
  *
@@ -96,17 +96,6 @@ WS_DLL_PUBLIC gboolean	col_get_writable(column_info *cinfo);
  */
 WS_DLL_PUBLIC void	col_set_writable(column_info *cinfo, const gboolean writable);
 
-/** 
- * Checks if the given column can be filled with data.
- *
- * @param cinfo the current packet row
- * @param col the column to use, e.g. COL_INFO
- *
- * @deprecated Not needed in new code the check is done in 
- * in the column function calls.
- */
-WS_DLL_PUBLIC gint	check_col(column_info *cinfo, const gint col);
-
 /** Sets a fence for the current column content,
  * so this content won't be affected by further col_... function calls.
  *
@@ -262,7 +251,7 @@ WS_DLL_PUBLIC void	col_append_sep_fstr(column_info *cinfo, const gint col, const
 WS_DLL_PUBLIC void 	col_set_time(column_info *cinfo, const int col,
 			const nstime_t *ts, const char *fieldname);
 
-WS_DLL_PUBLIC void set_fd_time(frame_data *fd, gchar *buf);
+WS_DLL_PUBLIC void set_fd_time(const struct epan_session *epan, frame_data *fd, gchar *buf);
 
 #ifdef __cplusplus
 }
