@@ -1,7 +1,7 @@
 /* column.c
  * Routines for handling column preferences
  *
- * $Id$
+ * $Id: column.c 52627 2013-10-15 18:27:35Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,7 +35,6 @@
 
 #include <epan/timestamp.h>
 #include <epan/prefs.h>
-#include <epan/nstime.h>
 #include <epan/dfilter/dfilter.h>
 #include <epan/column.h>
 #include <epan/packet.h>
@@ -44,7 +43,7 @@
    string */
 const gchar *
 col_format_to_string(const gint fmt) {
-  const gchar *slist[] = {
+  static const gchar *const slist[NUM_COL_FMTS] = {
     "%q",                                       /* 0) COL_8021Q_VLAN_ID */
     "%Yt",                                      /* 1) COL_ABS_DATE_TIME */
     "%At",                                      /* 2) COL_ABS_TIME */
@@ -116,7 +115,9 @@ col_format_to_string(const gint fmt) {
 
 /* Given a format number (as defined in column_info.h), returns its
   description */
-static const gchar *dlist[NUM_COL_FMTS] = {
+const gchar *
+col_format_desc(const gint fmt) {
+  static const gchar *const dlist[NUM_COL_FMTS] = {
     "802.1Q VLAN id",                           /* 0) COL_8021Q_VLAN_ID */
     "Absolute date and time",                   /* 1) COL_ABS_DATE_TIME */
     "Absolute time",                            /* 2) COL_ABS_TIME */
@@ -178,14 +179,22 @@ static const gchar *dlist[NUM_COL_FMTS] = {
     "UTC date and time",                        /* 58) COL_UTC_DATE_TIME */
     "UTC time",                                 /* 59) COL_UTC_TIME */
     "Time (format as specified)"                /* 60) COL_CLS_TIME */
-};
+  };
 
-const gchar *
-col_format_desc(const gint fmt) {
   g_assert((fmt >= 0) && (fmt < NUM_COL_FMTS));
   return(dlist[fmt]);
 }
 
+void
+column_dump_column_formats(void)
+{
+  gint fmt;
+
+  for (fmt = 0; fmt < NUM_COL_FMTS; fmt++) {
+    printf("%s\t%s\n", col_format_to_string(fmt), col_format_desc(fmt));
+  }
+}
+
 /* Marks each array element true if it can be substituted for the given
    column format */
 void
@@ -803,3 +812,16 @@ build_column_format_array(column_info *cinfo, const gint num_cols, const gboolea
   }
 }
 
+/*
+ * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ *
+ * Local variables:
+ * c-basic-offset: 2
+ * tab-width: 2
+ * indent-tabs-mode: nil
+ * End:
+ *
+ * vi: set shiftwidth=2 tabstop=2 expandtab:
+ * :indentSize=2:tabSize=2:noTabs=true:
+ */
+
