@@ -1,7 +1,7 @@
 /* conversation.c
  * Routines for building lists of packets that are part of a "conversation"
  *
- * $Id$
+ * $Id: conversation.c 52084 2013-09-15 20:47:45Z eapache $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -180,17 +180,32 @@ conversation_create_from_template(conversation_t *conversation, const address *a
  * Compute the hash value for two given address/port pairs if the match
  * is to be exact.
  */
+/* http://eternallyconfuzzled.com/tuts/algorithms/jsw_tut_hashing.aspx#existing 
+ * One-at-a-Time hash
+ */
 static guint
 conversation_hash_exact(gconstpointer v)
 {
 	const conversation_key *key = (const conversation_key *)v;
 	guint hash_val;
+	address tmp_addr;
 
 	hash_val = 0;
+	tmp_addr.len  = 4;
+
 	ADD_ADDRESS_TO_HASH(hash_val, &key->addr1);
-	hash_val += key->port1;
+
+	tmp_addr.data = &key->port1;
+	ADD_ADDRESS_TO_HASH(hash_val, &tmp_addr);
+
 	ADD_ADDRESS_TO_HASH(hash_val, &key->addr2);
-	hash_val += key->port2;
+
+	tmp_addr.data = &key->port2;
+	ADD_ADDRESS_TO_HASH(hash_val, &tmp_addr);
+
+	hash_val += ( hash_val << 3 );
+	hash_val ^= ( hash_val >> 11 );
+	hash_val += ( hash_val << 15 );
 
 	return hash_val;
 }
@@ -256,11 +271,22 @@ conversation_hash_no_addr2(gconstpointer v)
 {
 	const conversation_key *key = (const conversation_key *)v;
 	guint hash_val;
+	address tmp_addr;
 
 	hash_val = 0;
+	tmp_addr.len  = 4;
+
 	ADD_ADDRESS_TO_HASH(hash_val, &key->addr1);
-	hash_val += key->port1;
-	hash_val += key->port2;
+
+	tmp_addr.data = &key->port1;
+	ADD_ADDRESS_TO_HASH(hash_val, &tmp_addr);
+
+	tmp_addr.data = &key->port2;
+	ADD_ADDRESS_TO_HASH(hash_val, &tmp_addr);
+
+	hash_val += ( hash_val << 3 );
+	hash_val ^= ( hash_val >> 11 );
+	hash_val += ( hash_val << 15 );
 
 	return hash_val;
 }
@@ -310,12 +336,22 @@ conversation_hash_no_port2(gconstpointer v)
 {
 	const conversation_key *key = (const conversation_key *)v;
 	guint hash_val;
+	address tmp_addr;
 
 	hash_val = 0;
+	tmp_addr.len  = 4;
+
 	ADD_ADDRESS_TO_HASH(hash_val, &key->addr1);
-	hash_val += key->port1;
+
+	tmp_addr.data = &key->port1;
+	ADD_ADDRESS_TO_HASH(hash_val, &tmp_addr);
+
 	ADD_ADDRESS_TO_HASH(hash_val, &key->addr2);
 
+	hash_val += ( hash_val << 3 );
+	hash_val ^= ( hash_val >> 11 );
+	hash_val += ( hash_val << 15 );
+
 	return hash_val;
 }
 
@@ -364,10 +400,19 @@ conversation_hash_no_addr2_or_port2(gconstpointer v)
 {
 	const conversation_key *key = (const conversation_key *)v;
 	guint hash_val;
+	address tmp_addr;
 
 	hash_val = 0;
+	tmp_addr.len  = 4;
+
 	ADD_ADDRESS_TO_HASH(hash_val, &key->addr1);
-	hash_val += key->port1;
+
+	tmp_addr.data = &key->port1;
+	ADD_ADDRESS_TO_HASH(hash_val, &tmp_addr);
+
+	hash_val += ( hash_val << 3 );
+	hash_val ^= ( hash_val >> 11 );
+	hash_val += ( hash_val << 15 );
 
 	return hash_val;
 }
@@ -650,7 +695,7 @@ conversation_new(const guint32 setup_frame, const address *addr1, const address
 	memset(conversation, 0, sizeof(conversation_t));
 
 	conversation->index = new_index;
-	conversation->setup_frame = setup_frame;
+	conversation->setup_frame = conversation->last_frame = setup_frame;
 	conversation->data_list = NULL;
 
 	/* clear dissector handle */
@@ -824,12 +869,18 @@ find_conversation(const guint32 frame_num, const address *addr_a, const address
       /*
        * Neither search address B nor search port B are wildcarded,
        * start out with an exact match.
-       * Exact matches check both directions.
        */
       conversation =
          conversation_lookup_hashtable(conversation_hashtable_exact,
          frame_num, addr_a, addr_b, ptype,
          port_a, port_b);
+      /* Didn't work, try the other direction */
+      if (conversation == NULL) {
+	      conversation =
+		 conversation_lookup_hashtable(conversation_hashtable_exact,
+		 frame_num, addr_b, addr_a, ptype,
+		 port_b, port_a);
+      }
       if ((conversation == NULL) && (addr_a->type == AT_FC)) {
          /* In Fibre channel, OXID & RXID are never swapped as
           * TCP/UDP ports are in TCP/IP.
@@ -1242,7 +1293,11 @@ find_or_create_conversation(packet_info *pinfo)
 	/* Have we seen this conversation before? */
 	if((conv = find_conversation(pinfo->fd->num, &pinfo->src, &pinfo->dst,
 				     pinfo->ptype, pinfo->srcport,
-				     pinfo->destport, 0)) == NULL) {
+				     pinfo->destport, 0)) != NULL) {
+		if (pinfo->fd->num > conv->last_frame) {
+			conv->last_frame = pinfo->fd->num;
+		}
+	} else {
 		/* No, this is a new conversation. */
 		conv = conversation_new(pinfo->fd->num, &pinfo->src,
 					&pinfo->dst, pinfo->ptype,
@@ -1251,3 +1306,40 @@ find_or_create_conversation(packet_info *pinfo)
 
 	return conv;
 }
+
+GHashTable *
+get_conversation_hashtable_exact(void)
+{
+	return conversation_hashtable_exact;
+}
+
+GHashTable *
+get_conversation_hashtable_no_addr2(void)
+{
+	return conversation_hashtable_no_addr2;
+}
+
+GHashTable *
+get_conversation_hashtable_no_port2(void)
+{
+	return conversation_hashtable_no_port2;
+}
+
+GHashTable *
+get_conversation_hashtable_no_addr2_or_port2(void)
+{
+	return conversation_hashtable_no_addr2_or_port2;
+}
+
+/*
+ * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ *
+ * Local variables:
+ * c-basic-offset: 8
+ * tab-width: 8
+ * indent-tabs-mode: t
+ * End:
+ *
+ * vi: set shiftwidth=8 tabstop=8 noexpandtab:
+ * :indentSize=8:tabSize=8:noTabs=false:
+ */
