@@ -1,7 +1,7 @@
 /* conversation.h
  * Routines for building lists of packets that are part of a "conversation"
  *
- * $Id$
+ * $Id: conversation.h 52078 2013-09-15 19:35:10Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -78,6 +78,8 @@ typedef struct conversation {
 								/** pointer to the last conversation on hash chain */
 	guint32	index;				/** unique ID for conversation */
 	guint32 setup_frame;		/** frame number that setup this conversation */
+	/* Assume that setup_frame is also the lowest frame number for now. */
+	guint32 last_frame;		/** highest frame number in this conversation */
 	GSList *data_list;			/** list of data associated with conversation */
 	dissector_handle_t dissector_handle;
 								/** handle for protocol dissector client associated with conversation */
@@ -181,6 +183,22 @@ try_conversation_dissector(const address *addr_a, const address *addr_b, const p
 extern void conversation_set_port2(conversation_t *conv, const guint32 port);
 extern void conversation_set_addr2(conversation_t *conv, const address *addr);
 
+WS_DLL_PUBLIC
+GHashTable *get_conversation_hashtable_exact(void);
+
+WS_DLL_PUBLIC
+GHashTable *get_conversation_hashtable_no_addr2(void);
+
+WS_DLL_PUBLIC
+GHashTable *get_conversation_hashtable_no_addr2(void);
+
+WS_DLL_PUBLIC
+GHashTable * get_conversation_hashtable_no_port2(void);
+
+WS_DLL_PUBLIC
+GHashTable *get_conversation_hashtable_no_addr2_or_port2(void);
+
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
