@@ -1,6 +1,6 @@
 /* airpdcap.c
  *
- * $Id$
+ * $Id: airpdcap.c 51254 2013-08-10 21:28:01Z alagoutte $
  * Copyright (c) 2006 CACE Technologies, Davis (California)
  * All rights reserved.
  *
@@ -38,20 +38,22 @@
 
 #include "config.h"
 
-#include <epan/tvbuff.h>
+#include <glib.h>
+
 #include <wsutil/crc32.h>
+#include <wsutil/rc4.h>
+#include <wsutil/sha1.h>
+#include <wsutil/md5.h>
+#include <wsutil/pint.h>
+
+#include <epan/tvbuff.h>
 #include <epan/strutil.h>
 #include <epan/emem.h>
-#include <epan/pint.h>
-#include <epan/crypt/rc4.h>
 #include <epan/crypt/airpdcap_rijndael.h>
 
 #include "airpdcap_system.h"
 #include "airpdcap_int.h"
 
-#include "sha1.h"
-#include "md5.h"
-
 #include "airpdcap_debug.h"
 
 #include "wep-wpadefs.h"
@@ -126,7 +128,7 @@ extern "C" {
 /**
  * It is a step of the PBKDF2 (specifically the PKCS #5 v2.0) defined in
  * the RFC 2898 to derive a key (used as PMK in WPA)
- * @param password [IN] pointer to a password (sequence of between 8 and
+ * @param ppbytes [IN] pointer to a password (sequence of between 8 and
  * 63 ASCII encoded characters)
  * @param ssid [IN] pointer to the SSID string encoded in max 32 ASCII
  * encoded characters
@@ -149,7 +151,7 @@ static INT AirPDcapRsnaPwd2PskStep(
  * It calculates the passphrase-to-PSK mapping reccomanded for use with
  * RSNAs. This implementation uses the PBKDF2 method defined in the RFC
  * 2898.
- * @param password [IN] pointer to a password (sequence of between 8 and
+ * @param passphrase [IN] pointer to a password (sequence of between 8 and
  * 63 ASCII encoded characters)
  * @param ssid [IN] pointer to the SSID string encoded in max 32 ASCII
  * encoded characters
@@ -1674,8 +1676,7 @@ AirPDcapGetBssidAddress(
     }
 }
 
-/* Function used to derive the PTK. Refer to IEEE 802.11I-2004, pag. 74
- * and IEEE 802.11i-2004, pag. 164 */
+/* Function used to derive the PTK. Refer to IEEE 802.11I-2004, pag. 74 */
 static void
 AirPDcapRsnaPrfX(
     AIRPDCAP_SEC_ASSOCIATION *sa,
@@ -1687,7 +1688,6 @@ AirPDcapRsnaPrfX(
     UINT8 i;
     UCHAR R[100];
     INT offset=sizeof("Pairwise key expansion");
-    UCHAR output[80]; /* allow for sha1 overflow. */
 
     memset(R, 0, 100);
 
@@ -1724,9 +1724,8 @@ AirPDcapRsnaPrfX(
     for(i = 0; i < (x+159)/160; i++)
     {
         R[offset] = i;
-        sha1_hmac(pmk, 32, R, 100, &output[20 * i]);
+        sha1_hmac(pmk, 32, R, 100, ptk + i * 20);
     }
-    memcpy(ptk, output, x/8);
 }
 
 static INT
