@@ -1,6 +1,6 @@
 /* dfilter-macro.c
  *
- * $Id$
+ * $Id: dfilter-macro.c 50598 2013-07-15 02:48:26Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,6 +26,7 @@
 
 #include <stdio.h>
 #include <errno.h>
+#include <ctype.h>
 #include <string.h>
 
 #include "dfilter-int.h"
@@ -33,7 +34,6 @@
 #include "dfilter-macro.h"
 #include <epan/emem.h>
 #include <epan/uat-int.h>
-#include <epan/report_err.h>
 #include <epan/proto.h>
 #include <wsutil/file_util.h>
 
@@ -287,7 +287,7 @@ static const gchar* dfilter_macro_apply_recurse(const gchar* text, guint depth,
 				}
 				break;
 			} case NAME: {
-				if ( g_ascii_isalnum(c) || c == '_' || c == '-' || c == '.' ) {
+				if ( isalnum((int)c) || c == '_' || c == '-' || c == '.' ) {
 					g_string_append_c(name,c);
 				} else if ( c == ':') {
 					state = ARGS;
@@ -398,11 +398,22 @@ static void macro_update(void* mp, const gchar** error) {
 	gchar* w;
 	gchar* part;
 	int argc = 0;
+	guint i;
 
 	DUMP_MACRO(m);
 
 	*error = NULL;
 
+	for (i = 0; i < num_macros; i++) {
+		if (m == &(macros[i])) continue;
+
+		if ( g_str_equal(m->name,macros[i].name) ) {
+			*error = ep_strdup_printf("macro '%s' exists already", m->name);
+			m->usable = FALSE;
+			return;
+		}
+	}
+
 	/* Invalidate the display filter in case it's in use */
 	if (dfilter_macro_uat && dfilter_macro_uat->post_update_cb)
 	  dfilter_macro_uat->post_update_cb();
@@ -567,9 +578,7 @@ static void* macro_copy(void* dest, const void* orig, size_t len _U_) {
 	return d;
 }
 
-static gboolean macro_name_chk(void *mp, const char *in_name, guint name_len,
-		const void *u1 _U_, const void *u2 _U_, const char **error) {
-	dfilter_macro_t* m = (dfilter_macro_t*)mp;
+static gboolean macro_name_chk(void* r _U_, const char* in_name, guint name_len, const void* u1 _U_, const void* u2 _U_, const char** error) {
 	guint i;
 
 	if (name_len == 0) {
@@ -578,28 +587,12 @@ static gboolean macro_name_chk(void *mp, const char *in_name, guint name_len,
 	}
 
 	for (i=0; i < name_len; i++) {
-		if (!(in_name[i] == '_' || g_ascii_isalnum(in_name[i]) ) ) {
+		if (!(in_name[i] == '_' || isalnum((guchar)in_name[i]) ) ) {
 			*error = "invalid char in name";
 			return FALSE;
 		}
 	}
 
-	/* When loading (!m->name) or when adding/changing the an item with a
-	 * different name, check for uniqueness. NOTE: if a duplicate already
-	 * exists (because the user manually edited the file), then this will
-	 * not trigger a warning. */
-	if (!m->name || !g_str_equal(m->name, in_name)) {
-		for (i = 0; i < num_macros; i++) {
-			/* This a string field which is always NUL-terminated,
-			 * so no need to check name_len. */
-			if (g_str_equal(in_name, macros[i].name)) {
-				*error = g_strdup_printf("macro '%s' already exists",
-							 in_name);
-				return FALSE;
-			}
-		}
-	}
-
 	return TRUE;
 }
 
@@ -609,6 +602,9 @@ UAT_CSTRING_CB_DEF(macro,text,dfilter_macro_t)
 void dfilter_macro_init(void) {
 	static uat_field_t uat_fields[] =  {
 		UAT_FLD_CSTRING_OTHER(macro,name,"Name",macro_name_chk,"The name of the macro."),
+		/* N.B. it would be nice if there was a field type for display filters (with
+		   auto-completion & colouring), but this wouldn't work here as the filter string
+		   will contain $1, etc... */
 		UAT_FLD_CSTRING_ISPRINT(macro,text,"Text","The text this macro resolves to."),
 		UAT_END_FIELDS
 	};
@@ -637,7 +633,7 @@ void dfilter_macro_get_uat(void** p) {
 #ifdef DUMP_DFILTER_MACRO
 /*
  * The dfilter_macro_t has several characteristics that are
- * not immediattly obvious. The dump_dfilter_filter_macro_t()
+ * not immediately obvious. The dump_dfilter_filter_macro_t()
  * function can be used to help "visualize" the contents of
  * a dfilter_macro_t.
  *
