@@ -1,5 +1,5 @@
 /*
- * $Id$
+ * $Id: semcheck.h 51247 2013-08-10 17:49:28Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -25,7 +25,7 @@
 #define SEMCHECK_H
 
 gboolean
-dfw_semcheck(dfwork_t *dfw);
+dfw_semcheck(dfwork_t *dfw, GPtrArray *deprecated);
 
 
 #endif
