@@ -1,5 +1,5 @@
 /*
- * $Id$
+ * $Id: sttype-range.h 50949 2013-07-27 17:17:15Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,7 +27,7 @@
 #include "syntax-tree.h"
 #include "drange.h"
 
-STTYPE_ACCESSOR_PROTOTYPE(header_field_info*, range, hfinfo)
+STTYPE_ACCESSOR_PROTOTYPE(stnode_t*, range, entity)
 STTYPE_ACCESSOR_PROTOTYPE(drange_t*, range, drange)
 
 /* Set a range */
