@@ -1,5 +1,5 @@
 /*
- * $Id$
+ * $Id: syntax-tree.c 51247 2013-08-10 17:49:28Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -91,6 +91,7 @@ stnode_new(sttype_id_t type_id, gpointer data)
 	node = g_new(stnode_t, 1);
 	node->magic = STNODE_MAGIC;
         node->deprecated_token = NULL;
+	node->inside_brackets = FALSE;
 
 	if (type_id == STTYPE_UNINITIALIZED) {
 		node->type = NULL;
@@ -112,6 +113,12 @@ stnode_new(sttype_id_t type_id, gpointer data)
 	return node;
 }
 
+void
+stnode_set_bracket(stnode_t *node, gboolean bracket)
+{
+	node->inside_brackets = bracket;
+}
+
 stnode_t*
 stnode_dup(const stnode_t *org)
 {
@@ -132,6 +139,7 @@ stnode_dup(const stnode_t *org)
 	else
 		node->data = org->data;
 	node->value = org->value;
+	node->inside_brackets = org->inside_brackets;
 
 	return node;
 }
