@@ -4,7 +4,7 @@
  * Copyright 2004, Jelmer Vernooij <jelmer@samba.org>
  * Copyright 2004, Devin Heitmueller <dheitmueller@netilla.com>
  *
- * $Id$
+ * $Id: packet-aim.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1167,7 +1167,7 @@ dissect_aim_tlv_value_string (proto_item *ti, guint16 valueid _U_, tvbuff_t *tvb
 	gint string_len;
 
 	string_len = tvb_length(tvb);
-	buf = tvb_get_ephemeral_string(tvb, 0, string_len);
+	buf = tvb_get_string(wmem_packet_scope(), tvb, 0, string_len);
 	proto_item_set_text(ti, "Value: %s", format_text(buf, string_len));
 
 	return string_len;
@@ -1184,7 +1184,7 @@ dissect_aim_tlv_value_string08_array (proto_item *ti, guint16 valueid _U_, tvbuf
 	while (tvb_reported_length_remaining(tvb, offset) > 1)
 	{
 		guint8 string_len = tvb_get_guint8(tvb, offset++);
-		guint8 *buf = tvb_get_ephemeral_string(tvb, offset, string_len);
+		guint8 *buf = tvb_get_string(wmem_packet_scope(), tvb, offset, string_len);
 		proto_tree_add_text(entry, tvb, offset, string_len, "%s",
 				    format_text(buf, string_len));
 		offset += string_len;
@@ -1289,7 +1289,7 @@ dissect_aim_tlv_value_messageblock (proto_item *ti, guint16 valueid _U_, tvbuff_
 		offset += 2;
 
 		/* The actual message */
-		buf = tvb_get_ephemeral_string(tvb, offset, blocklen - 4);
+		buf = tvb_get_string(wmem_packet_scope(), tvb, offset, blocklen - 4);
 		proto_item_append_text(ti, "Message: %s ",
 				    format_text(buf, blocklen - 4));
 		proto_tree_add_item(entry, hf_aim_messageblock_message, tvb,
@@ -1735,7 +1735,8 @@ proto_register_aim(void)
 				       " To use this option, you must also enable \"Allow subdissectors to reassemble TCP streams\" in the TCP protocol settings.",
 				       &aim_desegment);
 
-	subdissector_table = register_dissector_table("aim.family", "Family ID", FT_UINT16, BASE_HEX);
+	subdissector_table = register_dissector_table("aim.family",
+		"AIM Family ID", FT_UINT16, BASE_HEX);
 }
 
 void
