@@ -2,7 +2,7 @@
  * Routines for AJP13 dissection
  * Copyright 2002, Christopher K. St. John <cks@distributopia.com>
  *
- * $Id$
+ * $Id: packet-ajp13.c 52296 2013-09-30 15:21:09Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,7 +30,7 @@
 #include <glib.h>
 
 #include <epan/packet.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/conversation.h>
 #include "packet-tcp.h"
 
@@ -401,7 +401,6 @@ display_rsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ajp13_tree, ajp13_con
       const gchar *hval;
       guint16 hval_len, hname_len;
       const gchar* hname = NULL;
-      header_field_info *hfinfo;
       int hpos = pos;
       /* int cl = 0; TODO: Content-Length header (encoded by 0x08) is special */
 
@@ -419,12 +418,9 @@ display_rsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ajp13_tree, ajp13_con
 
         hval = ajp13_get_nstring(tvb, pos, &hval_len);
 
-        if (ajp13_tree) {
-          hfinfo = proto_registrar_get_nth(*rsp_headers[hid]);
-          proto_tree_add_string_format(ajp13_tree, *rsp_headers[hid],
+        proto_tree_add_string_format_value(ajp13_tree, *rsp_headers[hid],
                                        tvb, hpos, 2+hval_len+2, hval,
-                                       "%s: %s", hfinfo->name, hval);
-        }
+                                       "%s", hval);
         pos+=hval_len+2;
 #if 0
         /* TODO: Content-Length header (encoded by 0x08) is special */
@@ -437,12 +433,10 @@ display_rsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ajp13_tree, ajp13_con
 
         hval = ajp13_get_nstring(tvb, pos, &hval_len);
 
-        if (ajp13_tree) {
-          proto_tree_add_string_format(ajp13_tree, hf_ajp13_additional_header,
+        proto_tree_add_string_format(ajp13_tree, hf_ajp13_additional_header,
                                 tvb, hpos, hname_len+2+hval_len+2,
-                                ep_strdup_printf("%s: %s", hname, hval),
+                                wmem_strdup_printf(wmem_packet_scope(), "%s: %s", hname, hval),
                                 "%s: %s", hname, hval);
-        }
         pos+=hval_len+2;
       }
     }
@@ -650,7 +644,6 @@ display_req_forward(tvbuff_t *tvb, packet_info *pinfo,
     guint8 hcd;
     guint8 hid;
     const gchar* hname = NULL;
-    header_field_info *hfinfo;
     int hpos = pos;
     int cl = 0;
     const gchar *hval;
@@ -670,12 +663,9 @@ display_req_forward(tvbuff_t *tvb, packet_info *pinfo,
 
       hval = ajp13_get_nstring(tvb, pos, &hval_len);
 
-      if (ajp13_tree) {
-        hfinfo = proto_registrar_get_nth(*req_headers[hid]);
-        proto_tree_add_string_format(ajp13_tree, *req_headers[hid],
+      proto_tree_add_string_format(ajp13_tree, *req_headers[hid],
                                      tvb, hpos, 2+hval_len+2, hval,
-                                     "%s: %s", hfinfo->name, hval);
-      }
+                                     "%s", hval);
       pos+=hval_len+2;
 
       if (hid == 0x08)
@@ -686,12 +676,10 @@ display_req_forward(tvbuff_t *tvb, packet_info *pinfo,
 
       hval = ajp13_get_nstring(tvb, pos, &hval_len);
 
-      if (ajp13_tree) {
-        proto_tree_add_string_format(ajp13_tree, hf_ajp13_additional_header,
+      proto_tree_add_string_format(ajp13_tree, hf_ajp13_additional_header,
                                      tvb, hpos, hname_len+2+hval_len+2,
-                                     ep_strdup_printf("%s: %s", hname, hval),
+                                     wmem_strdup_printf(wmem_packet_scope(), "%s: %s", hname, hval),
                                      "%s: %s", hname, hval);
-      }
       pos+=hval_len+2;
     }
 
@@ -709,7 +697,6 @@ display_req_forward(tvbuff_t *tvb, packet_info *pinfo,
     const gchar* aval;
     guint16 aval_len, aname_len;
 
-    header_field_info *hfinfo;
     int apos = pos;
 
     /* ATTRIBUTE CODE/NAME
@@ -730,12 +717,10 @@ display_req_forward(tvbuff_t *tvb, packet_info *pinfo,
       aval = ajp13_get_nstring(tvb, pos, &aval_len);
       pos+=aval_len+2;
 
-      if (ajp13_tree) {
-        proto_tree_add_string_format(ajp13_tree, hf_ajp13_req_attribute,
+      proto_tree_add_string_format(ajp13_tree, hf_ajp13_req_attribute,
                                      tvb, apos, 1+aname_len+2+aval_len+2,
-                                     ep_strdup_printf("%s: %s", aname, aval),
+                                     wmem_strdup_printf(wmem_packet_scope(), "%s: %s", aname, aval),
                                      "%s: %s", aname, aval);
-      }
     } else if (aid == 0x0B ) {
       /* ssl_key_length */
       if (ajp13_tree) {
@@ -748,15 +733,12 @@ display_req_forward(tvbuff_t *tvb, packet_info *pinfo,
       if (aid >= array_length(req_attributes))
         aid = 0;
 
-      hfinfo = proto_registrar_get_nth(*req_attributes[aid]);
       aval = ajp13_get_nstring(tvb, pos, &aval_len);
       pos+=aval_len+2;
 
-      if (ajp13_tree) {
-        proto_tree_add_string_format(ajp13_tree, *req_attributes[aid],
+      proto_tree_add_string_format(ajp13_tree, *req_attributes[aid],
                                      tvb, apos, 1+aval_len+2, aval,
-                                     "%s: %s", hfinfo->name, aval);
-      }
+                                     "%s", aval);
     }
   }
 }
@@ -783,7 +765,7 @@ dissect_ajp13_tcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   cd = (ajp13_conv_data*)conversation_get_proto_data(conv, proto_ajp13);
   if (!cd) {
-    cd = se_new(ajp13_conv_data);
+    cd = wmem_new(wmem_file_scope(), ajp13_conv_data);
     cd->content_length = 0;
     cd->was_get_body_chunk = FALSE;
     conversation_add_proto_data(conv, proto_ajp13, cd);
@@ -800,7 +782,7 @@ dissect_ajp13_tcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
      * time we've see the packet, and it must be the first "in order"
      * pass through the data.
      */
-    fd = se_new(ajp13_frame_data);
+    fd = wmem_new(wmem_file_scope(), ajp13_frame_data);
     p_add_proto_data(pinfo->fd, proto_ajp13, 0, fd);
     fd->is_request_body = FALSE;
     if (cd->content_length) {
