@@ -12,7 +12,7 @@
  * Copyright 2007, Michael Lum <michael.lum [AT] utstar.com>
  * In association with UTStarcom Inc.
  *
- * $Id$
+ * $Id: packet-ansi_801.c 51983 2013-09-12 20:37:30Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -41,6 +41,7 @@
 #include <math.h>
 
 #include <epan/packet.h>
+#include <epan/wmem/wmem.h>
 
 void proto_register_ansi_801(void);
 void proto_reg_handoff_ansi_801(void);
@@ -97,10 +98,10 @@ static int hf_ansi_801_num_fixes = -1;
 static int hf_ansi_801_t_betw_fixes = -1;
 static int hf_ansi_801_offset_req = -1;
 
+static dissector_handle_t ansi_801_handle;
+
 static char bigbuf[1024];
 static dissector_handle_t data_handle;
-static packet_info *g_pinfo;
-static proto_tree *g_tree;
 
 
 /* PARAM FUNCTIONS */
@@ -784,7 +785,7 @@ pr_loc_response(tvbuff_t *tvb, proto_tree *tree, guint len, guint32 offset)
 		fl_value = (float)(0.5 * (1 << (value >> 1)));
 		if (value & 0x01)
 			fl_value *= 1.5f;
-		str = ep_strdup_printf("%.2f meters", fl_value);
+		str = wmem_strdup_printf(wmem_packet_scope(), "%.2f meters", fl_value);
 	}
 	proto_tree_add_uint_bits_format_value(tree, hf_ansi_801_loc_uncrtnty_a, tvb, bit_offset, 5, value,
 					      "%s (0x%02x)", str, value);
@@ -800,7 +801,7 @@ pr_loc_response(tvbuff_t *tvb, proto_tree *tree, guint len, guint32 offset)
 		fl_value = (float)(0.5 * (1 << (value >> 1)));
 		if (value & 0x01)
 			fl_value *= 1.5f;
-		str = ep_strdup_printf("%.2f meters", fl_value);
+		str = wmem_strdup_printf(wmem_packet_scope(), "%.2f meters", fl_value);
 	}
 	proto_tree_add_uint_bits_format_value(tree, hf_ansi_801_loc_uncrtnty_p, tvb, bit_offset, 5, value,
 					      "%s (0x%02x)", str, value);
@@ -879,7 +880,7 @@ pr_loc_response(tvbuff_t *tvb, proto_tree *tree, guint len, guint32 offset)
 			fl_value = (float)(0.5 * (1 << (value >> 1)));
 			if (value & 0x01)
 				fl_value *= 1.5f;
-			str = ep_strdup_printf("%.2f meters", fl_value);
+			str = wmem_strdup_printf(wmem_packet_scope(), "%.2f meters", fl_value);
 		}
 		proto_tree_add_uint_bits_format_value(tree, hf_ansi_801_loc_uncrtnty_v, tvb, bit_offset, 5, value,
 						      "%s (0x%02x)", str, value);
@@ -2122,8 +2123,6 @@ dissect_ansi_801(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_item *ansi_801_item;
 	proto_tree *ansi_801_tree = NULL;
 
-	g_pinfo = pinfo;
-
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, ansi_proto_name_short);
 
 	/* In the interest of speed, if "tree" is NULL, don't do any work not
@@ -2131,8 +2130,6 @@ dissect_ansi_801(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	 */
 	if (tree)
 	{
-		g_tree = tree;
-
 		/*
 		 * create the ansi_801 protocol tree
 		 */
@@ -2391,17 +2388,13 @@ proto_register_ansi_801(void)
 	proto_register_subtree_array(ett, array_length(ett));
 
 	/* subdissector code */
-	register_dissector("ansi_801", dissect_ansi_801, proto_ansi_801);
+	ansi_801_handle = register_dissector("ansi_801", dissect_ansi_801, proto_ansi_801);
 }
 
 
 void
 proto_reg_handoff_ansi_801(void)
 {
-	dissector_handle_t ansi_801_handle;
-
-	ansi_801_handle = create_dissector_handle(dissect_ansi_801, proto_ansi_801);
-
 	dissector_add_uint("ansi_map.pld", ANSI_801_FORWARD, ansi_801_handle);
 	dissector_add_uint("ansi_map.pld", ANSI_801_REVERSE, ansi_801_handle);
 	dissector_add_uint("ansi_a.pld",   ANSI_801_FORWARD, ansi_801_handle);
