@@ -2,7 +2,7 @@
  * Routines for dissection of Apple network-midi session establishment.
  * Copyright 2006-2012, Tobias Erichsen <t.erichsen@gmx.de>
  *
- * $Id$
+ * $Id: packet-applemidi.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -52,6 +52,7 @@
 
 #include <glib.h>
 #include <epan/packet.h>
+#include <epan/wmem/wmem.h>
 #include <epan/conversation.h>
 
 #include "packet-rtp.h"
@@ -169,7 +170,7 @@ dissect_applemidi_common( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, g
 
 			/* Name is optional */
 			if ( len > 0 ) {
-				name = tvb_get_ephemeral_string( tvb, offset, len );
+				name = tvb_get_string( wmem_packet_scope(), tvb, offset, len );
 				string_size = (gint)( strlen( name ) + 1 );
 				proto_tree_add_item( applemidi_tree, hf_applemidi_name, tvb, offset, string_size, ENC_UTF_8|ENC_NA );
 				col_append_fstr( pinfo->cinfo, COL_INFO, ": peer = \"%s\"", name );
@@ -303,11 +304,11 @@ dissect_applemidi_heur( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
 	/* set dynamic payload-type 97 which is used by Apple for their RTP-MIDI implementation for this
 	   address/port-tuple to cause RTP-dissector to call the RTP-MIDI-dissector for payload-decoding */
 
-	encoding_name_and_rate = se_new(encoding_name_and_rate_t);
+	encoding_name_and_rate = wmem_new(wmem_file_scope(), encoding_name_and_rate_t);
 	rtp_dyn_payload = g_hash_table_new( g_int_hash, g_int_equal );
-	encoding_name_and_rate->encoding_name = se_strdup( "rtp-midi" );
+	encoding_name_and_rate->encoding_name = wmem_strdup( wmem_file_scope(), "rtp-midi" );
 	encoding_name_and_rate->sample_rate = 10000;
-	key = se_new(gint);
+	key = wmem_new(wmem_file_scope(), gint);
 	*key = 97;
 	g_hash_table_insert( rtp_dyn_payload, key, encoding_name_and_rate );
         rtp_add_address( pinfo, &pinfo->src, pinfo->srcport, 0, APPLEMIDI_DISSECTOR_SHORTNAME,
