@@ -2,7 +2,7 @@
  * Routines for AppleTalk packet disassembly: LLAP, DDP, NBP, ATP, ASP,
  * RTMP, PAP.
  *
- * $Id$
+ * $Id: packet-atalk.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Simon Wilkinson <sxw@dcs.ed.ac.uk>
  *
@@ -40,7 +40,7 @@
 
 #include <epan/prefs.h>
 #include <epan/reassemble.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 
 #include "packet-atalk.h"
 #include "packet-afp.h"
@@ -572,7 +572,7 @@ static int dissect_pascal_string(tvbuff_t *tvb, int offset, proto_tree *tree,
      * code, we could perhaps avoid allocating and freeing
      * this string buffer.
      */
-    tmp  = (gchar*)tvb_get_ephemeral_string(tvb, offset, len);
+    tmp  = (gchar*)tvb_get_string(wmem_packet_scope(), tvb, offset, len);
     item = proto_tree_add_string(tree, hf_index, tvb, offset-1, len+1, tmp);
 
     subtree = proto_item_add_subtree(item, ett_pstring);
@@ -820,10 +820,10 @@ dissect_atp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
          we have both a request for 1 packet and a request for n packets,
          hopefully most of the time ATP_EOM will be set in the last packet.
       */
-      new_request_key = se_new(asp_request_key);
+      new_request_key = wmem_new(wmem_file_scope(), asp_request_key);
       *new_request_key = request_key;
 
-      request_val = se_new(asp_request_val);
+      request_val = wmem_new(wmem_file_scope(), asp_request_val);
       request_val->value = nbe;
 
       g_hash_table_insert(atp_request_hash, new_request_key,request_val);
@@ -888,7 +888,7 @@ dissect_atp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
      move asp back in atp?
   */
   if (atp_defragment && aspinfo.reply && (more_fragment || frag_number != 0)) {
-    fragment_data *fd_head;
+    fragment_head *fd_head;
     int hdr;
 
     hdr = ATP_HDRSIZE -1;
@@ -1057,9 +1057,8 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
   if (machine_ofs)
     proto_tree_add_item(tree, hf_asp_server_type, tvb, machine_ofs, 1, ENC_ASCII|ENC_NA);
 
-  ofs = tvb_get_ntohs(tvb, offset +AFPSTATUS_VERSOFF);
+  ofs = offset +tvb_get_ntohs(tvb, offset +AFPSTATUS_VERSOFF);
   if (ofs) {
-    ofs += offset;
     nbe = tvb_get_guint8(tvb, ofs);
     ti = proto_tree_add_text(tree, tvb, ofs, 1, "Version list: %u", nbe);
     ofs++;
@@ -1071,9 +1070,8 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
     }
   }
 
-  ofs = tvb_get_ntohs(tvb, offset +AFPSTATUS_UAMSOFF);
+  ofs = offset +tvb_get_ntohs(tvb, offset +AFPSTATUS_UAMSOFF);
   if (ofs) {
-    ofs += offset;
     nbe = tvb_get_guint8(tvb, ofs);
     ti = proto_tree_add_text(tree, tvb, ofs, 1, "UAMS list: %u", nbe);
     ofs++;
@@ -1085,11 +1083,9 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
     }
   }
 
-  ofs = tvb_get_ntohs(tvb, offset +AFPSTATUS_ICONOFF);
-  if (ofs) {
-    ofs += offset;
+  ofs = offset +tvb_get_ntohs(tvb, offset +AFPSTATUS_ICONOFF);
+  if (ofs)
     proto_tree_add_item(tree, hf_asp_server_icon, tvb, ofs, 256, ENC_NA);
-  }
 
   if (sign_ofs) {
     proto_tree_add_item(tree, hf_asp_server_signature, tvb, sign_ofs, 16, ENC_NA);
@@ -1130,7 +1126,7 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
         break;
       case 4: /* DNS */
         if (len > 2) {
-          tmp = (gchar*)tvb_get_ephemeral_string(tvb, ofs +2, len -2);
+          tmp = (gchar*)tvb_get_string(wmem_packet_scope(), tvb, ofs +2, len -2);
           ti = proto_tree_add_text(adr_tree, tvb, ofs, len, "dns %s", tmp);
           break;
         }
@@ -1166,7 +1162,7 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
 
     ofs = utf_ofs;
     ulen = tvb_get_ntohs(tvb, ofs);
-    tmp = (gchar*)tvb_get_ephemeral_string(tvb, ofs + 2, ulen);
+    tmp = (gchar*)tvb_get_string(wmem_packet_scope(), tvb, ofs + 2, ulen);
     ti = proto_tree_add_text(tree, tvb, ofs, ulen +2, "UTF8 server name: %s", tmp);
     sub_tree = proto_item_add_subtree(ti, ett_asp_utf8_name);
     proto_tree_add_uint(sub_tree, hf_asp_server_utf8_name_len, tvb, ofs, 2, ulen);
@@ -1297,10 +1293,10 @@ get_transaction(tvbuff_t *tvb, packet_info *pinfo)
   request_val = (asp_request_val *) g_hash_table_lookup(asp_request_hash, &request_key);
   if (!request_val && !aspinfo->reply )  {
     fn = tvb_get_guint8(tvb, 0);
-    new_request_key = se_new(asp_request_key);
+    new_request_key = wmem_new(wmem_file_scope(), asp_request_key);
     *new_request_key = request_key;
 
-    request_val = se_new(asp_request_val);
+    request_val = wmem_new(wmem_file_scope(), asp_request_val);
     request_val->value = fn;
 
     g_hash_table_insert(asp_request_hash, new_request_key, request_val);
@@ -2449,7 +2445,7 @@ proto_reg_handoff_atalk(void)
 
   ddp_handle = create_dissector_handle(dissect_ddp, proto_ddp);
   dissector_add_uint("ethertype", ETHERTYPE_ATALK, ddp_handle);
-  dissector_add_uint("chdlctype", ETHERTYPE_ATALK, ddp_handle);
+  dissector_add_uint("chdlc.protocol", ETHERTYPE_ATALK, ddp_handle);
   dissector_add_uint("ppp.protocol", PPP_AT, ddp_handle);
   dissector_add_uint("null.type", BSD_AF_APPLETALK, ddp_handle);
   dissector_add_uint("arcnet.protocol_id", ARCNET_PROTO_APPLETALK, ddp_handle);
