@@ -1,7 +1,7 @@
 /* packet-atm.c
  * Routines for ATM packet disassembly
  *
- * $Id$
+ * $Id: packet-atm.c 51159 2013-08-05 19:09:44Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -128,6 +128,9 @@ static gint ett_aal1 = -1;
 static gint ett_aal3_4 = -1;
 static gint ett_oamaal = -1;
 
+static dissector_handle_t atm_handle;
+static dissector_handle_t atm_untruncated_handle;
+
 static dissector_handle_t eth_withoutfcs_handle;
 static dissector_handle_t tr_handle;
 static dissector_handle_t fr_handle;
@@ -1143,17 +1146,16 @@ dissect_reassembled_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
             guint8 octet[8];
             tvb_memcpy(next_tvb, octet, 0, sizeof(octet));
 
+            decoded = TRUE;
             if (octet[0] == 0xaa
              && octet[1] == 0xaa
              && octet[2] == 0x03) /* LLC SNAP as per RFC2684 */
             {
                 call_dissector(llc_handle, next_tvb, pinfo, tree);
-                decoded = TRUE;
             }
             else if ((pntohs(octet) & 0xff) == PPP_IP)
             {
                 call_dissector(ppp_handle, next_tvb, pinfo, tree);
-                decoded = TRUE;
             }
             else if (pntohs(octet) == 0x00)
             {
@@ -1161,7 +1163,6 @@ dissect_reassembled_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
                 proto_tree_add_text(tree, tvb, 0, 2, "Pad: 0x0000");
                 next_tvb = tvb_new_subset_remaining(tvb, 2);
                 call_dissector(eth_handle, next_tvb, pinfo, tree);
-                decoded = TRUE;
             }
             else if (octet[2] == 0x03    && /* NLPID */
                     ((octet[3] == 0xcc   || /* IPv4  */
@@ -1171,7 +1172,6 @@ dissect_reassembled_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
             {
                 /* assume network interworking with FR 2 byte header */
                 call_dissector(fr_handle, next_tvb, pinfo, tree);
-                decoded = TRUE;
             }
             else if (octet[4] == 0x03    && /* NLPID */
                     ((octet[5] == 0xcc   || /* IPv4  */
@@ -1181,14 +1181,21 @@ dissect_reassembled_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
             {
                 /* assume network interworking with FR 4 byte header */
                 call_dissector(fr_handle, next_tvb, pinfo, tree);
-                decoded = TRUE;
             }
             else if (((octet[0] & 0xf0)== 0x40) ||
                      ((octet[0] & 0xf0) == 0x60))
             {
                 call_dissector(ip_handle, next_tvb, pinfo, tree);
-                decoded = TRUE;
             }
+            else
+            {
+                decoded = FALSE;
+            }
+        }
+
+        if (tree && !decoded) {
+            /* Dump it as raw data. */
+            call_dissector(data_handle, next_tvb, pinfo, tree);
         }
       }
       break;
@@ -2144,8 +2151,8 @@ proto_register_atm(void)
                                            "ATM LANE", "lane");
 
   register_dissector("lane", dissect_lane, proto_atm_lane);
-  register_dissector("atm_untruncated", dissect_atm_untruncated, proto_atm);
-  register_dissector("atm_truncated", dissect_atm, proto_atm);
+  atm_handle = register_dissector("atm_truncated", dissect_atm, proto_atm);
+  atm_untruncated_handle = register_dissector("atm_untruncated", dissect_atm_untruncated, proto_atm);
   register_dissector("atm_oam_cell", dissect_atm_oam_cell, proto_oamaal);
 
   atm_module = prefs_register_protocol ( proto_atm, NULL );
@@ -2162,8 +2169,6 @@ proto_register_atm(void)
 void
 proto_reg_handoff_atm(void)
 {
-  dissector_handle_t atm_handle, atm_untruncated_handle;
-
   /*
    * Get handles for the Ethernet, Token Ring, Frame Relay, LLC,
    * SSCOP, LANE, and ILMI dissectors.
@@ -2182,11 +2187,8 @@ proto_reg_handoff_atm(void)
   fp_handle             = find_dissector("fp");
   gprs_ns_handle        = find_dissector("gprs_ns");
 
-  atm_handle = create_dissector_handle(dissect_atm, proto_atm);
   dissector_add_uint("wtap_encap", WTAP_ENCAP_ATM_PDUS, atm_handle);
 
-  atm_untruncated_handle = create_dissector_handle(dissect_atm_untruncated,
-                                                   proto_atm);
   dissector_add_uint("wtap_encap", WTAP_ENCAP_ATM_PDUS_UNTRUNCATED,
                 atm_untruncated_handle);
 }
