@@ -2,7 +2,7 @@
  * Routines for Babel dissection (RFC 6126)
  * Copyright 2011 by Juliusz Chroboczek <jch@pps.jussieu.fr>
  *
- * $Id$
+ * $Id: packet-babel.c 51991 2013-09-12 22:03:31Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,6 +28,7 @@
 #include <glib.h>
 
 #include <epan/packet.h>
+#include <epan/wmem/wmem.h>
 
 void proto_register_babel(void);
 void proto_reg_handoff_babel(void);
@@ -119,7 +120,7 @@ format_address(const unsigned char *prefix)
 static const char *
 format_prefix(const unsigned char *prefix, unsigned char plen)
 {
-    return ep_strdup_printf("%s/%u", format_address(prefix), plen);
+    return wmem_strdup_printf(wmem_packet_scope(), "%s/%u", format_address(prefix), plen);
 }
 
 static int
