@@ -1,7 +1,7 @@
 /* packet-beep.c
  * Routines for BEEP packet disassembly
  *
- * $Id$
+ * $Id: packet-beep.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Copyright (c) 2000 by Richard Sharpe <rsharpe@ns.aus.com>
  * Modified 2001 Darren New <dnew@invisible.net> for BEEP.
@@ -31,12 +31,13 @@
 #include "config.h"
 
 #include <stdio.h>
+#include <ctype.h>
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/addr_resolv.h>
 #include <epan/prefs.h>
 #include <epan/conversation.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/expert.h>
 
 #define TCP_PORT_BEEP 10288
@@ -113,6 +114,11 @@ static int ett_mime_header = -1;
 static int ett_header = -1;
 static int ett_trailer = -1;
 
+static expert_field ei_beep_more = EI_INIT;
+static expert_field ei_beep_cr_terminator = EI_INIT;
+static expert_field ei_beep_lf_terminator = EI_INIT;
+static expert_field ei_beep_invalid_terminator = EI_INIT;
+
 /* Get the state of the more flag ... */
 
 #define BEEP_VIOL         0
@@ -228,7 +234,7 @@ dissect_beep_more(tvbuff_t *tvb, packet_info *pinfo, int offset,
      ret = 1;
      break;
   default:
-    expert_add_info_format(pinfo, hidden_item, PI_PROTOCOL, PI_WARN, "Expected More Flag (* or .)");
+    expert_add_info(pinfo, hidden_item, &ei_beep_more);
     ret = -1;
     break;
   }
@@ -251,7 +257,7 @@ static int num_len(tvbuff_t *tvb, int offset)
 {
   unsigned int i = 0;
 
-  while (g_ascii_isdigit(tvb_get_guint8(tvb, offset + i))) i++;
+  while (isdigit(tvb_get_guint8(tvb, offset + i))) i++;
 
   return i;
 
@@ -267,8 +273,6 @@ static int num_len(tvbuff_t *tvb, int offset)
 static int
 check_term(tvbuff_t *tvb, packet_info *pinfo, int offset, proto_tree *tree)
 {
-  proto_item  *ti;
-
   /* First, check for CRLF, or, if global_beep_strict_term is false,
    * one of CR or LF ... If neither of these hold, we add an element
    * that complains of a protocol violation, and return -1, else
@@ -287,21 +291,19 @@ check_term(tvbuff_t *tvb, packet_info *pinfo, int offset, proto_tree *tree)
 
   if ((tvb_get_guint8(tvb, offset) == 0x0d) && !global_beep_strict_term) {
 
-    ti = proto_tree_add_text(tree, tvb, offset, 1, "Terminator: CR");
-    expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN, "Nonstandard Terminator: CR");
+    proto_tree_add_expert(tree, pinfo, &ei_beep_cr_terminator, tvb, offset, 1);
     return 1;
 
   }
-  
+
   if ((tvb_get_guint8(tvb, offset) == 0x0a) && !global_beep_strict_term) {
 
-    ti = proto_tree_add_text(tree, tvb, offset, 1, "Terminator: LF");
-    expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN, "Nonstandard Terminator: LF");
+    proto_tree_add_expert(tree, pinfo, &ei_beep_lf_terminator, tvb, offset, 1);
     return 1;
   }
 
-  ti = proto_tree_add_text(tree, tvb, offset, 1, "Terminator: %s", tvb_format_text(tvb, offset, 2));
-  expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN, "Invalid Terminator: %s", tvb_format_text(tvb, offset, 2));
+  proto_tree_add_expert_format(tree, pinfo, &ei_beep_invalid_terminator, tvb,
+                                offset, 1, "Terminator: %s", tvb_format_text(tvb, offset, 2));
   return -1;
 }
 
@@ -530,7 +532,7 @@ dissect_beep_tree(tvbuff_t *tvb, int offset, packet_info *pinfo,
     }
     else {  /* Protocol violation, so dissect rest as undisectable */
       if (tree && (tvb_length_remaining(tvb, offset) > 0)) {
-        proto_tree_add_item(tree, hf_beep_payload_undissected, tvb, offset, 
+        proto_tree_add_item(tree, hf_beep_payload_undissected, tvb, offset,
                             tvb_length_remaining(tvb, offset), ENC_NA|ENC_ASCII);
       }
       return -1;
@@ -562,7 +564,7 @@ dissect_beep_tree(tvbuff_t *tvb, int offset, packet_info *pinfo,
       /* We dissect the rest as data and bail ... */
 
       if (tree && (tvb_length_remaining(tvb, offset) > 0)) {
-        proto_tree_add_item(tree, hf_beep_payload_undissected, tvb, offset, 
+        proto_tree_add_item(tree, hf_beep_payload_undissected, tvb, offset,
                             tvb_length_remaining(tvb, offset), ENC_NA|ENC_ASCII);
       }
 
@@ -644,7 +646,7 @@ dissect_beep_tree(tvbuff_t *tvb, int offset, packet_info *pinfo,
       /* We dissect the rest as data and bail ... */
 
       if (tree && (tvb_length_remaining(tvb, offset) > 0)) {
-        proto_tree_add_item(tree, hf_beep_payload_undissected, tvb, offset, 
+        proto_tree_add_item(tree, hf_beep_payload_undissected, tvb, offset,
                             tvb_length_remaining(tvb, offset), ENC_NA|ENC_ASCII);
       }
 
@@ -673,7 +675,7 @@ dissect_beep_tree(tvbuff_t *tvb, int offset, packet_info *pinfo,
       /* We dissect the rest as data and bail ... */
 
       if (tree && (tvb_length_remaining(tvb, offset) > 0)) {
-        proto_tree_add_item(tree, hf_beep_payload_undissected, tvb, offset, 
+        proto_tree_add_item(tree, hf_beep_payload_undissected, tvb, offset,
                             tvb_length_remaining(tvb, offset), ENC_NA|ENC_ASCII);
       }
 
@@ -793,10 +795,10 @@ dissect_beep(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
       if (!request_val) { /* Create one */
 
-        new_request_key = (struct beep_request_key *)se_alloc(sizeof(struct beep_request_key));
+        new_request_key = wmem_new(wmem_file_scope(), struct beep_request_key);
         new_request_key->conversation = conversation->index;
 
-        request_val = (struct beep_request_val *)se_alloc(sizeof(struct beep_request_val));
+        request_val = wmem_new(wmem_file_scope(), struct beep_request_val);
         request_val->processed = 0;
         request_val->size = 0;
 
@@ -866,7 +868,7 @@ dissect_beep(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
      * elsewhere for other frames
      */
 
-    beep_frame_data = se_new(struct beep_proto_data);
+    beep_frame_data = wmem_new(wmem_file_scope(), struct beep_proto_data);
 
     beep_frame_data->pl_left = pl_left;
     beep_frame_data->pl_size = 0;
@@ -882,7 +884,7 @@ dissect_beep(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   if (beep_frame_data == NULL) {
 
-    beep_frame_data = (struct beep_proto_data *)se_alloc(sizeof(struct beep_proto_data));
+    beep_frame_data = wmem_new(wmem_file_scope(), struct beep_proto_data);
 
     beep_frame_data->pl_left = 0;
     beep_frame_data->pl_size = 0;
@@ -894,7 +896,7 @@ dissect_beep(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   if (tvb_length_remaining(tvb, offset) > 0) {
 
-    offset += dissect_beep_tree(tvb, offset, pinfo, beep_tree, request_val, beep_frame_data);
+    /*offset += */dissect_beep_tree(tvb, offset, pinfo, beep_tree, request_val, beep_frame_data);
 
   }
 
@@ -973,13 +975,23 @@ proto_register_beep(void)
     &ett_header,
     &ett_trailer,
   };
+  static ei_register_info ei[] = {
+     { &ei_beep_more, { "beep.more.expected", PI_PROTOCOL, PI_WARN, "Expected More Flag (* or .)", EXPFILL }},
+     { &ei_beep_cr_terminator, { "beep.cr_terminator", PI_PROTOCOL, PI_WARN, "Nonstandard Terminator: CR", EXPFILL }},
+     { &ei_beep_lf_terminator, { "beep.lf_terminator", PI_PROTOCOL, PI_WARN, "Nonstandard Terminator: LF", EXPFILL }},
+     { &ei_beep_invalid_terminator, { "beep.invalid_terminator", PI_PROTOCOL, PI_WARN, "Invalid Terminator", EXPFILL }},
+  };
+
   module_t *beep_module;
+  expert_module_t* expert_beep;
 
   proto_beep = proto_register_protocol("Blocks Extensible Exchange Protocol",
                                        "BEEP", "beep");
 
   proto_register_field_array(proto_beep, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
+  expert_beep = expert_register_protocol(proto_beep);
+  expert_register_field_array(expert_beep, ei, array_length(ei));
   register_init_routine(&beep_init_protocol);
 
   /* Register our configuration options for BEEP, particularly our port */
