@@ -3,7 +3,7 @@
  *
  * Copyright 2009, Stig Bjorlykke <stig@bjorlykke.org>
  *
- * $Id$
+ * $Id: packet-bjnp.c 52478 2013-10-09 20:31:23Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,7 +26,10 @@
 
 #include "config.h"
 
+#include <ctype.h>
+
 #include <epan/packet.h>
+#include <epan/wmem/wmem.h>
 
 #define PNAME  "Canon BJNP"
 #define PSNAME "BJNP"
@@ -67,6 +70,8 @@ static int hf_payload = -1;
 
 static gint ett_bjnp = -1;
 
+static dissector_handle_t bjnp_handle;
+
 static const value_string dev_type_vals[] = {
   { PRINTER_COMMAND,    "Printer Command"       },
   { SCANNER_COMMAND,    "Scanner Command"       },
@@ -95,6 +100,10 @@ static int dissect_bjnp (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, vo
   guint8      dev_type, cmd_code;
   gchar      *info;
 
+  /* If it does not start with a printable character it's not BJNP */
+  if(!isprint(tvb_get_guint8(tvb, 0)))
+    return 0;
+
   col_set_str (pinfo->cinfo, COL_PROTOCOL, PSNAME);
   col_clear (pinfo->cinfo, COL_INFO);
 
@@ -112,8 +121,9 @@ static int dissect_bjnp (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, vo
   proto_tree_add_item (bjnp_tree, hf_cmd_code, tvb, offset, 1, ENC_BIG_ENDIAN);
   offset++;
 
-  info = ep_strdup_printf("%s: %s",val_to_str (dev_type, dev_type_vals, "Unknown type (%d)"),
-                          val_to_str (cmd_code, cmd_code_vals, "Unknown code (%d)"));
+  info = wmem_strdup_printf(wmem_packet_scope(), "%s: %s",
+                            val_to_str (dev_type, dev_type_vals, "Unknown type (%d)"),
+                            val_to_str (cmd_code, cmd_code_vals, "Unknown code (%d)"));
 
   proto_item_append_text (ti, ", %s", info);
   col_add_str (pinfo->cinfo, COL_INFO, info);
@@ -167,7 +177,8 @@ void proto_register_bjnp (void)
   };
 
   proto_bjnp = proto_register_protocol (PNAME, PSNAME, PFNAME);
-  new_register_dissector (PFNAME, dissect_bjnp, proto_bjnp);
+
+  bjnp_handle = new_register_dissector (PFNAME, dissect_bjnp, proto_bjnp);
 
   proto_register_field_array (proto_bjnp, hf, array_length (hf));
   proto_register_subtree_array (ett, array_length (ett));
@@ -175,9 +186,6 @@ void proto_register_bjnp (void)
 
 void proto_reg_handoff_bjnp (void)
 {
-  dissector_handle_t bjnp_handle;
-
-  bjnp_handle = find_dissector (PFNAME);
   dissector_add_uint ("udp.port", BJNP_PORT1, bjnp_handle);
   dissector_add_uint ("udp.port", BJNP_PORT2, bjnp_handle);
   dissector_add_uint ("udp.port", BJNP_PORT3, bjnp_handle);
