@@ -1,6 +1,6 @@
 /* packet-brp.c
  *
- * $Id$
+ * $Id: packet-brp.c 51159 2013-08-05 19:09:44Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -44,6 +44,8 @@ void proto_reg_handoff_brp(void);
 /* Wireshark ID of the BRP protocol */
 static int proto_brp = -1;
 
+static dissector_handle_t brp_handle;
+
 /*static int global_brp_port = 1958; *//* The port is registered for another protocol */
 
 static const value_string brp_packettype_names[] = {
@@ -126,6 +128,8 @@ static gint ett_brp_flid = -1;
 static gint ett_brp_rmttl = -1;
 static gint ett_brp_fltype = -1;
 
+static expert_field ei_brp_type_unknown = EI_INIT;
+
 /* Preferences */
 static guint global_brp_port = 0;
 
@@ -142,12 +146,10 @@ dissect_brp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
     /* If there is a "tree" requested, we handle that request. */
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, PROTO_TAG_BRP);
-    if(check_col(pinfo->cinfo,COL_INFO)){
-        /* We add some snazzy bizness to the info field to quickly ascertain
-           what type of message was sent to/from the BRS/BRC. */
-        col_add_fstr(pinfo->cinfo, COL_INFO, "Message Type - %s",
-             val_to_str(packet_type, brp_packettype_names, "Unknown (0x%02x)"));
-    }
+    /* We add some snazzy bizness to the info field to quickly ascertain
+        what type of message was sent to/from the BRS/BRC. */
+    col_add_fstr(pinfo->cinfo, COL_INFO, "Message Type - %s",
+            val_to_str(packet_type, brp_packettype_names, "Unknown (0x%02x)"));
 
     /* This call adds our tree to the main dissection tree. */
 
@@ -314,7 +316,7 @@ dissect_brp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 
         default:
             /* Invalid type */
-            expert_add_info_format(pinfo, brp_item, PI_UNDECODED, PI_WARN, "Unknown packet type");
+            expert_add_info(pinfo, brp_item, &ei_brp_type_unknown);
             break;
         }
 
@@ -326,6 +328,7 @@ return offset;
 void proto_register_brp (void)
 {
     module_t *brp_module;
+    expert_module_t* expert_brp;
 
     /* A data field is something you can search/filter on.
     *
@@ -391,9 +394,16 @@ void proto_register_brp (void)
         &ett_brp_rmttl
 
     };
+
+    static ei_register_info ei[] = {
+        { &ei_brp_type_unknown, { "brp.type.unknown", PI_UNDECODED, PI_WARN, "Unknown packet type", EXPFILL }},
+    };
+
     proto_brp = proto_register_protocol ("BRP Protocol", "BRP", "brp");
     proto_register_field_array (proto_brp, hf, array_length (hf));
     proto_register_subtree_array (ett, array_length (ett));
+    expert_brp = expert_register_protocol(proto_brp);
+    expert_register_field_array(expert_brp, ei, array_length(ei));
 
     /* Register preferences module */
     brp_module = prefs_register_protocol(proto_brp, proto_reg_handoff_brp);
@@ -404,18 +414,16 @@ void proto_register_brp (void)
                                    "Set the UDP port for BRP messages",
                                    10, &global_brp_port);
 
-    new_register_dissector("brp", dissect_brp, proto_brp);
+    brp_handle = new_register_dissector("brp", dissect_brp, proto_brp);
 }
 
 /*--- proto_reg_handoff_brp -------------------------------------------*/
 void proto_reg_handoff_brp(void)
 {
     static gboolean           initialized = FALSE;
-    static dissector_handle_t brp_handle;
     static guint              saved_brp_port;
 
     if (!initialized) {
-        brp_handle = new_create_dissector_handle(dissect_brp, proto_brp);
         dissector_add_handle("udp.port", brp_handle);
         initialized = TRUE;
     } else {
