@@ -3,7 +3,7 @@
  * Routines for BT-DHT dissection
  * Copyright 2011, Xiao Xiangquan <xiaoxiangquan@gmail.com>
  *
- * $Id$
+ * $Id: packet-bt-dht.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * A plugin for BT-DHT packet:
  *
@@ -31,6 +31,7 @@
 #include <epan/packet.h>
 #include <epan/conversation.h>
 #include <epan/prefs.h>
+#include <epan/wmem/wmem.h>
 
 /* Specifications: BEP-0005
  * http://www.bittorrent.org/beps/bep_0005.html
@@ -103,7 +104,7 @@ bencoded_string_length(tvbuff_t *tvb, guint *offset_ptr)
   while(tvb_get_guint8(tvb, offset) != ':')
     ++offset;
 
-  len = atoi(tvb_get_ephemeral_string(tvb, start, offset-start));
+  len = atoi(tvb_get_string(wmem_packet_scope(), tvb, start, offset-start));
   ++offset; /* skip the ':' */
 
   *offset_ptr = offset;
@@ -126,7 +127,7 @@ dissect_bencoded_string(tvbuff_t *tvb, packet_info _U_*pinfo, proto_tree *tree,
   if( tohex )
     *result = tvb_bytes_to_str(tvb, offset, string_len );
   else
-    *result = tvb_get_ephemeral_string( tvb, offset, string_len );
+    *result = tvb_get_string( wmem_packet_scope(), tvb, offset, string_len );
 
   proto_tree_add_string_format( tree, hf_bencoded_string, tvb, offset, string_len, *result, "%s: %s", label, *result );
   offset += string_len;
@@ -142,16 +143,15 @@ dissect_bencoded_int(tvbuff_t *tvb, packet_info _U_*pinfo, proto_tree *tree, gui
 {
   guint start_offset;
 
-  start_offset = offset;
-
   /* we have confirmed that the first byte is 'i' */
   offset += 1;
+  start_offset = offset;
 
   while( tvb_get_guint8(tvb,offset)!='e' )
     offset += 1;
 
-  *result = tvb_get_ephemeral_string( tvb, offset, offset-start_offset-1 );
-  proto_tree_add_string_format( tree, hf_bencoded_int, tvb, offset, offset-start_offset-1, *result,
+  *result = tvb_get_string( wmem_packet_scope(), tvb, start_offset, offset-start_offset);
+  proto_tree_add_string_format( tree, hf_bencoded_int, tvb, start_offset, offset-start_offset, *result,
     "%s: %s", label, *result );
 
   offset += 1;
@@ -225,7 +225,7 @@ dissect_bt_dht_error(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint
 
   proto_item_set_text( ti, "%s: error %s, %s", label, error_no, error_msg );
   col_append_fstr( pinfo->cinfo, COL_INFO, "error_no=%s error_msg=%s ", error_no, error_msg );
-  *result = ep_strdup_printf("error %s, %s", error_no, error_msg );
+  *result = wmem_strdup_printf(wmem_packet_scope(), "error %s, %s", error_no, error_msg );
 
   return offset;
 }
@@ -282,7 +282,7 @@ dissect_bt_dht_values(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint
 
   proto_item_set_text( ti, "%s: %d peers", label, peer_index );
   col_append_fstr( pinfo->cinfo, COL_INFO, "reply=%d peers ", peer_index );
-  *result = ep_strdup_printf("%d peers", peer_index);
+  *result = wmem_strdup_printf(wmem_packet_scope(), "%d peers", peer_index);
 
   return offset;
 }
@@ -328,7 +328,7 @@ dissect_bt_dht_nodes(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint
   }
   proto_item_set_text( ti, "%s: %d nodes", label, node_index );
   col_append_fstr( pinfo->cinfo, COL_INFO, "reply=%d nodes ", node_index );
-  *result = ep_strdup_printf("%d", node_index);
+  *result = wmem_strdup_printf(wmem_packet_scope(), "%d", node_index);
 
   return offset;
 }
