@@ -3,7 +3,7 @@
  *
  * Copyright 2012, Allan M. Madsen <allan.m@madsen.dk>
  *
- * $Id$
+ * $Id: packet-btatt.c 51156 2013-08-05 18:09:43Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -62,6 +62,11 @@ static int hf_btatt_signature = -1;
 static gint ett_btatt = -1;
 static gint ett_btatt_list = -1;
 
+static expert_field ei_btatt_uuid_format_unknown = EI_INIT;
+static expert_field ei_btatt_handle_too_few = EI_INIT;
+
+static dissector_handle_t btatt_handle;
+
 /* Opcodes */
 static const value_string opcode_vals[] = {
     {0x01, "Error Response"},
@@ -250,8 +255,8 @@ static const value_string flags_vals[] = {
 void proto_register_btatt(void);
 void proto_reg_handoff_btatt(void);
 
-static void
-dissect_btatt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+static int
+dissect_btatt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
     int offset = 0;
     proto_item *ti, *item;
@@ -274,7 +279,7 @@ dissect_btatt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     }
 
     if (tvb_length_remaining(tvb, 0) < 1)
-        return;
+        return FALSE;
 
     ti = proto_tree_add_item(tree, proto_btatt, tvb, 0, -1, ENC_NA);
     st = proto_item_add_subtree(ti, ett_btatt);
@@ -343,7 +348,7 @@ dissect_btatt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 }
             }
             else {
-                expert_add_info_format(pinfo, item, PI_PROTOCOL, PI_WARN, "Unknown format");
+                expert_add_info(pinfo, item, &ei_btatt_uuid_format_unknown);
             }
         }
         break;
@@ -352,15 +357,15 @@ dissect_btatt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         col_append_fstr(pinfo->cinfo, COL_INFO, ", %s, Handles: 0x%04x..0x%04x",
                             val_to_str_ext_const(tvb_get_letohs(tvb, offset+4), &uuid_vals_ext, "<unknown>"),
                             tvb_get_letohs(tvb, offset), tvb_get_letohs(tvb, offset+2));
-        
+
         proto_tree_add_item(st, hf_btatt_starting_handle, tvb, offset, 2, ENC_LITTLE_ENDIAN);
         offset += 2;
         proto_tree_add_item(st, hf_btatt_ending_handle, tvb, offset, 2, ENC_LITTLE_ENDIAN);
         offset += 2;
         proto_tree_add_item(st, hf_btatt_uuid16, tvb, offset, 2, ENC_LITTLE_ENDIAN);
         offset += 2;
-        proto_tree_add_item(st, hf_btatt_value, tvb, offset, -1, ENC_NA);
-        offset = tvb_reported_length(tvb);
+        if( tvb_length_remaining(tvb, offset)  > 0)
+            proto_tree_add_item(st, hf_btatt_value, tvb, offset, -1, ENC_NA);
         break;
 
     case 0x07: /* Find By Type Value Response */
@@ -370,7 +375,7 @@ dissect_btatt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                                             tvb_get_letohs(tvb, offset), tvb_get_letohs(tvb, offset+2));
 
             ltree = proto_item_add_subtree(item, ett_btatt_list);
-            
+
             proto_tree_add_item(ltree, hf_btatt_handle, tvb, offset, 2, ENC_LITTLE_ENDIAN);
             offset += 2;
             proto_tree_add_item(ltree, hf_btatt_group_end_handle, tvb, offset, 2, ENC_LITTLE_ENDIAN);
@@ -383,12 +388,12 @@ dissect_btatt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         col_append_fstr(pinfo->cinfo, COL_INFO, ", %s, Handles: 0x%04x..0x%04x",
                             val_to_str_ext_const(tvb_get_letohs(tvb, offset+4), &uuid_vals_ext, "<unknown>"),
                             tvb_get_letohs(tvb, offset), tvb_get_letohs(tvb, offset+2));
-        
+
         proto_tree_add_item(st, hf_btatt_starting_handle, tvb, offset, 2, ENC_LITTLE_ENDIAN);
         offset += 2;
         proto_tree_add_item(st, hf_btatt_ending_handle, tvb, offset, 2, ENC_LITTLE_ENDIAN);
         offset += 2;
-        
+
         if (tvb_length_remaining(tvb, offset) == 2) {
             proto_tree_add_item(st, hf_btatt_uuid16, tvb, offset, 2, ENC_LITTLE_ENDIAN);
             offset += 2;
@@ -418,7 +423,7 @@ dissect_btatt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                                                     tvb_get_letohs(tvb, offset));
 
                     ltree = proto_item_add_subtree(item, ett_btatt_list);
-                    
+
                     proto_tree_add_item(ltree, hf_btatt_handle, tvb, offset, 2, ENC_LITTLE_ENDIAN);
                     offset += 2;
                     proto_tree_add_item(ltree, hf_btatt_value, tvb, offset, length - 2, ENC_NA);
@@ -438,7 +443,6 @@ dissect_btatt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     case 0x0d: /* Read Blob Response */
     case 0x0f: /* Multiple Read Response */
         proto_tree_add_item(st, hf_btatt_value, tvb, offset, -1, ENC_NA);
-        offset = tvb_reported_length(tvb);
         break;
 
     case 0x0c: /* Read Blob Request */
@@ -452,11 +456,10 @@ dissect_btatt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     case 0x0e: /* Multiple Read Request */
         if(tvb_length_remaining(tvb, offset) < 4) {
-            expert_add_info_format(pinfo, item, PI_PROTOCOL, PI_WARN,
-                                                    "Too few handles, should be 2 or more");
+            expert_add_info(pinfo, item, &ei_btatt_handle_too_few);
             break;
         }
-        
+
         col_append_str(pinfo->cinfo, COL_INFO, ", Handles: ");
         while (tvb_length_remaining(tvb, offset) >= 2) {
             proto_tree_add_item(st, hf_btatt_handle, tvb, offset, 2, ENC_LITTLE_ENDIAN);
@@ -474,14 +477,14 @@ dissect_btatt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
             if(length > 0) {
                 col_append_fstr(pinfo->cinfo, COL_INFO, ", Attribute List Length: %u", tvb_length_remaining(tvb, offset)/length);
-            
+
                 while (tvb_length_remaining(tvb, offset) >= length) {
                     item = proto_tree_add_text(st, tvb, offset, length,
                                                     "Attribute Data, Handle: 0x%04x, Group End Handle: 0x%04x",
                                                     tvb_get_letohs(tvb, offset), tvb_get_letohs(tvb, offset+2));
 
                     ltree = proto_item_add_subtree(item, ett_btatt_list);
-                
+
                     proto_tree_add_item(ltree, hf_btatt_handle, tvb, offset, 2, ENC_LITTLE_ENDIAN);
                     offset += 2;
                     proto_tree_add_item(ltree, hf_btatt_group_end_handle, tvb, offset, 2, ENC_LITTLE_ENDIAN);
@@ -501,7 +504,6 @@ dissect_btatt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         proto_tree_add_item(st, hf_btatt_handle, tvb, offset, 2, ENC_LITTLE_ENDIAN);
         offset += 2;
         proto_tree_add_item(st, hf_btatt_value, tvb, offset, -1, ENC_NA);
-        offset = tvb_reported_length(tvb);
         break;
 
     case 0x16: /* Prepare Write Request */
@@ -513,7 +515,6 @@ dissect_btatt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         proto_tree_add_item(st, hf_btatt_offset, tvb, offset, 2, ENC_LITTLE_ENDIAN);
         offset += 2;
         proto_tree_add_item(st, hf_btatt_value, tvb, offset, -1, ENC_NA);
-        offset = tvb_reported_length(tvb);
         break;
 
     case 0x18: /* Execute Write Request */
@@ -545,107 +546,108 @@ dissect_btatt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     default:
         break;
     }
+    return offset;
 }
 
 void
 proto_register_btatt(void)
 {
     module_t *module;
-    
+
     static hf_register_info hf[] = {
         {&hf_btatt_opcode,
             {"Opcode", "btatt.opcode",
-            FT_UINT8, BASE_HEX, VALS(opcode_vals), 0x0,          
+            FT_UINT8, BASE_HEX, VALS(opcode_vals), 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_handle,
             {"Handle", "btatt.handle",
-            FT_UINT16, BASE_HEX, NULL, 0x0,          
+            FT_UINT16, BASE_HEX, NULL, 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_starting_handle,
             {"Starting Handle", "btatt.starting_handle",
-            FT_UINT16, BASE_HEX, NULL, 0x0,          
+            FT_UINT16, BASE_HEX, NULL, 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_ending_handle,
             {"Ending Handle", "btatt.ending_handle",
-            FT_UINT16, BASE_HEX, NULL, 0x0,          
+            FT_UINT16, BASE_HEX, NULL, 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_group_end_handle,
             {"Group End Handle", "btatt.group_end_handle",
-            FT_UINT16, BASE_HEX, NULL, 0x0,          
+            FT_UINT16, BASE_HEX, NULL, 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_value,
             {"Value", "btatt.value",
-            FT_BYTES, BASE_NONE, NULL, 0x0,          
+            FT_BYTES, BASE_NONE, NULL, 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_req_opcode_in_error,
             {"Request Opcode in Error", "btatt.req_opcode_in_error",
-            FT_UINT8, BASE_HEX, VALS(opcode_vals), 0x0,          
+            FT_UINT8, BASE_HEX, VALS(opcode_vals), 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_handle_in_error,
             {"Handle in Error", "btatt.handle_in_error",
-            FT_UINT16, BASE_HEX, NULL, 0x0,          
+            FT_UINT16, BASE_HEX, NULL, 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_error_code,
             {"Error Code", "btatt.error_code",
-            FT_UINT8, BASE_HEX, VALS(error_vals), 0x0,          
+            FT_UINT8, BASE_HEX, VALS(error_vals), 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_uuid16,
             {"UUID", "btatt.uuid16",
-            FT_UINT16, BASE_HEX |BASE_EXT_STRING, &uuid_vals_ext, 0x0,          
+            FT_UINT16, BASE_HEX |BASE_EXT_STRING, &uuid_vals_ext, 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_uuid128,
             {"UUID", "btatt.uuid128",
-            FT_BYTES, BASE_NONE, NULL, 0x0,          
+            FT_BYTES, BASE_NONE, NULL, 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_client_rx_mtu,
             {"Client Rx MTU", "btatt.client_rx_mtu",
-            FT_UINT16, BASE_DEC, NULL, 0x0,          
+            FT_UINT16, BASE_DEC, NULL, 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_server_rx_mtu,
             {"Server Rx MTU", "btatt.server_rx_mtu",
-            FT_UINT16, BASE_DEC, NULL, 0x0,          
+            FT_UINT16, BASE_DEC, NULL, 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_uuid_format,
             {"UUID Format", "btatt.uuid_format",
-            FT_UINT8, BASE_HEX, VALS(uuid_format_vals), 0x0,          
+            FT_UINT8, BASE_HEX, VALS(uuid_format_vals), 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_length,
             {"Length", "btatt.length",
-            FT_UINT8, BASE_DEC, NULL, 0x0,          
+            FT_UINT8, BASE_DEC, NULL, 0x0,
             "Length of Handle/Value Pair", HFILL}
         },
         {&hf_btatt_offset,
             {"Offset", "btatt.offset",
-            FT_UINT16, BASE_DEC, NULL, 0x0,          
+            FT_UINT16, BASE_DEC, NULL, 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_flags,
             {"Flags", "btatt.flags",
-            FT_UINT8, BASE_HEX, VALS(flags_vals), 0x0,          
+            FT_UINT8, BASE_HEX, VALS(flags_vals), 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_sign_counter,
             {"Sign Counter", "btatt.sign_counter",
-            FT_UINT32, BASE_DEC, NULL, 0x0,          
+            FT_UINT32, BASE_DEC, NULL, 0x0,
             NULL, HFILL}
         },
         {&hf_btatt_signature,
             {"Signature", "btatt.signature",
-            FT_BYTES, BASE_NONE, NULL, 0x0,          
+            FT_BYTES, BASE_NONE, NULL, 0x0,
             NULL, HFILL}
         }
     };
@@ -656,14 +658,23 @@ proto_register_btatt(void)
         &ett_btatt_list
     };
 
+    static ei_register_info ei[] = {
+        { &ei_btatt_uuid_format_unknown, { "btatt.uuid_format.unknown", PI_PROTOCOL, PI_WARN, "Unknown format", EXPFILL }},
+        { &ei_btatt_handle_too_few, { "btatt.handle.too_few", PI_PROTOCOL, PI_WARN, "Too few handles, should be 2 or more", EXPFILL }},
+    };
+
+    expert_module_t* expert_btatt;
+
     /* Register the protocol name and description */
     proto_btatt = proto_register_protocol("Bluetooth Attribute Protocol", "BT ATT", "btatt");
 
-    register_dissector("btatt", dissect_btatt, proto_btatt);
+    btatt_handle = new_register_dissector("btatt", dissect_btatt, proto_btatt);
 
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_btatt, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_btatt = expert_register_protocol(proto_btatt);
+    expert_register_field_array(expert_btatt, ei, array_length(ei));
 
     module = prefs_register_protocol(proto_btatt, NULL);
     prefs_register_static_text_preference(module, "att.version",
@@ -674,9 +685,6 @@ proto_register_btatt(void)
 void
 proto_reg_handoff_btatt(void)
 {
-    dissector_handle_t btatt_handle;
-
-    btatt_handle = find_dissector("btatt");
     dissector_add_uint("btl2cap.psm", BTL2CAP_PSM_ATT, btatt_handle);
     dissector_add_uint("btl2cap.cid", BTL2CAP_FIXED_CID_ATT, btatt_handle);
 }
