@@ -3,7 +3,7 @@
  *
  * Copyright 2012, Michal Labedzki for Tieto Corporation
  *
- * $Id$
+ * $Id: packet-btavctp.c 51907 2013-09-09 22:30:40Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -52,6 +52,8 @@ static int hf_btavctp_number_of_packets         = -1;
 
 static gint ett_btavctp             = -1;
 
+static expert_field ei_btavctp_unexpected_frame = EI_INIT;
+
 static dissector_table_t avctp_service_dissector_table;
 
 static dissector_handle_t data_handle    = NULL;
@@ -69,10 +71,10 @@ typedef struct _fragments_t {
     guint32      count;
     guint32      number_of_packets;
     guint32      pid;
-    emem_tree_t  *fragment;
+    wmem_tree_t  *fragment;
 } fragments_t;
 
-static emem_tree_t *reassembling = NULL;
+static wmem_tree_t *reassembling = NULL;
 static fragments_t *fragments    = NULL;
 
 static const value_string packet_type_vals[] = {
@@ -189,7 +191,7 @@ dissect_btavctp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     } else {
         fragment_t     *fragment;
-        emem_tree_key_t key[6];
+        wmem_tree_key_t key[6];
         guint32         k_interface_id;
         guint32         k_adapter_id;
         guint32         k_chandle;
@@ -236,18 +238,18 @@ dissect_btavctp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 fragments->pid = pid;
 
                 fragments->count = 1;
-                fragments->fragment = se_tree_create(EMEM_TREE_TYPE_RED_BLACK, "btavctp fragments");
-                se_tree_insert32(fragments->fragment, fragments->count, fragment);
+                fragments->fragment = wmem_tree_new(wmem_file_scope());
+                wmem_tree_insert32(fragments->fragment, fragments->count, fragment);
 
                 fragments->interface_id = interface_id;
                 fragments->adapter_id   = adapter_id;
                 fragments->chandle      = chandle;
                 fragments->psm          = psm;
 
-                se_tree_insert32_array(reassembling, key, fragments);
+                wmem_tree_insert32_array(reassembling, key, fragments);
 
             } else {
-                fragments = (fragments_t *)se_tree_lookup32_array_le(reassembling, key);
+                fragments = (fragments_t *)wmem_tree_lookup32_array_le(reassembling, key);
                 if (!(fragments && fragments->interface_id == interface_id &&
                         fragments->adapter_id == adapter_id &&
                         fragments->chandle == chandle &&
@@ -258,7 +260,7 @@ dissect_btavctp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             call_dissector(data_handle, next_tvb, pinfo, tree);
 
         } else if (packet_type == PACKET_TYPE_CONTINUE) {
-            fragments = (fragments_t *)se_tree_lookup32_array_le(reassembling, key);
+            fragments = (fragments_t *)wmem_tree_lookup32_array_le(reassembling, key);
             if (!(fragments && fragments->interface_id == interface_id &&
                     fragments->adapter_id == adapter_id &&
                     fragments->chandle == chandle &&
@@ -272,7 +274,7 @@ dissect_btavctp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 tvb_memcpy(tvb, fragment->data, offset, fragment->length);
 
                 fragments->count++;
-                se_tree_insert32(fragments->fragment, fragments->count, fragment);
+                wmem_tree_insert32(fragments->fragment, fragments->count, fragment);
 
                 fragments->interface_id = interface_id;
                 fragments->adapter_id   = adapter_id;
@@ -298,7 +300,7 @@ dissect_btavctp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 key[5].length = 0;
                 key[5].key = NULL;
 
-                se_tree_insert32_array(reassembling, key, fragments);
+                wmem_tree_insert32_array(reassembling, key, fragments);
             }
 
             call_dissector(data_handle, next_tvb, pinfo, tree);
@@ -306,7 +308,7 @@ dissect_btavctp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         } else if (packet_type == PACKET_TYPE_END) {
             guint    i_length = 0;
 
-            fragments = (fragments_t *)se_tree_lookup32_array_le(reassembling, key);
+            fragments = (fragments_t *)wmem_tree_lookup32_array_le(reassembling, key);
             if (!(fragments && fragments->interface_id == interface_id &&
                     fragments->adapter_id == adapter_id &&
                     fragments->chandle == chandle &&
@@ -320,7 +322,7 @@ dissect_btavctp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 tvb_memcpy(tvb, fragment->data, offset, fragment->length);
 
                 fragments->count++;
-                se_tree_insert32(fragments->fragment, fragments->count, fragment);
+                wmem_tree_insert32(fragments->fragment, fragments->count, fragment);
 
                 fragments->interface_id = interface_id;
                 fragments->adapter_id   = adapter_id;
@@ -346,26 +348,25 @@ dissect_btavctp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 key[5].length = 0;
                 key[5].key = NULL;
 
-                se_tree_insert32_array(reassembling, key, fragments);
+                wmem_tree_insert32_array(reassembling, key, fragments);
             }
 
             length = 0;
             if (!fragments || fragments->count != fragments->number_of_packets) {
-                expert_add_info_format(pinfo, pitem, PI_PROTOCOL, PI_WARN,
-                    "Unexpected frame");
+                expert_add_info(pinfo, pitem, &ei_btavctp_unexpected_frame);
                 call_dissector(data_handle, next_tvb, pinfo, tree);
             } else {
                 guint8   *reassembled;
 
                 for (i_frame = 1; i_frame <= fragments->count; ++i_frame) {
-                    fragment = (fragment_t *)se_tree_lookup32_le(fragments->fragment, i_frame);
+                    fragment = (fragment_t *)wmem_tree_lookup32_le(fragments->fragment, i_frame);
                     length += fragment->length;
                 }
 
                 reassembled = (guint8 *) wmem_alloc(wmem_file_scope(), length);
 
                 for (i_frame = 1; i_frame <= fragments->count; ++i_frame) {
-                    fragment = (fragment_t *)se_tree_lookup32_le(fragments->fragment, i_frame);
+                    fragment = (fragment_t *)wmem_tree_lookup32_le(fragments->fragment, i_frame);
                     memcpy(reassembled + i_length,
                             fragment->data,
                             fragment->length);
@@ -393,6 +394,7 @@ void
 proto_register_btavctp(void)
 {
     module_t *module;
+    expert_module_t* expert_btavctp;
 
     static hf_register_info hf[] = {
         { &hf_btavctp_transaction,
@@ -436,15 +438,21 @@ proto_register_btavctp(void)
         &ett_btavctp
     };
 
-    reassembling = se_tree_create(EMEM_TREE_TYPE_RED_BLACK, "btavctp reassembling");
+    static ei_register_info ei[] = {
+        { &ei_btavctp_unexpected_frame, { "btavctp.unexpected_frame", PI_PROTOCOL, PI_WARN, "Unexpected frame", EXPFILL }},
+    };
 
-    avctp_service_dissector_table = register_dissector_table("btavctp.service", "AVCTP Service", FT_UINT16, BASE_HEX);
+    reassembling = wmem_tree_new_autoreset(wmem_epan_scope(), wmem_file_scope());
+
+    avctp_service_dissector_table = register_dissector_table("btavctp.service", "BT AVCTP Service", FT_UINT16, BASE_HEX);
 
     proto_btavctp = proto_register_protocol("Bluetooth AVCTP Protocol", "BT AVCTP", "btavctp");
     register_dissector("btavctp", dissect_btavctp, proto_btavctp);
 
     proto_register_field_array(proto_btavctp, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_btavctp = expert_register_protocol(proto_btavctp);
+    expert_register_field_array(expert_btavctp, ei, array_length(ei));
 
     module = prefs_register_protocol(proto_btavctp, NULL);
     prefs_register_static_text_preference(module, "avctp.version",
