@@ -6,7 +6,7 @@
  * Refactored for wireshark checkin
  *   Ronnie Sahlberg 2006
  *
- * $Id$
+ * $Id: packet-btl2cap.c 51852 2013-09-09 00:44:09Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -134,6 +134,10 @@ static gint ett_btl2cap_extfeatures = -1;
 static gint ett_btl2cap_fixedchans = -1;
 static gint ett_btl2cap_control = -1;
 
+static expert_field ei_btl2cap_parameter_mismatch = EI_INIT;
+static expert_field ei_btl2cap_sdulength_bad = EI_INIT;
+static expert_field ei_btl2cap_length_bad = EI_INIT;
+
 /* Initialize dissector table */
 static dissector_table_t l2cap_psm_dissector_table;
 static dissector_table_t l2cap_cid_dissector_table;
@@ -143,13 +147,13 @@ static dissector_table_t l2cap_service_dissector_table;
  * The same table is used both for SCID and DCID.
  * For received CIDs we 'or' the cid with 0x80000000 in this table
  */
-static emem_tree_t *cid_to_psm_table  = NULL;
-static emem_tree_t *sdp_service_infos = NULL;
+static wmem_tree_t *cid_to_psm_table  = NULL;
+static wmem_tree_t *sdp_service_infos = NULL;
 
 typedef struct _config_data_t {
     guint8      mode;
     guint8      txwindow;
-    emem_tree_t *start_fragments;  /* indexed by pinfo->fd->num */
+    wmem_tree_t *start_fragments;  /* indexed by pinfo->fd->num */
 } config_data_t;
 
 typedef struct _sdu_reassembly_t
@@ -214,6 +218,8 @@ static const value_string psm_vals[] = {
     { 0x0019, "AVDTP" },
     { 0x001B, "AVCTP-Browsing" },
     { 0x001D, "UDI_C-Plane" },
+    { 0x001F, "ATT" },
+    { 0x0021, "3DSP" },
     { 0, NULL }
 };
 value_string_ext ext_psm_vals = VALUE_STRING_EXT_INIT(psm_vals);
@@ -370,7 +376,7 @@ void proto_reg_handoff_btl2cap(void);
 static guint16
 get_service_uuid(packet_info *pinfo, guint16 psm, gboolean is_local_psm)
 {
-    emem_tree_key_t    key[10];
+    wmem_tree_key_t    key[10];
     guint32            k_interface_id;
     guint32            k_adapter_id;
     guint32            k_sdp_psm;
@@ -432,7 +438,10 @@ get_service_uuid(packet_info *pinfo, guint16 psm, gboolean is_local_psm)
     key[9].length = 0;
     key[9].key = NULL;
 
-    service_info = (service_info_t *) se_tree_lookup32_array_le(sdp_service_infos, key);
+    if (sdp_service_infos)
+        service_info = (service_info_t *) wmem_tree_lookup32_array_le(sdp_service_infos, key);
+    else
+        service_info = NULL;
     if (service_info && service_info->interface_id == interface_id &&
             service_info->adapter_id == adapter_id &&
             service_info->sdp_psm == SDP_PSM_DEFAULT &&
@@ -522,7 +531,7 @@ dissect_connrequest(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *t
     }
 
     if (!pinfo->fd->flags.visited) {
-        emem_tree_key_t    key[6];
+        wmem_tree_key_t    key[6];
         guint32            k_interface_id;
         guint32            k_adapter_id;
         guint32            k_chandle;
@@ -553,10 +562,10 @@ dissect_connrequest(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *t
         psm_data->local_service = (pinfo->p2p_dir == P2P_DIR_RECV) ? TRUE : FALSE;
         psm_data->in.mode      = 0;
         psm_data->in.txwindow  = 0;
-        psm_data->in.start_fragments = se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK, "bthci_l2cap fragment starts");
+        psm_data->in.start_fragments = wmem_tree_new(wmem_file_scope());
         psm_data->out.mode     = 0;
         psm_data->out.txwindow = 0;
-        psm_data->out.start_fragments = se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK, "bthci_l2cap fragment starts");
+        psm_data->out.start_fragments = wmem_tree_new(wmem_file_scope());
         psm_data->interface_id = k_interface_id;
         psm_data->adapter_id   = k_adapter_id;
         psm_data->chandle      = k_chandle;
@@ -575,7 +584,7 @@ dissect_connrequest(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *t
         key[5].length = 0;
         key[5].key    = NULL;
 
-        se_tree_insert32_array(cid_to_psm_table, key, psm_data);
+        wmem_tree_insert32_array(cid_to_psm_table, key, psm_data);
     }
     return offset;
 }
@@ -755,7 +764,7 @@ dissect_configrequest(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree
     if (tvb_reported_length_remaining(tvb, offset) > 0) {
         psm_data_t        *psm_data;
         config_data_t     *config_data;
-        emem_tree_key_t    key[6];
+        wmem_tree_key_t    key[6];
         guint32            k_interface_id;
         guint32            k_adapter_id;
         guint32            k_chandle;
@@ -791,7 +800,7 @@ dissect_configrequest(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree
         key[5].length = 0;
         key[5].key    = NULL;
 
-        psm_data = (psm_data_t *)se_tree_lookup32_array_le(cid_to_psm_table, key);
+        psm_data = (psm_data_t *)wmem_tree_lookup32_array_le(cid_to_psm_table, key);
         if (psm_data && psm_data->interface_id == interface_id &&
                 psm_data->adapter_id == adapter_id &&
                 psm_data->chandle == chandle &&
@@ -945,7 +954,7 @@ dissect_configresponse(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree
     if (tvb_reported_length_remaining(tvb, offset) > 0) {
         psm_data_t        *psm_data;
         config_data_t     *config_data;
-        emem_tree_key_t    key[6];
+        wmem_tree_key_t    key[6];
         guint32            k_interface_id;
         guint32            k_adapter_id;
         guint32            k_chandle;
@@ -981,7 +990,7 @@ dissect_configresponse(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree
         key[5].length = 0;
         key[5].key    = NULL;
 
-        psm_data = (psm_data_t *)se_tree_lookup32_array_le(cid_to_psm_table, key);
+        psm_data = (psm_data_t *)wmem_tree_lookup32_array_le(cid_to_psm_table, key);
         if (psm_data && psm_data->interface_id == interface_id &&
                 psm_data->adapter_id == adapter_id &&
                 psm_data->chandle == chandle &&
@@ -1030,7 +1039,7 @@ dissect_connresponse(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *
 
     if (pinfo->fd->flags.visited == 0) {
         psm_data_t        *psm_data;
-        emem_tree_key_t    key[6];
+        wmem_tree_key_t    key[6];
         guint32            k_interface_id;
         guint32            k_adapter_id;
         guint32            k_chandle;
@@ -1066,7 +1075,7 @@ dissect_connresponse(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *
         key[5].length = 0;
         key[5].key    = NULL;
 
-        psm_data = (psm_data_t *)se_tree_lookup32_array_le(cid_to_psm_table, key);
+        psm_data = (psm_data_t *)wmem_tree_lookup32_array_le(cid_to_psm_table, key);
         if (psm_data && psm_data->interface_id == interface_id &&
                 psm_data->adapter_id == adapter_id &&
                 psm_data->chandle == chandle &&
@@ -1095,7 +1104,7 @@ dissect_connresponse(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *
 
             psm_data->dcid = cid;
 
-            se_tree_insert32_array(cid_to_psm_table, key, psm_data);
+            wmem_tree_insert32_array(cid_to_psm_table, key, psm_data);
         }
     }
 
@@ -1177,7 +1186,7 @@ dissect_connparamrequest(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tr
     slave_latency = tvb_get_letohs(tvb, offset);
 
     if(slave_latency >= 500 || slave_latency > 10.0 * tvb_get_letohs(tvb, offset + 2) / (max_interval *1.25))
-        expert_add_info_format(pinfo, item, PI_PROTOCOL, PI_WARN, "Parameter mismatch");
+        expert_add_info(pinfo, item, &ei_btl2cap_parameter_mismatch);
 
     offset += 2;
     item = proto_tree_add_item(tree, hf_btl2cap_timeout_multiplier, tvb, offset, 2, ENC_LITTLE_ENDIAN);
@@ -1220,7 +1229,7 @@ dissect_disconnrequestresponse(tvbuff_t *tvb, int offset, packet_info *pinfo, pr
 
     if (!pinfo->fd->flags.visited) {
         psm_data_t        *psm_data;
-        emem_tree_key_t    key[6];
+        wmem_tree_key_t    key[6];
         guint32            k_interface_id;
         guint32            k_adapter_id;
         guint32            k_chandle;
@@ -1258,7 +1267,7 @@ dissect_disconnrequestresponse(tvbuff_t *tvb, int offset, packet_info *pinfo, pr
         key[5].length = 0;
         key[5].key    = NULL;
 
-        psm_data = (psm_data_t *)se_tree_lookup32_array_le(cid_to_psm_table, key);
+        psm_data = (psm_data_t *)wmem_tree_lookup32_array_le(cid_to_psm_table, key);
         if (psm_data && psm_data->interface_id == interface_id &&
                 psm_data->adapter_id == adapter_id &&
                 psm_data->chandle == chandle &&
@@ -1286,7 +1295,7 @@ dissect_disconnrequestresponse(tvbuff_t *tvb, int offset, packet_info *pinfo, pr
         key[5].length = 0;
         key[5].key    = NULL;
 
-        psm_data = (psm_data_t *)se_tree_lookup32_array_le(cid_to_psm_table, key);
+        psm_data = (psm_data_t *)wmem_tree_lookup32_array_le(cid_to_psm_table, key);
         if (psm_data && psm_data->interface_id == interface_id &&
                 psm_data->adapter_id == adapter_id &&
                 psm_data->chandle == chandle &&
@@ -1400,7 +1409,7 @@ dissect_i_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, proto_tree
         /* Detect malformed data */
 
         if (length <= 6) {
-            expert_add_info_format(pinfo, pi, PI_MALFORMED, PI_WARN,
+            expert_add_info_format(pinfo, pi, &ei_btl2cap_sdulength_bad,
                     "SDU length too short: %u", length);
             THROW(ReportedBoundsError);
         }
@@ -1409,7 +1418,7 @@ dissect_i_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, proto_tree
 
         if (sdulen < length) {
             sdulen = length;
-            expert_add_info_format(pinfo, pi, PI_MALFORMED, PI_WARN,
+            expert_add_info_format(pinfo, pi, &ei_btl2cap_sdulength_bad,
                     "SDU length less than length of first packet (%u < %u)", sdulen, length);
         }
 
@@ -1421,9 +1430,9 @@ dissect_i_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, proto_tree
             mfp->reassembled = (guint8 *) wmem_alloc(wmem_file_scope(), sdulen);
             tvb_memcpy(tvb, mfp->reassembled, offset, sdulen);
             mfp->cur_off     = sdulen;
-            se_tree_insert32(config_data->start_fragments, pinfo->fd->num, mfp);
+            wmem_tree_insert32(config_data->start_fragments, pinfo->fd->num, mfp);
         } else {
-            mfp              = (sdu_reassembly_t *)se_tree_lookup32(config_data->start_fragments, pinfo->fd->num);
+            mfp              = (sdu_reassembly_t *)wmem_tree_lookup32(config_data->start_fragments, pinfo->fd->num);
         }
         if (mfp != NULL && mfp->last_frame) {
             proto_item *item;
@@ -1433,14 +1442,14 @@ dissect_i_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, proto_tree
         }
     } else {
         if (length <= 4) {
-            expert_add_info_format(pinfo, btl2cap_tree, PI_MALFORMED, PI_WARN,
+            expert_add_info_format(pinfo, btl2cap_tree, &ei_btl2cap_length_bad,
                     "Control / FCS length too short: %u", length);
             THROW(ReportedBoundsError);
         }
         length -= 4; /*Control, FCS*/
     }
     if (segment == 0x02 || segment == 0x03) {
-        mfp = (sdu_reassembly_t *)se_tree_lookup32_le(config_data->start_fragments, pinfo->fd->num);
+        mfp = (sdu_reassembly_t *)wmem_tree_lookup32_le(config_data->start_fragments, pinfo->fd->num);
         if (!pinfo->fd->flags.visited) {
             if (mfp != NULL && !mfp->last_frame && (mfp->tot_len>=mfp->cur_off + length)) {
                 tvb_memcpy(tvb, mfp->reassembled + mfp->cur_off, offset, length);
@@ -1782,7 +1791,7 @@ dissect_btl2cap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         }
     }
     else /* if (cid >= BTL2CAP_FIXED_CID_MAX) */ { /* Connection oriented channel */
-        emem_tree_key_t    key[6];
+        wmem_tree_key_t    key[6];
         guint32            k_interface_id;
         guint32            k_adapter_id;
         guint32            k_chandle;
@@ -1817,7 +1826,7 @@ dissect_btl2cap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         key[5].length = 0;
         key[5].key    = NULL;
 
-        psm_data = (psm_data_t *)se_tree_lookup32_array_le(cid_to_psm_table, key);
+        psm_data = (psm_data_t *)wmem_tree_lookup32_array_le(cid_to_psm_table, key);
         if (psm_data && psm_data->interface_id == interface_id &&
                 psm_data->adapter_id == adapter_id &&
                 psm_data->chandle == chandle &&
@@ -2036,12 +2045,12 @@ proto_register_btl2cap(void)
         },
         { &hf_btl2cap_info_window,
           { "Extended Window Size", "btl2cap.info_window",
-            FT_UINT32, BASE_DEC, NULL, 0x0100,
+            FT_UINT32, BASE_DEC, NULL, 0x01,
             "Extended Window Size support", HFILL }
         },
         { &hf_btl2cap_info_unicast,
           { "Unicast Connectionless Data Reception", "btl2cap.info_unicast",
-            FT_UINT32, BASE_DEC, NULL, 0x0200,
+            FT_UINT32, BASE_DEC, NULL, 0x02,
             "Unicast Connectionless Data Reception support", HFILL }
         },
         { &hf_btl2cap_info_fixedchans,
@@ -2316,6 +2325,14 @@ proto_register_btl2cap(void)
         &ett_btl2cap_control
     };
 
+    static ei_register_info ei[] = {
+        { &ei_btl2cap_parameter_mismatch, { "btl2cap.parameter_mismatch", PI_PROTOCOL, PI_WARN, "Unexpected frame", EXPFILL }},
+        { &ei_btl2cap_sdulength_bad, { "btl2cap.sdulength.bad", PI_MALFORMED, PI_WARN, "SDU length bad", EXPFILL }},
+        { &ei_btl2cap_length_bad, { "btl2cap.length.bad", PI_MALFORMED, PI_WARN, "Length bad", EXPFILL }},
+    };
+
+	expert_module_t* expert_btl2cap;
+
     /* Register the protocol name and description */
     proto_btl2cap = proto_register_protocol("Bluetooth L2CAP Protocol", "BT L2CAP", "btl2cap");
 
@@ -2329,8 +2346,10 @@ proto_register_btl2cap(void)
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_btl2cap, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_btl2cap = expert_register_protocol(proto_btl2cap);
+    expert_register_field_array(expert_btl2cap, ei, array_length(ei));
 
-    cid_to_psm_table     = se_tree_create(EMEM_TREE_TYPE_RED_BLACK, "btl2cap scid to psm");
+    cid_to_psm_table     = wmem_tree_new_autoreset(wmem_epan_scope(), wmem_file_scope()); /* scid: psm */
 }
 
 
