@@ -9,7 +9,7 @@
  * Refactored for wireshark checkin
  *   Ronnie Sahlberg 2006
  *
- * $Id$
+ * $Id: packet-btrfcomm.c 51982 2013-09-12 20:34:19Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -108,7 +108,9 @@ static gint ett_btdun = -1;
 static gint ett_btspp = -1;
 static gint ett_btgnss = -1;
 
-static emem_tree_t *sdp_service_infos = NULL;
+static expert_field ei_btrfcomm_mcc_length_bad = EI_INIT;
+
+static wmem_tree_t *sdp_service_infos = NULL;
 
 static dissector_table_t rfcomm_service_dissector_table;
 static dissector_table_t rfcomm_channel_dissector_table;
@@ -572,7 +574,7 @@ dissect_btrfcomm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     offset = dissect_btrfcomm_payload_length(tvb, offset, rfcomm_tree, &frame_len);
 
     if (dlci && (frame_len || (frame_type == 0xef) || (frame_type == 0x2f))) {
-        emem_tree_key_t  key[10];
+        wmem_tree_key_t  key[10];
         guint32          k_interface_id;
         guint32          k_adapter_id;
         guint32          k_sdp_psm;
@@ -619,7 +621,9 @@ dissect_btrfcomm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         key[9].length = 0;
         key[9].key = NULL;
 
-        service_info = (service_info_t *) se_tree_lookup32_array_le(sdp_service_infos, key);
+        if (sdp_service_infos) {
+            service_info = (service_info_t *) wmem_tree_lookup32_array_le(sdp_service_infos, key);
+        }
         if (service_info && service_info->interface_id == l2cap_data->interface_id &&
                 service_info->adapter_id == l2cap_data->adapter_id &&
                 service_info->sdp_psm == SDP_PSM_DEFAULT &&
@@ -677,7 +681,7 @@ dissect_btrfcomm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         offset = get_le_multi_byte_value(tvb, offset, ctrl_tree, &length, hf_mcc_len);
 
         if (length > (guint32) tvb_length_remaining(tvb, offset)) {
-            expert_add_info_format(pinfo, ctrl_tree, PI_MALFORMED, PI_ERROR, "Huge MCC length: %u", length);
+            expert_add_info_format(pinfo, ctrl_tree, &ei_btrfcomm_mcc_length_bad, "Huge MCC length: %u", length);
             return;
         }
 
@@ -733,11 +737,13 @@ dissect_btrfcomm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         next_tvb = tvb_new_subset(tvb, offset, frame_len, frame_len);
 
         rfcomm_data = (btrfcomm_data_t *) wmem_new(wmem_packet_scope(), btrfcomm_data_t);
-        rfcomm_data->interface_id = l2cap_data->interface_id;
-        rfcomm_data->adapter_id   = l2cap_data->adapter_id;
-        rfcomm_data->chandle      = l2cap_data->chandle;
-        rfcomm_data->cid          = l2cap_data->cid;
-        rfcomm_data->dlci         = dlci;
+        rfcomm_data->interface_id       = l2cap_data->interface_id;
+        rfcomm_data->adapter_id         = l2cap_data->adapter_id;
+        rfcomm_data->chandle            = l2cap_data->chandle;
+        rfcomm_data->cid                = l2cap_data->cid;
+        rfcomm_data->dlci               = dlci;
+        rfcomm_data->remote_bd_addr_oui = l2cap_data->remote_bd_addr_oui;
+        rfcomm_data->remote_bd_addr_id  = l2cap_data->remote_bd_addr_id;
         pinfo->private_data = rfcomm_data;
 
         if (!dissector_try_uint(rfcomm_channel_dissector_table, (guint32) dlci >> 1,
@@ -762,6 +768,7 @@ void
 proto_register_btrfcomm(void)
 {
     module_t *module;
+	expert_module_t* expert_btrfcomm;
 
     static hf_register_info hf[] = {
         { &hf_dlci,
@@ -951,6 +958,10 @@ proto_register_btrfcomm(void)
         &ett_mcc_dlci
     };
 
+    static ei_register_info ei[] = {
+        { &ei_btrfcomm_mcc_length_bad, { "btrfcomm.mcc_length_bad", PI_MALFORMED, PI_ERROR, "Huge MCC length", EXPFILL }},
+    };
+
     /* Register the protocol name and description */
     proto_btrfcomm = proto_register_protocol("Bluetooth RFCOMM Protocol", "BT RFCOMM", "btrfcomm");
     register_dissector("btrfcomm", dissect_btrfcomm, proto_btrfcomm);
@@ -958,9 +969,11 @@ proto_register_btrfcomm(void)
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_btrfcomm, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_btrfcomm = expert_register_protocol(proto_btrfcomm);
+    expert_register_field_array(expert_btrfcomm, ei, array_length(ei));
 
-    rfcomm_service_dissector_table = register_dissector_table("btrfcomm.service", "RFCOMM SERVICE", FT_UINT16, BASE_HEX);
-    rfcomm_channel_dissector_table = register_dissector_table("btrfcomm.channel", "RFCOMM Channel", FT_UINT16, BASE_DEC);
+    rfcomm_service_dissector_table = register_dissector_table("btrfcomm.service", "BT RFCOMM Service", FT_UINT16, BASE_HEX);
+    rfcomm_channel_dissector_table = register_dissector_table("btrfcomm.channel", "BT RFCOMM Channel", FT_UINT16, BASE_DEC);
 
     module = prefs_register_protocol(proto_btrfcomm, NULL);
     prefs_register_static_text_preference(module, "rfcomm.version",
