@@ -1,6 +1,6 @@
 /* packet-btrfcomm.h
  *
- * $Id$
+ * $Id: packet-btrfcomm.h 49886 2013-06-11 14:05:48Z eapache $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,6 +34,8 @@ typedef struct _btrfcomm_data_t {
     guint16 chandle;  /* only low 12 bits used */
     guint16 cid;
     guint8  dlci;
+    guint32 remote_bd_addr_oui;
+    guint32 remote_bd_addr_id;
 } btrfcomm_data_t;
 
 #endif
