@@ -3,7 +3,7 @@
  *
  * Copyright 2012, Allan M. Madsen <allan.m@madsen.dk>
  *
- * $Id$
+ * $Id: packet-btsmp.c 50351 2013-07-03 16:43:31Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -173,8 +173,8 @@ dissect_btsmp_key_dist(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree
     return offset + 1;
 }
 
-static void
-dissect_btsmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+static int
+dissect_btsmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
     int offset = 0;
     proto_item *ti;
@@ -197,7 +197,7 @@ dissect_btsmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     }
 
     if (tvb_length_remaining(tvb, 0) < 1)
-        return;
+        return FALSE;
 
     ti = proto_tree_add_item(tree, proto_btsmp, tvb, 0, -1, ENC_NA);
     st = proto_item_add_subtree(ti, ett_btsmp);
@@ -275,6 +275,8 @@ dissect_btsmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     default:
         break;
     }
+
+    return offset;
 }
 
 void
@@ -374,7 +376,7 @@ proto_register_btsmp(void)
     proto_btsmp = proto_register_protocol("Bluetooth Security Manager Protocol",
         "BT SMP", "btsmp");
 
-    register_dissector("btsmp", dissect_btsmp, proto_btsmp);
+    new_register_dissector("btsmp", dissect_btsmp, proto_btsmp);
 
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_btsmp, hf, array_length(hf));
