@@ -3,7 +3,7 @@
  * Copyright 2000, Scott Hovis scott.hovis@ums.msfc.nasa.gov
  * Enhanced 2008, Matt Dunkle Matthew.L.Dunkle@nasa.gov
  *
- * $Id$
+ * $Id: packet-ccsds.c 52045 2013-09-15 01:48:30Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -89,6 +89,8 @@ static gint ett_ccsds_primary_header = -1;
 static gint ett_ccsds_secondary_header = -1;
 static gint ett_ccsds_checkword = -1;
 
+static expert_field ei_ccsds_length_error = EI_INIT;
+
 /* Generic data handle */
 static dissector_handle_t data_handle;
 
@@ -318,7 +320,7 @@ dissect_ccsds(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	col_set_str(pinfo->cinfo, COL_INFO, "CCSDS Packet");
 
 	first_word=tvb_get_ntohs(tvb, 0);
-	col_add_fstr(pinfo->cinfo, COL_INFO, "APID %1$4d (0x%1$03X)", first_word&HDR_APID);
+    col_add_fstr(pinfo->cinfo, COL_INFO, "APID %4d (0x%03X)", first_word&HDR_APID, first_word&HDR_APID);
 
 	reported_length = tvb_reported_length_remaining(tvb, 0);
 	ccsds_length    = tvb_get_ntohs(tvb, 4) + CCSDS_PRIMARY_HEADER_LENGTH + 1;
@@ -355,8 +357,7 @@ dissect_ccsds(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		item = proto_tree_add_item(primary_header_tree, hf_ccsds_length, tvb, offset, 2, ENC_BIG_ENDIAN);
 	}
 	if (ccsds_length > reported_length) {
-		expert_add_info_format(pinfo, item, PI_MALFORMED, PI_ERROR,
-				       "Length field value is greater than the packet seen on the wire");
+		expert_add_info(pinfo, item, &ei_ccsds_length_error);
 	}
 	if (tree) {
 		offset += 2;
@@ -464,16 +465,16 @@ dissect_ccsds(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 				/* Report checkword status */
 				if (checkword_sum == checkword_field) {
-					item = proto_tree_add_uint_format(ccsds_tree, hf_ccsds_checkword, tvb, offset, 2, checkword_field,
-							"CCSDS checkword: 0x%04x [correct]", checkword_field);
+					item = proto_tree_add_uint_format_value(ccsds_tree, hf_ccsds_checkword, tvb, offset, 2, checkword_field,
+							"0x%04x [correct]", checkword_field);
 					checkword_tree = proto_item_add_subtree(item, ett_ccsds_checkword);
 					item = proto_tree_add_boolean(checkword_tree, hf_ccsds_checkword_good, tvb, offset, 2, TRUE);
 					PROTO_ITEM_SET_GENERATED(item);
 					item = proto_tree_add_boolean(checkword_tree, hf_ccsds_checkword_bad, tvb, offset, 2, FALSE);
 					PROTO_ITEM_SET_GENERATED(item);
 				} else {
-					item = proto_tree_add_uint_format(ccsds_tree, hf_ccsds_checkword, tvb, offset, 2, checkword_field,
-							"CCSDS checkword: 0x%04x [incorrect, should be 0x%04x]", checkword_field, checkword_sum);
+					item = proto_tree_add_uint_format_value(ccsds_tree, hf_ccsds_checkword, tvb, offset, 2, checkword_field,
+							"0x%04x [incorrect, should be 0x%04x]", checkword_field, checkword_sum);
 					checkword_tree = proto_item_add_subtree(item, ett_ccsds_checkword);
 					item = proto_tree_add_boolean(checkword_tree, hf_ccsds_checkword_good, tvb, offset, 2, FALSE);
 					PROTO_ITEM_SET_GENERATED(item);
@@ -663,15 +664,22 @@ proto_register_ccsds(void)
 		&ett_ccsds_checkword
 	};
 
+	static ei_register_info ei[] = {
+		{ &ei_ccsds_length_error, { "ccsds.length.error", PI_MALFORMED, PI_ERROR, "Length field value is greater than the packet seen on the wire", EXPFILL }},
+	};
+
 	/* Define the CCSDS preferences module */
 	module_t *ccsds_module;
+	expert_module_t* expert_ccsds;
 
 	/* Register the protocol name and description */
 	proto_ccsds = proto_register_protocol("CCSDS", "CCSDS", "ccsds");
 
-        /* Required function calls to register the header fields and subtrees used */
+	/* Required function calls to register the header fields and subtrees used */
 	proto_register_field_array(proto_ccsds, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	expert_ccsds = expert_register_protocol(proto_ccsds);
+	expert_register_field_array(expert_ccsds, ei, array_length(ei));
 
 	register_dissector ( "ccsds", dissect_ccsds, proto_ccsds );
 
