@@ -2,7 +2,7 @@
  * Routines for the disassembly of the "Cisco Discovery Protocol"
  * (c) Copyright Hannes R. Boehm <hannes@boehm.org>
  *
- * $Id$
+ * $Id: packet-cdp.c 52045 2013-09-15 01:48:30Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,6 +31,7 @@
 #include <epan/packet.h>
 #include <epan/strutil.h>
 #include <epan/in_cksum.h>
+#include <epan/wmem/wmem.h>
 
 #include <epan/oui.h>
 #include <epan/nlpid.h>
@@ -245,7 +246,7 @@ dissect_cdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     if (data_length & 1) {
         guint8 *padded_buffer;
         /* Allocate new buffer */
-        padded_buffer = (guint8 *)ep_alloc(data_length+1);
+        padded_buffer = (guint8 *)wmem_alloc(wmem_packet_scope(), data_length+1);
         tvb_memcpy(tvb, padded_buffer, 0, data_length);
         /* Swap bytes in last word */
         padded_buffer[data_length] = padded_buffer[data_length-1];
@@ -268,13 +269,13 @@ dissect_cdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     checksum_good = (computed_checksum == 0);
     checksum_bad = !checksum_good;
     if (checksum_good) {
-        checksum_item = proto_tree_add_uint_format(cdp_tree,
+        checksum_item = proto_tree_add_uint_format_value(cdp_tree,
                                                    hf_cdp_checksum, tvb, offset, 2, packet_checksum,
-                                                   "Checksum: 0x%04x [correct]", packet_checksum);
+                                                   "0x%04x [correct]", packet_checksum);
     } else {
-        checksum_item = proto_tree_add_uint_format(cdp_tree,
+        checksum_item = proto_tree_add_uint_format_value(cdp_tree,
                                                    hf_cdp_checksum, tvb, offset, 2, packet_checksum,
-                                                   "Checksum: 0x%04x [incorrect, should be 0x%04x]",
+                                                   "0x%04x [incorrect, should be 0x%04x]",
                                                    packet_checksum,
                                                    in_cksum_shouldbe(packet_checksum, computed_checksum));
     }
@@ -1021,7 +1022,6 @@ dissect_address_tlv(tvbuff_t *tvb, int offset, int length, proto_tree *tree)
     /* XXX - the Cisco document seems to be saying that, for 802.2-format
        protocol types, 0xAAAA03 0x000000 0x0800 is IPv6, but 0x0800 is
        the Ethernet protocol type for IPv4. */
-    length = 2 + protocol_length + 2 + address_length;
     address_type_str = NULL;
     address_str = NULL;
     if ((protocol_type == PROTO_TYPE_NLPID) && (protocol_length == 1)) {
@@ -1335,6 +1335,6 @@ proto_reg_handoff_cdp(void)
     data_handle = find_dissector("data");
     cdp_handle  = create_dissector_handle(dissect_cdp, proto_cdp);
     dissector_add_uint("llc.cisco_pid", 0x2000, cdp_handle);
-    dissector_add_uint("chdlctype",     0x2000, cdp_handle);
+    dissector_add_uint("chdlc.protocol", 0x2000, cdp_handle);
     dissector_add_uint("ppp.protocol",  0x0207, cdp_handle);
 }
