@@ -1,6 +1,6 @@
 /* packet-cell_broadcast.h
  *
- * $Id$
+ * $Id: packet-cell_broadcast.h 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Copyright 2011, Mike Morrin <mike.morrin [AT] ipaccess.com>,
  *
@@ -29,40 +29,36 @@
 
 /**
  * Dissects the GSM/UMTS/SABP Message Identifier
- * 
- * @param tvb
- * @param tree
- * @param offset
  *
- * @return the offset after the Message Identifier
+ * @param tvb the tv buffer of the current data
+ * @param tree the tree to append this item to
+ * @param offset the offset in the tvb
  */
-guint dissect_cbs_message_identifier(tvbuff_t *tvb, proto_tree *tree, guint offset);
+void dissect_cbs_message_identifier(tvbuff_t *tvb, proto_tree *tree, guint16 offset);
 
 
 /**
  * Decodes the GSM/UMTS/SABP message Serial Number
- * 
- * @param tvb
- * @param tree
- * @param offset
  *
- * @return the offset after the Serial Number
+ * @param tvb the tv buffer of the current data
+ * @param tree the tree to append this item to
+ * @param offset the offset in the tvb
  */
-guint dissect_cbs_serial_number(tvbuff_t *tvb, proto_tree *tree, guint offset);
+void dissect_cbs_serial_number(tvbuff_t *tvb, proto_tree *tree, guint16 offset);
 
 
 /**
  * Dissects UMTS/SABP Cell Broadcast Message
- * 
- * @param tvb
- * @param pinfo
- * @param tree
+ *
+ * @param tvb the tv buffer of the current data
+ * @param pinfo the packet info of the current data
+ * @param tree the tree to append this item to
  */
-void dissect_umts_cell_broadcast_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
+guint16 dissect_umts_cell_broadcast_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 
 /**
  * Dissects CB Data
  */
-tvbuff_t * dissect_cbs_data(guint8 sms_encoding, tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo, guint offset);
+tvbuff_t * dissect_cbs_data(guint8 sms_encoding, tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo, guint16 offset);
 
 #endif /* PACKET_CELL_BROADCAST_H */
