@@ -2,7 +2,7 @@
  * Routines for Cisco Session Management Protocol dissection
  * Copyright 2004, Duncan Sargeant <dunc-ethereal@rcpt.to>
  *
- * $Id$
+ * $Id: packet-cisco-sm.c 52099 2013-09-16 14:05:31Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -101,7 +101,7 @@ static const value_string sm_backhaul_reason_code[] = {
 	{ 0x00, "Layer management request"},
 	{ 0x01, "SUERM (Signal Unit Error Monitor) failure"},
 	{ 0x02, "Excessively long alignment period"},
-	{ 0x03, "T7 timer expired"}, 
+	{ 0x03, "T7 timer expired"},
 	{ 0x04, "Physical interface failure"},
 	{ 0x05, "Two or three invalid BSNs"},
 	{ 0x06, "Two or three invalid FIBs"},
@@ -114,7 +114,7 @@ static const value_string sm_backhaul_reason_code[] = {
 	{ 0x17, "Proving period failure"},
 	{ 0x18, "Timer T1 expired waiting for FISU (Fill-In Signal Unit)"},
 	{ 0x19, "SIN received in the in-service state"},
-	{ 0x20, "CTS lost"}, 
+	{ 0x20, "CTS lost"},
 	{ 0x25, "No resources"},
 	{    0, NULL}
 };
@@ -275,7 +275,6 @@ dissect_sm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_tree *sm_tree;
 	tvbuff_t *next_tvb = NULL;
 	guint32 sm_message_type;
-	guint32 bsn_num = 0;
 	guint32 bh_event_code = 0;
 	guint16 protocol;
 	guint16 msg_type = 0;
@@ -293,8 +292,8 @@ dissect_sm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	ti = proto_tree_add_item(tree, proto_sm, tvb, offset, 0, ENC_NA);
 	sm_tree = proto_item_add_subtree(ti, ett_sm);
 
-	proto_tree_add_uint_format(sm_tree, hf_sm_sm_msg_type, tvb, offset, 4, sm_message_type,
-		"SM Message type: %s (0x%0x)", val_to_str_const(sm_message_type, sm_message_type_value, "reserved"), sm_message_type);
+	proto_tree_add_uint_format_value(sm_tree, hf_sm_sm_msg_type, tvb, offset, 4, sm_message_type,
+		"%s (0x%0x)", val_to_str_const(sm_message_type, sm_message_type_value, "reserved"), sm_message_type);
 
 	offset = offset + 4;
 	if (sm_message_type ==  MESSAGE_TYPE_PDU) {
@@ -310,8 +309,8 @@ dissect_sm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			proto_tree_add_item(sm_tree, hf_sm_msg_id, tvb, offset, 2, ENC_BIG_ENDIAN);
 			offset = offset +2;
 			msg_type = tvb_get_ntohs(tvb,offset);
-			proto_tree_add_uint_format(sm_tree, hf_sm_msg_type, tvb, offset, 2, msg_type,
-				"Message type: %s (0x%0x)", val_to_str_const(msg_type, sm_pdu_type_value, "reserved"),
+			proto_tree_add_uint_format_value(sm_tree, hf_sm_msg_type, tvb, offset, 2, msg_type,
+				"%s (0x%0x)", val_to_str_const(msg_type, sm_pdu_type_value, "reserved"),
 				msg_type);
 			msg_type = tvb_get_ntohs(tvb,offset);
 			offset = offset + 2;
@@ -386,7 +385,7 @@ dissect_sm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				offset = offset +2;
 				next_tvb = tvb_new_subset(tvb, offset, length, length);
 				call_dissector(sdp_handle, next_tvb, pinfo, sm_tree);
-				offset = offset+length;
+				/*offset = offset+length;*/
 
 			}
 			/*return;*/
@@ -418,7 +417,7 @@ dissect_sm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				offset = offset +2;
 				next_tvb = tvb_new_subset(tvb, offset, length, length);
 				call_dissector(sdp_handle, next_tvb, pinfo, sm_tree);
-				offset = offset+length;
+				/*offset = offset+length;*/
 
 			}
 			break;
@@ -426,8 +425,8 @@ dissect_sm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			proto_tree_add_item(sm_tree, hf_sm_msg_id, tvb, offset, 2, ENC_BIG_ENDIAN);
 			offset = offset +2;
 			msg_type = tvb_get_ntohs(tvb,offset);
-			proto_tree_add_uint_format(sm_tree, hf_sm_msg_type, tvb, offset, 2, msg_type,
-				"Message type: %s (0x%0x)", val_to_str_const(msg_type, sm_pdu_type_value, "reserved"),
+			proto_tree_add_uint_format_value(sm_tree, hf_sm_msg_type, tvb, offset, 2, msg_type,
+				"%s (0x%0x)", val_to_str_const(msg_type, sm_pdu_type_value, "reserved"),
 				msg_type);
 			msg_type = tvb_get_ntohs(tvb,offset);
 			offset = offset + 2;
@@ -461,9 +460,7 @@ dissect_sm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					proto_tree_add_item(sm_tree, hf_sm_retrieval_type, tvb, offset, 4, ENC_BIG_ENDIAN);
 					if (msg_type == PDU_RETRIEVAL_CONFIRM && tvb_get_ntohl(tvb,offset) == 0x01) {
 						offset += 4;
-						bsn_num = tvb_get_ntohl(tvb,offset);
-						proto_tree_add_uint_format(sm_tree, hf_sm_bsn_num, tvb, offset, 4,
-												   bsn_num, "BSN: %d", bsn_num);
+						proto_tree_add_item(sm_tree, hf_sm_bsn_num, tvb, offset, 4, ENC_BIG_ENDIAN);
 					}
 					break;
 				case PDU_LSC_REQUEST:
@@ -576,7 +573,7 @@ proto_register_sm(void)
 			FT_UINT32, BASE_HEX, VALS(sm_linkdown_cause_code), 0x0,
 			NULL, HFILL }
 		},
-		
+
 		{ &hf_sm_retrieval_type,
 		  { "Retrieval type","sm.retrieval_type",
 			FT_UINT32, BASE_HEX, VALS(sm_retrieval_type), 0x0,
@@ -593,8 +590,8 @@ proto_register_sm(void)
 			NULL, HFILL }
 		},
 		{ &hf_sm_bsn_num,
-		  { "BSN Number","sm.bsn_num",
-			FT_UINT32, BASE_HEX, NULL, 0x0,
+		  { "BSN","sm.bsn_num",
+			FT_UINT32, BASE_DEC, NULL, 0x0,
 			NULL, HFILL }
 		},
 
