@@ -1,7 +1,7 @@
 /* packet-csm-encaps.c
  * Routines for CSM_ENCAPS dissection
  * Copyright 2005, Angelo Bannack <angelo.bannack@siemens.com>
- * $Id$
+ * $Id: packet-csm-encaps.c 52013 2013-09-13 17:25:54Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,7 +31,7 @@
 
 #include <epan/packet.h>
 #include <epan/tap.h>
-
+#include <epan/wmem/wmem.h>
 #include <epan/etypes.h>
 
 
@@ -161,11 +161,11 @@ static const gchar *
 csm_fc(guint16 fc, guint16 ct)
 {
     if (fc == 0x0000) {
-        return ep_strdup(val_to_str(ct, class_type_vals,
-                       "0x%04x"));
+        return wmem_strdup(wmem_packet_scope(),
+                           val_to_str(ct, class_type_vals, "0x%04x"));
     } else {
-        return ep_strdup(val_to_str(fc, function_code_vals,
-                       "0x%04x"));
+        return wmem_strdup(wmem_packet_scope(),
+                           val_to_str(fc, function_code_vals, "0x%04x"));
     }
 }
 
