@@ -2,7 +2,7 @@
  * Routines for dcerpc conv dissection
  * Copyright 2001, Todd Sabin <tas@webspan.net>
  *
- * $Id$
+ * $Id: packet-dcerpc-conv.c 52310 2013-10-01 13:02:12Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -64,13 +64,11 @@ conv_dissect_who_are_you_rqst (tvbuff_t *tvb, int offset,
 	offset = dissect_ndr_uuid_t (tvb, offset, pinfo, tree, drep, hf_conv_who_are_you_rqst_actuid, &actuid);
 	offset = dissect_ndr_time_t (tvb, offset, pinfo, tree, drep, hf_conv_who_are_you_rqst_boot_time, NULL);
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_add_fstr(pinfo->cinfo, COL_INFO,
+	col_add_fstr(pinfo->cinfo, COL_INFO,
 			     "conv_who_are_you request actuid: %08x-%04x-%04x-%02x%02x-%02x%02x%02x%02x%02x%02x",
 			     actuid.Data1, actuid.Data2, actuid.Data3,
 			     actuid.Data4[0], actuid.Data4[1], actuid.Data4[2], actuid.Data4[3],
 			     actuid.Data4[4], actuid.Data4[5], actuid.Data4[6], actuid.Data4[7]);
-        }
 
 	return offset;
 }
@@ -90,10 +88,8 @@ conv_dissect_who_are_you_resp (tvbuff_t *tvb, int offset,
 	offset = dissect_ndr_uint32 (tvb, offset, pinfo, tree, drep, hf_conv_rc, &st);
 
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_add_fstr(pinfo->cinfo, COL_INFO, "conv_who_are_you response seq:%u st:%s",
+	col_add_fstr(pinfo->cinfo, COL_INFO, "conv_who_are_you response seq:%u st:%s",
 			     seq, val_to_str_ext(st, &dce_error_vals_ext, "%u"));
-	}
 
 	return offset;
 }
@@ -114,13 +110,11 @@ conv_dissect_who_are_you2_rqst (tvbuff_t *tvb, int offset,
         offset = dissect_ndr_uuid_t (tvb, offset, pinfo, tree, drep, hf_conv_who_are_you2_rqst_actuid, &actuid);
         offset = dissect_ndr_time_t (tvb, offset, pinfo, tree, drep, hf_conv_who_are_you2_rqst_boot_time, NULL);
 
-        if (check_col(pinfo->cinfo, COL_INFO)) {
 		col_add_fstr(pinfo->cinfo, COL_INFO,
 			     "conv_who_are_you2 request actuid: %08x-%04x-%04x-%02x%02x-%02x%02x%02x%02x%02x%02x",
 			     actuid.Data1, actuid.Data2, actuid.Data3,
 			     actuid.Data4[0], actuid.Data4[1], actuid.Data4[2], actuid.Data4[3],
 			     actuid.Data4[4], actuid.Data4[5], actuid.Data4[6], actuid.Data4[7]);
-        }
 
 	return offset;
 }
@@ -142,14 +136,12 @@ conv_dissect_who_are_you2_resp (tvbuff_t *tvb, int offset,
 	offset = dissect_ndr_uuid_t (tvb, offset, pinfo, tree, drep, hf_conv_who_are_you2_resp_casuuid, &cas_uuid);
 	offset = dissect_ndr_uint32 (tvb, offset, pinfo, tree, drep, hf_conv_rc, &st);
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_add_fstr(pinfo->cinfo, COL_INFO,
+	col_add_fstr(pinfo->cinfo, COL_INFO,
 			     "conv_who_are_you2 response seq:%u st:%s cas:%08x-%04x-%04x-%02x%02x-%02x%02x%02x%02x%02x%02x",
 			     seq, val_to_str_ext(st, &dce_error_vals_ext, "%u"),
 			     cas_uuid.Data1, cas_uuid.Data2, cas_uuid.Data3,
 			     cas_uuid.Data4[0], cas_uuid.Data4[1], cas_uuid.Data4[2], cas_uuid.Data4[3],
 			     cas_uuid.Data4[4], cas_uuid.Data4[5], cas_uuid.Data4[6], cas_uuid.Data4[7]);
-        }
 
 	return offset;
 }
