@@ -2,7 +2,7 @@
  * Routines for dcerpc endpoint mapper dissection
  * Copyright 2001, Todd Sabin <tas@webspan.net>
  *
- * $Id$
+ * $Id: packet-dcerpc-epm.c 52310 2013-10-01 13:02:12Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -70,6 +70,9 @@ static gint ett_epm = -1;
 static gint ett_epm_tower_floor = -1;
 static gint ett_epm_entry = -1;
 
+static expert_field ei_epm_proto_undecoded = EI_INIT;
+
+
 /* the UUID is identical for interface versions 3 and 4 */
 static e_uuid_t uuid_epm = { 0xe1af8308, 0x5d1f, 0x11c9, { 0x91, 0xa4, 0x08, 0x00, 0x2b, 0x14, 0xa0, 0xfa } };
 static guint16  ver_epm3 = 3;
@@ -184,7 +187,7 @@ epm_dissect_ept_entry_t(tvbuff_t *tvb, int offset,
                                  hf_epm_ann_offset, NULL);
     offset = dissect_ndr_uint32 (tvb, offset, pinfo, tree, drep,
                                  hf_epm_ann_len, &len);
-    str=tvb_get_ephemeral_string(tvb, offset, len);
+    str=tvb_get_string(wmem_packet_scope(), tvb, offset, len);
     proto_tree_add_item(tree, hf_epm_annotation, tvb, offset, len, ENC_ASCII|ENC_NA);
     offset += len;
 
@@ -193,9 +196,7 @@ epm_dissect_ept_entry_t(tvbuff_t *tvb, int offset,
             proto_item_append_text(item, " Service:%s ", str);
             proto_item_append_text(tree->parent, " Service:%s ", str);
         }
-        if (check_col(pinfo->cinfo, COL_INFO)) {
-            col_append_fstr(pinfo->cinfo, COL_INFO, ", Service:%s", str);
-        }
+        col_append_fstr(pinfo->cinfo, COL_INFO, ", Service:%s", str);
     }
 
     proto_item_set_len(item, offset-old_offset);
@@ -437,17 +438,17 @@ epm_dissect_tower_data (tvbuff_t *tvb, int offset,
 
         case PROTO_ID_NAMED_PIPES: /* \\PIPE\xxx   named pipe */
             proto_tree_add_item(tr, hf_epm_proto_named_pipes, tvb, offset, len, ENC_ASCII|ENC_NA);
-            proto_item_append_text(tr, "NamedPipe:%s", tvb_get_ephemeral_string(tvb, offset, len));
+            proto_item_append_text(tr, "NamedPipe:%s", tvb_get_string(wmem_packet_scope(), tvb, offset, len));
             break;
 
         case PROTO_ID_NAMED_PIPES_2: /* PIPENAME  named pipe */
             proto_tree_add_item(tr, hf_epm_proto_named_pipes, tvb, offset, len, ENC_ASCII|ENC_NA);
-            proto_item_append_text(tr, "PIPE:%s", tvb_get_ephemeral_string(tvb, offset, len));
+            proto_item_append_text(tr, "PIPE:%s", tvb_get_string(wmem_packet_scope(), tvb, offset, len));
             break;
 
         case PROTO_ID_NETBIOS: /* \\NETBIOS   netbios name */
             proto_tree_add_item(tr, hf_epm_proto_netbios_name, tvb, offset, len, ENC_ASCII|ENC_NA);
-            proto_item_append_text(tr, "NetBIOS:%s", tvb_get_ephemeral_string(tvb, offset, len));
+            proto_item_append_text(tr, "NetBIOS:%s", tvb_get_string(wmem_packet_scope(), tvb, offset, len));
             break;
         case PROTO_ID_HTTP: /* RPC over HTTP */
             proto_tree_add_item(tr, hf_epm_proto_http_port, tvb, offset, 2, ENC_BIG_ENDIAN);
@@ -456,10 +457,8 @@ epm_dissect_tower_data (tvbuff_t *tvb, int offset,
 
         default:
             if(len){
-                expert_add_info_format(pinfo, pi, PI_UNDECODED, PI_WARN, "RightHandSide not decoded yet for proto_id 0x%x",
+                expert_add_info_format(pinfo, pi, &ei_epm_proto_undecoded, "RightHandSide not decoded yet for proto_id 0x%x",
                     proto_id);
-                tvb_ensure_bytes_exist(tvb, offset, len);
-                proto_tree_add_text(tr, tvb, offset, len, "RightHandSide not decoded yet for proto_id 0x%x", proto_id);
             }
         }
         offset += len;
@@ -767,10 +766,18 @@ proto_register_epm (void)
         &ett_epm_entry
     };
 
+    static ei_register_info ei[] = {
+        { &ei_epm_proto_undecoded, { "epm.proto_id.undecoded", PI_UNDECODED, PI_WARN, "RightHandSide not decoded yet for proto_id", EXPFILL }},
+    };
+
+    expert_module_t* expert_epm3;
+
     /* interface version 3 */
     proto_epm3 = proto_register_protocol ("DCE/RPC Endpoint Mapper", "EPM", "epm");
     proto_register_field_array (proto_epm3, hf, array_length (hf));
     proto_register_subtree_array (ett, array_length (ett));
+    expert_epm3 = expert_register_protocol(proto_epm3);
+    expert_register_field_array(expert_epm3, ei, array_length(ei));
 
     /* interface version 4 */
     proto_epm4 = proto_register_protocol ("DCE/RPC Endpoint Mapper v4", "EPMv4", "epm4");
