@@ -2,7 +2,7 @@
  * Routines for DCERPC NDR dissection
  * Copyright 2001, Todd Sabin <tas@webspan.net>
  *
- * $Id$
+ * $Id: packet-dcerpc-ndr.c 52310 2013-10-01 13:02:12Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,7 +28,7 @@
 #include <glib.h>
 
 #include <epan/packet.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include "packet-dcerpc.h"
 
 
@@ -85,7 +85,7 @@ PIDL_dissect_uint8(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 
         hf_info = proto_registrar_get_nth(hfindex);
 
-        valstr = (char *)ep_alloc(64);
+        valstr = (char *)wmem_alloc(wmem_packet_scope(), 64);
         valstr[0]=0;
 
         switch (hf_info->display) {
@@ -107,9 +107,7 @@ PIDL_dissect_uint8(tvbuff_t *tvb, gint offset, packet_info *pinfo,
             REPORT_DISSECTOR_BUG("Invalid hf->display value");
         }
 
-        if (check_col(pinfo->cinfo, COL_INFO)) {
-            col_append_fstr(pinfo->cinfo, COL_INFO," %s:%s", hf_info->name, valstr);
-        }
+        col_append_fstr(pinfo->cinfo, COL_INFO," %s:%s", hf_info->name, valstr);
     }
 
     return offset;
@@ -169,7 +167,7 @@ PIDL_dissect_uint16(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 
         hf_info = proto_registrar_get_nth(hfindex);
 
-        valstr = (char *)ep_alloc(64);
+        valstr = (char *)wmem_alloc(wmem_packet_scope(), 64);
         valstr[0]=0;
 
         switch (hf_info->display) {
@@ -191,9 +189,7 @@ PIDL_dissect_uint16(tvbuff_t *tvb, gint offset, packet_info *pinfo,
             REPORT_DISSECTOR_BUG("Invalid hf->display value");
         }
 
-        if (check_col(pinfo->cinfo, COL_INFO)) {
-            col_append_fstr(pinfo->cinfo, COL_INFO," %s:%s", hf_info->name, valstr);
-        }
+        col_append_fstr(pinfo->cinfo, COL_INFO," %s:%s", hf_info->name, valstr);
     }
 
     return offset;
@@ -300,7 +296,7 @@ PIDL_dissect_uint32(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 
         hf_info = proto_registrar_get_nth(hfindex);
 
-        valstr = (char *)ep_alloc(64);
+        valstr = (char *)wmem_alloc(wmem_packet_scope(), 64);
         valstr[0]=0;
 
         switch (hf_info->display) {
@@ -322,9 +318,7 @@ PIDL_dissect_uint32(tvbuff_t *tvb, gint offset, packet_info *pinfo,
             REPORT_DISSECTOR_BUG("Invalid hf->display value");
         }
 
-        if (check_col(pinfo->cinfo, COL_INFO)) {
-            col_append_fstr(pinfo->cinfo, COL_INFO," %s:%s", hf_info->name, valstr);
-        }
+        col_append_fstr(pinfo->cinfo, COL_INFO," %s:%s", hf_info->name, valstr);
     }
 
     return offset;
@@ -383,9 +377,9 @@ dissect_ndr_uint64(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 
     if (!di->no_align && (offset % 8)) {
         gint padding = 8 - (offset % 8);
+        offset += padding;
         /*add the item for padding bytes*/
         proto_tree_add_text(tree, tvb, offset, padding, "NDR-Padding: %d bytes", padding);
-        offset += padding;
     }
     return dissect_dcerpc_uint64(tvb, offset, pinfo,
                                  tree, drep, hfindex, pdata);
@@ -417,7 +411,7 @@ PIDL_dissect_uint64(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 
         hf_info = proto_registrar_get_nth(hfindex);
 
-        valstr = (char *)ep_alloc(64);
+        valstr = (char *)wmem_alloc(wmem_packet_scope(), 64);
         valstr[0]=0;
 
         switch (hf_info->display) {
@@ -439,9 +433,7 @@ PIDL_dissect_uint64(tvbuff_t *tvb, gint offset, packet_info *pinfo,
             REPORT_DISSECTOR_BUG("Invalid hf->display value");
         }
 
-        if (check_col(pinfo->cinfo, COL_INFO)) {
-            col_append_fstr(pinfo->cinfo, COL_INFO," %s:%s", hf_info->name, valstr);
-        }
+        col_append_fstr(pinfo->cinfo, COL_INFO," %s:%s", hf_info->name, valstr);
     }
 
     return offset;
