@@ -6,7 +6,7 @@
  * Copyright 2001-2003, Tim Potter <tpot@samba.org>
  * Copyright 2011, Matthieu Patou <mat@matws.net>
  *
- * $Id$
+ * $Id: packet-dcerpc-nt.c 52310 2013-10-01 13:02:12Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -33,7 +33,7 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include "packet-dcerpc.h"
 #include "packet-dcerpc-nt.h"
 #include "packet-windows-common.h"
@@ -82,7 +82,7 @@ dissect_ndr_datablob(tvbuff_t *tvb, int offset, packet_info *pinfo,
 			int use_remaining_space)
 {
 	proto_item *item;
-	guint3264 len;
+	guint32 len;
 	proto_tree *subtree = tree;
 
 	item = proto_tree_add_text(tree, tvb, offset, 0, "%s",
@@ -93,11 +93,11 @@ dissect_ndr_datablob(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	if (use_remaining_space) {
 		len = tvb_length_remaining (tvb, offset);
 	} else {
-		offset = dissect_ndr_uint3264(tvb, offset, pinfo, subtree, drep,
+		offset = dissect_ndr_uint32(tvb, offset, pinfo, subtree, drep,
 				    hf_nt_data_blob_len, &len);
 	}
-	proto_tree_add_text(subtree, tvb, offset, (int)len, "Blob data");
-	offset += (int)len;
+	proto_tree_add_text(subtree, tvb, offset, len, "Blob data");
+	offset += len;
 	return offset;
 }
 
@@ -129,8 +129,8 @@ dissect_null_term_string(tvbuff_t *tvb, int offset,
 	}
 
 	len = tmp_offset - offset;
-	/* tvb_get_ephemeral_string didn't want the length with the 0*/
-	s = tvb_get_ephemeral_string(tvb, offset, len);
+	/* tvb_get_string didn't want the length with the 0*/
+	s = tvb_get_string(wmem_packet_scope(), tvb, offset, len);
 	proto_tree_add_string(tree, hf_index, tvb, offset, len + 1, s);
 
 	return tmp_offset;
@@ -165,8 +165,8 @@ dissect_null_term_wstring(tvbuff_t *tvb, int offset,
 	}
 	len = tmp_offset - offset;
 
-	/* tvb_get_ephemeral_string didn't want the length with the 0*/
-	s = tvb_get_unicode_string(tvb, offset, len, ENC_LITTLE_ENDIAN);
+	/* tvb_get_string didn't want the length with the 0*/
+	s = tvb_get_unicode_string(NULL, tvb, offset, len, ENC_LITTLE_ENDIAN);
 	proto_tree_add_string(tree, hf_index, tvb, offset, len, s);
 	g_free(s);
 
@@ -357,8 +357,7 @@ static void cb_byte_array_postprocess(packet_info *pinfo, proto_tree *tree _U_,
 	/* Append string to COL_INFO */
 
 	if (options & CB_STR_COL_INFO) {
-		if (check_col(pinfo->cinfo, COL_INFO))
-			col_append_fstr(pinfo->cinfo, COL_INFO, ", %s", s);
+		col_append_fstr(pinfo->cinfo, COL_INFO, ", %s", s);
 	}
 
 	/* Append string to upper-level proto_items */
@@ -665,10 +664,10 @@ static void add_pol_handle(e_ctx_hnd *policy_hnd, guint32 frame,
 		 * and put the hash value in the policy handle hash
 		 * table.
 		 */
-		value = (pol_hash_value *)se_alloc(sizeof(pol_hash_value));
+		value = (pol_hash_value *)wmem_alloc(wmem_file_scope(), sizeof(pol_hash_value));
 		value->list = pol;
 		pol->next = NULL;
-		key = (pol_hash_key *)se_alloc(sizeof(pol_hash_key));
+		key = (pol_hash_key *)wmem_alloc(wmem_file_scope(), sizeof(pol_hash_key));
 		memcpy(&key->policy_hnd, policy_hnd, sizeof(key->policy_hnd));
 		g_hash_table_insert(pol_hash, key, value);
 	} else {
@@ -765,7 +764,7 @@ void dcerpc_smb_store_pol_pkts(e_ctx_hnd *policy_hnd, packet_info *pinfo,
 
 	/* Create a new value */
 
-	pol = (pol_value *)se_alloc(sizeof(pol_value));
+	pol = (pol_value *)wmem_alloc(wmem_file_scope(), sizeof(pol_value));
 
 	pol->open_frame = is_open ? pinfo->fd->num : 0;
 	pol->close_frame = is_close ? pinfo->fd->num : 0;
@@ -837,17 +836,17 @@ void dcerpc_store_polhnd_name(e_ctx_hnd *policy_hnd, packet_info *pinfo,
 			if (strcmp(pol->name, name) != 0)
 				g_warning("dcerpc_smb: pol_hash name collision %s/%s\n", value->name, name);
 #endif
-			/* pol->name is se_allocated, don't free it now */
+			/* pol->name is wmem_file_scope() allocated, don't free it now */
 		}
 
-		pol->name = se_strdup(name);
+		pol->name = wmem_strdup(wmem_file_scope(), name);
 
 		return;
 	}
 
 	/* Create a new value */
 
-	pol = (pol_value *)se_alloc(sizeof(pol_value));
+	pol = (pol_value *)wmem_alloc(wmem_file_scope(), sizeof(pol_value));
 
 	pol->open_frame = 0;
 	pol->close_frame = 0;
@@ -855,9 +854,9 @@ void dcerpc_store_polhnd_name(e_ctx_hnd *policy_hnd, packet_info *pinfo,
 	pol->last_frame = 0;
 	pol->type = 0;
 	if (name)
-		pol->name = se_strdup(name);
+		pol->name = wmem_strdup(wmem_file_scope(), name);
 	else
-		pol->name = se_strdup("<UNKNOWN>");
+		pol->name = wmem_strdup(wmem_file_scope(), "<UNKNOWN>");
 
 	add_pol_handle(policy_hnd, pinfo->fd->num, pol, value);
 }
@@ -940,7 +939,7 @@ dissect_ntstatus(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 	offset = dissect_ndr_uint32(tvb, offset, pinfo, tree, drep,
 				    hfindex, &status);
 
-	if (status != 0 && check_col(pinfo->cinfo, COL_INFO))
+	if (status != 0)
 		col_append_fstr(pinfo->cinfo, COL_INFO, ", %s",
 				val_to_str(status, NT_errors,
 					   "Unknown error 0x%08x"));
@@ -962,7 +961,7 @@ dissect_doserror(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 	offset = dissect_ndr_uint32(tvb, offset, pinfo, tree, drep,
 				    hfindex, &status);
 
-	if (status != 0 && check_col(pinfo->cinfo, COL_INFO))
+	if (status != 0)
 		col_append_fstr(pinfo->cinfo, COL_INFO, ", %s",
 				val_to_str(status, DOS_errors,
 					   "Unknown error 0x%08x"));
@@ -1145,7 +1144,7 @@ PIDL_dissect_policy_hnd(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 		if(!pol_name){
 			pol_name="<...>";
 		}
-		pol_string=ep_strdup_printf("%s(%s)", pinfo->dcerpc_procedure_name, pol_name);
+		pol_string=wmem_strdup_printf(wmem_packet_scope(), "%s(%s)", pinfo->dcerpc_procedure_name, pol_name);
 		dcerpc_store_polhnd_name(&policy_hnd, pinfo, pol_string);
 		dcerpc_store_polhnd_type(&policy_hnd, pinfo, param&PIDL_POLHND_TYPE_MASK);
 	}
@@ -1157,7 +1156,7 @@ PIDL_dissect_policy_hnd(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 
 		dcv = (dcerpc_call_value *)di->call_data;
 		if(!dcv->pol){
-			dcv->pol=(e_ctx_hnd *)se_memdup(&policy_hnd, sizeof(e_ctx_hnd));
+			dcv->pol=(e_ctx_hnd *)wmem_memdup(wmem_file_scope(), &policy_hnd, sizeof(e_ctx_hnd));
 		}
 	}
 
@@ -1285,15 +1284,14 @@ void cb_wstr_postprocess(packet_info *pinfo, proto_tree *tree _U_,
 	 * some way we can get that string, rather than duplicating the
 	 * efforts of that routine?
 	 */
-	s = tvb_get_ephemeral_unicode_string(
+	s = tvb_get_unicode_string(wmem_packet_scope(),
 		tvb, start_offset + 12, end_offset - start_offset - 12,
 		ENC_LITTLE_ENDIAN);
 
 	/* Append string to COL_INFO */
 
 	if (options & CB_STR_COL_INFO) {
-		if (check_col(pinfo->cinfo, COL_INFO))
-			col_append_fstr(pinfo->cinfo, COL_INFO, ", %s", s);
+		col_append_fstr(pinfo->cinfo, COL_INFO, ", %s", s);
 	}
 
 	/* Append string to upper-level proto_items */
@@ -1348,14 +1346,13 @@ void cb_str_postprocess(packet_info *pinfo, proto_tree *tree _U_,
 	 * some way we can get that string, rather than duplicating the
 	 * efforts of that routine?
 	 */
-	s = tvb_get_ephemeral_string(
+	s = tvb_get_string(wmem_packet_scope(),
 		tvb, start_offset + 12, (end_offset - start_offset - 12) );
 
 	/* Append string to COL_INFO */
 
 	if (options & CB_STR_COL_INFO) {
-		if (check_col(pinfo->cinfo, COL_INFO))
-			col_append_fstr(pinfo->cinfo, COL_INFO, ", %s", s);
+		col_append_fstr(pinfo->cinfo, COL_INFO, ", %s", s);
 	}
 
 	/* Append string to upper-level proto_items */
@@ -1443,7 +1440,7 @@ dissect_ndr_nt_SID(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		 * so we need to make its private data have
 		 * session duration as well.
 		 */
-		dcv->private_data = se_strdup(sid_str);
+		dcv->private_data = wmem_strdup(wmem_file_scope(), sid_str);
 	}
 
 	return offset;
@@ -1473,8 +1470,7 @@ dissect_ndr_nt_SID_with_options(tvbuff_t *tvb, int offset, packet_info *pinfo, p
 			   while we just do a conformance run,	 this might
 			   have sideeffects so it needs some more thoughts first.
 			*/
-			if (check_col(pinfo->cinfo, COL_INFO))
-				col_append_fstr(pinfo->cinfo, COL_INFO, ", %s", s);
+			col_append_fstr(pinfo->cinfo, COL_INFO, ", %s", s);
 		}
 
 		/* Append string to upper-level proto_items */
