@@ -5,7 +5,7 @@
  * This information is based off the released idl files from opengroup.
  * ftp://ftp.opengroup.org/pub/dce122/dce/src/security.tar.gz  security/idl/rpriv.idl
  *
- * $Id$
+ * $Id: packet-dcerpc-rpriv.c 52310 2013-10-01 13:02:12Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -77,20 +77,18 @@ rpriv_dissect_get_eptgt_rqst (tvbuff_t *tvb, int offset,
 	/* advance to get size of cell, and princ */
 
 	proto_tree_add_item (tree, hf_rpriv_get_eptgt_rqst_key_t, tvb, offset, key_size, ENC_ASCII|ENC_NA);
-	key_t1 = tvb_get_ephemeral_string(tvb, offset, key_size);
+	key_t1 = tvb_get_string(wmem_packet_scope(), tvb, offset, key_size);
 	offset += key_size;
 
 	offset += 8;
 	offset = dissect_ndr_uint32 (tvb, offset, pinfo, tree, drep, hf_rpriv_get_eptgt_rqst_key_size2, &key_size2);
 	proto_tree_add_item (tree, hf_rpriv_get_eptgt_rqst_key_t2, tvb, offset, key_size2, ENC_ASCII|ENC_NA);
-	key_t2 = tvb_get_ephemeral_string(tvb, offset, key_size2);
+	key_t2 = tvb_get_string(wmem_packet_scope(), tvb, offset, key_size2);
 	offset += key_size2;
 
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO,
+	col_append_fstr(pinfo->cinfo, COL_INFO,
 				" Request for: %s in %s ", key_t2, key_t1);
-	}
 
 	return offset;
 
