@@ -5,7 +5,7 @@
  * This information is based off the released idl files from opengroup.
  * ftp://ftp.opengroup.org/pub/dce122/dce/src/security.tar.gz security/idl/rs_acct.idl
  *
- * $Id$
+ * $Id: packet-dcerpc-rs_acct.c 52310 2013-10-01 13:02:12Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -66,13 +66,11 @@ rs_acct_dissect_lookup_rqst (tvbuff_t *tvb, int offset,
 
 	if (key_size){ /* Not able to yet decipher the OTHER versions of this call just yet. */
 		proto_tree_add_item (tree, hf_rs_acct_lookup_rqst_key_t, tvb, offset, key_size, ENC_ASCII|ENC_NA);
-		keyx_t = tvb_get_ephemeral_string(tvb, offset, key_size);
+		keyx_t = tvb_get_string(wmem_packet_scope(), tvb, offset, key_size);
 		offset += key_size;
 
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_append_fstr(pinfo->cinfo, COL_INFO,
+		col_append_fstr(pinfo->cinfo, COL_INFO,
 				" Request for: %s ", keyx_t);
-		}
 	} else {
 		col_append_str(pinfo->cinfo, COL_INFO,
 				" Request (other)");
@@ -97,13 +95,11 @@ rs_acct_dissect_get_projlist_rqst (tvbuff_t *tvb, int offset,
 
 	proto_tree_add_item (tree, hf_rs_acct_get_projlist_rqst_key_t,
 			     tvb, offset, key_size, ENC_ASCII|ENC_NA);
-	keyx_t = tvb_get_ephemeral_string(tvb, offset, key_size);
+	keyx_t = tvb_get_string(wmem_packet_scope(), tvb, offset, key_size);
 	offset += key_size;
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO,
+	col_append_fstr(pinfo->cinfo, COL_INFO,
 			" Request for: %s", keyx_t);
-	}
 
 	return offset;
 }
