@@ -5,7 +5,7 @@
  * This information is based off the released idl files from opengroup.
  * ftp://ftp.opengroup.org/pub/dce122/dce/src/security.tar.gz security/idl/rs_misc.idl
  *
- * $Id$
+ * $Id: packet-dcerpc-rs_misc.c 52310 2013-10-01 13:02:12Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -64,13 +64,11 @@ rs_misc_dissect_login_get_info_rqst (tvbuff_t *tvb, int offset,
 	if (key_size){ /* Not able to yet decipher the OTHER versions of this call just yet. */
 
 		proto_tree_add_item (tree, hf_rs_misc_login_get_info_rqst_key_t, tvb, offset, key_size, ENC_ASCII|ENC_NA);
-		key_t1 = tvb_get_ephemeral_string(tvb, offset, key_size);
+		key_t1 = tvb_get_string(wmem_packet_scope(), tvb, offset, key_size);
 		offset += key_size;
 
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_append_fstr(pinfo->cinfo, COL_INFO,
+		col_append_fstr(pinfo->cinfo, COL_INFO,
 				"rs_login_get_info Request for: %s ", key_t1);
-		}
 	} else {
 		col_append_str(pinfo->cinfo, COL_INFO,
 				"rs_login_get_info Request (other)");
