@@ -4,7 +4,7 @@
  * Copyright 2003, Ronnie Sahlberg,  added function dissectors
  * Copyright 2010, Brett Kuskie <fullaxx@gmail.com>
  *
- * $Id$
+ * $Id: packet-dcerpc-svcctl.c 52310 2013-10-01 13:02:12Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,7 +29,7 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include "packet-dcerpc.h"
 #include "packet-dcerpc-svcctl.h"
 #include "packet-dcerpc-nt.h"
@@ -279,7 +279,7 @@ svcctl_dissect_OpenSCManager_rqst(tvbuff_t *tvb, int offset,
 	/* OpenSCManager() stores the server\database  in se_data */
 	if(!pinfo->fd->flags.visited){
 		if(!dcv->se_data){
-			dcv->se_data=se_strdup_printf("%s\\%s",mn,dn);
+			dcv->se_data=wmem_strdup_printf(wmem_file_scope(), "%s\\%s",mn,dn);
 		}
 	}
 
@@ -315,7 +315,7 @@ svcctl_dissect_OpenSCManager_reply(tvbuff_t *tvb, int offset,
 		const char *pol_name;
 
 		if (dcv->se_data){
-			pol_name = ep_strdup_printf(
+			pol_name = wmem_strdup_printf(wmem_packet_scope(),
 				"OpenSCManagerW(%s)", (char *)dcv->se_data);
 		} else {
 			pol_name = "Unknown OpenSCManagerW() handle";
@@ -365,7 +365,7 @@ svcctl_dissect_OpenSCManagerW_rqst(tvbuff_t *tvb, int offset,
 	/* OpenSCManager() stores the server\database  in se_data */
 	if(!pinfo->fd->flags.visited){
 		if(!dcv->se_data){
-			dcv->se_data=se_strdup_printf("%s\\%s",mn,dn);
+			dcv->se_data=wmem_strdup_printf(wmem_file_scope(), "%s\\%s",mn,dn);
 		}
 	}
 
@@ -401,7 +401,7 @@ svcctl_dissect_OpenSCManagerW_reply(tvbuff_t *tvb, int offset,
 		const char *pol_name;
 
 		if (dcv->se_data){
-			pol_name = ep_strdup_printf(
+			pol_name = wmem_strdup_printf(wmem_packet_scope(),
 				"OpenSCManagerW(%s)", (char *)dcv->se_data);
 		} else {
 			pol_name = "Unknown OpenSCManagerW() handle";
@@ -540,8 +540,7 @@ svcctl_dissect_CloseServiceHandle_rqst(tvbuff_t *tvb, int offset,
 	dcerpc_fetch_polhnd_data(&policy_hnd, &pol_name, NULL, NULL, NULL,
 			     pinfo->fd->num);
 
-	if (check_col(pinfo->cinfo, COL_INFO) && pol_name)
-		col_append_fstr(pinfo->cinfo, COL_INFO, ", %s",
+	col_append_fstr(pinfo->cinfo, COL_INFO, ", %s",
 				pol_name);
 
 	return offset;
