@@ -2,7 +2,7 @@
  * Routines for ETSI Distribution & Communication Protocol
  * Copyright 2006, British Broadcasting Corporation
  *
- * $Id$
+ * $Id: packet-dcp-etsi.c 52468 2013-10-09 16:20:54Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,7 +32,7 @@
 #include <epan/reassemble.h>
 #include <wsutil/crcdrm.h>
 #include <epan/reedsolomon.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <string.h>
 
 /* forward reference */
@@ -148,6 +148,7 @@ dissect_dcp_etsi (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void *
 {
   guint8 *sync;
   proto_tree *dcp_tree = NULL;
+  guint16 word;
 
   /* 6.1 AF packet structure
    *
@@ -179,9 +180,10 @@ dissect_dcp_etsi (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void *
   if(tvb_length(tvb) < 11)
     return FALSE;
 
-  sync = tvb_get_ephemeral_string (tvb, 0, 2);
-  if((sync[0]!='A' && sync[0]!='P') || sync[1]!='F')
-    return FALSE;
+  word = tvb_get_ntohs(tvb,0);
+  /* Check for 'AF or 'PF' */
+  if(word != 0x4146 && word != 0x5046)
+	  return FALSE;
 
   pinfo->current_proto = "DCP (ETSI)";
 
@@ -196,6 +198,7 @@ dissect_dcp_etsi (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void *
     dcp_tree = proto_item_add_subtree (ti, ett_edcp);
   }
 
+  sync = tvb_get_string (wmem_packet_scope(), tvb, 0, 2);
   dissector_try_string(dcp_dissector_table, (char*)sync, tvb, pinfo, dcp_tree);
   return TRUE;
 }
@@ -256,7 +259,7 @@ dissect_pft_fec_detailed(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree,
   gboolean fec _U_,
   guint16 rsk,
   guint16 rsz,
-  fragment_data *fdx
+  fragment_head *fdx
 )
 {
   guint32 decoded_size;
@@ -281,27 +284,27 @@ dissect_pft_fec_detailed(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree,
   else {
     guint fragments=0;
     guint32 *got;
-    fragment_data *fd;
-    fragment_data *fd_head;
+    fragment_item *fd;
+    fragment_head *fd_head;
 
     if(tree)
       proto_tree_add_text (tree, tvb, 0, -1, "want %d, got %d need %d",
                            fcount, fragments, rx_min
         );
-    got = (guint32 *)ep_alloc(fcount*sizeof(guint32));
+    got = (guint32 *)wmem_alloc(wmem_packet_scope(), fcount*sizeof(guint32));
 
     /* make a list of the findex (offset) numbers of the fragments we have */
     fd = fragment_get(&dcp_reassembly_table, pinfo, seq, NULL);
     for (fd_head = fd; fd_head != NULL && fragments < fcount; fd_head = fd_head->next) {
-      if(fd_head->data) {
+      if(fd_head->tvb_data) {
         got[fragments++] = fd_head->offset; /* this is the findex of the fragment */
       }
     }
     /* have we got enough for Reed Solomon to try to correct ? */
     if(fragments>=rx_min) { /* yes, in theory */
       guint i,current_findex;
-      fragment_data *frag=NULL;
-      guint8 *dummy_data = (guint8*) ep_alloc0 (plen);
+      fragment_head *frag=NULL;
+      guint8 *dummy_data = (guint8*) wmem_alloc0 (wmem_packet_scope(), plen);
       tvbuff_t *dummytvb = tvb_new_real_data(dummy_data, plen, plen);
       /* try and decode with missing fragments */
       if(tree)
@@ -393,7 +396,7 @@ dissect_pft_fragmented(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree,
 {
   gboolean first, last;
   tvbuff_t *new_tvb=NULL;
-  fragment_data *frag_edcp = NULL;
+  fragment_head *frag_edcp = NULL;
   pinfo->fragmented = TRUE;
   first = findex == 0;
   last = fcount == (findex+1);
@@ -602,7 +605,8 @@ dissect_af (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
       proto_tree_add_boolean(af_tree, hf_edcp_crc_ok, tvb, offset, 2, c==0xe2f0);
     }
   }
-  offset += 2;
+  /*offset += 2;*/
+
   dissector_try_uint(af_dissector_table, pt, next_tvb, pinfo, tree);
 }
 
@@ -635,14 +639,14 @@ dissect_tpl(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
   while(offset<tvb_length(tvb)) {
     guint32 bits;
     guint32 bytes;
-    char *tag = (char*)tvb_get_ephemeral_string (tvb, offset, 4); offset += 4;
+    char *tag = (char*)tvb_get_string (wmem_packet_scope(), tvb, offset, 4); offset += 4;
     bits = tvb_get_ntohl(tvb, offset); offset += 4;
     bytes = bits / 8;
     if(bits % 8)
       bytes++;
     if(tree) {
       if(strcmp(tag, "*ptr")==0) {
-        prot = (char*)tvb_get_ephemeral_string (tvb, offset, 4);
+        prot = (char*)tvb_get_string (wmem_packet_scope(), tvb, offset, 4);
         maj = tvb_get_ntohs(tvb, offset+4);
         min = tvb_get_ntohs(tvb, offset+6);
         proto_tree_add_bytes_format(tpl_tree, hf_tpl_tlv, tvb,
@@ -903,10 +907,10 @@ proto_register_dcp_etsi (void)
   dcp_dissector_table = register_dissector_table("dcp-etsi.sync",
             "DCP Sync", FT_STRING, BASE_NONE);
   af_dissector_table = register_dissector_table("dcp-af.pt",
-            "AF Payload Type", FT_UINT8, BASE_DEC);
+            "DCP-AF Payload Type", FT_UINT8, BASE_DEC);
 
   tpl_dissector_table = register_dissector_table("dcp-tpl.ptr",
-            "AF Payload Type", FT_STRING, BASE_NONE);
+            "DCP-TPL Protocol Type & Revision", FT_STRING, BASE_NONE);
 
   register_init_routine(dcp_init_protocol);
 
