@@ -1,7 +1,7 @@
 /* packet-dec-bpdu.c
  * Routines for DEC BPDU (DEC Spanning Tree Protocol) disassembly
  *
- * $Id$
+ * $Id: packet-dec-bpdu.c 51958 2013-09-11 21:37:58Z cmaynard $
  *
  * Copyright 2001 Paul Ionescu <paul@acorp.ro>
  *
@@ -280,6 +280,6 @@ proto_reg_handoff_dec_bpdu(void)
     dec_bpdu_handle = create_dissector_handle(dissect_dec_bpdu,
                                               proto_dec_bpdu);
     dissector_add_uint("ethertype", ETHERTYPE_DEC_LB, dec_bpdu_handle);
-    dissector_add_uint("chdlctype", ETHERTYPE_DEC_LB, dec_bpdu_handle);
+    dissector_add_uint("chdlc.protocol", ETHERTYPE_DEC_LB, dec_bpdu_handle);
     dissector_add_uint("ppp.protocol", PPP_DEC_LB, dec_bpdu_handle);
 }
