@@ -6,7 +6,7 @@
  * Copyright 2003-2005 Fred Hoekstra, Philips Medical Systems.
  *                (fred.hoekstra@philips.com)
  *
- * $Id$
+ * $Id: packet-dec-dnart.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Use was made of the following documentation:
  *
@@ -51,7 +51,7 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/etypes.h>
 #include <epan/ppptypes.h>
 
@@ -346,19 +346,18 @@ dnet_ntoa(const guint8 *data)
 {
     if (data[0] == 0xAA && data[1] == 0x00 && data[2] == 0x04 && data[3] == 0x00) {
         guint16 dnet_addr = data[4] | (data[5] << 8);
-        return ep_strdup_printf("%d.%d", dnet_addr >> 10, dnet_addr & 0x03FF);
+        return wmem_strdup_printf(wmem_packet_scope(), "%d.%d", dnet_addr >> 10, dnet_addr & 0x03FF);
     }
     return NULL;
 }
 
 static void
-set_dnet_address(packet_info *pinfo, address *paddr_src, address *paddr_tgt)
+set_dnet_address(address *paddr_src, address *paddr_tgt)
 {
     if (paddr_tgt->type != AT_STRINGZ && paddr_src->type == AT_ETHER) {
         char *addr = dnet_ntoa((const guint8 *)paddr_src->data);
         if (addr != NULL)
-            SET_ADDRESS(paddr_tgt, AT_STRINGZ, 1,
-                    wmem_strdup(pinfo->pool, addr));
+            SET_ADDRESS(paddr_tgt, AT_STRINGZ, 1, addr);
     }
 }
 
@@ -379,10 +378,10 @@ dissect_dec_rt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "DEC DNA");
     col_clear(pinfo->cinfo, COL_INFO);
 
-    set_dnet_address(pinfo, &pinfo->dl_src, &pinfo->net_src);
-    set_dnet_address(pinfo, &pinfo->dl_src, &pinfo->src);
-    set_dnet_address(pinfo, &pinfo->dl_dst, &pinfo->net_dst);
-    set_dnet_address(pinfo, &pinfo->dl_dst, &pinfo->dst);
+    set_dnet_address(&pinfo->dl_src, &pinfo->net_src);
+    set_dnet_address(&pinfo->dl_src, &pinfo->src);
+    set_dnet_address(&pinfo->dl_dst, &pinfo->net_dst);
+    set_dnet_address(&pinfo->dl_dst, &pinfo->dst);
 
     offset += 2;
     msg_flags = tvb_get_guint8(tvb, offset);
@@ -463,7 +462,7 @@ dissect_dec_rt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         offset += 3;
         ti = proto_tree_add_item(rt_tree, hf_dec_rt_dst_addr, tvb,
                 offset, 6, ENC_NA);
-        addr = dnet_ntoa((const guint8 *)ep_tvb_memdup(tvb, offset, 6));
+        addr = dnet_ntoa((const guint8 *)tvb_memdup(wmem_packet_scope(), tvb, offset, 6));
         if (addr != NULL) {
             proto_item_append_text(ti, " (%s)", addr);
         }
@@ -474,7 +473,7 @@ dissect_dec_rt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         offset += 8;
         ti = proto_tree_add_item(rt_tree, hf_dec_rt_src_addr, tvb,
             offset, 6, ENC_NA);
-        addr = dnet_ntoa((const guint8 *)ep_tvb_memdup(tvb, offset, 6));
+        addr = dnet_ntoa((const guint8 *)tvb_memdup(wmem_packet_scope(), tvb, offset, 6));
         if (addr != NULL) {
             proto_item_append_text(ti, " (%s)", addr);
         }
@@ -542,8 +541,7 @@ dissect_dec_rt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         proto_tree_add_item(nsp_msg_tree, hf_dec_rt_src_node, tvb, offset, 2, ENC_LITTLE_ENDIAN);
         offset += 2;
 
-        offset =
-            handle_nsp_msg(tvb,
+        handle_nsp_msg(tvb,
                            pinfo,
                            nsp_msg_tree,
                            offset,
@@ -565,7 +563,7 @@ do_initialization_msg(
     col_set_str(pinfo->cinfo, COL_INFO, "Routing control, initialization message");
     proto_tree_add_item(tree, hf_dec_rt_src_node, tvb,
         my_offset, 2, ENC_LITTLE_ENDIAN);
-    offset += 2;
+    my_offset += 2;
     proto_tree_add_item(tree, hf_dec_rt_tiinfo, tvb,
         my_offset, 2, ENC_LITTLE_ENDIAN);
     my_offset += 2;
@@ -604,7 +602,7 @@ do_verification_msg(
     col_set_str(pinfo->cinfo, COL_INFO, "Routing control, verification message");
     proto_tree_add_item(tree, hf_dec_rt_src_node, tvb,
         my_offset, 2, ENC_LITTLE_ENDIAN);
-    offset += 2;
+    my_offset += 2;
     remainder_count = tvb_get_guint8(tvb, my_offset);
     if (remainder_count != 0) {
         proto_tree_add_item(tree, hf_dec_rt_fcnval, tvb,
@@ -722,7 +720,7 @@ do_hello_msg(
     my_offset +=3;
     ti = proto_tree_add_item(tree, hf_dec_rt_id, tvb,
         my_offset, 6, ENC_NA);
-    addr = dnet_ntoa((const guint8 *)ep_tvb_memdup(tvb, my_offset, 6));
+    addr = dnet_ntoa((const guint8 *)tvb_memdup(wmem_packet_scope(), tvb, my_offset, 6));
     if (addr != NULL) {
         proto_item_append_text(ti, " (%s)", addr);
     }
@@ -766,7 +764,7 @@ do_hello_msg(
         my_offset += 8;
         ti = proto_tree_add_item(tree, hf_dec_rt_neighbor, tvb,
                 my_offset, 6, ENC_NA);
-        addr = dnet_ntoa((const guint8 *)ep_tvb_memdup(tvb, my_offset, 6));
+        addr = dnet_ntoa((const guint8 *)tvb_memdup(wmem_packet_scope(), tvb, my_offset, 6));
         if (addr != NULL) {
             proto_item_append_text(ti, " (%s)", addr);
         }
@@ -815,7 +813,7 @@ do_hello_msg(
 
                 ti_localb = proto_tree_add_item(list_ether, hf_dec_rt_router_id,
                     tvb, my_offset, 6, ENC_NA);
-                addr = dnet_ntoa((const guint8 *)ep_tvb_memdup(tvb, my_offset, 6));
+                addr = dnet_ntoa((const guint8 *)tvb_memdup(wmem_packet_scope(), tvb, my_offset, 6));
                 if (addr != NULL) {
                     proto_item_append_text(ti_localb, " (%s)", addr);
                 }
@@ -1493,7 +1491,7 @@ proto_reg_handoff_dec_rt(void)
     dec_rt_handle = create_dissector_handle(dissect_dec_rt,
                                             proto_dec_rt);
     dissector_add_uint("ethertype", ETHERTYPE_DNA_RT, dec_rt_handle);
-    dissector_add_uint("chdlctype", ETHERTYPE_DNA_RT, dec_rt_handle);
+    dissector_add_uint("chdlc.protocol", ETHERTYPE_DNA_RT, dec_rt_handle);
     dissector_add_uint("ppp.protocol", PPP_DEC4, dec_rt_handle);
 /*  dissector_add_uint("ppp.protocol", PPP_DECNETCP, dec_rt_handle);*/
 }
