@@ -2,7 +2,7 @@
  * Routines for dissecting 3GPP OctetSting AVP:s
  * Copyright 2008, Anders Broman <anders.broman[at]ericsson.com>
  *
- * $Id$
+ * $Id: packet-diameter_3gpp.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,6 +35,7 @@
 #include <epan/packet.h>
 #include <epan/asn1.h>
 
+#include "packet-diameter.h"
 #include "packet-gsm_map.h"
 #include "packet-gsm_a_common.h"
 #include "packet-e164.h"
@@ -59,10 +60,46 @@ static int hf_diameter_3gpp_service_ind             = -1;
 static int hf_diameter_mbms_service_id              = -1;
 static int hf_diameter_address_digits = -1;
 static int hf_diameter_3gpp_spare_bits = -1;
+static int hf_diameter_3gpp_uar_flags_flags = -1;
+static int hf_diameter_3gpp_uar_flags_flags_bit0 = -1;
 static int hf_diameter_3gpp_feature_list_flags = -1;
 static int hf_diameter_3gpp_feature_list_flags_bit0 = -1;
 static int hf_diameter_3gpp_feature_list_flags_bit1 = -1;
 static int hf_diameter_3gpp_feature_list_flags_bit2 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit0 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit1 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit2 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit3 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit4 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit5 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit6 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit7 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit8 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit9 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit10 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit11 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit12 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit13 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit14 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit15 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit16 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit17 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit18 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit19 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit20 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit21 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit22 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit23 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit24 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit25 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit26 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit27 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit28 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit29 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit30 = -1;
+static int hf_diameter_3gpp_feature_list1_s6a_flags_bit31 = -1;
+static int hf_diameter_3gpp_feature_list2_s6a_flags_bit0 = -1;
+static int hf_diameter_3gpp_feature_list2_s6a_flags_bit1 = -1;
 static int hf_diameter_3gpp_ulr_flags = -1;
 static int hf_diameter_3gpp_ulr_flags_bit0 = -1;
 static int hf_diameter_3gpp_ulr_flags_bit1 = -1;
@@ -71,6 +108,7 @@ static int hf_diameter_3gpp_ulr_flags_bit3 = -1;
 static int hf_diameter_3gpp_ulr_flags_bit4 = -1;
 static int hf_diameter_3gpp_ulr_flags_bit5 = -1;
 static int hf_diameter_3gpp_ulr_flags_bit6 = -1;
+static int hf_diameter_3gpp_ulr_flags_bit7 = -1;
 static int hf_diameter_3gpp_ula_flags = -1;
 static int hf_diameter_3gpp_ula_flags_bit0 = -1;
 static int hf_diameter_3gpp_dsr_flags = -1;
@@ -90,6 +128,7 @@ static int hf_diameter_3gpp_dsr_flags_bit12 = -1;
 static int hf_diameter_3gpp_dsr_flags_bit13 = -1;
 static int hf_diameter_3gpp_dsr_flags_bit14 = -1;
 static int hf_diameter_3gpp_dsr_flags_bit15 = -1;
+static int hf_diameter_3gpp_dsr_flags_bit16 = -1;
 static int hf_diameter_3gpp_dsa_flags = -1;
 static int hf_diameter_3gpp_dsa_flags_bit0 = -1;
 static int hf_diameter_3gpp_ida_flags = -1;
@@ -112,12 +151,14 @@ static int hf_diameter_3gpp_idr_flags_bit2 = -1;
 static int hf_diameter_3gpp_idr_flags_bit3 = -1;
 static int hf_diameter_3gpp_idr_flags_bit4 = -1;
 static int hf_diameter_3gpp_idr_flags_bit5 = -1;
+static int hf_diameter_3gpp_idr_flags_bit6 = -1;
 static int hf_diameter_3gpp_ipv6addr = -1;
 static int hf_diameter_3gpp_mbms_abs_time_ofmbms_data_tfer = -1;
 static int hf_diameter_3gpp_udp_port = -1;
 static gint diameter_3gpp_path_ett = -1;
 static gint diameter_3gpp_msisdn_ett = -1;
 static gint diameter_3gpp_feature_list_ett = -1;
+static gint diameter_3gpp_uar_flags_ett = -1;
 static gint diameter_3gpp_tmgi_ett  = -1;
 static gint diameter_3gpp_ulr_flags_ett = -1;
 static gint diameter_3gpp_ula_flags_ett = -1;
@@ -131,13 +172,54 @@ static gint diameter_3gpp_idr_flags_ett = -1;
 /* Dissector handles */
 static dissector_handle_t xml_handle;
 
+/* AVP Code: 23 3GPP-MS-TimeZone
+ * 3GPP TS 29.061
+ */
+static const value_string daylight_saving_time_vals[] = {
+    {0, "No adjustment"},
+    {1, "+1 hour adjustment for Daylight Saving Time"},
+    {2, "+2 hours adjustment for Daylight Saving Time"},
+    {3, "Reserved"},
+    {0, NULL}
+};
+
+static int
+dissect_diameter_3gpp_ms_timezone(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, void *data _U_)
+{
+    int offset = 0;
+    guint8      oct;
+    char        sign;
+
+    /* 3GPP TS 23.040 version 6.6.0 Release 6
+     * 9.2.3.11 TP-Service-Centre-Time-Stamp (TP-SCTS)
+     * :
+     * The Time Zone indicates the difference, expressed in quarters of an hour,
+     * between the local time and GMT. In the first of the two semi-octets,
+     * the first bit (bit 3 of the seventh octet of the TP-Service-Centre-Time-Stamp field)
+     * represents the algebraic sign of this difference (0: positive, 1: negative).
+     */
+
+    oct = tvb_get_guint8(tvb, offset);
+    sign = (oct & 0x08) ? '-' : '+';
+    oct = (oct >> 4) + (oct & 0x07) * 10;
+
+    proto_tree_add_text(tree, tvb, offset, 1, "Timezone: GMT %c %d hours %d minutes", sign, oct / 4, oct % 4 * 15);
+    offset++;
+
+    oct = tvb_get_guint8(tvb, offset) & 0x3;
+    proto_tree_add_text(tree, tvb, offset, 1, "%s", val_to_str_const(oct, daylight_saving_time_vals, "Unknown"));
+    offset++;
+
+    return offset;
+}
+
 /* AVP Code: 917 MBMS-GGSN-IPv6-Address */
 static int
 dissect_diameter_3gpp_ipv6addr(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, void *data _U_)
 {
     int offset = 0;
 
-    proto_tree_add_item(tree, hf_diameter_3gpp_ipv6addr, tvb, offset, 16, ENC_BIG_ENDIAN);
+    proto_tree_add_item(tree, hf_diameter_3gpp_ipv6addr, tvb, offset, 16, ENC_NA);
 
     offset += 16;
 
@@ -185,7 +267,54 @@ dissect_diameter_3gpp_visited_nw_id(tvbuff_t *tvb, packet_info *pinfo _U_, proto
 
     return length;
 }
+
+/* AVP Code: 629 Feature-List-id
+ * Feature list Id is neede to dissect Feature list in S6a/S6d application
+ * Ref 3GPP TS 29.272
+ */
+
+static int
+dissect_diameter_3gpp_feature_list_id(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree _U_, void *data _U_)
+{
+    diam_sub_dis_t *diam_sub_dis_inf;
+
+    if(pinfo->private_data){
+        diam_sub_dis_inf = (diam_sub_dis_t*)pinfo->private_data;
+        diam_sub_dis_inf->feature_list_id = tvb_get_ntohl(tvb,0);
+    }
+
+	return 4;
+}
+
+/* AVP Code: 637 UAR-Flags
+ * imscxdx.xml
+ * IMS Cx Dx AVPS 3GPP TS 29.229
+ */
+
+static int
+dissect_diameter_3gpp_uar_flags(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, void *data _U_) {
+
+    proto_item* item;
+    proto_tree *sub_tree;
+    int offset = 0;
+    guint32 bit_offset;
+
+    item       = proto_tree_add_item(tree, hf_diameter_3gpp_uar_flags_flags, tvb, offset, 4, ENC_BIG_ENDIAN);
+    sub_tree   = proto_item_add_subtree(item, diameter_3gpp_uar_flags_ett);
+
+    bit_offset = 0;
+    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_spare_bits, tvb, bit_offset, 31, ENC_BIG_ENDIAN);
+    bit_offset+=31;
+    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_uar_flags_flags_bit0, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+    bit_offset++;
+
+    offset = bit_offset>>3;
+
+    return offset;
+}
+
 /* AVP Code: 630 Feature-List
+ * Interpretation depends on Application Id
  * imscxdx.xml
  * IMS Cx Dx AVPS 3GPP TS 29.229
  */
@@ -196,23 +325,106 @@ dissect_diameter_3gpp_feature_list(tvbuff_t *tvb, packet_info *pinfo _U_, proto_
     proto_item* item;
     proto_tree *sub_tree;
     int offset = 0;
-    guint32 bit_offset;
+    guint32 bit_offset, application_id = 0, feature_list_id = 0;
+    diam_sub_dis_t *diam_sub_dis_inf;
 
     item       = proto_tree_add_item(tree, hf_diameter_3gpp_feature_list_flags, tvb, offset, 4, ENC_BIG_ENDIAN);
     sub_tree   = proto_item_add_subtree(item, diameter_3gpp_feature_list_ett);
 
+    if(pinfo->private_data){
+        diam_sub_dis_inf = (diam_sub_dis_t*)pinfo->private_data;
+        application_id = diam_sub_dis_inf->application_id;
+        feature_list_id = diam_sub_dis_inf->feature_list_id;
+    }
     bit_offset = 0;
-    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_spare_bits, tvb, bit_offset, 29, ENC_BIG_ENDIAN);
-    bit_offset+=29;
-    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list_flags_bit2, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
-    bit_offset++;
-    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list_flags_bit1, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
-    bit_offset++;
-    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list_flags_bit0, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
-    bit_offset++;
+    if(application_id == 16777216){
+        /* ApplicationId: 3GPP Cx (16777216) */
+        proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_spare_bits, tvb, bit_offset, 29, ENC_BIG_ENDIAN);
+        bit_offset+=29;
+        proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list_flags_bit2, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+        bit_offset++;
+        proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list_flags_bit1, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+        bit_offset++;
+        proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list_flags_bit0, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+        bit_offset++;
 
-    offset = bit_offset>>3;
-    return offset;
+        /*offset = bit_offset>>3;*/
+    }else if(application_id == 16777251){
+        /* ApplicationId: 3GPP S6a/S6d */
+        if(feature_list_id == 1){
+            /* 3GPP TS 29.272 Table 7.3.10/1: Features of Feature-List-ID 1 used in S6a/S6d */
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit31, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit30, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit29, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit28, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit27, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit26, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit25, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit24, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit23, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit22, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit21, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit20, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit19, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit18, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit17, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit16, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit15, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit14, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit13, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit12, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit11, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit10, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit9, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit8, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit7, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit6, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit5, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit4, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit3, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit2, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit1, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list1_s6a_flags_bit0, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+        }else if(feature_list_id == 2){
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_spare_bits, tvb, bit_offset, 30, ENC_BIG_ENDIAN);
+            bit_offset+=30;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list2_s6a_flags_bit1, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+            bit_offset++;
+            proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_feature_list2_s6a_flags_bit0, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+        }
+    }
+    return 4;
 
 }
 
@@ -431,7 +643,10 @@ dissect_diameter_3gpp_mbms_abs_time_ofmbms_data_tfer(tvbuff_t *tvb, packet_info
     return offset;
 }
 
-/* AVP Code: 1405 ULR-Flags */
+/* 3GPP TS 29.272
+ * 7.3.7 ULR-Flags
+ * AVP Code: 1405 ULR-Flags
+ */
 static int
 dissect_diameter_3gpp_ulr_flags(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, void *data _U_) {
 
@@ -443,8 +658,10 @@ dissect_diameter_3gpp_ulr_flags(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tre
     item = proto_tree_add_item(tree, hf_diameter_3gpp_ulr_flags, tvb, offset, 4, ENC_BIG_ENDIAN);
     sub_tree = proto_item_add_subtree(item, diameter_3gpp_ulr_flags_ett);
     bit_offset = 0;
-    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_spare_bits, tvb, bit_offset, 25, ENC_BIG_ENDIAN);
-    bit_offset+=25;
+    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_spare_bits, tvb, bit_offset, 24, ENC_BIG_ENDIAN);
+    bit_offset+=24;
+    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_ulr_flags_bit7, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+    bit_offset++;
     proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_ulr_flags_bit6, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
     bit_offset++;
     proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_ulr_flags_bit5, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
@@ -487,7 +704,11 @@ dissect_diameter_3gpp_ula_flags(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tre
 
 }
 
-/* AVP Code: 1421 DSR-Flags */
+/*
+ * 3GPP TS 29.272
+ * 7.3.25 DSR-Flags
+ * AVP Code: 1421 DSR-Flags
+ */
 static int
 dissect_diameter_3gpp_dsr_flags(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, void *data _U_) {
 
@@ -499,8 +720,10 @@ dissect_diameter_3gpp_dsr_flags(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tre
     item = proto_tree_add_item(tree, hf_diameter_3gpp_dsr_flags, tvb, offset, 4, ENC_BIG_ENDIAN);
     sub_tree = proto_item_add_subtree(item, diameter_3gpp_dsr_flags_ett);
     bit_offset = 0;
-    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_spare_bits, tvb, bit_offset, 16, ENC_BIG_ENDIAN);
-    bit_offset+=16;
+    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_spare_bits, tvb, bit_offset, 15, ENC_BIG_ENDIAN);
+    bit_offset+=15;
+    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_dsr_flags_bit16, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
+    bit_offset++;
     proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_dsr_flags_bit15, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
     bit_offset++;
     proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_dsr_flags_bit14, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
@@ -654,8 +877,10 @@ dissect_diameter_3gpp_idr_flags(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tre
     item = proto_tree_add_item(tree, hf_diameter_3gpp_idr_flags, tvb, offset, 4, ENC_BIG_ENDIAN);
     sub_tree = proto_item_add_subtree(item, diameter_3gpp_idr_flags_ett);
     bit_offset = 0;
-    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_spare_bits, tvb, bit_offset, 26, ENC_BIG_ENDIAN);
-    bit_offset+=26;
+    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_spare_bits, tvb, bit_offset, 25, ENC_BIG_ENDIAN);
+    bit_offset+=25;
+    proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_idr_flags_bit6, tvb,  bit_offset, 1, ENC_BIG_ENDIAN);
+    bit_offset++;
     proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_idr_flags_bit5, tvb,  bit_offset, 1, ENC_BIG_ENDIAN);
     bit_offset++;
     proto_tree_add_bits_item(sub_tree, hf_diameter_3gpp_idr_flags_bit4, tvb, bit_offset, 1, ENC_BIG_ENDIAN);
@@ -688,15 +913,24 @@ proto_reg_handoff_diameter_3gpp(void)
      * Registered by packet-gtpv2.c
      */
 
-    /* AVP Code: 600 Visited-Network-Identifier */
+    /* AVP Code: 23 3GPP-MS-TimeZone */
+    dissector_add_uint("diameter.3gpp", 23, new_create_dissector_handle(dissect_diameter_3gpp_ms_timezone, proto_diameter_3gpp));
+
+	/* AVP Code: 600 Visited-Network-Identifier */
     dissector_add_uint("diameter.3gpp", 600, new_create_dissector_handle(dissect_diameter_3gpp_visited_nw_id, proto_diameter_3gpp));
 
     /* AVP Code: 606 User-Data */
     dissector_add_uint("diameter.3gpp", 606, new_create_dissector_handle(dissect_diameter_3gpp_user_data, proto_diameter_3gpp));
 
+    /* AVP Code: 629 Feature-List */
+    dissector_add_uint("diameter.3gpp", 629, new_create_dissector_handle(dissect_diameter_3gpp_feature_list_id, proto_diameter_3gpp));
+
     /* AVP Code: 630 Feature-List */
     dissector_add_uint("diameter.3gpp", 630, new_create_dissector_handle(dissect_diameter_3gpp_feature_list, proto_diameter_3gpp));
 
+    /* AVP Code: 637 UAR-Flags */
+    dissector_add_uint("diameter.3gpp", 637, new_create_dissector_handle(dissect_diameter_3gpp_uar_flags, proto_diameter_3gpp));
+
     /* AVP Code: 640 Path */
     dissector_add_uint("diameter.3gpp", 640, new_create_dissector_handle(dissect_diameter_3gpp_path, proto_diameter_3gpp));
 
@@ -836,6 +1070,16 @@ proto_register_diameter_3gpp(void)
             FT_UINT32, BASE_HEX, NULL, 0x0,
             NULL, HFILL }
         },
+        { &hf_diameter_3gpp_uar_flags_flags,
+            { "Flags", "diameter.3gpp.uar_flags_flags",
+            FT_UINT32, BASE_HEX, NULL, 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_uar_flags_flags_bit0,
+            { "Emergency registration", "diameter.3gpp.uar_flags_flags_bit0",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_set_notset), 0x0,
+            NULL, HFILL }
+        },
         { &hf_diameter_3gpp_feature_list_flags,
             { "Feature-List Flags", "diameter.3gpp.feature_list_flags",
             FT_UINT32, BASE_HEX, NULL, 0x0,
@@ -856,6 +1100,177 @@ proto_register_diameter_3gpp(void)
             FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
             NULL, HFILL }
         },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit0,
+            { "Operator Determined Barring of all Packet Oriented Services", "diameter.3gpp.feature_list1_s6a_flags_bit0",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit1,
+            { "Operator Determined Barring of Packet Oriented Services from access points that are within the HPLMN whilst the subscriber is roaming in a VPLMN", "diameter.3gpp.feature_list1_s6a_flags_bit1",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit2,
+            { "Operator Determined Barring of Packet Oriented Services from access points that are within the roamed to VPLMN", "diameter.3gpp.feature_list1_s6a_flags_bit2",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit3,
+            { "Operator Determined Barring of all outgoing calls", "diameter.3gpp.feature_list1_s6a_flags_bit3",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit4,
+            { "Operator Determined Barring of all outgoing international calls", "diameter.3gpp.feature_list1_s6a_flags_bit4",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit5,
+            { "Operator Determined Barring of all outgoing international calls except those directed to the home PLMN country", "diameter.3gpp.feature_list1_s6a_flags_bit5",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit6,
+            { "Operator Determined Barring of all outgoing inter-zonal calls", "diameter.3gpp.feature_list1_s6a_flags_bit6",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit7,
+            { "Operator Determined Barring of all outgoing inter-zonal calls except those directed to the home PLMN country", "diameter.3gpp.feature_list1_s6a_flags_bit7",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit8,
+            { "Operator Determined Barring of all outgoing international calls except those directed to the home PLMN country and Barring of all outgoing inter-zonal calls", "diameter.3gpp.feature_list1_s6a_flags_bit8",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+		{ &hf_diameter_3gpp_feature_list1_s6a_flags_bit9,
+            { "Regional Subscription", "diameter.3gpp.feature_list1_s6a_flags_bit9",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit10,
+            { "Trace Function", "diameter.3gpp.feature_list1_s6a_flags_bit10",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit11,
+            { "All LCS Privacy Exception Classes", "diameter.3gpp.feature_list1_s6a_flags_bit11",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit12,
+            { "Allow location by any LCS client", "diameter.3gpp.feature_list1_s6a_flags_bit12",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit13,
+            { "Allow location by any value added LCS client to which a call/session is established from the target UE", "diameter.3gpp.feature_list1_s6a_flags_bit13",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit14,
+            { "Allow location by designated external value added LCS clients", "diameter.3gpp.feature_list1_s6a_flags_bit14",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit15,
+            { "Allow location by designated PLMN operator LCS clients", "diameter.3gpp.feature_list1_s6a_flags_bit15",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit16,
+            { "Allow location by LCS clients of a designated LCS service type", "diameter.3gpp.feature_list1_s6a_flags_bit16",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit17,
+            { "All Mobile Originating Location Request Classes", "diameter.3gpp.feature_list1_s6a_flags_bit17",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit18,
+            { "Allow an MS to request its own location", "diameter.3gpp.feature_list1_s6a_flags_bit18",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+		{ &hf_diameter_3gpp_feature_list1_s6a_flags_bit19,
+            { "Allow an MS to perform self location without interaction with the PLMN", "diameter.3gpp.feature_list1_s6a_flags_bit19",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit20,
+            { "Allow an MS to request transfer of its location to another LCS client", "diameter.3gpp.feature_list1_s6a_flags_bit20",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit21,
+            { "Short Message MO-PP", "diameter.3gpp.feature_list1_s6a_flags_bit21",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit22,
+            { "Barring of Outgoing Calls", "diameter.3gpp.feature_list1_s6a_flags_bit22",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit23,
+            { "Barring of all outgoing calls", "diameter.3gpp.feature_list1_s6a_flags_bit23",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit24,
+            { "Barring of outgoing international calls", "diameter.3gpp.feature_list1_s6a_flags_bit24",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit25,
+            { "Barring of outgoing international calls except those directed to the home PLMN Country", "diameter.3gpp.feature_list1_s6a_flags_bit25",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit26,
+            { "UE Reachability Notifcation", "diameter.3gpp.feature_list1_s6a_flags_bit26",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit27,
+            { "Terminating Access Domain Selection Data Retrieval", "diameter.3gpp.feature_list1_s6a_flags_bit27",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit28,
+            { "State/Location Information Retrieval", "diameter.3gpp.feature_list1_s6a_flags_bit28",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit29,
+            { "Partial Purge from a Combined MME/SGSN", "diameter.3gpp.feature_list1_s6a_flags_bit29",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit30,
+            { "UE Time Zone Retrieval", "diameter.3gpp.feature_list1_s6a_flags1_bit30",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list1_s6a_flags_bit31,
+            { "Additional MSISDN", "diameter.3gpp.feature_list1_s6a_flags_bit31",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list2_s6a_flags_bit0,
+            { "SMS in MME", "diameter.3gpp.feature_list2_s6a_flags_bit0",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_feature_list2_s6a_flags_bit1,
+            { "SMS in SGSN", "diameter.3gpp.feature_list2_s6a_flags_bit1",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_supported_not_supported), 0x0,
+            NULL, HFILL }
+        },
         { &hf_diameter_3gpp_ulr_flags,
             { "ULR Flags", "diameter.3gpp.ulr_flags",
             FT_UINT32, BASE_HEX, NULL, 0x0,
@@ -896,6 +1311,11 @@ proto_register_diameter_3gpp(void)
             FT_BOOLEAN, BASE_NONE, TFS(&tfs_set_notset), 0x0,
             NULL, HFILL }
         },
+        { &hf_diameter_3gpp_ulr_flags_bit7,
+            { "SMS-Only-Indication", "diameter.3gpp.ulr_flags_bit7",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_set_notset), 0x0,
+            NULL, HFILL }
+        },
         { &hf_diameter_3gpp_ula_flags,
             { "ULA Flags", "diameter.3gpp.ula_flags",
             FT_UINT32, BASE_HEX, NULL, 0x0,
@@ -982,12 +1402,17 @@ proto_register_diameter_3gpp(void)
             NULL, HFILL }
         },
         { &hf_diameter_3gpp_dsr_flags_bit14,
-            { "Subscribed VSRVCC Withdrawal", "diameter.3gpp.dsr_flags_bit14",
+            { "Subscribed periodic RAU-TAU Timer Withdrawal", "diameter.3gpp.dsr_flags_bit14",
             FT_BOOLEAN, BASE_NONE, TFS(&tfs_set_notset), 0x0,
             NULL, HFILL }
         },
         { &hf_diameter_3gpp_dsr_flags_bit15,
-            { "Subscribed periodic RAU-TAU Timer Withdrawal", "diameter.3gpp.dsr_flags_bit15",
+            { "Subscribed VSRVCC Withdrawal", "diameter.3gpp.dsr_flags_bit15",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_set_notset), 0x0,
+            NULL, HFILL }
+        },
+        { &hf_diameter_3gpp_dsr_flags_bit16,
+            { "A-MSISDN Withdrawal", "diameter.3gpp.dsr_flags_bit16",
             FT_BOOLEAN, BASE_NONE, TFS(&tfs_set_notset), 0x0,
             NULL, HFILL }
         },
@@ -1101,6 +1526,11 @@ proto_register_diameter_3gpp(void)
             FT_BOOLEAN, BASE_NONE, TFS(&tfs_set_notset), 0x0,
             NULL, HFILL }
         },
+        { &hf_diameter_3gpp_idr_flags_bit6,
+            { "Remove SMS Registration", "diameter.3gpp.idr_flags_bit6",
+            FT_BOOLEAN, BASE_NONE, TFS(&tfs_set_notset), 0x0,
+            NULL, HFILL }
+        },
         { &hf_diameter_3gpp_ipv6addr,
             { "IPv6 Address", "diameter.3gpp.ipv6addr",
             FT_IPv6, BASE_NONE, NULL, 0x0,
@@ -1122,6 +1552,7 @@ proto_register_diameter_3gpp(void)
     static gint *ett[] = {
         &diameter_3gpp_path_ett,
         &diameter_3gpp_msisdn_ett,
+        &diameter_3gpp_uar_flags_ett,
         &diameter_3gpp_feature_list_ett,
         &diameter_3gpp_tmgi_ett,
         &diameter_3gpp_ulr_flags_ett,
