@@ -2,7 +2,7 @@
  * Routines for dlm3 dissection
  * Copyright 2007, Masatake YAMATO <jet@gyve.org>
  *
- * $Id$
+ * $Id: packet-dlm3.c 50354 2013-07-03 16:43:58Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -683,7 +683,7 @@ dissect_dlm3_rcom_config(tvbuff_t *tvb, proto_tree *tree,
                       hf_dlm3_rf_unused, tvb, offset, 8, ENC_LITTLE_ENDIAN);
 
 
-  offset += 8;
+  /*offset += 8;*/
   /* END */
 }
 
@@ -793,7 +793,7 @@ dissect_dlm3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void *d
                            dlm3_cmd,
                            "packet-dlm3.c internal bug"));
 
-  /* if (parent_tree) */ {
+  if (parent_tree) {
     offset = 0;
 
     item = proto_tree_add_item(parent_tree, proto_dlm3, tvb, offset,
