@@ -2,7 +2,7 @@
  * Routines for dsi packet dissection
  * Copyright 2001, Randy McEoin <rmceoin@pe.com>
  *
- * $Id$
+ * $Id: packet-dsi.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -342,8 +342,7 @@ dissect_dsi_reply_get_status(tvbuff_t *tvb, proto_tree *tree, gint offset)
 
 		sign_ofs = tvb_get_ntohs(tvb, ofs);
 		proto_tree_add_text(tree, tvb, ofs, 2, "Signature offset: %d", sign_ofs);
-		if (sign_ofs)
-			sign_ofs += offset;
+		sign_ofs += offset;
 
 		if ((flag & AFPSRVRINFO_TCPIP)) {
 			ofs += 2;
@@ -366,15 +365,12 @@ dissect_dsi_reply_get_status(tvbuff_t *tvb, proto_tree *tree, gint offset)
 		}
 	}
 
-	ofs = tvb_get_ntohs(tvb, offset +AFPSTATUS_MACHOFF);
-	if (ofs) {
-		ofs += offset;
+	ofs = offset +tvb_get_ntohs(tvb, offset +AFPSTATUS_MACHOFF);
+	if (ofs)
 		proto_tree_add_item(tree, hf_dsi_server_type, tvb, ofs, 1, ENC_ASCII|ENC_NA);
-	}
 
-	ofs = tvb_get_ntohs(tvb, offset +AFPSTATUS_VERSOFF);
+	ofs = offset +tvb_get_ntohs(tvb, offset +AFPSTATUS_VERSOFF);
 	if (ofs) {
-		ofs += offset;
 		nbe = tvb_get_guint8(tvb, ofs);
 		ti = proto_tree_add_text(tree, tvb, ofs, 1, "Version list: %d", nbe);
 		ofs++;
@@ -386,9 +382,8 @@ dissect_dsi_reply_get_status(tvbuff_t *tvb, proto_tree *tree, gint offset)
 		}
 	}
 
-	ofs = tvb_get_ntohs(tvb, offset +AFPSTATUS_UAMSOFF);
+	ofs = offset +tvb_get_ntohs(tvb, offset +AFPSTATUS_UAMSOFF);
 	if (ofs) {
-		ofs += offset;
 		nbe = tvb_get_guint8(tvb, ofs);
 		ti = proto_tree_add_text(tree, tvb, ofs, 1, "UAMS list: %d", nbe);
 		ofs++;
@@ -400,11 +395,9 @@ dissect_dsi_reply_get_status(tvbuff_t *tvb, proto_tree *tree, gint offset)
 		}
 	}
 
-	ofs = tvb_get_ntohs(tvb, offset +AFPSTATUS_ICONOFF);
-	if (ofs) {
-		ofs += offset;
+	ofs = offset +tvb_get_ntohs(tvb, offset +AFPSTATUS_ICONOFF);
+	if (ofs)
 		proto_tree_add_item(tree, hf_dsi_server_icon, tvb, ofs, 256, ENC_NA);
-	}
 
 	if (sign_ofs) {
 		proto_tree_add_item(tree, hf_dsi_server_signature, tvb, sign_ofs, 16, ENC_NA);
@@ -445,7 +438,7 @@ dissect_dsi_reply_get_status(tvbuff_t *tvb, proto_tree *tree, gint offset)
 			case 4: /* DNS */
 			case 5: /* SSH tunnel */
 				if (len > 2) {
-					tmp = tvb_get_ephemeral_string(tvb, ofs +2, len -2);
+					tmp = tvb_get_string(wmem_packet_scope(), tvb, ofs +2, len -2);
 					ti = proto_tree_add_text(adr_tree, tvb, ofs, len, "%s: %s",
 								(type==4)?"dns":"ssh tunnel", tmp);
 					break;
@@ -496,7 +489,7 @@ dissect_dsi_reply_get_status(tvbuff_t *tvb, proto_tree *tree, gint offset)
 
 		ofs = utf_ofs;
 		ulen = tvb_get_ntohs(tvb, ofs);
-		tmp = tvb_get_ephemeral_string(tvb, ofs + 2, ulen);
+		tmp = tvb_get_string(wmem_packet_scope(), tvb, ofs + 2, ulen);
 		ti = proto_tree_add_text(tree, tvb, ofs, ulen + 2, "UTF8 server name: %s", tmp);
 		sub_tree = proto_item_add_subtree(ti, ett_dsi_utf8_name);
 		proto_tree_add_uint(sub_tree, hf_dsi_utf8_server_name_len, tvb, ofs, 2, ulen);
@@ -519,13 +512,10 @@ dissect_dsi_packet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint32		dsi_length;
 	guint32		dsi_reserved;
 	struct		aspinfo aspinfo;
-	gint            col_info;
 
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "DSI");
-	col_info = check_col(pinfo->cinfo, COL_INFO);
-	if (col_info)
-		col_clear(pinfo->cinfo, COL_INFO);
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	dsi_flags = tvb_get_guint8(tvb, 0);
 	dsi_command = tvb_get_guint8(tvb, 1);
@@ -534,15 +524,12 @@ dissect_dsi_packet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	dsi_length = tvb_get_ntohl(tvb, 8);
 	dsi_reserved = tvb_get_ntohl(tvb, 12);
 
-	if (col_info) {
-		col_add_fstr(pinfo->cinfo, COL_INFO, "%s %s (%u)",
+	col_add_fstr(pinfo->cinfo, COL_INFO, "%s %s (%u)",
 			val_to_str(dsi_flags, flag_vals,
 				   "Unknown flag (0x%02x)"),
 			val_to_str_ext(dsi_command, &func_vals_ext,
 				   "Unknown function (0x%02x)"),
 			dsi_requestid);
-	}
-
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_dsi, tvb, 0, -1, ENC_NA);
@@ -566,9 +553,9 @@ dissect_dsi_packet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				4, 4, dsi_code);
 			break;
 		}
-		proto_tree_add_uint_format(dsi_tree, hf_dsi_length, tvb,
+		proto_tree_add_uint_format_value(dsi_tree, hf_dsi_length, tvb,
 			8, 4, dsi_length,
-			"Length: %u bytes", dsi_length);
+			"%u bytes", dsi_length);
 		proto_tree_add_uint(dsi_tree, hf_dsi_reserved, tvb,
 			12, 4, dsi_reserved);
 	}
