@@ -2,7 +2,7 @@
  * Routines for DVB Application Information Table (AIT) dissection
  * Copyright 2012-2013, Martin Kaiser <martin@kaiser.cx>
  *
- * $Id$
+ * $Id: packet-dvb-ait.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -64,6 +64,14 @@ static int hf_dvb_ait_descr_app_name_lang = -1;
 static int hf_dvb_ait_descr_app_name_name = -1;
 static int hf_dvb_ait_descr_trpt_proto_id = -1;
 static int hf_dvb_ait_descr_trpt_proto_label = -1;
+static int hf_dvb_ait_descr_trpt_sel_remote = -1;
+static int hf_dvb_ait_descr_trpt_sel_onid = -1;
+static int hf_dvb_ait_descr_trpt_sel_tsid = -1;
+static int hf_dvb_ait_descr_trpt_sel_svcid = -1;
+static int hf_dvb_ait_descr_trpt_sel_comp = -1;
+static int hf_dvb_ait_descr_trpt_sel_url_base = -1;
+static int hf_dvb_ait_descr_trpt_sel_url_ext_cnt = -1;
+static int hf_dvb_ait_descr_trpt_sel_url_ext = -1;
 static int hf_dvb_ait_descr_trpt_sel_bytes = -1;
 static int hf_dvb_ait_descr_sal_init_path = -1;
 static int hf_dvb_ait_app_loop_len = -1;
@@ -116,9 +124,12 @@ static const value_string ait_descr_tag[] = {
     { 0, NULL }
 };
 
+#define TRPT_OBJ_CAROUSEL 0x0001
+#define TRPT_HTTP         0x0003
+
 static const value_string trpt_proto_id[] = {
-    { 0x0001, "Object Carousel" },
-    { 0x0003, "Transport via HTTP" },
+    { TRPT_OBJ_CAROUSEL, "Object Carousel" },
+    { TRPT_HTTP,         "Transport via HTTP" },
     { 0, NULL }
 };
 
@@ -204,10 +215,13 @@ static gint
 dissect_dvb_ait_trpt_proto_desc_body(tvbuff_t *tvb, guint offset,
         guint8 body_len, packet_info *pinfo _U_, proto_tree *tree)
 {
-    guint   offset_start;
+    guint     offset_start;
+    guint16   proto_id;
+    gboolean  remote_connection;
 
     offset_start = offset;
 
+    proto_id = tvb_get_ntohs(tvb, offset);
     proto_tree_add_item(tree, hf_dvb_ait_descr_trpt_proto_id,
             tvb, offset, 2, ENC_BIG_ENDIAN);
     offset += 2;
@@ -215,9 +229,52 @@ dissect_dvb_ait_trpt_proto_desc_body(tvbuff_t *tvb, guint offset,
             tvb, offset, 1, ENC_BIG_ENDIAN);
     offset++;
     if (offset-offset_start < body_len) {
-        proto_tree_add_item(tree, hf_dvb_ait_descr_trpt_sel_bytes,
-            tvb, offset, offset_start+body_len-offset, ENC_BIG_ENDIAN);
-        offset = offset_start+body_len;
+        if (proto_id == TRPT_OBJ_CAROUSEL) {
+            remote_connection = ((tvb_get_guint8(tvb, offset) & 0x80) == 0x80);
+            proto_tree_add_item(tree, hf_dvb_ait_descr_trpt_sel_remote,
+                tvb, offset, 1, ENC_BIG_ENDIAN);
+            offset++;
+            if (remote_connection) {
+                proto_tree_add_item(tree, hf_dvb_ait_descr_trpt_sel_onid,
+                        tvb, offset, 2, ENC_BIG_ENDIAN);
+                offset += 2;
+                proto_tree_add_item(tree, hf_dvb_ait_descr_trpt_sel_tsid,
+                        tvb, offset, 2, ENC_BIG_ENDIAN);
+                offset += 2;
+                proto_tree_add_item(tree, hf_dvb_ait_descr_trpt_sel_svcid,
+                        tvb, offset, 2, ENC_BIG_ENDIAN);
+                offset += 2;
+            }
+            proto_tree_add_item(tree, hf_dvb_ait_descr_trpt_sel_comp,
+                    tvb, offset, 1, ENC_BIG_ENDIAN);
+            offset++;
+        }
+        else if (proto_id == TRPT_HTTP) {
+            guint8 url_base_len, url_ext_cnt, url_ext_len, i;
+
+            url_base_len = tvb_get_guint8(tvb, offset);
+            /* FT_UINT_STRING with one leading length byte */
+            proto_tree_add_item(tree, hf_dvb_ait_descr_trpt_sel_url_base,
+                tvb, offset, 1, ENC_ASCII|ENC_NA);
+            offset += 1+url_base_len;
+
+            url_ext_cnt = tvb_get_guint8(tvb, offset);
+            proto_tree_add_item(tree, hf_dvb_ait_descr_trpt_sel_url_ext_cnt,
+                tvb, offset, 1, ENC_BIG_ENDIAN);
+            offset++;
+
+            for (i=0; i<url_ext_cnt; i++) {
+                url_ext_len = tvb_get_guint8(tvb, offset);
+                proto_tree_add_item(tree, hf_dvb_ait_descr_trpt_sel_url_ext,
+                        tvb, offset, 1, ENC_ASCII|ENC_NA);
+                offset += 1+url_ext_len;
+            }
+        }
+        else {
+            proto_tree_add_item(tree, hf_dvb_ait_descr_trpt_sel_bytes,
+                tvb, offset, offset_start+body_len-offset, ENC_BIG_ENDIAN);
+            offset = offset_start+body_len;
+        }
     }
 
     return (gint)(offset-offset_start);
@@ -295,7 +352,7 @@ dissect_dvb_ait_descriptor(tvbuff_t *tvb, guint offset,
     return ret;
 }
 
- 
+
 static int
 dissect_dvb_ait(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
@@ -307,7 +364,7 @@ dissect_dvb_ait(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data
     gint        ret;
     guint32     org_id;
     guint16     app_id;
-    
+
     col_clear(pinfo->cinfo, COL_INFO);
     col_set_str(pinfo->cinfo, COL_INFO, "Application Information Table (AIT)");
 
@@ -469,6 +526,30 @@ proto_register_dvb_ait(void)
         { &hf_dvb_ait_descr_trpt_proto_label,
             { "Transport protocol label", "dvb_ait.descr.trpt_proto.label",
                 FT_UINT8, BASE_HEX, NULL, 0, NULL, HFILL } },
+        { &hf_dvb_ait_descr_trpt_sel_remote,
+            { "Remote connection", "dvb_ait.descr.trpt_proto.remote",
+                FT_UINT8, BASE_HEX, NULL, 0x80, NULL, HFILL } },
+        { &hf_dvb_ait_descr_trpt_sel_onid,
+            { "Original network ID", "dvb_ait.descr.trpt_proto.onid",
+                FT_UINT16, BASE_HEX, NULL, 0, NULL, HFILL } },
+        { &hf_dvb_ait_descr_trpt_sel_tsid,
+            { "Transport stream ID", "dvb_ait.descr.trpt_proto.tsid",
+                FT_UINT16, BASE_HEX, NULL, 0, NULL, HFILL } },
+        { &hf_dvb_ait_descr_trpt_sel_svcid,
+            { "Service ID", "dvb_ait.descr.trpt_proto.svcid",
+                FT_UINT16, BASE_HEX, NULL, 0, NULL, HFILL } },
+        { &hf_dvb_ait_descr_trpt_sel_comp,
+            { "Component tag", "dvb_ait.descr.trpt_proto.comp_tag",
+                FT_UINT8, BASE_HEX, NULL, 0, NULL, HFILL } },
+        { &hf_dvb_ait_descr_trpt_sel_url_base,
+            { "URL base", "dvb_ait.descr.trpt_proto.url_base",
+            FT_UINT_STRING, BASE_NONE, NULL, 0, NULL, HFILL } },
+        { &hf_dvb_ait_descr_trpt_sel_url_ext_cnt,
+            { "URL extension count", "dvb_ait.descr.trpt_proto.url_ext_cnt",
+                FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL } },
+        { &hf_dvb_ait_descr_trpt_sel_url_ext,
+            { "URL extension", "dvb_ait.descr.trpt_proto.url_ext",
+            FT_UINT_STRING, BASE_NONE, NULL, 0, NULL, HFILL } },
         { &hf_dvb_ait_descr_trpt_sel_bytes,
             { "Selector bytes", "dvb_ait.descr.trpt_proto.selector_bytes",
                 FT_BYTES, BASE_NONE, NULL, 0, NULL, HFILL } },
