@@ -2,7 +2,7 @@
  * Routines for DVB (ETSI EN 300 468) Time and Date Table (TDT) dissection
  * Copyright 2012, Guy Martin <gmsoft@tuxicoman.be>
  *
- * $Id$
+ * $Id: packet-dvb-tdt.c 52269 2013-09-29 16:40:01Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -61,8 +61,7 @@ dissect_dvb_tdt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     if (packet_mpeg_sect_mjd_to_utc_time(tvb, offset, &utc_time) < 0) {
         proto_tree_add_text(dvb_tdt_tree, tvb, offset, 5, "Unparseable time");
     } else {
-        proto_tree_add_time_format(dvb_tdt_tree, hf_dvb_tdt_utc_time, tvb, offset, 5, &utc_time,
-            "UTC Time : %s UTC", abs_time_to_str(&utc_time, ABSOLUTE_TIME_UTC, FALSE));
+        proto_tree_add_time(dvb_tdt_tree, hf_dvb_tdt_utc_time, tvb, offset, 5, &utc_time);
     }
     offset += 5;
 
