@@ -4,7 +4,7 @@
  *    Mijo Safradin <mijo at linux.vnet.ibm.com>
  * Copyright 2011,2012  IBM Corp.
  *
- * $Id$
+ * $Id: packet-ecp-oui.c 51907 2013-09-09 22:30:40Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -398,7 +398,8 @@ void proto_register_ecp_oui(void)
 		&ett_802_1qbg_capabilities_flags,
 	};
 
-	ieee802a_add_oui(OUI_IEEE_802_1QBG, "ieee802a.ecp_pid", "ECP", &hf_reg);
+	ieee802a_add_oui(OUI_IEEE_802_1QBG, "ieee802a.ecp_pid",
+		"IEEE802a ECP PID", &hf_reg);
 
 	proto_ecp = proto_register_protocol("ECP Protocol", "ECP", "ecp");
 	proto_register_field_array(proto_ecp, hf, array_length(hf));
