@@ -2,7 +2,7 @@
  * Routines for elcom packet dissection
  * Copyright 2008, 2011 juha.takala@iki.fi (Juha Takala)
  *
- * $Id$
+ * $Id: packet-elcom.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -218,7 +218,7 @@ dissect_lower_address(proto_item *ti_arg, gint ett_arg,
         offset += 8;                /* skip the zero bytes */
 
         /* SUFFIX */
-        suffix = tvb_get_ephemeral_string(tvb, offset+1, len2);
+        suffix = tvb_get_string(wmem_packet_scope(), tvb, offset+1, len2);
         ti = proto_tree_add_item(tree, hf_suff, tvb, offset, 1, ENC_ASCII|ENC_LITTLE_ENDIAN);
         offset += len2+1;
 
@@ -429,14 +429,14 @@ dissect_elcom(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         is_request = (pinfo->match_port == pinfo->destport);
         elcom_len  = tvb_get_ntohs(tvb, 0);
         length_ok  = (tvb_reported_length(tvb) == (elcom_len+2));
-        if (check_col(pinfo->cinfo, COL_INFO)) {
-                col_add_fstr(pinfo->cinfo, COL_INFO, "%s Len=%d%s",
+
+        col_add_fstr(pinfo->cinfo, COL_INFO, "%s Len=%d%s",
                              is_request ? "Request" : "Response",
                              elcom_len,
                              length_ok ? "" : " (incorrect)");
 
-                elcom_msg_type = tvb_get_guint8(tvb, 2);
-                switch (elcom_msg_type) {
+        elcom_msg_type = tvb_get_guint8(tvb, 2);
+        switch (elcom_msg_type) {
                 case P_CONRQ:
                 case P_CONRS:
 
@@ -450,7 +450,7 @@ dissect_elcom(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                         if (tvb_get_guint8(tvb, 3+1+TOTAL_LEN+LOWADR_LEN) != SUFFIX_LEN) return;
 
                         /* finally believe that there is valid suffix */
-                        suffix = tvb_get_ephemeral_string(tvb, 3+2+LOWADR_LEN, 2);
+                        suffix = tvb_get_string(wmem_packet_scope(), tvb, 3+2+LOWADR_LEN, 2);
                         col_append_fstr(pinfo->cinfo, COL_INFO, " %s Connect", suffix);
                         break;
 
@@ -474,7 +474,6 @@ dissect_elcom(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 case P_RELRS:
                         col_append_str(pinfo->cinfo, COL_INFO, " Response");
                         break;
-                }
         }
 
         if (!tree)
