@@ -8,7 +8,7 @@
  *
  * (c) 2007 Joost Yervante Damad <joost[AT]teluna.org>
  *
- * $Id$
+ * $Id: packet-epmd.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald[AT]wireshark.org>
@@ -147,7 +147,7 @@ dissect_epmd_request(packet_info *pinfo, tvbuff_t *tvb, gint offset, proto_tree
             name_length = tvb_get_ntohs(tvb, offset);
             proto_tree_add_item(tree, hf_epmd_name_len, tvb, offset, 2, ENC_BIG_ENDIAN);
             proto_tree_add_item(tree, hf_epmd_name, tvb, offset + 2, name_length, ENC_ASCII|ENC_NA);
-            name = tvb_get_ephemeral_string(tvb, offset + 2, name_length);
+            name = tvb_get_string(wmem_packet_scope(), tvb, offset + 2, name_length);
             offset += 2 + name_length;
             if (tvb_length_remaining(tvb, offset) >= 2) {
                 guint16 elen=0;
@@ -155,7 +155,7 @@ dissect_epmd_request(packet_info *pinfo, tvbuff_t *tvb, gint offset, proto_tree
                 proto_tree_add_item(tree, hf_epmd_elen, tvb, offset, 2, ENC_BIG_ENDIAN);
                 if (elen > 0)
                     proto_tree_add_item(tree, hf_epmd_edata, tvb, offset + 2, elen, ENC_NA);
-                offset += 2 + elen;
+                /*offset += 2 + elen;*/
             }
             break;
 
@@ -163,7 +163,7 @@ dissect_epmd_request(packet_info *pinfo, tvbuff_t *tvb, gint offset, proto_tree
         case EPMD_PORT2_REQ:
             name_length = tvb_length_remaining(tvb, offset);
             proto_tree_add_item(tree, hf_epmd_name, tvb, offset, name_length, ENC_ASCII|ENC_NA);
-            name = tvb_get_ephemeral_string(tvb, offset, name_length);
+            name = tvb_get_string(wmem_packet_scope(), tvb, offset, name_length);
             break;
 
         case EPMD_ALIVE_REQ:
@@ -171,7 +171,7 @@ dissect_epmd_request(packet_info *pinfo, tvbuff_t *tvb, gint offset, proto_tree
             offset += 2;
             name_length = tvb_length_remaining(tvb, offset);
             proto_tree_add_item(tree, hf_epmd_name, tvb, offset, name_length, ENC_ASCII|ENC_NA);
-            name = tvb_get_ephemeral_string(tvb, offset, name_length);
+            name = tvb_get_string(wmem_packet_scope(), tvb, offset, name_length);
             break;
 
         case EPMD_NAMES_REQ:
@@ -192,7 +192,7 @@ dissect_epmd_response_names(packet_info *pinfo _U_, tvbuff_t *tvb, gint offset,
     proto_tree_add_item(tree, hf_epmd_names, tvb, offset, -1, ENC_NA);
 }
 
-static void
+static int
 dissect_epmd_response(packet_info *pinfo, tvbuff_t *tvb, gint offset, proto_tree *tree) {
     guint8          type, result;
     guint32         port;
@@ -203,7 +203,7 @@ dissect_epmd_response(packet_info *pinfo, tvbuff_t *tvb, gint offset, proto_tree
     port = tvb_get_ntohl(tvb, offset);
     if (port == EPMD_PORT) {
         dissect_epmd_response_names(pinfo, tvb, offset, tree);
-        return;
+        return 0;
     }
 
     type = tvb_get_guint8(tvb, offset);
@@ -250,7 +250,7 @@ dissect_epmd_response(packet_info *pinfo, tvbuff_t *tvb, gint offset, proto_tree
             name_length = tvb_get_ntohs(tvb, offset);
             proto_tree_add_item(tree, hf_epmd_name_len, tvb, offset, 2, ENC_BIG_ENDIAN);
             proto_tree_add_item(tree, hf_epmd_name, tvb, offset + 2, name_length, ENC_ASCII|ENC_NA);
-            name = tvb_get_ephemeral_string(tvb, offset + 2, name_length);
+            name = tvb_get_string(wmem_packet_scope(), tvb, offset + 2, name_length);
             offset += 2 + name_length;
             if (tvb_length_remaining(tvb, offset) >= 2) {
                 guint16 elen=0;
@@ -267,6 +267,7 @@ dissect_epmd_response(packet_info *pinfo, tvbuff_t *tvb, gint offset, proto_tree
             }
             break;
     }
+    return offset;
 }
 
 static gboolean
