@@ -2,7 +2,7 @@
  * Routines for Ether-S-I/O dissection (from Saia Burgess Controls AG )
  * Copyright 2010, Christian Durrer <christian.durrer@sensemail.ch>
  *
- * $Id$
+ * $Id: packet-esio.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -64,6 +64,8 @@ static gint ett_esio_transfer_header = -1;
 static gint ett_esio_transfer_data = -1;
 static gint ett_esio_data = -1;
 
+static expert_field ei_esio_telegram_lost = EI_INIT;
+
 /* value to string definitions*/
 /* Ether-S-I/O telegram types*/
 static const value_string esio_tlg_types[] = {
@@ -143,34 +145,33 @@ dissect_esio(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
        col_set_str(pinfo->cinfo, COL_PROTOCOL, "ESIO");
        col_clear(pinfo->cinfo, COL_INFO);
        esio_telegram_type = tvb_get_guint8(tvb,5);
-       if (check_col(pinfo->cinfo, COL_INFO)) {
-              switch (esio_telegram_type) {
-              case ESIO_TRANSFER:
-                     esio_src_id = tvb_get_ntohl(tvb,16);
-                     esio_nbr_data_transfers = tvb_get_guint8(tvb, 20);
-                     esio_dst_id = tvb_get_ntohl(tvb,26);
-                     col_add_fstr( pinfo->cinfo, COL_INFO,
-                                   "Data transfer: Src ID: %d, Dst ID(s): %d",
-                                   esio_src_id, esio_dst_id);
-                     if (esio_nbr_data_transfers > 1) {
-                            col_append_fstr( pinfo->cinfo, COL_INFO,
-                                             " ...");
-                     }
-                     break;
-              case ESIO_STATUS:
-                     esio_src_id = tvb_get_ntohl(tvb,16);
-                     col_add_fstr( pinfo->cinfo, COL_INFO,
-                                   "Status/diag telegram: Src ID: %d",
-                                   esio_src_id);
-                     break;
-              default:
-                     /* All other telegrams */
-                     col_set_str( pinfo->cinfo, COL_INFO,
-                                  "Unknown telegram");
-                     break;
-              }
 
+       switch (esio_telegram_type) {
+       case ESIO_TRANSFER:
+                esio_src_id = tvb_get_ntohl(tvb,16);
+                esio_nbr_data_transfers = tvb_get_guint8(tvb, 20);
+                esio_dst_id = tvb_get_ntohl(tvb,26);
+                col_add_fstr( pinfo->cinfo, COL_INFO,
+                            "Data transfer: Src ID: %d, Dst ID(s): %d",
+                            esio_src_id, esio_dst_id);
+                if (esio_nbr_data_transfers > 1) {
+                    col_append_fstr( pinfo->cinfo, COL_INFO,
+                                        " ...");
+                }
+                break;
+       case ESIO_STATUS:
+                esio_src_id = tvb_get_ntohl(tvb,16);
+                col_add_fstr( pinfo->cinfo, COL_INFO,
+                            "Status/diag telegram: Src ID: %d",
+                            esio_src_id);
+                break;
+       default:
+                /* All other telegrams */
+                col_set_str( pinfo->cinfo, COL_INFO,
+                            "Unknown telegram");
+                break;
        }
+
 /* create display subtree for the protocol */
        offset = 0;
        ti = proto_tree_add_item(tree, proto_esio, tvb, offset, -1, ENC_NA);
@@ -264,8 +265,7 @@ dissect_esio(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
                                          hf_esio_rio_flags, tvb, offset+11, 1, ENC_BIG_ENDIAN);
               } /* if (tree) */
               if (tvb_get_guint8(tvb, offset + 9) > 0) {
-                     expert_add_info_format(pinfo, hi, PI_SEQUENCE, PI_NOTE,
-                                            "Telegram(s) lost");
+                     expert_add_info(pinfo, hi, &ei_esio_telegram_lost);
               }
               break;
        }
@@ -402,12 +402,20 @@ proto_register_esio(void)
               &ett_esio_data
        };
 
+        static ei_register_info ei[] = {
+            { &ei_esio_telegram_lost, { "esio.telegram_lost", PI_SEQUENCE, PI_NOTE, "Telegram(s) lost", EXPFILL }},
+        };
+
+       expert_module_t* expert_esio;
+
 /* Register the protocol name and description */
        proto_esio = proto_register_protocol("SAIA Ether-S-I/O protocol", "ESIO", "esio");
 
 /* Required function calls to register the header fields and subtrees used */
        proto_register_field_array(proto_esio, hf, array_length(hf));
        proto_register_subtree_array(ett, array_length(ett));
+       expert_esio = expert_register_protocol(proto_esio);
+       expert_register_field_array(expert_esio, ei, array_length(ei));
 }
 
 void
