@@ -3,7 +3,7 @@
  * payloads (i.e., payloads when there could be an Ethernet trailer and
  * possibly an FCS).
  *
- * $Id$
+ * $Id: packet-ethertype.c 51198 2013-08-07 22:52:43Z morriss $
  *
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -179,6 +179,7 @@ const value_string etype_vals[] = {
 	{ ETHERTYPE_WAI,                  "WAI Authentication Protocol" },
 	{ ETHERTYPE_HSR,                  "High-availability Seamless Redundancy (IEC62439 Part 3)" },
 	{ ETHERTYPE_BPQ,                  "AX.25"},
+	{ ETHERTYPE_CMD,                  "CiscoMetaData"},
 	{ 0, NULL }
 };
 
@@ -329,6 +330,9 @@ add_dix_trailer(packet_info *pinfo, proto_tree *tree, proto_tree *fh_tree, int t
 	guint		 length;
 	tvbuff_t	*trailer_tvb;
 
+	if (fh_tree == NULL)
+		return;	/* we're not building a protocol tree */
+
 	/* OK, how much is there in that tvbuff now? */
 	length = tvb_reported_length(next_tvb);
 
