@@ -5,7 +5,7 @@
  *	3GPP TS 31.111 v9.7.0 (Release 9 / 2012-03)
  * Copyright 2010-2011 by Harald Welte <laforge@gnumonks.org>
  *
- * $Id$
+ * $Id: packet-etsi_card_app_toolkit.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -44,7 +44,7 @@ void proto_reg_handoff_card_app_toolkit(void);
 
 static int proto_cat = -1;
 
-static dissector_table_t sms_dissector_table;	/* SMS TPDU */
+static dissector_handle_t gsm_sms_handle;	/* SMS TPDU */
 
 static int hf_cat_tlv = -1;
 
@@ -945,10 +945,10 @@ dissect_cat(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			switch (g8) {
 			case 0x20:
 				proto_tree_add_item(elem_tree, hf_ctlv_result_term, tvb, pos+1, 1, ENC_NA);
-				break; 
+				break;
 			case 0x26:
 				proto_tree_add_item(elem_tree, hf_ctlv_result_launch_browser, tvb, pos+1, 1, ENC_NA);
-				break; 
+				break;
 			case 0x38:
 				proto_tree_add_item(elem_tree, hf_ctlv_result_multiplecard, tvb, pos+1, 1, ENC_NA);
 				break;
@@ -976,7 +976,7 @@ dissect_cat(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		case 0x0b:	/* sms tpdu */
 			new_tvb = tvb_new_subset(tvb, pos, len, len);
 			if (new_tvb) {
-				dissector_try_uint(sms_dissector_table, 0, new_tvb, pinfo, elem_tree);
+				call_dissector_only(gsm_sms_handle, new_tvb, pinfo, elem_tree, NULL);
 			}
 			break;
 		case 0x0d:	/* text string */
@@ -1204,7 +1204,7 @@ dissect_cat(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		case 0x76:	/* Geographical Location Parameters / IARI */
 			if (ims_event) {
 				proto_tree_add_unicode_string(elem_tree, hf_ctlv_iari, tvb, pos, len,
-					tvb_get_ephemeral_string_enc(tvb, pos, len, ENC_UTF_8 | ENC_NA));
+					tvb_get_string_enc(wmem_packet_scope(), tvb, pos, len, ENC_UTF_8 | ENC_NA));
 			}
 			break;
 		case 0x77:	/* GAD Shapes / IMPU list */
@@ -1214,7 +1214,7 @@ dissect_cat(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					if (tvb_get_guint8(tvb, pos+i) == 0x80) {
 						g8 = tvb_get_guint8(tvb, pos+i+1);
 						proto_tree_add_unicode_string(elem_tree, hf_ctlv_impu, tvb, pos+i+2, g8,
-							tvb_get_ephemeral_string_enc(tvb, pos+i+2, g8, ENC_UTF_8 | ENC_NA));
+							tvb_get_string_enc(wmem_packet_scope(), tvb, pos+i+2, g8, ENC_UTF_8 | ENC_NA));
 						i += 2+g8;
 					} else {
 						break;
@@ -1224,7 +1224,7 @@ dissect_cat(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			break;
 		case 0x78:	/* NMEA sentence / IMS Status-Code */
 			if (ims_event) {
-				guint8 *status_code = tvb_get_ephemeral_string(tvb, pos, len);
+				guint8 *status_code = tvb_get_string(wmem_packet_scope(), tvb, pos, len);
 				proto_tree_add_string_format_value(elem_tree, hf_ctlv_ims_status_code, tvb, pos, len,
 					status_code, "%s (%s)", status_code, str_to_str(status_code, ims_status_code, "Unknown"));
 			}
@@ -1673,7 +1673,5 @@ proto_register_card_app_toolkit(void)
 void
 proto_reg_handoff_card_app_toolkit(void)
 {
-	sms_dissector_table =
-		register_dissector_table("etsi_cat.sms_tpdu", "3GPP SMS TPDU",
-		FT_UINT8, BASE_DEC);
+	gsm_sms_handle = find_dissector("gsm_sms");
 }
