@@ -2,7 +2,7 @@
  * Routines for the disassembly of Extreme Networks specific
  * protocols (EDP/ESRP/EAPS(including ESL)/ELSM)
  *
- * $Id$
+ * $Id: packet-extreme.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Copyright 2005 Joerg Mayer (see AUTHORS file)
  *
@@ -431,7 +431,7 @@ dissect_display_tlv(tvbuff_t *tvb, packet_info *pinfo, int offset, int length, p
 	offset += 4;
 	length -= 4;
 
-	display_name = tvb_get_ephemeral_string(tvb, offset, length);
+	display_name = tvb_get_string(wmem_packet_scope(), tvb, offset, length);
 	proto_item_append_text(display_item, ": \"%s\"",
 	        format_text(display_name, strlen(display_name)));
 	proto_tree_add_string(display_tree, hf_edp_display_string, tvb, offset, length,
@@ -596,8 +596,7 @@ dissect_vlan_tlv(tvbuff_t *tvb, packet_info *pinfo, int offset, int length, prot
 		return offset;
 	}
 	vlan_id = tvb_get_ntohs(tvb, offset);
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_append_fstr(pinfo->cinfo, COL_INFO, "%d", vlan_id);
+	col_append_fstr(pinfo->cinfo, COL_INFO, "%d", vlan_id);
 	proto_item_append_text(vlan_item, ": ID %d", vlan_id);
 	proto_tree_add_uint(vlan_tree, hf_edp_vlan_id, tvb, offset, 2,
 		vlan_id);
@@ -626,7 +625,7 @@ dissect_vlan_tlv(tvbuff_t *tvb, packet_info *pinfo, int offset, int length, prot
 	offset += 4;
 	length -= 4;
 
-	vlan_name = tvb_get_ephemeral_string(tvb, offset, length);
+	vlan_name = tvb_get_string(wmem_packet_scope(), tvb, offset, length);
 	proto_item_append_text(vlan_item, ", Name \"%s\"",
 	        format_text(vlan_name, strlen(vlan_name)));
 	proto_tree_add_string(vlan_tree, hf_edp_vlan_name, tvb, offset, length,
@@ -759,8 +758,7 @@ dissect_eaps_tlv(tvbuff_t *tvb, packet_info *pinfo, int offset, int length _U_,
 	offset += 38;
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "EAPS");
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_append_fstr(pinfo->cinfo, COL_INFO, " ID: %d, MAC: %s",
+	col_append_fstr(pinfo->cinfo, COL_INFO, " ID: %d, MAC: %s",
 			ctrlvlanid, sysmac_str);
 
 	return offset;
@@ -876,8 +874,7 @@ dissect_esl_tlv(tvbuff_t *tvb, packet_info *pinfo, int offset, int length, proto
 	offset += length;
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "ESL");
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_append_fstr(pinfo->cinfo, COL_INFO, " ID: %d, MAC: %s",
+	col_append_fstr(pinfo->cinfo, COL_INFO, " ID: %d, MAC: %s",
 			ctrlvlanid, sysmac_str);
 
 	return offset;
@@ -894,8 +891,7 @@ dissect_elsm_tlv(tvbuff_t *tvb, packet_info *pinfo, int offset, int length,
 	type = tvb_get_guint8(tvb, offset + 4);
 	subtype = tvb_get_guint8(tvb, offset + 4 + 1);
 
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_append_fstr(pinfo->cinfo, COL_INFO, " %s%s (#%d)",
+	col_append_fstr(pinfo->cinfo, COL_INFO, " %s%s (#%d)",
 			val_to_str(type, elsm_type_vals, "Unknown (0x%02x)"),
 			val_to_str(subtype, elsm_subtype_vals, " Unknown (0x%02x)"),
 			seqno);
@@ -1074,8 +1070,7 @@ dissect_edp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                     			"TLV with invalid length: %u", tlv_length);
 				break;
 			}
-			if (check_col(pinfo->cinfo, COL_INFO) &&
-				tlv_type != EDP_TYPE_NULL)
+			if (tlv_type != EDP_TYPE_NULL)
 				col_append_fstr(pinfo->cinfo, COL_INFO, " %s",
 					val_to_str(tlv_type, edp_type_vals, "[0x%02x]"));
 
@@ -1514,5 +1509,5 @@ proto_register_extreme_oui(void)
 	  }
 	};
 
-	llc_add_oui(OUI_EXTREME, "llc.extreme_pid", "Extreme OUI PID", hf);
+	llc_add_oui(OUI_EXTREME, "llc.extreme_pid", "LLC Extreme OUI PID", hf);
 }
