@@ -4,7 +4,7 @@
  *   Copyright 2003  Ronnie Sahlberg, exchange first/last matching and
  *                                    tap listener and misc updates
  *
- * $Id$
+ * $Id: packet-fc.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,7 +39,7 @@
 #include "packet-fclctl.h"
 #include "packet-fcbls.h"
 #include <epan/tap.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/crc32-tvb.h>
 #include <epan/expert.h>
 
@@ -138,13 +138,17 @@ static gint ett_fctl = -1;
 static gint ett_fcbls = -1;
 static gint ett_fc_vft = -1;
 
+static expert_field ei_fccrc = EI_INIT;
+
+static dissector_handle_t fc_handle, fcsof_handle;
 static dissector_table_t fcftype_dissector_table;
-static dissector_handle_t data_handle, fc_handle;
+
+static dissector_handle_t data_handle;
 
 static int fc_tap = -1;
 
 typedef struct _fc_conv_data_t {
-    emem_tree_t *exchanges;
+    wmem_tree_t *exchanges;
 } fc_conv_data_t;
 
 
@@ -539,9 +543,8 @@ dissect_fc_vft(proto_tree *parent_tree,
     hop_ct = tvb_get_guint8(tvb, offset + 4);
 
     if (parent_tree) {
-        item = proto_tree_add_uint_format(parent_tree, hf_fc_vft, tvb, offset,
-                                    8, vf_id, "VFT Header: "
-                                    "VF_ID %d Pri %d Hop Count %d",
+        item = proto_tree_add_uint_format_value(parent_tree, hf_fc_vft, tvb, offset,
+                                    8, vf_id, "VF_ID %d Pri %d Hop Count %d",
                                     vf_id, pri, hop_ct);
         tree = proto_item_add_subtree(item, ett_fc_vft);
     }
@@ -658,7 +661,6 @@ dissect_fc_fctl(packet_info *pinfo _U_, proto_tree *parent_tree, tvbuff_t *tvb,
         if (flags & (~( FC_FCTL_REL_OFFSET )))
             proto_item_append_text(item, ",");
     }
-    flags&=(~( FC_FCTL_REL_OFFSET ));
 
 }
 
@@ -691,7 +693,7 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
     int vft_offset = -1;
     gboolean is_lastframe_inseq, is_1frame_inseq/*, is_valid_frame*/;
     gboolean is_exchg_resp = 0;
-    fragment_data *fcfrag_head;
+    fragment_head *fcfrag_head;
     guint32 frag_id;
     guint32 frag_size;
     guint8 df_ctl, seq_id;
@@ -768,8 +770,8 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
     conversation=find_or_create_conversation(pinfo);
     fc_conv_data=(fc_conv_data_t *)conversation_get_proto_data(conversation, proto_fc);
     if(!fc_conv_data){
-        fc_conv_data=se_new(fc_conv_data_t);
-        fc_conv_data->exchanges=se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK, "FC Exchanges");
+        fc_conv_data=wmem_new(wmem_file_scope(), fc_conv_data_t);
+        fc_conv_data->exchanges=wmem_tree_new(wmem_file_scope());
         conversation_add_proto_data(conversation, proto_fc, fc_conv_data);
     }
 
@@ -777,9 +779,9 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
     /* XXX we should come up with a way to handle when the 16bit oxid wraps
      * so that large traces will work
      */
-    fc_ex=(itlq_nexus_t *)se_tree_lookup32(fc_conv_data->exchanges, fchdr.oxid);
+    fc_ex=(itlq_nexus_t *)wmem_tree_lookup32(fc_conv_data->exchanges, fchdr.oxid);
     if(!fc_ex){
-        fc_ex=se_new(itlq_nexus_t);
+        fc_ex=wmem_new(wmem_file_scope(), itlq_nexus_t);
         fc_ex->first_exchange_frame=0;
         fc_ex->last_exchange_frame=0;
         fc_ex->lun=0xffff;
@@ -791,7 +793,7 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
         fc_ex->flags=0;
         fc_ex->alloc_len=0;
         fc_ex->extra_data=NULL;
-        se_tree_insert32(fc_conv_data->exchanges, fchdr.oxid, fc_ex);
+        wmem_tree_insert32(fc_conv_data->exchanges, fchdr.oxid, fc_ex);
     }
     /* populate the exchange struct */
     if(!pinfo->fd->flags.visited){
@@ -851,16 +853,14 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
 
     ftype = fc_get_ftype (fchdr.r_ctl, fchdr.type);
 
-    if (check_col (pinfo->cinfo, COL_INFO)) {
-         col_add_str (pinfo->cinfo, COL_INFO, val_to_str (ftype, fc_ftype_vals,
-                                                          "Unknown Type (0x%x)"));
+    col_add_str (pinfo->cinfo, COL_INFO, val_to_str (ftype, fc_ftype_vals,
+                                                        "Unknown Type (0x%x)"));
 
-        if (ftype == FC_FTYPE_LINKCTL)
-            col_append_fstr (pinfo->cinfo, COL_INFO, ", %s",
-                             val_to_str ((fchdr.r_ctl & 0x0F),
-                                          fc_lctl_proto_val,
-                                          "LCTL 0x%x"));
-    }
+    if (ftype == FC_FTYPE_LINKCTL)
+        col_append_fstr (pinfo->cinfo, COL_INFO, ", %s",
+                            val_to_str ((fchdr.r_ctl & 0x0F),
+                                        fc_lctl_proto_val,
+                                        "LCTL 0x%x"));
 
     if (vft_offset >= 0) {
         dissect_fc_vft(fc_tree, tvb, vft_offset);
@@ -871,9 +871,9 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
     case FC_RCTL_LINK_DATA:
     case FC_RCTL_VIDEO:
         /* the lower 4 bits of R_CTL are the information category */
-        proto_tree_add_uint_format (fc_tree, hf_fc_rctl, tvb, offset,
+        proto_tree_add_uint_format_value(fc_tree, hf_fc_rctl, tvb, offset,
                                     FC_RCTL_SIZE, fchdr.r_ctl,
-                                    "R_CTL: 0x%x(%s/%s)",
+                                    "0x%x(%s/%s)",
                                     fchdr.r_ctl,
                                     val_to_str ((fchdr.r_ctl & 0xF0),
                                                 fc_routing_val, "0x%x"),
@@ -883,9 +883,9 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
 
     case FC_RCTL_LINK_CTL:
         /* the lower 4 bits of R_CTL indicate the type of link ctl frame */
-        proto_tree_add_uint_format (fc_tree, hf_fc_rctl, tvb, offset,
+        proto_tree_add_uint_format_value(fc_tree, hf_fc_rctl, tvb, offset,
                                     FC_RCTL_SIZE, fchdr.r_ctl,
-                                    "R_CTL: 0x%x(%s/%s)",
+                                    "0x%x(%s/%s)",
                                     fchdr.r_ctl,
                                     val_to_str ((fchdr.r_ctl & 0xF0),
                                                 fc_routing_val, "0x%x"),
@@ -898,9 +898,9 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
 
         case 0x00:
             /* the lower 4 bits of R_CTL indicate the type of BLS frame */
-            proto_tree_add_uint_format (fc_tree, hf_fc_rctl, tvb, offset,
+            proto_tree_add_uint_format_value(fc_tree, hf_fc_rctl, tvb, offset,
                                         FC_RCTL_SIZE, fchdr.r_ctl,
-                                        "R_CTL: 0x%x(%s/%s)",
+                                        "0x%x(%s/%s)",
                                         fchdr.r_ctl,
                                         val_to_str ((fchdr.r_ctl & 0xF0),
                                                     fc_routing_val, "0x%x"),
@@ -909,9 +909,9 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
             break;
 
         default:
-            proto_tree_add_uint_format (fc_tree, hf_fc_rctl, tvb, offset,
+            proto_tree_add_uint_format_value(fc_tree, hf_fc_rctl, tvb, offset,
                                         FC_RCTL_SIZE, fchdr.r_ctl,
-                                        "R_CTL: 0x%x(%s/0x%x)",
+                                        "0x%x(%s/0x%x)",
                                         fchdr.r_ctl,
                                         val_to_str ((fchdr.r_ctl & 0xF0),
                                                     fc_routing_val, "0x%x"),
@@ -925,9 +925,9 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
 
         case 0x01:
             /* the lower 4 bits of R_CTL indicate the type of ELS frame */
-            proto_tree_add_uint_format (fc_tree, hf_fc_rctl, tvb, offset,
+            proto_tree_add_uint_format_value(fc_tree, hf_fc_rctl, tvb, offset,
                                         FC_RCTL_SIZE, fchdr.r_ctl,
-                                        "R_CTL: 0x%x(%s/%s)",
+                                        "0x%x(%s/%s)",
                                         fchdr.r_ctl,
                                         val_to_str ((fchdr.r_ctl & 0xF0),
                                                     fc_routing_val, "0x%x"),
@@ -936,9 +936,9 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
             break;
 
         default:
-            proto_tree_add_uint_format (fc_tree, hf_fc_rctl, tvb, offset,
+            proto_tree_add_uint_format_value(fc_tree, hf_fc_rctl, tvb, offset,
                                         FC_RCTL_SIZE, fchdr.r_ctl,
-                                        "R_CTL: 0x%x(%s/0x%x)",
+                                        "0x%x(%s/0x%x)",
                                         fchdr.r_ctl,
                                         val_to_str ((fchdr.r_ctl & 0xF0),
                                                     fc_routing_val, "0x%x"),
@@ -948,9 +948,9 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
         break;
 
     default:
-        proto_tree_add_uint_format (fc_tree, hf_fc_rctl, tvb, offset,
+        proto_tree_add_uint_format_value(fc_tree, hf_fc_rctl, tvb, offset,
                                     FC_RCTL_SIZE, fchdr.r_ctl,
-                                    "R_CTL: 0x%x(%s/0x%x)",
+                                    "0x%x(%s/0x%x)",
                                     fchdr.r_ctl,
                                     val_to_str ((fchdr.r_ctl & 0xF0),
                                                 fc_routing_val, "0x%x"),
@@ -984,9 +984,9 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
             /* for F_BSY frames, the upper 4 bits of the type field specify the
              * reason for the BSY.
              */
-            proto_tree_add_uint_format (fc_tree, hf_fc_type, tvb,
+            proto_tree_add_uint_format_value(fc_tree, hf_fc_type, tvb,
                                         offset+8, FC_TYPE_SIZE,
-                                        fchdr.type,"Type: 0x%x(%s)", fchdr.type,
+                                        fchdr.type,"0x%x(%s)", fchdr.type,
                                         fclctl_get_typestr ((guint8) (fchdr.r_ctl & 0x0F),
                                                             fchdr.type));
         } else {
@@ -1017,9 +1017,9 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
             /* In all these cases of Link Ctl frame, the parameter field
              * encodes the detailed error message
              */
-            proto_tree_add_uint_format (fc_tree, hf_fc_param, tvb,
+            proto_tree_add_uint_format_value(fc_tree, hf_fc_param, tvb,
                                         offset+20, 4, param,
-                                        "Parameter: 0x%x(%s)", param,
+                                        "0x%x(%s)", param,
                                         fclctl_get_paramstr ((fchdr.r_ctl & 0x0F),
                                                              param));
         } else {
@@ -1027,9 +1027,9 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
         }
     } else if (ftype == FC_FTYPE_BLS) {
         if ((fchdr.r_ctl & 0x0F) == FC_BLS_ABTS) {
-            proto_tree_add_uint_format (fc_tree, hf_fc_param, tvb,
+            proto_tree_add_uint_format_value(fc_tree, hf_fc_param, tvb,
                                         offset+20, 4, param,
-                                        "Parameter: 0x%x(%s)", param,
+                                        "0x%x(%s)", param,
                                         ((param & 0x0F) == 1 ? "Abort Sequence" :
                                          "Abort Exchange"));
         } else {
@@ -1055,9 +1055,9 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
         /* Yes - dissect it. */
         if (tree) {
             proto_tree_add_string (fc_tree, hf_fc_nh_da, tvb, next_offset, 8,
-                                   fcwwn_to_str (tvb_get_ephemeral_string (tvb, offset, 8)));
+                                   fcwwn_to_str (tvb_get_string (wmem_packet_scope(), tvb, offset, 8)));
             proto_tree_add_string (fc_tree, hf_fc_nh_sa, tvb, offset+8, 8,
-                                   fcwwn_to_str (tvb_get_ephemeral_string (tvb, offset+8, 8)));
+                                   fcwwn_to_str (tvb_get_string (wmem_packet_scope(), tvb, offset+8, 8)));
         }
         next_offset += 16;
     }
@@ -1134,10 +1134,10 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
                 cdata->seq_cnt = fchdr.seqcnt;
             }
             else {
-                req_key = se_new(fcseq_conv_key_t);
+                req_key = wmem_new(wmem_file_scope(), fcseq_conv_key_t);
                 req_key->conv_idx = conversation->index;
 
-                cdata = se_new(fcseq_conv_data_t);
+                cdata = wmem_new(wmem_file_scope(), fcseq_conv_data_t);
                 cdata->seq_cnt = fchdr.seqcnt;
 
                 g_hash_table_insert (fcseq_req_hash, req_key, cdata);
@@ -1172,9 +1172,7 @@ dissect_fc_helper (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
                                          !is_lastframe_inseq);
 
              if (fcfrag_head) {
-                  next_tvb = tvb_new_child_real_data(tvb, fcfrag_head->data,
-                                                fcfrag_head->datalen,
-                                                fcfrag_head->datalen);
+                  next_tvb = tvb_new_chain(tvb, fcfrag_head->tvb_data);
 
                   /* Add the defragmented data to the data source list. */
                   add_new_data_source(pinfo, next_tvb, "Reassembled FC");
@@ -1292,17 +1290,16 @@ dissect_fcsof(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
     proto_tree_add_uint(fcsof_tree, hf_fcsof, tvb, sof_offset, 4, sof);
 
     if (crc == crc_computed) {
-        proto_tree_add_uint_format(fcsof_tree, hf_fccrc, tvb,
+        proto_tree_add_uint_format_value(fcsof_tree, hf_fccrc, tvb,
                                        crc_offset, 4, crc,
-                                       "CRC: %8.8x [valid]", crc);
+                                       "%8.8x [valid]", crc);
     } else {
-        it = proto_tree_add_uint_format(fcsof_tree, hf_fccrc, tvb,
+        it = proto_tree_add_uint_format_value(fcsof_tree, hf_fccrc, tvb,
                                        crc_offset, 4, crc,
-                                       "CRC: %8.8x "
-                                       "[error: should be %8.8x]",
+                                       "%8.8x [error: should be %8.8x]",
                                        crc, crc_computed);
 
-        expert_add_info_format(pinfo, it, PI_CHECKSUM, PI_ERROR,
+        expert_add_info_format(pinfo, it, &ei_fccrc,
                                    "Bad FC CRC %8.8x %8.x",
                                    crc, crc_computed);
     }
@@ -1502,7 +1499,12 @@ proto_register_fc(void)
         &ett_fctl
     };
 
+    static ei_register_info ei[] = {
+        { &ei_fccrc, { "fc.crc.bad", PI_CHECKSUM, PI_ERROR, "Bad checksum", EXPFILL }},
+    };
+
     module_t *fc_module;
+    expert_module_t* expert_fc;
 
     /* FC SOF */
 
@@ -1526,13 +1528,15 @@ proto_register_fc(void)
 
     /* Register the protocol name and description */
     proto_fc = proto_register_protocol ("Fibre Channel", "FC", "fc");
-    register_dissector ("fc", dissect_fc, proto_fc);
+    fc_handle = register_dissector ("fc", dissect_fc, proto_fc);
     register_dissector ("fc_ifcp", dissect_fc_ifcp, proto_fc);
     fc_tap = register_tap("fc");
 
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_fc, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_fc = expert_register_protocol(proto_fc);
+    expert_register_field_array(expert_fc, ei, array_length(ei));
 
     /* subdissectors called through this table will find the fchdr structure
      * through pinfo->private_data
@@ -1564,7 +1568,7 @@ proto_register_fc(void)
     proto_register_field_array(proto_fcsof, sof_hf, array_length(sof_hf));
     proto_register_subtree_array(sof_ett, array_length(sof_ett));
 
-    register_dissector("fcsof", dissect_fcsof, proto_fcsof);
+    fcsof_handle = register_dissector("fcsof", dissect_fcsof, proto_fcsof);
 }
 
 
@@ -1575,12 +1579,8 @@ proto_register_fc(void)
 void
 proto_reg_handoff_fc (void)
 {
-    dissector_handle_t fcsof_handle;
-
-    fc_handle = find_dissector("fc");
     dissector_add_uint("wtap_encap", WTAP_ENCAP_FIBRE_CHANNEL_FC2, fc_handle);
 
-    fcsof_handle = find_dissector("fcsof");
     dissector_add_uint("wtap_encap", WTAP_ENCAP_FIBRE_CHANNEL_FC2_WITH_FRAME_DELIMS, fcsof_handle);
 
     data_handle = find_dissector("data");
