@@ -2,7 +2,7 @@
  * Routines for FC Common Transport Protocol (used by GS3 services)
  * Copyright 2001, Dinesh G Dutt <ddutt@andiamo.com>
  *
- * $Id$
+ * $Id: packet-fcct.c 51904 2013-09-09 21:55:57Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -163,20 +163,18 @@ dissect_fcct (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     cthdr.opcode = g_ntohs (cthdr.opcode);
     cthdr.maxres_size = g_ntohs (cthdr.maxres_size);
 
-    if (check_col (pinfo->cinfo, COL_INFO)) {
-        if (cthdr.opcode < FCCT_MSG_REQ_MAX) {
-            col_append_str (pinfo->cinfo, COL_INFO, " Request");
-        }
-        else if (cthdr.opcode == FCCT_MSG_ACC) {
-            col_append_str (pinfo->cinfo, COL_INFO, " Accept");
-        }
-        else if (cthdr.opcode == FCCT_MSG_RJT) {
-            col_append_fstr (pinfo->cinfo, COL_INFO, " Reject (%s)",
-                             val_to_str (cthdr.rjt_code, fc_ct_rjt_code_vals, "0x%x"));
-        }
-        else {
-            col_append_str (pinfo->cinfo, COL_INFO, " Reserved");
-        }
+    if (cthdr.opcode < FCCT_MSG_REQ_MAX) {
+        col_append_str (pinfo->cinfo, COL_INFO, " Request");
+    }
+    else if (cthdr.opcode == FCCT_MSG_ACC) {
+        col_append_str (pinfo->cinfo, COL_INFO, " Accept");
+    }
+    else if (cthdr.opcode == FCCT_MSG_RJT) {
+        col_append_fstr (pinfo->cinfo, COL_INFO, " Reject (%s)",
+                            val_to_str (cthdr.rjt_code, fc_ct_rjt_code_vals, "0x%x"));
+    }
+    else {
+        col_append_str (pinfo->cinfo, COL_INFO, " Reserved");
     }
 
     in_id = cthdr.in_id;
@@ -279,7 +277,7 @@ proto_register_fcct(void)
     proto_register_subtree_array(ett, array_length(ett));
 
     fcct_gserver_table = register_dissector_table ("fcct.server",
-                                                   "Server",
+                                                   "FCCT Server",
                                                    FT_UINT8, BASE_HEX);
 }
 
