@@ -2,7 +2,7 @@
  * Routines for FC Fabric Configuration Server
  * Copyright 2001, Dinesh G Dutt <ddutt@andiamo.com>
  *
- * $Id$
+ * $Id: packet-fcfcs.c 52052 2013-09-15 09:12:01Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,7 +28,7 @@
 #include <glib.h>
 
 #include <epan/packet.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/conversation.h>
 #include <epan/etypes.h>
 #include "packet-scsi.h"
@@ -817,18 +817,16 @@ dissect_fcfcs (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             cdata->opcode = opcode;
         }
         else {
-            req_key = se_new(fcfcs_conv_key_t);
+            req_key = wmem_new(wmem_file_scope(), fcfcs_conv_key_t);
             req_key->conv_idx = conversation->index;
 
-            cdata = se_new(fcfcs_conv_data_t);
+            cdata = wmem_new(wmem_file_scope(), fcfcs_conv_data_t);
             cdata->opcode = opcode;
 
             g_hash_table_insert (fcfcs_req_hash, req_key, cdata);
         }
-        if (check_col (pinfo->cinfo, COL_INFO)) {
-            col_add_str (pinfo->cinfo, COL_INFO,
+        col_add_str (pinfo->cinfo, COL_INFO,
                          val_to_str (opcode, fc_fcs_opcode_abbrev_val, "0x%x"));
-        }
     }
     else {
         /* Opcode is ACC or RJT */
@@ -837,12 +835,10 @@ dissect_fcfcs (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                                           pinfo->rxid, NO_PORT2);
         isreq = 0;
         if (!conversation) {
-            if (tree && (opcode == FCCT_MSG_ACC)) {
-                if (check_col (pinfo->cinfo, COL_INFO)) {
-                    col_add_str (pinfo->cinfo, COL_INFO,
+            if (opcode == FCCT_MSG_ACC) {
+                col_add_str (pinfo->cinfo, COL_INFO,
                                  val_to_str (opcode, fc_fcs_opcode_abbrev_val,
                                              "0x%x"));
-                }
                 /* No record of what this accept is for. Can't decode */
                 proto_tree_add_text (fcfcs_tree, tvb, 0, tvb_length (tvb),
                                      "No record of Exchg. Unable to decode MSG_ACC/RJT");
@@ -862,18 +858,16 @@ dissect_fcfcs (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                     failed_opcode = cdata->opcode;
             }
 
-            if (check_col (pinfo->cinfo, COL_INFO)) {
-                if (opcode != FCCT_MSG_RJT) {
-                    col_add_fstr (pinfo->cinfo, COL_INFO, "MSG_ACC (%s)",
-                                  val_to_str (opcode, fc_fcs_opcode_abbrev_val,
-                                              "0x%x"));
-                }
-                else {
-                    col_add_fstr (pinfo->cinfo, COL_INFO, "MSG_RJT (%s)",
-                                  val_to_str (failed_opcode,
-                                              fc_fcs_opcode_abbrev_val,
-                                              "0x%x"));
-                }
+            if (opcode != FCCT_MSG_RJT) {
+                col_add_fstr (pinfo->cinfo, COL_INFO, "MSG_ACC (%s)",
+                                val_to_str (opcode, fc_fcs_opcode_abbrev_val,
+                                            "0x%x"));
+            }
+            else {
+                col_add_fstr (pinfo->cinfo, COL_INFO, "MSG_RJT (%s)",
+                                val_to_str (failed_opcode,
+                                            fc_fcs_opcode_abbrev_val,
+                                            "0x%x"));
             }
 
             if (tree) {
