@@ -2,7 +2,7 @@
  * Routines for FastCGI dissection
  * Copyright 2010, Tom Hughes <tom@compton.nu>
  *
- * $Id$
+ * $Id: packet-fcgi.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -51,6 +51,8 @@ static int ett_fcgi_begin_request = -1;
 static int ett_fcgi_end_request = -1;
 static int ett_fcgi_params = -1;
 
+static dissector_handle_t fcgi_handle;
+
 #define FCGI_BEGIN_REQUEST       1
 #define FCGI_ABORT_REQUEST       2
 #define FCGI_END_REQUEST         3
@@ -125,11 +127,11 @@ dissect_nv_pairs(tvbuff_t *tvb, proto_tree *fcgi_tree, gint offset, guint16 len)
          offset += 4;
       }
 
-      name = tvb_get_ephemeral_string(tvb, offset, namelen);
+      name = tvb_get_string(wmem_packet_scope(), tvb, offset, namelen);
       offset += namelen;
 
       if (valuelen > 0) {
-         value = tvb_get_ephemeral_string(tvb, offset, valuelen);
+         value = tvb_get_string(wmem_packet_scope(), tvb, offset, valuelen);
          offset += valuelen;
 
          proto_tree_add_text(fcgi_tree, tvb, start_offset, offset - start_offset, "%s = %s", name, value);
@@ -396,18 +398,16 @@ proto_register_fcgi(void)
                                   10,
                                   &tcp_port);
 
-   register_dissector("fcgi", dissect_fcgi, proto_fcgi);
+   fcgi_handle = register_dissector("fcgi", dissect_fcgi, proto_fcgi);
 }
 
 void
 proto_reg_handoff_fcgi(void)
 {
    static gboolean initialized = FALSE;
-   static dissector_handle_t fcgi_handle;
    static guint saved_tcp_port;
 
    if (!initialized) {
-      fcgi_handle = create_dissector_handle(dissect_fcgi, proto_fcgi);
       dissector_add_handle("tcp.port", fcgi_handle);  /* for "decode as" */
       initialized = TRUE;
    } else if (saved_tcp_port != 0) {
