@@ -3,7 +3,7 @@
  * Routines for FCoIB dissection - Fibre Channel over Infiniband
  * Copyright (c) 2010 Mellanox Technologies Ltd. (slavak@mellanox.co.il)
  *
- * $Id$
+ * $Id: packet-fcoib.c 52052 2013-09-15 09:12:01Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,6 +34,7 @@
 #include <epan/crc32-tvb.h>
 #include <epan/etypes.h>
 #include <epan/expert.h>
+#include <epan/wmem/wmem.h>
 #include <errno.h>
 #include "packet-infiniband.h"
 
@@ -115,6 +116,8 @@ static int hf_fcoib_crc_good    = -1;
 static int ett_fcoib            = -1;
 static int ett_fcoib_crc        = -1;
 
+static expert_field ei_fcoib_crc = EI_INIT;
+
 static dissector_handle_t data_handle;
 static dissector_handle_t fc_handle;
 
@@ -232,7 +235,7 @@ dissect_fcoib(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U
     ver = "";
     version = tvb_get_guint8(tvb, 0 + FCOIB_VER_OFFSET) >> 4;
     if (version != 0)
-        ver = ep_strdup_printf(ver, "ver %d ", version);
+        ver = wmem_strdup_printf(wmem_packet_scope(), ver, "ver %d ", version);
 
     eof_str = "none";
     if (tvb_bytes_exist(tvb, eof_offset, 1)) {
@@ -280,16 +283,15 @@ dissect_fcoib(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U
      */
     if (crc_exists) {
         if (crc == crc_computed) {
-            item = proto_tree_add_uint_format(fcoib_tree, hf_fcoib_crc, tvb,
+            item = proto_tree_add_uint_format_value(fcoib_tree, hf_fcoib_crc, tvb,
                                               crc_offset, 4, crc,
-                                              "CRC: %8.8x [valid]", crc);
+                                              "%8.8x [valid]", crc);
         } else {
-            item = proto_tree_add_uint_format(fcoib_tree, hf_fcoib_crc, tvb,
+            item = proto_tree_add_uint_format_value(fcoib_tree, hf_fcoib_crc, tvb,
                                               crc_offset, 4, crc,
-                                              "CRC: %8.8x "
-                                              "[error: should be %8.8x]",
+                                              "%8.8x [error: should be %8.8x]",
                                               crc, crc_computed);
-            expert_add_info_format(pinfo, item, PI_CHECKSUM, PI_ERROR,
+            expert_add_info_format(pinfo, item, &ei_fcoib_crc,
                                    "Bad FC CRC %8.8x %8.x",
                                    crc, crc_computed);
         }
@@ -372,6 +374,12 @@ proto_register_fcoib(void)
         &ett_fcoib_crc
     };
 
+    static ei_register_info ei[] = {
+        { &ei_fcoib_crc, { "fcoib.crc.bad", PI_CHECKSUM, PI_ERROR, "Bad checksum", EXPFILL }},
+    };
+
+    expert_module_t* expert_fcoib;
+
     /* Register the protocol name and description */
     proto_fcoib = proto_register_protocol("Fibre Channel over Infiniband",
         "FCoIB", "fcoib");
@@ -380,6 +388,8 @@ proto_register_fcoib(void)
      * subtrees used */
     proto_register_field_array(proto_fcoib, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_fcoib = expert_register_protocol(proto_fcoib);
+    expert_register_field_array(expert_fcoib, ei, array_length(ei));
 
     fcoib_module = prefs_register_protocol(proto_fcoib, proto_reg_handoff_fcoib);
 
@@ -432,9 +442,7 @@ proto_reg_handoff_fcoib(void)
         int i;
 
         for (i = 0; i < 2; i++) {
-            if (gPREF_ID[i][0] == '\0') {
-                error_occured = TRUE;
-            } else if (gPREF_TYPE[i] == 0) {   /* LID */
+            if (gPREF_TYPE[i] == 0) {   /* LID */
                 errno = 0;  /* reset any previous error indicators */
                 *((guint16*)manual_addr_data[i]) = (guint16)strtoul(gPREF_ID[i], &not_parsed, 0);
                 if (errno || *not_parsed != '\0') {
@@ -443,7 +451,7 @@ proto_reg_handoff_fcoib(void)
                     SET_ADDRESS(&manual_addr[i], AT_IB, sizeof(guint16), manual_addr_data[i]);
                 }
             } else {    /* GID */
-                if (! inet_pton(AF_INET6, gPREF_ID[i], manual_addr_data[i]) ) {
+                if (inet_pton(AF_INET6, gPREF_ID[i], manual_addr_data[i]) <= 0) {
                     error_occured = TRUE;
                 } else {
                     SET_ADDRESS(&manual_addr[i], AT_IB, GID_SIZE, manual_addr_data[i]);
