@@ -2,7 +2,7 @@
  * Routines for FC Inter-switch link services
  * Copyright 2001, Dinesh G Dutt <ddutt@cisco.com>
  *
- * $Id$
+ * $Id: packet-fcswils.c 52272 2013-09-29 18:19:29Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,7 +28,7 @@
 #include <glib.h>
 
 #include <epan/packet.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/conversation.h>
 #include <epan/etypes.h>
 #include "packet-scsi.h"
@@ -469,7 +469,7 @@ static guint8 *
 zonenm_to_str(tvbuff_t *tvb, gint offset)
 {
     int len = tvb_get_guint8(tvb, offset);
-    return tvb_get_ephemeral_string(tvb, offset+4, len);
+    return tvb_get_string(wmem_packet_scope(), tvb, offset+4, len);
 }
 
 /* Offset points to the start of the zone object */
@@ -718,11 +718,11 @@ dissect_swils_elp(tvbuff_t *tvb, proto_tree *elp_tree, guint8 isreq _U_)
         proto_tree_add_item(elp_tree, hf_swils_elp_rev, tvb, offset++, 1, ENC_BIG_ENDIAN);
         proto_tree_add_item(elp_tree, hf_swils_elp_flags, tvb, offset, 2, ENC_NA);
         offset += 3;
-        proto_tree_add_uint_format(elp_tree, hf_swils_elp_r_a_tov, tvb, offset, 4,
-                                   elp.r_a_tov, "R_A_TOV: %d msecs", elp.r_a_tov);
+        proto_tree_add_uint_format_value(elp_tree, hf_swils_elp_r_a_tov, tvb, offset, 4,
+                                   elp.r_a_tov, "%d msecs", elp.r_a_tov);
         offset += 4;
-        proto_tree_add_uint_format(elp_tree, hf_swils_elp_e_d_tov, tvb, offset, 4,
-                                   elp.e_d_tov, "E_D_TOV: %d msecs", elp.e_d_tov);
+        proto_tree_add_uint_format_value(elp_tree, hf_swils_elp_e_d_tov, tvb, offset, 4,
+                                   elp.e_d_tov, "%d msecs", elp.e_d_tov);
         offset += 4;
         proto_tree_add_string(elp_tree, hf_swils_elp_req_epn, tvb, offset, 8,
                               fcwwn_to_str(elp.req_epname));
@@ -740,8 +740,8 @@ dissect_swils_elp(tvbuff_t *tvb, proto_tree *elp_tree, guint8 isreq _U_)
         } else {
             flags="Class F Invld";
         }
-        proto_tree_add_bytes_format(elp_tree, hf_swils_elp_clsf_svcp, tvb, offset, 6,
-                                    &elp.clsf_svcparm[0], "Class F Svc Parameters: (%s)", flags);
+        proto_tree_add_bytes_format_value(elp_tree, hf_swils_elp_clsf_svcp, tvb, offset, 6,
+                                    &elp.clsf_svcparm[0], "(%s)", flags);
         offset += 6;
 
         proto_tree_add_item(elp_tree, hf_swils_elp_clsf_rcvsz, tvb, offset, 2, ENC_BIG_ENDIAN);
@@ -758,7 +758,7 @@ dissect_swils_elp(tvbuff_t *tvb, proto_tree *elp_tree, guint8 isreq _U_)
             char *flagsbuf;
             gint stroff, returned_length;
 
-            flagsbuf=(char *)ep_alloc(MAX_FLAGS_LEN);
+            flagsbuf=(char *)wmem_alloc(wmem_packet_scope(), MAX_FLAGS_LEN);
             stroff = 0;
 
             returned_length = g_snprintf(flagsbuf+stroff, MAX_FLAGS_LEN-stroff,
@@ -773,7 +773,7 @@ dissect_swils_elp(tvbuff_t *tvb, proto_tree *elp_tree, guint8 isreq _U_)
                 stroff += MIN(returned_length, MAX_FLAGS_LEN-stroff);
             }
             if (elp.cls1_svcparm[0] & 0x10) {
-                returned_length = g_snprintf(flagsbuf+stroff, MAX_FLAGS_LEN-stroff, " | LKS");
+                /*returned_length =*/ g_snprintf(flagsbuf+stroff, MAX_FLAGS_LEN-stroff, " | LKS");
             }
             flags=flagsbuf;
         }
@@ -781,8 +781,8 @@ dissect_swils_elp(tvbuff_t *tvb, proto_tree *elp_tree, guint8 isreq _U_)
             flags="Class 1 Invalid";
         }
 
-        proto_tree_add_bytes_format(elp_tree, hf_swils_elp_cls1_svcp, tvb, offset, 2,
-                                    NULL, "Class 1 Svc Parameters: (%s)", flags);
+        proto_tree_add_bytes_format_value(elp_tree, hf_swils_elp_cls1_svcp, tvb, offset, 2,
+                                    NULL, "(%s)", flags);
         offset += 2;
         if (elp.cls1_svcparm[0] & 0x80) {
             proto_tree_add_item(elp_tree, hf_swils_elp_cls1_rcvsz, tvb, offset, 2, ENC_BIG_ENDIAN);
@@ -801,9 +801,9 @@ dissect_swils_elp(tvbuff_t *tvb, proto_tree *elp_tree, guint8 isreq _U_)
             flags="Class 2 Invld";
         }
 
-        proto_tree_add_bytes_format(elp_tree, hf_swils_elp_cls2_svcp, tvb, offset, 2,
+        proto_tree_add_bytes_format_value(elp_tree, hf_swils_elp_cls2_svcp, tvb, offset, 2,
                                     &elp.cls2_svcparm[0],
-                                    "Class 2 Svc Parameters: (%s)", flags);
+                                    "(%s)", flags);
         offset += 2;
 
         if (elp.cls2_svcparm[0] & 0x80) {
@@ -822,9 +822,9 @@ dissect_swils_elp(tvbuff_t *tvb, proto_tree *elp_tree, guint8 isreq _U_)
         else {
             flags="Class 3 Invld";
         }
-        proto_tree_add_bytes_format(elp_tree, hf_swils_elp_cls3_svcp, tvb, offset, 2,
+        proto_tree_add_bytes_format_value(elp_tree, hf_swils_elp_cls3_svcp, tvb, offset, 2,
                                     &elp.cls3_svcparm[0],
-                                    "Class 3 Svc Parameters: (%s)", flags);
+                                    "(%s)", flags);
         offset += 2;
 
         if (elp.cls3_svcparm[0] & 0x80) {
@@ -870,9 +870,9 @@ dissect_swils_efp(tvbuff_t *tvb, proto_tree *efp_tree, guint8 isreq _U_)
     efp.payload_len = tvb_get_ntohs(tvb, offset);
     if (efp.payload_len < FC_SWILS_EFP_SIZE) {
         if (efp_tree)
-            proto_tree_add_uint_format(efp_tree, hf_swils_efp_payload_len,
+            proto_tree_add_uint_format_value(efp_tree, hf_swils_efp_payload_len,
                                        tvb, offset, 2, efp.payload_len,
-                                       "Payload Len: %u (bogus, must be >= %u)",
+                                       "%u (bogus, must be >= %u)",
                                        efp.payload_len, FC_SWILS_EFP_SIZE);
         return;
     }
@@ -1806,10 +1806,10 @@ dissect_fcswils(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             cdata->opcode = opcode;
         }
         else {
-            req_key = se_new(fcswils_conv_key_t);
+            req_key = wmem_new(wmem_file_scope(), fcswils_conv_key_t);
             req_key->conv_idx = conversation->index;
 
-            cdata = se_new(fcswils_conv_data_t);
+            cdata = wmem_new(wmem_file_scope(), fcswils_conv_data_t);
             cdata->opcode = opcode;
 
             g_hash_table_insert(fcswils_req_hash, req_key, cdata);
@@ -1852,19 +1852,17 @@ dissect_fcswils(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         }
     }
 
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-        if (isreq == FC_SWILS_REQ) {
-            col_add_str(pinfo->cinfo, COL_INFO,
+    if (isreq == FC_SWILS_REQ) {
+        col_add_str(pinfo->cinfo, COL_INFO,
+                    val_to_str(opcode, fc_swils_opcode_key_val, "0x%x"));
+    }
+    else if (opcode == FC_SWILS_SWRJT) {
+        col_add_fstr(pinfo->cinfo, COL_INFO, "SW_RJT (%s)",
+                        val_to_str(failed_opcode, fc_swils_opcode_key_val, "0x%x"));
+    }
+    else {
+        col_add_fstr(pinfo->cinfo, COL_INFO, "SW_ACC (%s)",
                         val_to_str(opcode, fc_swils_opcode_key_val, "0x%x"));
-        }
-        else if (opcode == FC_SWILS_SWRJT) {
-            col_add_fstr(pinfo->cinfo, COL_INFO, "SW_RJT (%s)",
-                         val_to_str(failed_opcode, fc_swils_opcode_key_val, "0x%x"));
-        }
-        else {
-            col_add_fstr(pinfo->cinfo, COL_INFO, "SW_ACC (%s)",
-                         val_to_str(opcode, fc_swils_opcode_key_val, "0x%x"));
-        }
     }
 
     if (tree) {
@@ -1927,7 +1925,7 @@ proto_register_fcswils(void)
            NULL, HFILL}},
 
         { &hf_swils_elp_clsf_svcp,
-          {"Class F Svc Param", "swils.elp.clsfp",
+          {"Class F Svc Parameters", "swils.elp.clsfp",
            FT_BYTES, BASE_NONE, NULL, 0x0,
            NULL, HFILL}},
 
@@ -1952,7 +1950,7 @@ proto_register_fcswils(void)
            NULL, HFILL}},
 
         { &hf_swils_elp_cls1_svcp,
-          {"Class 1 Svc Param", "swils.elp.cls1p",
+          {"Class 1 Svc Parameters", "swils.elp.cls1p",
            FT_BYTES, BASE_NONE, NULL, 0x0,
            NULL, HFILL}},
 
@@ -1962,7 +1960,7 @@ proto_register_fcswils(void)
            NULL, HFILL}},
 
         { &hf_swils_elp_cls2_svcp,
-          {"Class 2 Svc Param", "swils.elp.cls2p",
+          {"Class 2 Svc Parameters", "swils.elp.cls2p",
            FT_BYTES, BASE_NONE, NULL, 0x0,
            NULL, HFILL}},
 
@@ -1972,7 +1970,7 @@ proto_register_fcswils(void)
            NULL, HFILL}},
 
         { &hf_swils_elp_cls3_svcp,
-          {"Class 3 Svc Param", "swils.elp.cls3p",
+          {"Class 3 Svc Parameters", "swils.elp.cls3p",
            FT_BYTES, BASE_NONE, NULL, 0x0,
            NULL, HFILL}},
 
