@@ -3,7 +3,7 @@
  * Routines for dissecting IETF ForCES protocol layer messages.Now support the following TML types:TCP+UDP,SCTP.
  * Copyright 2009, NDSC & Zhejiang Gongshang University,Fenggen Jia <fgjia@mail.zjgsu.edu.cn or fenggen.jia@gmail.com>
  *
- * $Id$
+ * $Id: packet-forces.c 52045 2013-09-15 01:48:30Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -186,6 +186,14 @@ static gint  ett_forces_astreason_tlv = -1;
 /*Main_TLV unknown subtree*/
 static gint  ett_forces_unknown_tlv = -1;
 
+
+static expert_field ei_forces_length = EI_INIT;
+static expert_field ei_forces_tlv_type = EI_INIT;
+static expert_field ei_forces_tlv_length = EI_INIT;
+static expert_field ei_forces_lfbselect_tlv_type_operation_path_length = EI_INIT;
+static expert_field ei_forces_lfbselect_tlv_type_operation_type = EI_INIT;
+static expert_field ei_forces_redirect_tlv_redirect_data_tlv_length = EI_INIT;
+
 /*ACK values and the strings to be displayed*/
 static const value_string main_header_flags_ack_vals[] = {
     { 0x0, "NoACK" },
@@ -308,7 +316,7 @@ dissect_path_data_tlv(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gint
                             tvb, offset+2, 2, ENC_BIG_ENDIAN);
         if (length_TLV < TLV_TL_LENGTH)
         {
-            expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN, "Bogus TLV length: %u", length_TLV);
+            expert_add_info_format(pinfo, ti, &ei_forces_lfbselect_tlv_type_operation_path_length, "Bogus TLV length: %u", length_TLV);
             break;
         }
         proto_item_set_len(ti, length_TLV);
@@ -365,12 +373,12 @@ dissect_operation_tlv(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gint
         ti = proto_tree_add_item(oper_tree, hf_forces_lfbselect_tlv_type_operation_type,
                                  tvb, offset, 2, ENC_BIG_ENDIAN);
         if (try_val_to_str(type, operation_type_vals) == NULL)
-            expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN,
+            expert_add_info_format(pinfo, ti, &ei_forces_lfbselect_tlv_type_operation_type,
                 "Bogus: ForCES Operation TLV (Type:0x%04x) is not supported", type);
 
         length = tvb_get_ntohs(tvb, offset+2);
-        proto_tree_add_uint_format(oper_tree, hf_forces_lfbselect_tlv_type_operation_length,
-                                   tvb, offset+2, 2, length, "Length: %u Bytes", length);
+        proto_tree_add_uint_format_value(oper_tree, hf_forces_lfbselect_tlv_type_operation_length,
+                                   tvb, offset+2, 2, length, "%u Bytes", length);
 
         dissect_path_data_tlv(tvb, pinfo, oper_tree, offset+TLV_TL_LENGTH);
         if (length == 0)
@@ -415,8 +423,8 @@ dissect_redirecttlv(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gint of
     proto_tree_add_item(meta_data_tree, hf_forces_redirect_tlv_meta_data_tlv_type, tvb, offset, 2, ENC_BIG_ENDIAN);
 
     length_meta = tvb_get_ntohs(tvb, offset+2);
-    proto_tree_add_uint_format(meta_data_tree, hf_forces_redirect_tlv_meta_data_tlv_length, tvb, offset+2, 2,
-                               length_meta, "Length: %u Bytes", length_meta);
+    proto_tree_add_uint_format_value(meta_data_tree, hf_forces_redirect_tlv_meta_data_tlv_length, tvb, offset+2, 2,
+                               length_meta, "%u Bytes", length_meta);
     proto_item_set_len(ti, length_meta);
 
     start_offset = offset;
@@ -428,8 +436,8 @@ dissect_redirecttlv(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gint of
         proto_tree_add_item(meta_data_ilv_tree, hf_forces_redirect_tlv_meta_data_tlv_meta_data_ilv_id,
                                    tvb, offset+8, 4, ENC_BIG_ENDIAN);
         length_ilv = tvb_get_ntohl(tvb, offset+12);
-        proto_tree_add_uint_format(meta_data_ilv_tree, hf_forces_redirect_tlv_meta_data_tlv_meta_data_ilv_length,
-                                   tvb,  offset+12, 4, length_ilv, "Length: %u Bytes", length_ilv);
+        proto_tree_add_uint_format_value(meta_data_ilv_tree, hf_forces_redirect_tlv_meta_data_tlv_meta_data_ilv_length,
+                                   tvb,  offset+12, 4, length_ilv, "%u Bytes", length_ilv);
         if (length_ilv > 0)
             proto_tree_add_item(meta_data_ilv_tree, hf_forces_redirect_tlv_meta_data_tlv_meta_data_ilv,
                                    tvb, offset+8, length_ilv, ENC_NA);
@@ -446,18 +454,16 @@ dissect_redirecttlv(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gint of
         proto_tree_add_item(redirect_data_tree, hf_forces_redirect_tlv_redirect_data_tlv_type,
                             tvb, offset, 2,  ENC_BIG_ENDIAN);
         length_redirect = tvb_get_ntohs(tvb, offset+2);
-        proto_tree_add_uint_format(redirect_data_tree, hf_forces_redirect_tlv_redirect_data_tlv_length,
-                            tvb, offset+2, 2, length_redirect, "Length: %u Bytes", length_redirect);
+        proto_tree_add_uint_format_value(redirect_data_tree, hf_forces_redirect_tlv_redirect_data_tlv_length,
+                            tvb, offset+2, 2, length_redirect, "%u Bytes", length_redirect);
 
         if (tvb_reported_length_remaining(tvb, offset) < length_redirect)
         {
-            expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN,
-                "Bogus: Redirect Data TLV length (%u bytes) is wrong", length_redirect);
+            expert_add_info_format(pinfo, ti, &ei_forces_redirect_tlv_redirect_data_tlv_length, "Bogus: Redirect Data TLV length (%u bytes) is wrong", length_redirect);
         }
         else if (length_redirect < TLV_TL_LENGTH + MIN_IP_HEADER_LENGTH)
         {
-            expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN,
-                "Bogus: Redirect Data TLV length (%u bytes) not big enough for IP layer", length_redirect);
+            expert_add_info_format(pinfo, ti, &ei_forces_redirect_tlv_redirect_data_tlv_length, "Bogus: Redirect Data TLV length (%u bytes) not big enough for IP layer", length_redirect);
         }
         else
         {
@@ -507,12 +513,10 @@ dissect_forces(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint32 offs
     ti = proto_tree_add_uint_format( forces_main_header_tree, hf_forces_length,
                                      tvb, offset+2, 2, length_count, "Length: %u Bytes", length_count);
     if (length_count != tvb_reported_length_remaining(tvb, offset))
-        expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN,
-            "Bogus: ForCES Header length (%u bytes) is wrong),should be (%u bytes)",
+        expert_add_info_format(pinfo, ti, &ei_forces_length, "Bogus: ForCES Header length (%u bytes) is wrong),should be (%u bytes)",
             length_count, tvb_reported_length_remaining(tvb, offset));
     if (length_count < 24)
-        expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN,
-            "Bogus: ForCES Header length (%u bytes) is less than 24bytes)", length_count);
+        expert_add_info_format(pinfo, ti, &ei_forces_length, "Bogus: ForCES Header length (%u bytes) is less than 24bytes)", length_count);
 
     col_add_fstr(pinfo->cinfo, COL_INFO, "Message Type: %s, Total Length:  %u Bytes",
             val_to_str(message_type, message_type_vals, "Unknown messagetype 0x%x"), length_count);
@@ -543,15 +547,14 @@ dissect_forces(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint32 offs
         tlv_item = proto_tree_add_item(forces_tlv_tree, hf_forces_tlv_type, tvb, offset, 2, ENC_BIG_ENDIAN);
         length_count = tvb_get_ntohs(tvb, offset+2) * 4;
         proto_item_set_len(ti, length_count);
-        ti = proto_tree_add_uint_format(forces_tlv_tree, hf_forces_tlv_length,
-                                        tvb, offset+2, 2, length_count, "Length: %u Bytes", length_count);
+        ti = proto_tree_add_uint_format_value(forces_tlv_tree, hf_forces_tlv_length,
+                                        tvb, offset+2, 2, length_count, "%u Bytes", length_count);
         if (tvb_reported_length_remaining(tvb, offset) < length_count)
-            expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN,
-                "Bogus: Main TLV length (%u bytes) is wrong", length_count);
+            expert_add_info_format(pinfo, ti, &ei_forces_tlv_length, "Bogus: Main TLV length (%u bytes) is wrong", length_count);
 
         if (length_count < TLV_TL_LENGTH)
         {
-            expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN, "Bogus TLV length: %u", length_count);
+            expert_add_info_format(pinfo, ti, &ei_forces_tlv_length, "Bogus TLV length: %u", length_count);
             break;
         }
 
@@ -585,8 +588,7 @@ dissect_forces(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint32 offs
             break;
 
         default:
-            expert_add_info_format(pinfo, tlv_item, PI_PROTOCOL, PI_WARN,
-                "Bogus: The Main_TLV type is unknown");
+            expert_add_info(pinfo, tlv_item, &ei_forces_tlv_type);
             ti = proto_tree_add_text(forces_tlv_tree, tvb, offset, length_count, "Unknown TLV");
             tlv_tree = proto_item_add_subtree(ti, ett_forces_unknown_tlv);
             proto_tree_add_item(tlv_tree, hf_forces_unknown_tlv, tvb, offset, length_count, ENC_NA);
@@ -617,6 +619,7 @@ void
 proto_register_forces(void)
 {
     module_t *forces_module;
+    expert_module_t* expert_forces;
 
     /* Setup list of header fields  See Section 1.6.1 for details*/
     static hf_register_info hf[] = {
@@ -805,12 +808,23 @@ proto_register_forces(void)
         &ett_forces_unknown_tlv
     };
 
+    static ei_register_info ei[] = {
+        { &ei_forces_length, { "forces.length.bad", PI_PROTOCOL, PI_WARN, "ForCES Header length is wrong", EXPFILL }},
+        { &ei_forces_tlv_type, { "forces.tlv.type.unknown", PI_PROTOCOL, PI_WARN, "Bogus: The Main_TLV type is unknown", EXPFILL }},
+        { &ei_forces_tlv_length, { "forces.tlv.length.bad", PI_PROTOCOL, PI_WARN, "Bogus TLV length", EXPFILL }},
+        { &ei_forces_lfbselect_tlv_type_operation_path_length, { "forces.lfbselect.tlv.type.operation.path.length.bad", PI_PROTOCOL, PI_WARN, "Bogus TLV length", EXPFILL }},
+        { &ei_forces_lfbselect_tlv_type_operation_type, { "forces.lfbselect.tlv.type.operation.type.unsupported", PI_PROTOCOL, PI_WARN, "ForCES Operation TLV is not supported", EXPFILL }},
+        { &ei_forces_redirect_tlv_redirect_data_tlv_length, { "forces.redirect.tlv.redirect.data.tlv.length.bad", PI_PROTOCOL, PI_WARN, "Redirect Data TLV length is wrong", EXPFILL }},
+    };
+
     /* Register the protocol name and description */
     proto_forces = proto_register_protocol("Forwarding and Control Element Separation Protocol", "ForCES", "forces");
 
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_forces, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_forces = expert_register_protocol(proto_forces);
+    expert_register_field_array(expert_forces, ei, array_length(ei));
 
     forces_module = prefs_register_protocol(proto_forces,proto_reg_handoff_forces);
 
@@ -886,19 +900,19 @@ proto_reg_handoff_forces(void)
     /* Register SCTP port for medium priority dissection */
     if ((alternate_sctp_med_prio_channel_port != 0) &&
         (alternate_sctp_med_prio_channel_port != forces_alternate_sctp_med_prio_channel_port))
-        dissector_delete_uint("sctp.port", alternate_sctp_med_prio_channel_port, forces_handle);
+        dissector_delete_uint("udp.port", alternate_sctp_med_prio_channel_port, forces_handle);
     if ((forces_alternate_sctp_med_prio_channel_port != 0) &&
         (alternate_sctp_med_prio_channel_port != forces_alternate_sctp_med_prio_channel_port))
-        dissector_add_uint("sctp.port", forces_alternate_sctp_med_prio_channel_port, forces_handle);
+        dissector_add_uint("udp.port", forces_alternate_sctp_med_prio_channel_port, forces_handle);
     alternate_sctp_med_prio_channel_port = forces_alternate_sctp_med_prio_channel_port;
 
     /* Register SCTP port for low priority dissection */
     if ((alternate_sctp_low_prio_channel_port != 0) &&
         (alternate_sctp_low_prio_channel_port != forces_alternate_sctp_low_prio_channel_port))
-        dissector_delete_uint("sctp.port", alternate_sctp_low_prio_channel_port, forces_handle);
+        dissector_delete_uint("udp.port", alternate_sctp_low_prio_channel_port, forces_handle);
     if ((forces_alternate_sctp_low_prio_channel_port != 0) &&
         (alternate_sctp_low_prio_channel_port != forces_alternate_sctp_low_prio_channel_port))
-        dissector_add_uint("sctp.port", forces_alternate_sctp_low_prio_channel_port, forces_handle);
+        dissector_add_uint("udp.port", forces_alternate_sctp_low_prio_channel_port, forces_handle);
     alternate_sctp_low_prio_channel_port = forces_alternate_sctp_low_prio_channel_port;
 }
 
