@@ -2,7 +2,7 @@
  * Routines for the disassembly of Foundry LLC messages (currently
  * Foundry Discovery Protocol - FDP only)
  *
- * $Id$
+ * $Id: packet-foundry.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Copyright 2012 Joerg Mayer (see AUTHORS file)
  *
@@ -90,7 +90,7 @@ typedef enum {
 	FDP_TYPE_VERSION = 5,
 	FDP_TYPE_MODEL = 6,
 	FDP_TYPE_VLANMAP = 0x0101,
-	FDP_TYPE_TAG = 0x0102,
+	FDP_TYPE_TAG = 0x0102
 } fdp_type_t;
 
 static const value_string fdp_type_vals[] = {
@@ -148,7 +148,7 @@ dissect_string_tlv(tvbuff_t *tvb, packet_info *pinfo, int offset, int length, pr
 	offset += 4;
 	length -= 4;
 
-	string_value = tvb_get_ephemeral_string(tvb, offset, length);
+	string_value = tvb_get_string(wmem_packet_scope(), tvb, offset, length);
 	proto_item_append_text(string_item, ": \"%s\"",
 		format_text(string_value, strlen(string_value)));
 
@@ -306,8 +306,7 @@ dissect_fdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				break;
 			}
 			type_string = val_to_str(tlv_type, fdp_type_vals, "[%u]");
-			if (check_col(pinfo->cinfo, COL_INFO))
-				col_append_fstr(pinfo->cinfo, COL_INFO, " %s", type_string);
+			col_append_fstr(pinfo->cinfo, COL_INFO, " %s", type_string);
 
 			switch (tlv_type) {
 			case FDP_TYPE_NAME:
@@ -464,5 +463,5 @@ proto_register_foundry_oui(void)
 	  }
 	};
 
-	llc_add_oui(OUI_FOUNDRY, "llc.foundry_pid", "Foundry OUI PID", hf);
+	llc_add_oui(OUI_FOUNDRY, "llc.foundry_pid", "LLC Foundry OUI PID", hf);
 }
