@@ -7,7 +7,7 @@
  * ----------------
  * http://gearman.org/index.php?id=protocol
  *
- * $Id$
+ * $Id: packet-gearman.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -69,6 +69,8 @@ static gint ett_gearman = -1;
 static gint ett_gearman_command = -1;
 static gint ett_gearman_content = -1;
 
+static expert_field ei_gearman_pkt_type_unknown = EI_INIT;
+
 static gboolean gearman_desegment  = TRUE;
 
 static const int GEARMAN_COMMAND_HEADER_SIZE = 12;
@@ -188,7 +190,7 @@ dissect_binary_packet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   col_set_str(pinfo->cinfo, COL_PROTOCOL, "Gearman");
   col_clear(pinfo->cinfo,COL_INFO);
 
-  magic_code = tvb_get_ephemeral_string(tvb, 1, 3);
+  magic_code = tvb_get_string(wmem_packet_scope(), tvb, 1, 3);
   type = tvb_get_ntohl(tvb, 4);
   size = tvb_get_ntohl(tvb, 8);
 
@@ -408,7 +410,7 @@ dissect_binary_packet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   default:
     if (size > 0)
-      expert_add_info_format(pinfo, content_item, PI_PROTOCOL, PI_WARN, "Unknown command");
+      expert_add_info(pinfo, content_item, &ei_gearman_pkt_type_unknown);
   }
 
   col_set_fence(pinfo->cinfo, COL_INFO);
@@ -438,7 +440,7 @@ dissect_management_packet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       if (cmdlen == linelen && 0 == tvb_strneql(tvb, offset, GEARMAN_MGR_CMDS[i], cmdlen))
       {
         proto_tree_add_item(gearman_tree, hf_gearman_mgr_cmd, tvb, offset, cmdlen, ENC_ASCII|ENC_NA);
-        col_add_fstr(pinfo->cinfo, COL_INFO, "[MGR] %s", tvb_get_ephemeral_string(tvb, offset, linelen));
+        col_add_fstr(pinfo->cinfo, COL_INFO, "[MGR] %s", tvb_get_string(wmem_packet_scope(), tvb, offset, linelen));
         type = 1;
         break;
       }
@@ -451,12 +453,12 @@ dissect_management_packet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
       if (type == 0)
       {
-        col_add_fstr(pinfo->cinfo, COL_INFO, "[MGR] %s", tvb_get_ephemeral_string(tvb, offset, linelen));
+        col_add_fstr(pinfo->cinfo, COL_INFO, "[MGR] %s", tvb_get_string(wmem_packet_scope(), tvb, offset, linelen));
         type = -1;
       }
       else
       {
-        col_append_sep_fstr(pinfo->cinfo, COL_INFO, ",", "%s", tvb_get_ephemeral_string(tvb, offset, linelen));
+        col_append_sep_fstr(pinfo->cinfo, COL_INFO, ",", "%s", tvb_get_string(wmem_packet_scope(), tvb, offset, linelen));
       }
     }
 
@@ -518,12 +520,19 @@ proto_register_gearman(void)
     &ett_gearman_content
   };
 
+  static ei_register_info ei[] = {
+     { &ei_gearman_pkt_type_unknown, { "gearman.pkt_type.unknown", PI_PROTOCOL, PI_WARN, "Unknown command", EXPFILL }},
+  };
+
   module_t *gearman_module;
+  expert_module_t* expert_gearman;
 
   proto_gearman = proto_register_protocol("Gearman Protocol", "Gearman", "gearman");
 
   proto_register_field_array(proto_gearman, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
+  expert_gearman = expert_register_protocol(proto_gearman);
+  expert_register_field_array(expert_gearman, ei, array_length(ei));
 
   gearman_module = prefs_register_protocol(proto_gearman, NULL);
   prefs_register_bool_preference(gearman_module, "desegment",
