@@ -3,7 +3,7 @@
  * RFC 1939
  * Copyright 2010, Jelmer Vernooij <jelmer@samba.org>
  *
- * $Id$
+ * $Id: packet-git.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -55,7 +55,7 @@ static gboolean tvb_get_packet_length(tvbuff_t *tvb, int offset,
 {
 	guint8 *lenstr;
 
-	lenstr = tvb_get_ephemeral_string(tvb, offset, 4);
+	lenstr = tvb_get_string(wmem_packet_scope(), tvb, offset, 4);
 
 	return (sscanf(lenstr, "%hx", length) == 1);
 }
