@@ -4,7 +4,7 @@
  * With contributions from:
  *    Shreedhara LG <shreedharlg@gmail.com>
  *
- * $Id$
+ * $Id: packet-gluster.h 52144 2013-09-19 13:04:37Z eapache $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -351,6 +351,9 @@ enum gf_fop_procnum {
 	GFS3_OP_READDIRP,
 	GFS3_OP_RELEASE,
 	GFS3_OP_RELEASEDIR,
+	GFS3_OP_FREMOVEXATTR,
+	GFS3_OP_FALLOCATE,
+	GFS3_OP_DISCARD,
 	GFS3_OP_MAXVALUE
 };
 
