@@ -2,7 +2,7 @@
  * Routines for GlusterFS dissection
  * Copyright 2012, Niels de Vos <ndevos@redhat.com>
  *
- * $Id$
+ * $Id: packet-glusterfs.c 52180 2013-09-22 20:04:35Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -527,7 +527,7 @@ gluster_rpc_dissect_dict(proto_tree *tree, tvbuff_t *tvb, int hfindex, int offse
 		offset += 4;
 
 		/* read the key, '\0' terminated */
-		key = tvb_get_ephemeral_stringz(tvb, offset, &key_len);
+		key = tvb_get_stringz(wmem_packet_scope(), tvb, offset, &key_len);
 		start_offset2 = offset;
 		if (tree)
 			dict_item = proto_tree_add_text(subtree, tvb, offset, -1, "%s: ", key);
@@ -552,7 +552,7 @@ gluster_rpc_dissect_dict(proto_tree *tree, tvbuff_t *tvb, int hfindex, int offse
 						       tvb_get_letohl(tvb, offset + 4),
 						       tvb_get_letohl(tvb, offset + 8));
 			} else {
-				value = tvb_get_ephemeral_string(tvb, offset, value_len);
+				value = tvb_get_string(wmem_packet_scope(), tvb, offset, value_len);
 				proto_item_append_text(dict_item, "%s", value);
 			}
 		}
@@ -1184,20 +1184,6 @@ glusterfs_gfs3_3_op_read_call(tvbuff_t *tvb, int offset,
 	return offset;
 }
 
-static int
-glusterfs_gfs3_3_op_write_reply(tvbuff_t *tvb, int offset, packet_info *pinfo,
-							proto_tree *tree)
-{
-	offset = gluster_dissect_common_reply(tvb, offset, pinfo, tree);
-	offset = glusterfs_rpc_dissect_gf_iatt(tree, tvb,
-					hf_glusterfs_preparent_iatt, offset);
-	offset = glusterfs_rpc_dissect_gf_iatt(tree, tvb,
-					hf_glusterfs_postparent_iatt, offset);
-	offset = gluster_rpc_dissect_dict(tree, tvb, hf_glusterfs_dict, offset);
-
-	return offset;
-}
-
 static int
 glusterfs_gfs3_3_op_write_call(tvbuff_t *tvb, int offset,
 				packet_info *pinfo _U_, proto_tree *tree)
@@ -1641,6 +1627,7 @@ glusterfs_gfs3_3_op_readdirp_reply(tvbuff_t *tvb, int offset,
         return offset;
 }
 
+/* READDIRP and DISCARD both use this */
 static int
 glusterfs_gfs3_3_op_readdirp_call(tvbuff_t *tvb, int offset,
 				packet_info *pinfo _U_, proto_tree *tree)
@@ -1676,6 +1663,32 @@ glusterfs_gfs3_3_op_releasedir_call(tvbuff_t *tvb, int offset,
 	return offset;
 }
 
+static int
+glusterfs_gfs3_3_op_fremovexattr_call(tvbuff_t *tvb, int offset,
+				packet_info *pinfo _U_, proto_tree *tree)
+{
+	offset = glusterfs_rpc_dissect_gfid(tree, tvb, hf_glusterfs_gfid, offset);
+	offset = dissect_rpc_uint64(tvb, tree, hf_glusterfs_fd, offset);
+	offset = dissect_rpc_string(tvb, tree, hf_glusterfs_name, offset, NULL);
+	offset = gluster_rpc_dissect_dict(tree, tvb, hf_glusterfs_dict, offset);
+
+	return offset;
+}
+
+static int
+glusterfs_gfs3_3_op_fallocate_call(tvbuff_t *tvb, int offset,
+				packet_info *pinfo _U_, proto_tree *tree)
+{
+	offset = glusterfs_rpc_dissect_gfid(tree, tvb, hf_glusterfs_gfid, offset);
+	offset = dissect_rpc_uint64(tvb, tree, hf_glusterfs_fd, offset);
+	offset = glusterfs_rpc_dissect_flags(tree, tvb, offset);
+	offset = dissect_rpc_uint64(tvb, tree, hf_glusterfs_offset, offset);
+	offset = dissect_rpc_uint32(tvb, tree, hf_glusterfs_size, offset);
+	offset = gluster_rpc_dissect_dict(tree, tvb, hf_glusterfs_dict, offset);
+
+	return offset;
+}
+
 /* This function is for common replay. RELEASE , RELEASEDIR and some other function use this method */
 
 int
@@ -1831,7 +1844,7 @@ static const vsff glusterfs3_3_fop_proc[] = {
 	},
 	{
 		GFS3_OP_WRITE, "WRITE",
-		glusterfs_gfs3_3_op_write_call, glusterfs_gfs3_3_op_write_reply
+		glusterfs_gfs3_3_op_write_call, glusterfs_gfs3_3_op_setattr_reply
 	},
 	{
 		GFS3_OP_STATFS, "STATFS",
@@ -1887,7 +1900,7 @@ static const vsff glusterfs3_3_fop_proc[] = {
 	},
 	{
 		GFS3_OP_LOOKUP, "LOOKUP",
-		glusterfs_gfs3_3_op_lookup_call, glusterfs_gfs3_3_op_write_reply
+		glusterfs_gfs3_3_op_lookup_call, glusterfs_gfs3_3_op_setattr_reply
 	},
 	{
 		GFS3_OP_READDIR, "READDIR",
@@ -1948,54 +1961,69 @@ static const vsff glusterfs3_3_fop_proc[] = {
 		GFS3_OP_RELEASEDIR, "RELEASEDIR",
  		glusterfs_gfs3_3_op_releasedir_call, glusterfs_gfs3_3_op_common_reply
 	},
+	{
+		GFS3_OP_FREMOVEXATTR, "FREMOVEXATTR",
+ 		glusterfs_gfs3_3_op_fremovexattr_call, glusterfs_gfs3_3_op_common_reply
+	},
+	{
+		GFS3_OP_FALLOCATE, "FALLOCATE",
+ 		glusterfs_gfs3_3_op_fallocate_call, glusterfs_gfs3_3_op_setattr_reply
+	},
+	{
+		GFS3_OP_DISCARD, "DISCARD",
+ 		glusterfs_gfs3_3_op_readdirp_call, glusterfs_gfs3_3_op_setattr_reply
+	},
 	{ 0, NULL, NULL, NULL }
 };
 
 
 static const value_string glusterfs3_1_fop_proc_vals[] = {
-	{ GFS3_OP_NULL,        "NULL" },
-	{ GFS3_OP_STAT,        "STAT" },
-	{ GFS3_OP_READLINK,    "READLINK" },
-	{ GFS3_OP_MKNOD,       "MKNOD" },
-	{ GFS3_OP_MKDIR,       "MKDIR" },
-	{ GFS3_OP_UNLINK,      "UNLINK" },
-	{ GFS3_OP_RMDIR,       "RMDIR" },
-	{ GFS3_OP_SYMLINK,     "SYMLINK" },
-	{ GFS3_OP_RENAME,      "RENAME" },
-	{ GFS3_OP_LINK,        "LINK" },
-	{ GFS3_OP_TRUNCATE,    "TRUNCATE" },
-	{ GFS3_OP_OPEN,        "OPEN" },
-	{ GFS3_OP_READ,        "READ" },
-	{ GFS3_OP_WRITE,       "WRITE" },
-	{ GFS3_OP_STATFS,      "STATFS" },
-	{ GFS3_OP_FLUSH,       "FLUSH" },
-	{ GFS3_OP_FSYNC,       "FSYNC" },
-	{ GFS3_OP_SETXATTR,    "SETXATTR" },
-	{ GFS3_OP_GETXATTR,    "GETXATTR" },
-	{ GFS3_OP_REMOVEXATTR, "REMOVEXATTR" },
-	{ GFS3_OP_OPENDIR,     "OPENDIR" },
-	{ GFS3_OP_FSYNCDIR,    "FSYNCDIR" },
-	{ GFS3_OP_ACCESS,      "ACCESS" },
-	{ GFS3_OP_CREATE,      "CREATE" },
-	{ GFS3_OP_FTRUNCATE,   "FTRUNCATE" },
-	{ GFS3_OP_FSTAT,       "FSTAT" },
-	{ GFS3_OP_LK,          "LK" },
-	{ GFS3_OP_LOOKUP,      "LOOKUP" },
-	{ GFS3_OP_READDIR,     "READDIR" },
-	{ GFS3_OP_INODELK,     "INODELK" },
-	{ GFS3_OP_FINODELK,    "FINODELK" },
-	{ GFS3_OP_ENTRYLK,     "ENTRYLK" },
-	{ GFS3_OP_FENTRYLK,    "FENTRYLK" },
-	{ GFS3_OP_XATTROP,     "XATTROP" },
-	{ GFS3_OP_FXATTROP,    "FXATTROP" },
-	{ GFS3_OP_FGETXATTR,   "FGETXATTR" },
-	{ GFS3_OP_FSETXATTR,   "FSETXATTR" },
-	{ GFS3_OP_RCHECKSUM,   "RCHECKSUM" },
-	{ GFS3_OP_SETATTR,     "SETATTR" },
-	{ GFS3_OP_FSETATTR,    "FSETATTR" },
-	{ GFS3_OP_READDIRP,    "READDIRP" },
-	{ GFS3_OP_RELEASE,     "RELEASE" },
-	{ GFS3_OP_RELEASEDIR,  "RELEASEDIR" },
+	{ GFS3_OP_NULL,         "NULL" },
+	{ GFS3_OP_STAT,         "STAT" },
+	{ GFS3_OP_READLINK,     "READLINK" },
+	{ GFS3_OP_MKNOD,        "MKNOD" },
+	{ GFS3_OP_MKDIR,        "MKDIR" },
+	{ GFS3_OP_UNLINK,       "UNLINK" },
+	{ GFS3_OP_RMDIR,        "RMDIR" },
+	{ GFS3_OP_SYMLINK,      "SYMLINK" },
+	{ GFS3_OP_RENAME,       "RENAME" },
+	{ GFS3_OP_LINK,         "LINK" },
+	{ GFS3_OP_TRUNCATE,     "TRUNCATE" },
+	{ GFS3_OP_OPEN,         "OPEN" },
+	{ GFS3_OP_READ,         "READ" },
+	{ GFS3_OP_WRITE,        "WRITE" },
+	{ GFS3_OP_STATFS,       "STATFS" },
+	{ GFS3_OP_FLUSH,        "FLUSH" },
+	{ GFS3_OP_FSYNC,        "FSYNC" },
+	{ GFS3_OP_SETXATTR,     "SETXATTR" },
+	{ GFS3_OP_GETXATTR,     "GETXATTR" },
+	{ GFS3_OP_REMOVEXATTR,  "REMOVEXATTR" },
+	{ GFS3_OP_OPENDIR,      "OPENDIR" },
+	{ GFS3_OP_FSYNCDIR,     "FSYNCDIR" },
+	{ GFS3_OP_ACCESS,       "ACCESS" },
+	{ GFS3_OP_CREATE,       "CREATE" },
+	{ GFS3_OP_FTRUNCATE,    "FTRUNCATE" },
+	{ GFS3_OP_FSTAT,        "FSTAT" },
+	{ GFS3_OP_LK,           "LK" },
+	{ GFS3_OP_LOOKUP,       "LOOKUP" },
+	{ GFS3_OP_READDIR,      "READDIR" },
+	{ GFS3_OP_INODELK,      "INODELK" },
+	{ GFS3_OP_FINODELK,     "FINODELK" },
+	{ GFS3_OP_ENTRYLK,      "ENTRYLK" },
+	{ GFS3_OP_FENTRYLK,     "FENTRYLK" },
+	{ GFS3_OP_XATTROP,      "XATTROP" },
+	{ GFS3_OP_FXATTROP,     "FXATTROP" },
+	{ GFS3_OP_FGETXATTR,    "FGETXATTR" },
+	{ GFS3_OP_FSETXATTR,    "FSETXATTR" },
+	{ GFS3_OP_RCHECKSUM,    "RCHECKSUM" },
+	{ GFS3_OP_SETATTR,      "SETATTR" },
+	{ GFS3_OP_FSETATTR,     "FSETATTR" },
+	{ GFS3_OP_READDIRP,     "READDIRP" },
+	{ GFS3_OP_RELEASE,      "RELEASE" },
+	{ GFS3_OP_RELEASEDIR,   "RELEASEDIR" },
+	{ GFS3_OP_FREMOVEXATTR, "FREMOVEXATTR" },
+	{ GFS3_OP_FALLOCATE,    "FALLOCATE" },
+	{ GFS3_OP_DISCARD,      "DISCARD" },
 	{ 0, NULL }
 };
 static value_string_ext glusterfs3_1_fop_proc_vals_ext = VALUE_STRING_EXT_INIT(glusterfs3_1_fop_proc_vals);
@@ -2075,11 +2103,11 @@ proto_register_glusterfs(void)
 				"GFID of the parent directory", HFILL }
 		},
 		{ &hf_glusterfs_oldgfid,
-			{ "Old GFID", "glusterfs.oldgfid", FT_BYTES,
+			{ "Old GFID", "glusterfs.oldgfid", FT_GUID,
 				BASE_NONE, NULL, 0, NULL, HFILL }
 		},
 		{ &hf_glusterfs_newgfid,
-			{ "New GFID", "glusterfs.newgfid", FT_BYTES,
+			{ "New GFID", "glusterfs.newgfid", FT_GUID,
 				BASE_NONE, NULL, 0, NULL, HFILL }
 		},
 		{ &hf_glusterfs_path,
