@@ -8,7 +8,7 @@
  *  [2] ETSI TS 101 376-4-8 V2.2.1 - GMPRS-1 04.008
  *  [3] ETSI TS 101 376-4-8 V3.1.1 - GMR-1 3G 44.008
  *
- * $Id$
+ * $Id: packet-gmr1_bcch.c 52349 2013-10-04 02:21:39Z eapache $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -33,6 +33,7 @@
 
 #include <glib.h>
 #include <epan/packet.h>
+#include <epan/wmem/wmem.h>
 
 #include "packet-csn1.h"
 
@@ -1047,7 +1048,11 @@ dissect_gmr1_bcch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	/* SI1 or SI2 */
 	if (is_si1) {
 		SystemInformation1_t *data;
-		data = ep_new(SystemInformation1_t);
+		data = wmem_new(wmem_packet_scope(), SystemInformation1_t);
+		/* Initialize the type to the last element, which is an
+		 * "Unknown", in case the dissector bails before getting this
+		 * far. */
+		data->SegmentType = array_length(SI1_SegmentChoice) - 1;
 		csnStreamDissector(bcch_tree, &ar, CSNDESCR(SystemInformation1_t), tvb, data, ett_gmr1_bcch);
 		col_append_fstr(
 			pinfo->cinfo, COL_INFO,
@@ -1056,7 +1061,11 @@ dissect_gmr1_bcch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		);
 	} else {
 		SystemInformation2_t *data;
-		data = ep_new(SystemInformation2_t);
+		data = wmem_new(wmem_packet_scope(), SystemInformation2_t);
+		/* Initialize the type to the last element, which is an
+		 * "Unknown", in case the dissector bails before getting this
+		 * far. */
+		data->SegmentType = array_length(SI2_SegmentChoice) - 1;
 		csnStreamDissector(bcch_tree, &ar, CSNDESCR(SystemInformation2_t), tvb, data, ett_gmr1_bcch);
 		col_append_fstr(
 			pinfo->cinfo, COL_INFO,
@@ -1426,3 +1435,16 @@ proto_reg_handoff_gmr1_bcch(void)
 {
 	data_handle = find_dissector("data");
 }
+
+/*
+ * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ *
+ * Local variables:
+ * c-basic-offset: 8
+ * tab-width: 8
+ * indent-tabs-mode: t
+ * End:
+ *
+ * vi: set shiftwidth=8 tabstop=8 noexpandtab:
+ * :indentSize=8:tabSize=8:noTabs=false:
+ */
