@@ -2,7 +2,7 @@
  * Routines for gnutella dissection
  * Copyright 2001, B. Johannessen <bob@havoq.com>
  *
- * $Id$
+ * $Id: packet-gnutella.c 52045 2013-09-15 01:48:30Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -385,8 +385,7 @@ static void dissect_gnutella_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
 			break;
 	}
 
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_append_sep_fstr(pinfo->cinfo, COL_INFO, NULL, "%s",
+	col_append_sep_fstr(pinfo->cinfo, COL_INFO, NULL, "%s",
 		    payload_descriptor_text);
 
 	if (tree) {
@@ -405,13 +404,13 @@ static void dissect_gnutella_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
 			GNUTELLA_SERVENT_ID_LENGTH,
 			ENC_NA);
 
-		proto_tree_add_uint_format(gnutella_header_tree,
+		proto_tree_add_uint_format_value(gnutella_header_tree,
 			hf_gnutella_header_payload,
 			tvb,
 			GNUTELLA_HEADER_PAYLOAD_OFFSET,
 			GNUTELLA_BYTE_LENGTH,
 			payload_descriptor,
-			"Payload: %i (%s)",
+			"%i (%s)",
 			payload_descriptor,
 			payload_descriptor_text);
 
