@@ -2,7 +2,7 @@
  * Routines for RFC 1436 Gopher protocol dissection
  * Copyright 2010, Gerald Combs <gerald@wireshark.org>
  *
- * $Id$
+ * $Id: packet-gopher.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -147,7 +147,7 @@ dissect_gopher(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _
         if (line_len == 0) {
             request = "[Directory list]";
         } else if (line_len > 0) {
-            request = tvb_get_ephemeral_string(tvb, 0, line_len);
+            request = tvb_get_string(wmem_packet_scope(), tvb, 0, line_len);
         }
         col_add_fstr(pinfo->cinfo, COL_INFO, "Request: %s", request);
     } else {
@@ -172,7 +172,7 @@ dissect_gopher(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _
                     col_append_fstr(pinfo->cinfo, COL_INFO, ": [Directory list]");
                 }
 
-                name = tvb_get_ephemeral_string(tvb, offset + 1, sel_start - offset - 2);
+                name = tvb_get_string(wmem_packet_scope(), tvb, offset + 1, sel_start - offset - 2);
                 ti = proto_tree_add_string(gopher_tree, hf_gopher_dir_item, tvb,
                                 offset, line_len + 1, name);
                 dir_tree = proto_item_add_subtree(ti, ett_dir_item);
