@@ -2,7 +2,7 @@
  * Routines for the Generic Routing Encapsulation (GRE) protocol
  * Brad Robel-Forrest <brad.robel-forrest@watchguard.com>
  *
- * $Id$
+ * $Id: packet-gre.c 49584 2013-05-26 03:29:07Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -84,6 +84,7 @@ static int hf_gre_3ggp2_seg = -1;
 static int hf_gre_wccp_redirect_header = -1;
 static int hf_gre_wccp_dynamic_service = -1;
 static int hf_gre_wccp_alternative_bucket_used = -1;
+static int hf_gre_wccp_redirect_header_valid = -1;
 static int hf_gre_wccp_service_id = -1;
 static int hf_gre_wccp_alternative_bucket = -1;
 static int hf_gre_wccp_primary_bucket = -1;
@@ -95,6 +96,8 @@ static gint ett_gre_wccp2_redirect_header = -1;
 static gint ett_3gpp2_attribs = -1;
 static gint ett_3gpp2_attr = -1;
 
+static expert_field ei_gre_checksum_incorrect = EI_INIT;
+
 static dissector_table_t gre_dissector_table;
 static dissector_handle_t data_handle;
 
@@ -117,6 +120,7 @@ const value_string gre_version[] = {
     { 0, NULL}
 };
 const value_string gre_typevals[] = {
+    { GRE_KEEPALIVE,       "Possible GRE keepalive packet" },
     { ETHERTYPE_PPP,       "PPP" },
     { ETHERTYPE_IP,        "IP" },
     { SAP_OSINL5,          "OSI"},
@@ -207,6 +211,12 @@ static const true_false_string gre_wccp_alternative_bucket_used_val = {
     "Primary bucket used",
 };
 
+static const true_false_string gre_wccp_redirect_header_valid_val = {
+  "Header is present, but ignore contents",
+  "Header contents are valid",
+};
+
+
 static int
 dissect_gre_3gpp2_attribs(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
@@ -293,6 +303,8 @@ dissect_gre_wccp2_redirect_header(tvbuff_t *tvb, int offset, proto_tree *tree)
 
     proto_tree_add_item(rh_tree, hf_gre_wccp_alternative_bucket_used, tvb, offset, 1, ENC_BIG_ENDIAN);
 
+    proto_tree_add_item(rh_tree, hf_gre_wccp_redirect_header_valid, tvb, offset, 1, FALSE);
+
     proto_tree_add_item(rh_tree, hf_gre_wccp_service_id, tvb, offset +1, 1, ENC_BIG_ENDIAN);
 
     proto_tree_add_item(rh_tree, hf_gre_wccp_alternative_bucket, tvb, offset +2, 1, ENC_BIG_ENDIAN);
@@ -408,7 +420,7 @@ dissect_gre(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                     proto_item_append_text(it_checksum," [correct]");
                 } else {
                     proto_item_append_text(it_checksum," [incorrect, should be 0x%04x]",in_cksum_shouldbe(cksum, computed_cksum));
-                    expert_add_info_format(pinfo, it_checksum, PI_MALFORMED, PI_WARN, "Incorrect GRE Checksum");
+                    expert_add_info(pinfo, it_checksum, &ei_gre_checksum_incorrect);
                 }
             }
 
@@ -673,12 +685,17 @@ proto_register_gre(void)
         },
         { &hf_gre_wccp_dynamic_service,
           { "Dynamic Service", "gre.wccp.dynamic_service",
-            FT_BOOLEAN, 8, TFS(&gre_wccp_dynamic_service_val), 0x80,
+            FT_BOOLEAN, 8, TFS(&gre_wccp_dynamic_service_val), 0x01,
             NULL, HFILL }
         },
         { &hf_gre_wccp_alternative_bucket_used,
           { "Alternative bucket used", "gre.wccp.alternative_bucket_used",
-            FT_BOOLEAN, 8, TFS(&gre_wccp_alternative_bucket_used_val), 0x40,
+            FT_BOOLEAN, 8, TFS(&gre_wccp_alternative_bucket_used_val), 0x02,
+            NULL, HFILL }
+        },
+        { &hf_gre_wccp_redirect_header_valid,
+          { "WCCP Redirect header is valid", "gre.wccp.redirect_header_valid",
+            FT_BOOLEAN, 8, TFS(&gre_wccp_redirect_header_valid_val), 0x04,
             NULL, HFILL }
         },
         { &hf_gre_wccp_service_id,
@@ -706,10 +723,19 @@ proto_register_gre(void)
         &ett_3gpp2_attr,
     };
 
+
+    static ei_register_info ei[] = {
+        { &ei_gre_checksum_incorrect, { "gre.checksum.incorrect", PI_PROTOCOL, PI_WARN, "Incorrect GRE Checksum", EXPFILL }},
+    };
+
+    expert_module_t* expert_gre;
+
     proto_gre = proto_register_protocol("Generic Routing Encapsulation",
                                         "GRE", "gre");
     proto_register_field_array(proto_gre, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_gre = expert_register_protocol(proto_gre);
+    expert_register_field_array(expert_gre, ei, array_length(ei));
 
     /* subdissector code */
     gre_dissector_table = register_dissector_table("gre.proto",
