@@ -11,7 +11,7 @@
  *   support on mobile radio interface
  *   (3GPP TS 24.011 version 4.1.1 Release 4)
  *
- * $Id$
+ * $Id: packet-gsm_a_rp.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -89,7 +89,7 @@ static gint ett_rp_msg = -1;
 
 static char a_bigbuf[1024];
 
-static dissector_table_t sms_dissector_table;	/* SMS TPDU */
+static dissector_handle_t gsm_sms_handle;	/* SMS TPDU */
 
 static proto_tree *g_tree;
 
@@ -159,7 +159,7 @@ de_rp_user_data(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo, guint32 off
 	 */
 	tpdu_tvb = tvb_new_subset(tvb, curr_offset, len, len);
 
-	dissector_try_uint(sms_dissector_table, 0, tpdu_tvb, pinfo, g_tree);
+	call_dissector_only(gsm_sms_handle, tpdu_tvb, pinfo, g_tree, NULL);
 
 	curr_offset += len;
 
@@ -539,7 +539,7 @@ proto_register_gsm_a_rp(void)
 	gint *ett[NUM_INDIVIDUAL_ELEMS +
 		  NUM_GSM_RP_MSG +
 		  NUM_GSM_RP_ELEM];
-        
+
 	ett[0] = &ett_rp_msg;
 
 	last_offset = NUM_INDIVIDUAL_ELEMS;
@@ -563,10 +563,6 @@ proto_register_gsm_a_rp(void)
 
 	proto_register_field_array(proto_a_rp, hf, array_length(hf));
 
-	sms_dissector_table =
-		register_dissector_table("gsm_a.sms_tpdu", "GSM SMS TPDU",
-		FT_UINT8, BASE_DEC);
-
 	proto_register_subtree_array(ett, array_length(ett));
 
 	register_dissector("gsm_a_rp", dissect_rp, proto_a_rp);
@@ -580,5 +576,5 @@ proto_reg_handoff_gsm_a_rp(void)
 	gsm_a_rp_handle = create_dissector_handle(dissect_rp, proto_a_rp);
 	/* Dissect messages embedded in SIP */
 	dissector_add_string("media_type","application/vnd.3gpp.sms", gsm_a_rp_handle);
-
+	gsm_sms_handle = find_dissector("gsm_sms");
 }
