@@ -5,7 +5,7 @@
  *
  * 3GPP TS 49.031 version v7.4.0 (2009-09)
  *
- * $Id$
+ * $Id: packet-gsm_bssmap_le.c 52053 2013-09-15 10:29:49Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,7 +32,7 @@
 
 #include <epan/packet.h>
 #include <epan/tap.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 
 #include "packet-bssap.h"
 #include "packet-sccp.h"
@@ -948,7 +948,9 @@ dissect_bssmap_le(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	str = try_val_to_str_idx((guint32) oct, gsm_bssmap_le_msg_strings, &idx);
 
 	if (sccp_msg_p && !sccp_msg_p->data.co.label) {
-		sccp_msg_p->data.co.label = se_strdup(val_to_str((guint32) oct, gsm_bssmap_le_msg_strings, "BSSMAP LE(0x%02x)"));
+		sccp_msg_p->data.co.label = wmem_strdup(wmem_file_scope(),
+												val_to_str((guint32) oct,
+												gsm_bssmap_le_msg_strings, "BSSMAP LE(0x%02x)"));
 	}
 
 	/*
