@@ -3,7 +3,7 @@
  *
  * Copyright 2011, Mike Morrin <mike.morrin [AT] ipaccess.com>
  *
- * $Id$
+ * $Id: packet-gsm_cbch.c 52616 2013-10-15 13:05:31Z eapache $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -214,7 +214,13 @@ dissect_schedule_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *top_tree
                 else if ((octet1 & 0xC0) == 0)
                 {
                     /* MDT 00 */
-                    if (octet1 < new_slots[i])
+                    if (octet1 == 0)
+                    {
+                        proto_tree_add_text(sched_subtree, tvb, offset++, 1,
+                                            "Slot: %d, Repeat of non-existant slot %d",
+                                            new_slots[i], octet1);
+                    }
+                    else if (octet1 < new_slots[i])
                     {
                         proto_tree_add_text(sched_subtree, tvb, offset++, 1,
                                             "Slot: %d, Message ID: %d, Repeat of Slot %d",
@@ -254,7 +260,13 @@ dissect_schedule_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *top_tree
             sched_subtree = proto_item_add_subtree(item, ett_schedule_new_msg);
             for (k=0; offset < len; j++)
             {
-                while ((other_slots[k]!=0xFFFF) && (k<sched_end))
+                /* XXX I don't know if a message can validly contain more than
+                 * 48 slots, but that's the size of the array we create so cap
+                 * it there to avoid uninitialized memory errors (see bug
+                 * https://bugs.wireshark.org/bugzilla/show_bug.cgi?id=9270) */
+                if (sched_end > 48)
+                    sched_end = 48;
+                while ((k<sched_end) && (other_slots[k]!=0xFFFF))
                 {
                     k++;
                 }
@@ -331,7 +343,7 @@ dissect_schedule_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *top_tree
 static void
 dissect_cbch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-    fragment_data *frag_data = NULL;
+    fragment_head *frag_data = NULL;
     guint8         octet, lb, lpd, seq_num;
     guint32        offset;
     guint32        len;
