@@ -5,7 +5,7 @@
  * 	3GPP TS 31.102
  * Copyright 2010-2011 by Harald Welte <laforge@gnumonks.org>
  *
- * $Id$
+ * $Id: packet-gsm_sim.c 52279 2013-09-29 22:50:27Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -772,6 +772,9 @@ static const value_string mf_dfs[] = {
 	{ 0x7f20, "DF.GSM" },
 	{ 0x7f22, "DF.IS-41" },
 	{ 0x7f23, "DF.FP-CTS" },
+	{ 0x7f31, "DF.iDEN" },
+	{ 0x7f80, "DF.PDC" },
+	{ 0x7f90, "DF.TETRA" },
 	{ 0x7fff, "ADF" },
 #if 0
 	{ 0, NULL }
@@ -2791,6 +2794,7 @@ proto_register_gsm_sim(void)
 	register_dissector("gsm_sim", dissect_gsm_sim, proto_gsm_sim);
 	register_dissector("gsm_sim.command", dissect_gsm_sim_command, proto_gsm_sim);
 	register_dissector("gsm_sim.response", dissect_gsm_sim_response, proto_gsm_sim);
+	register_dissector("gsm_sim.bertlv", dissect_bertlv, proto_gsm_sim);
 }
 
 /* This function is called once at startup and every time the user hits
