@@ -2,7 +2,7 @@
  * Routines for H.223 packet dissection
  * Copyright (c) 2004-5 MX Telecom Ltd <richardv@mxtelecom.com>
  *
- * $Id$
+ * $Id: packet-h223.c 52045 2013-09-15 01:48:30Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,7 +26,7 @@
 #include "config.h"
 
 #include <glib.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/bitswap.h>
 #include <epan/circuit.h>
 #include <epan/conversation.h>
@@ -52,7 +52,6 @@
 
 /* Wireshark ID of the H.223 protocol */
 static int proto_h223 = -1;
-static int proto_h223_bitswapped = -1;
 
 /* The following hf_* variables are used to hold the Wireshark IDs of
  * our header fields; they are filled out when we call
@@ -210,7 +209,7 @@ circuit_chain_lookup(const h223_call_info* call_info, guint32 child_vc)
     key.vc = child_vc;
     circuit_id = GPOINTER_TO_UINT(g_hash_table_lookup( circuit_chain_hashtable, &key ));
     if( circuit_id == 0 ) {
-        new_key = se_new(circuit_chain_key);
+        new_key = wmem_new(wmem_file_scope(), circuit_chain_key);
         *new_key = key;
         circuit_id = ++circuit_chain_count;
         g_hash_table_insert(circuit_chain_hashtable, new_key, GUINT_TO_POINTER(circuit_id));
@@ -293,7 +292,7 @@ add_h223_mux_element(h223_call_direction_data *direct, guint8 mc, h223_mux_eleme
 
     DISSECTOR_ASSERT(mc < 16);
 
-    li = se_new(h223_mux_element_listitem);
+    li = wmem_new(wmem_file_scope(), h223_mux_element_listitem);
     old_li_ptr = &(direct->mux_table[mc]);
     old_li = *old_li_ptr;
     if( !old_li ) {
@@ -340,7 +339,7 @@ find_h223_mux_element(h223_call_direction_data* direct, guint8 mc, guint32 frame
 static void
 add_h223_lc_params(h223_vc_info* vc_info, int direction, h223_lc_params *lc_params, guint32 framenum )
 {
-    h223_lc_params_listitem *li = se_new(h223_lc_params_listitem);
+    h223_lc_params_listitem *li = wmem_new(wmem_file_scope(), h223_lc_params_listitem);
     h223_lc_params_listitem **old_li_ptr = &(vc_info->lc_params[direction ? 0 : 1]);
     h223_lc_params_listitem *old_li = *old_li_ptr;
     if( !old_li ) {
@@ -387,7 +386,7 @@ init_direction_data(h223_call_direction_data *direct)
         direct->mux_table[i] = NULL;
 
     /* set up MC 0 to contain just VC 0 */
-    mc0_element = se_new(h223_mux_element);
+    mc0_element = wmem_new(wmem_file_scope(), h223_mux_element);
     add_h223_mux_element( direct, 0, mc0_element, 0 );
     mc0_element->sublist = NULL;
     mc0_element->vc = 0;
@@ -398,7 +397,7 @@ init_direction_data(h223_call_direction_data *direct)
 static h223_vc_info*
 h223_vc_info_new( h223_call_info* call_info )
 {
-    h223_vc_info *vc_info = se_new(h223_vc_info);
+    h223_vc_info *vc_info = wmem_new(wmem_file_scope(), h223_vc_info);
     vc_info->lc_params[0] = vc_info->lc_params[1] = NULL;
     vc_info->call_info = call_info;
     return vc_info;
@@ -432,7 +431,7 @@ create_call_info( guint32 start_frame )
     h223_call_info *datax;
     h223_lc_params *vc0_params;
 
-    datax = se_new(h223_call_info);
+    datax = wmem_new(wmem_file_scope(), h223_call_info);
 
     /* initialise the call info */
     init_direction_data(&datax -> direction_data[0]);
@@ -441,7 +440,7 @@ create_call_info( guint32 start_frame )
     /* FIXME shouldn't this be figured out dynamically? */
     datax -> h223_level = 2;
 
-    vc0_params = se_new(h223_lc_params);
+    vc0_params = wmem_new(wmem_file_scope(), h223_lc_params);
     vc0_params->al_type = al1Framed;
     vc0_params->al_params = NULL;
     vc0_params->segmentable = TRUE;
@@ -698,11 +697,11 @@ dissect_mux_al_pdu( tvbuff_t *tvb, packet_info *pinfo, proto_tree *vc_tree,
             real_checksum = tvb_get_guint8(tvb, len - 1);
 
             if( calc_checksum == real_checksum ) {
-                proto_tree_add_uint_format(al_tree, hf_h223_al2_crc, tvb, len - 1, 1, real_checksum,
-                                           "CRC: 0x%02x (correct)", real_checksum );
+                proto_tree_add_uint_format_value(al_tree, hf_h223_al2_crc, tvb, len - 1, 1, real_checksum,
+                                           "0x%02x (correct)", real_checksum );
             } else {
-                proto_tree_add_uint_format(al_tree, hf_h223_al2_crc, tvb, len - 1, 1, real_checksum,
-                                           "CRC: 0x%02x (incorrect, should be 0x%02x)", real_checksum, calc_checksum );
+                proto_tree_add_uint_format_value(al_tree, hf_h223_al2_crc, tvb, len - 1, 1, real_checksum,
+                                           "0x%02x (incorrect, should be 0x%02x)", real_checksum, calc_checksum );
                 tmp_item = proto_tree_add_boolean( al_tree, hf_h223_al2_crc_bad, tvb, len - 1, 1, TRUE );
                 PROTO_ITEM_SET_GENERATED(tmp_item);
 
@@ -1032,18 +1031,18 @@ dissect_mux_pdu( tvbuff_t *tvb, packet_info *pinfo, guint32 pkt_offset,
 
             case 2:
                 if( errors == -1 ) {
-                    proto_tree_add_uint_format(hdr_tree, hf_h223_mux_rawhdr, tvb,
+                    proto_tree_add_uint_format_value(hdr_tree, hf_h223_mux_rawhdr, tvb,
                                                0, 3, raw_hdr,
-                                               "Raw value: 0x%06x (uncorrectable errors)", raw_hdr );
+                                               "0x%06x (uncorrectable errors)", raw_hdr );
                 } else {
                     if( errors == 0 ) {
-                        proto_tree_add_uint_format(hdr_tree, hf_h223_mux_rawhdr, tvb,
+                        proto_tree_add_uint_format_value(hdr_tree, hf_h223_mux_rawhdr, tvb,
                                                    0, 3, raw_hdr,
-                                                   "Raw value: 0x%06x (correct)", raw_hdr );
+                                                   "0x%06x (correct)", raw_hdr );
                     } else {
-                        proto_tree_add_uint_format(hdr_tree, hf_h223_mux_rawhdr, tvb,
+                        proto_tree_add_uint_format_value(hdr_tree, hf_h223_mux_rawhdr, tvb,
                                                    0, 3, raw_hdr,
-                                                   "Raw value: 0x%06x (errors are 0x%06x)", raw_hdr, errors );
+                                                   "0x%06x (errors are 0x%06x)", raw_hdr, errors );
                     }
                     item = proto_tree_add_uint(hdr_tree,hf_h223_mux_correctedhdr,tvb,0,3,
                                                correct_hdr);
@@ -1370,7 +1369,7 @@ dissect_h223_bitswapped (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     guint i;
 
     len = tvb_length(tvb);
-    datax = (guint8 *)g_malloc(len);
+    datax = (guint8 *)wmem_alloc(pinfo->pool, len);
     for( i=0; i<len; i++)
         datax[i]=BIT_SWAP(tvb_get_guint8(tvb,i));
 
@@ -1381,9 +1380,6 @@ dissect_h223_bitswapped (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
      */
     reversed_tvb = tvb_new_child_real_data(tvb, datax,len,tvb_reported_length(tvb));
 
-    /* Add a freer */
-    tvb_set_free_cb(reversed_tvb, g_free);
-
     /* Add the reversed data to the data source list. */
     add_new_data_source(pinfo, reversed_tvb, "Bit-swapped H.223 frame" );
 
@@ -1601,14 +1597,11 @@ void proto_register_h223 (void)
 
     proto_h223 =
         proto_register_protocol ("ITU-T Recommendation H.223", "H.223", "h223");
-    /* Create a H.223 "placeholder" to remove confusion with Decode As" */
-    proto_h223_bitswapped =
-        proto_register_protocol ("ITU-T Recommendation H.223 (Bitswapped)", "H.223 (Bitswapped)", "h223_bitswapped");
 
     proto_register_field_array (proto_h223, hf, array_length (hf));
     proto_register_subtree_array (ett, array_length (ett));
     register_dissector("h223", dissect_h223, proto_h223);
-    register_dissector("h223_bitswapped", dissect_h223_bitswapped, proto_h223_bitswapped);
+    register_dissector("h223_bitswapped", dissect_h223_bitswapped, proto_h223);
 
     /* register our init routine to be called at the start of a capture,
        to clear out our hash tables etc */
