@@ -2,7 +2,7 @@
  * Routines for HART-IP packet dissection
  * Copyright 2012, Bill Schiller <bill.schiller@emerson.com>
  *
- * $Id$
+ * $Id: packet-hartip.c 52053 2013-09-15 10:29:49Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -33,6 +33,7 @@
 #include <epan/stats_tree.h>
 #include <epan/expert.h>
 #include <epan/prefs.h>
+#include <epan/wmem/wmem.h>
 #include "packet-tcp.h"
 
 static dissector_handle_t hartip_tcp_handle;
@@ -68,6 +69,9 @@ static gint ett_hartip = -1;
 static gint ett_hartip_hdr = -1;
 static gint ett_hartip_body = -1;
 
+static expert_field ei_hartip_data_none = EI_INIT;
+static expert_field ei_hartip_data_unexpected = EI_INIT;
+
 /* Command 0 response */
 static int hf_hartip_pt_rsp_expansion_code = -1;
 static int hf_hartip_pt_rsp_expanded_device_type = -1;
@@ -308,9 +312,9 @@ dissect_empty_body(proto_tree *tree, packet_info* pinfo, tvbuff_t *tvb,
 
   ti = proto_tree_add_item(tree, hf_hartip_data, tvb, offset, bodylen, ENC_NA);
   if (bodylen == 0) {
-    expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_NOTE, "No data");
+    expert_add_info(pinfo, ti, &ei_hartip_data_none);
   } else {
-    expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN, "Unexpected message body");
+    expert_add_info(pinfo, ti, &ei_hartip_data_unexpected);
   }
   return bodylen;
 }
@@ -385,7 +389,7 @@ dissect_string(proto_tree *tree, int hf, const char *name, int len,
   proto_item *ti;
   char       *str;
 
-  str = (char *)ep_alloc(256);
+  str = (char *)wmem_alloc(wmem_packet_scope(), 256);
 
   ti = proto_tree_add_item(tree, hf, tvb, offset, len, ENC_NA);
   if (len < 256) {
@@ -411,12 +415,12 @@ dissect_packAscii(proto_tree *tree, int hf, const char *name, int len,
   guint8     *tmp;
   char       *str = NULL;
 
-  str = (char *)ep_alloc(256+1);
+  str = (char *)wmem_alloc(wmem_packet_scope(), 256+1);
 
   ti = proto_tree_add_item(tree, hf, tvb, offset, len, ENC_NA);
 
   DISSECTOR_ASSERT(len < 3 * (256/4));
-  tmp = (guint8 *)ep_alloc0(len);
+  tmp = (guint8 *)wmem_alloc0(wmem_packet_scope(), len);
   tvb_memcpy(tvb, tmp, offset, len);
 
   iIndex = 0;
@@ -494,7 +498,7 @@ dissect_cmd0(proto_tree *body_tree, tvbuff_t *tvb, gint offset, gint bodylen)
     offset += dissect_byte(body_tree,  hf_hartip_pt_rsp_extended_device_status,           tvb, offset);
     offset += dissect_short(body_tree, hf_hartip_pt_rsp_manufacturer_Identification_code, tvb, offset);
     offset += dissect_short(body_tree, hf_hartip_pt_rsp_private_label,                    tvb, offset);
-    offset += dissect_byte(body_tree,  hf_hartip_pt_rsp_device_profile,                   tvb, offset);
+    /*offset += */dissect_byte(body_tree,  hf_hartip_pt_rsp_device_profile,                   tvb, offset);
 
     return bodylen;
   }
@@ -507,7 +511,7 @@ dissect_cmd1(proto_tree *body_tree, tvbuff_t *tvb, gint offset, gint bodylen)
 {
   if (bodylen >= 5) {
     offset += dissect_byte(body_tree,  hf_hartip_pt_rsp_pv_units, tvb, offset);
-    offset += dissect_float(body_tree, hf_hartip_pt_rsp_pv,       tvb, offset);
+    /*offset += */dissect_float(body_tree, hf_hartip_pt_rsp_pv,       tvb, offset);
     return bodylen;
   }
 
@@ -519,7 +523,7 @@ dissect_cmd2(proto_tree *body_tree, tvbuff_t *tvb, gint offset, gint bodylen)
 {
   if (bodylen >= 8) {
     offset += dissect_float(body_tree, hf_hartip_pt_rsp_pv_loop_current,  tvb, offset);
-    offset += dissect_float(body_tree, hf_hartip_pt_rsp_pv_percent_range, tvb, offset);
+    /*offset += */dissect_float(body_tree, hf_hartip_pt_rsp_pv_percent_range, tvb, offset);
     return bodylen;
   }
 
@@ -538,7 +542,7 @@ dissect_cmd3(proto_tree *body_tree, tvbuff_t *tvb, gint offset, gint bodylen)
     offset += dissect_byte(body_tree,  hf_hartip_pt_rsp_tv_units,        tvb, offset);
     offset += dissect_float(body_tree, hf_hartip_pt_rsp_tv,              tvb, offset);
     offset += dissect_byte(body_tree,  hf_hartip_pt_rsp_qv_units,        tvb, offset);
-    offset += dissect_float(body_tree, hf_hartip_pt_rsp_qv,              tvb, offset);
+    /*offset += */dissect_float(body_tree, hf_hartip_pt_rsp_qv,              tvb, offset);
 
     return bodylen;
   }
@@ -629,7 +633,7 @@ dissect_cmd13(proto_tree *body_tree, tvbuff_t *tvb, gint offset, gint bodylen)
     offset += dissect_packAscii(body_tree, hf_hartip_pt_rsp_packed_descriptor, "descriptor", 12, tvb, offset);
     offset += dissect_byte(body_tree,      hf_hartip_pt_rsp_day,                                 tvb, offset);
     offset += dissect_byte(body_tree,      hf_hartip_pt_rsp_month,                               tvb, offset);
-    offset += dissect_byte(body_tree,      hf_hartip_pt_rsp_year,                                tvb, offset);
+    /*offset += */dissect_byte(body_tree,      hf_hartip_pt_rsp_year,                                tvb, offset);
 
     return bodylen;
   }
@@ -657,7 +661,7 @@ dissect_cmd48(proto_tree *body_tree, tvbuff_t *tvb, gint offset, gint bodylen)
 
     if (bodylen >= 24) {
       proto_tree_add_item(body_tree,    hf_hartip_pt_rsp_device_sp_status,         tvb, offset, 11, ENC_NA);
-      offset += 11;
+      /*offset += 11;*/
     }
     return bodylen;
   }
@@ -877,7 +881,7 @@ dissect_hartip_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
   offset++;
 
   /* Setup statistics for tap. */
-  tapinfo = ep_new(hartip_tap_info);
+  tapinfo = wmem_new(wmem_packet_scope(), hartip_tap_info);
   tapinfo->message_type = message_type;
   tapinfo->message_id   = message_id;
   tap_queue_packet(hartip_tap, pinfo, tapinfo);
@@ -1516,11 +1520,19 @@ proto_register_hartip(void)
     &ett_hartip_body
   };
 
+  static ei_register_info ei[] = {
+     { &ei_hartip_data_none, { "hart_ip.data.none", PI_PROTOCOL, PI_NOTE, "No data", EXPFILL }},
+     { &ei_hartip_data_unexpected, { "hart_ip.data.unexpected", PI_PROTOCOL, PI_WARN, "Unexpected message body", EXPFILL }},
+  };
+
   module_t *hartip_module;
+  expert_module_t* expert_hartip;
 
   proto_hartip = proto_register_protocol("HART_IP Protocol", "HART_IP", "hart_ip");
   proto_register_field_array(proto_hartip, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
+  expert_hartip = expert_register_protocol(proto_hartip);
+  expert_register_field_array(expert_hartip, ei, array_length(ei));
 
   hartip_module = prefs_register_protocol(proto_hartip, NULL);
   prefs_register_bool_preference(hartip_module, "desegment",
