@@ -2,7 +2,7 @@
  * Routines for hclnfsd (Hummingbird NFS Daemon) dissection
  * Copyright 2001, Mike Frisch <frisch@hummingbird.com>
  *
- * $Id$
+ * $Id: packet-hclnfsd.c 52002 2013-09-13 10:13:19Z jmayer $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -33,6 +33,8 @@
 #include "packet-nfs.h"
 #include "packet-hclnfsd.h"
 
+#include <epan/wmem/wmem.h>
+
 static int proto_hclnfsd = -1;
 static int hf_hclnfsd_procedure_v1 = -1;
 static int hf_hclnfsd_request_type = -1;
@@ -150,7 +152,7 @@ hclnfsd_decode_obscure(const char *ident, int ident_len)
 	char *ident_decoded, *ident_out;
 	int j, x, y;
 
-	ident_decoded = (char *)ep_alloc(ident_len);
+	ident_decoded = (char *)wmem_alloc(wmem_packet_scope(), ident_len);
 	ident_out = ident_decoded;
 	for (x = -1, j = 0; j < ident_len; j++)
 	{
