@@ -2,7 +2,7 @@
  * Routines for Honeypot Protocol Feeds packet disassembly
  * Copyright 2013, Sebastiano DI PAOLA - <sebastiano.dipaola@gmail.com>
  *
- * $Id$
+ * $Id: packet-hpfeeds.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -47,9 +47,9 @@ static int hf_hpfeeds_opcode = -1;
 static int hf_hpfeeds_msg_length = -1;
 static int hf_hpfeeds_nonce = -1;
 static int hf_hpfeeds_secret = -1;
-static int hf_hpfeeds_payload = -1; 
-static int hf_hpfeeds_server_len = -1; 
-static int hf_hpfeeds_server = -1; 
+static int hf_hpfeeds_payload = -1;
+static int hf_hpfeeds_server_len = -1;
+static int hf_hpfeeds_server = -1;
 static int hf_hpfeeds_ident_len = -1;
 static int hf_hpfeeds_ident = -1;
 static int hf_hpfeeds_channel = -1;
@@ -58,6 +58,8 @@ static int hf_hpfeeds_errmsg = -1;
 
 static gint ett_hpfeeds = -1;
 
+static expert_field ei_hpfeeds_opcode_unknown = EI_INIT;
+
 static dissector_handle_t json_hdl;
 
 /* OPCODE */
@@ -97,7 +99,7 @@ static const value_string opcode_vals[] = {
 };
 
 /*
-* 
+*
 * These values are the channel used by "most" spread and used honeypots
 * In case we have publish message in one of these channel we can decode
 * payload completely
@@ -121,7 +123,7 @@ static void
 dissect_hpfeeds_error_pdu(tvbuff_t *tvb, proto_tree *tree, guint offset)
 {
     proto_tree_add_item(tree, hf_hpfeeds_errmsg, tvb, offset, -1, ENC_BIG_ENDIAN);
-} 
+}
 
 static void
 dissect_hpfeeds_info_pdu(tvbuff_t *tvb, proto_tree *tree, guint offset)
@@ -133,9 +135,9 @@ dissect_hpfeeds_info_pdu(tvbuff_t *tvb, proto_tree *tree, guint offset)
 
     len = tvb_get_guint8(tvb, offset);
     /* don't move the offset yet as we need to get data after this operation */
-    strptr = tvb_get_ephemeral_string(tvb, offset + 1, len);
+    strptr = tvb_get_string(wmem_packet_scope(), tvb, offset + 1, len);
     ti = proto_tree_add_text(tree, tvb, offset, -1, "Broker: %s", strptr);
-    data_subtree = proto_item_add_subtree(ti, ett_hpfeeds); 
+    data_subtree = proto_item_add_subtree(ti, ett_hpfeeds);
 
     proto_tree_add_item(data_subtree, hf_hpfeeds_server_len, tvb, offset, 1,
         ENC_BIG_ENDIAN);
@@ -143,8 +145,8 @@ dissect_hpfeeds_info_pdu(tvbuff_t *tvb, proto_tree *tree, guint offset)
 
     proto_tree_add_item(data_subtree, hf_hpfeeds_server, tvb, offset, len,
         ENC_BIG_ENDIAN);
-    offset += len;   
- 
+    offset += len;
+
     proto_tree_add_item(data_subtree, hf_hpfeeds_nonce, tvb, offset, -1,
         ENC_BIG_ENDIAN);
 }
@@ -153,15 +155,15 @@ static void
 dissect_hpfeeds_auth_pdu(tvbuff_t *tvb, proto_tree *tree, guint offset)
 {
     guint8 len = 0;
-    
+
     len = tvb_get_guint8(tvb, offset);
-    proto_tree_add_item(tree, hf_hpfeeds_ident_len, tvb, 
+    proto_tree_add_item(tree, hf_hpfeeds_ident_len, tvb,
                     offset, 1, ENC_BIG_ENDIAN);
     offset += 1;
-    proto_tree_add_item(tree, hf_hpfeeds_ident, tvb, 
+    proto_tree_add_item(tree, hf_hpfeeds_ident, tvb,
                     offset, len, ENC_BIG_ENDIAN);
-    offset += len;   
- 
+    offset += len;
+
     proto_tree_add_item(tree, hf_hpfeeds_secret, tvb,
                     offset, -1, ENC_BIG_ENDIAN);
 }
@@ -173,7 +175,7 @@ dissect_hpfeeds_publish_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     guint8 len = 0;
     guint8 *strptr = NULL;
     gint8 channel = CH_EINVAL;
-    tvbuff_t *json_tvb = NULL;      
+    tvbuff_t *json_tvb = NULL;
 
     len = tvb_get_guint8(tvb, offset);
     proto_tree_add_item(tree, hf_hpfeeds_ident_len, tvb, offset, 1,
@@ -181,16 +183,16 @@ dissect_hpfeeds_publish_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     offset += 1;
     proto_tree_add_item(tree, hf_hpfeeds_ident, tvb, offset, len,
         ENC_BIG_ENDIAN);
-    offset += len;   
+    offset += len;
     len = tvb_get_guint8(tvb, offset);
     proto_tree_add_item(tree, hf_hpfeeds_chan_len, tvb, offset, 1,
         ENC_BIG_ENDIAN);
     offset += 1;
-   
-    /* get the channel name as ephemeral string just to make an attempt 
-    *  in order to decode more payload if channel is "well known" 
+
+    /* get the channel name as ephemeral string just to make an attempt
+    *  in order to decode more payload if channel is "well known"
     */
-    strptr = tvb_get_ephemeral_string(tvb, offset, len);
+    strptr = tvb_get_string(wmem_packet_scope(), tvb, offset, len);
     proto_tree_add_item(tree, hf_hpfeeds_channel, tvb, offset, len,
         ENC_BIG_ENDIAN);
     offset += len;
@@ -213,7 +215,7 @@ dissect_hpfeeds_publish_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
                 ENC_NA);
         break;
     }
-   
+
 
 }
 
@@ -221,7 +223,7 @@ static void
 dissect_hpfeeds_subscribe_pdu(tvbuff_t *tvb, proto_tree *tree, guint offset)
 {
     guint8 len = 0;
-    /* get length of ident field */    
+    /* get length of ident field */
     len = tvb_get_guint8(tvb, offset);
     proto_tree_add_item(tree, hf_hpfeeds_ident_len, tvb, offset, 1,
         ENC_BIG_ENDIAN);
@@ -255,7 +257,7 @@ dissect_hpfeeds_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     guint8 opcode;
     proto_item *ti;
     proto_tree *data_subtree;
-   
+
     /* Get opcode and write it */
     opcode = tvb_get_guint8(tvb, offset);
 
@@ -265,13 +267,13 @@ dissect_hpfeeds_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     col_add_fstr(pinfo->cinfo, COL_INFO, "Type %s",
         val_to_str(opcode, opcode_vals, "Unknown (0x%02x)"));
 
-    ti = proto_tree_add_item(tree, hf_hpfeeds_opcode, tvb, offset, 
+    ti = proto_tree_add_item(tree, hf_hpfeeds_opcode, tvb, offset,
             1, ENC_BIG_ENDIAN);
     data_subtree = proto_item_add_subtree(ti, ett_hpfeeds);
     offset += 1;
 
     if (opcode >= array_length(opcode_vals) - 1) {
-        expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN, 
+        expert_add_info_format(pinfo, ti, &ei_hpfeeds_opcode_unknown,
                 "Unknown value %02x for opcode field", opcode);
     }
 
@@ -298,7 +300,7 @@ dissect_hpfeeds_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     }
 }
 
-static void 
+static void
 dissect_hpfeeds(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     guint msglen = 0;
@@ -312,14 +314,14 @@ dissect_hpfeeds(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     /* get message length in order to decide if we need to reassemble packet */
     msglen = tvb_get_ntohl(tvb, offset);
-    
-    /* Retrieve header data */    
+
+    /* Retrieve header data */
     if (tree) {
         ti = proto_tree_add_item(tree, proto_hpfeeds, tvb, 0, -1, ENC_NA);
         hpfeeds_tree = proto_item_add_subtree(ti, ett_hpfeeds);
-        proto_tree_add_item(hpfeeds_tree, hf_hpfeeds_msg_length, tvb, offset, 
+        proto_tree_add_item(hpfeeds_tree, hf_hpfeeds_msg_length, tvb, offset,
             4, ENC_BIG_ENDIAN);
-    } 
+    }
 
     if (tvb_reported_length(tvb) < msglen) {
         /* we need to reassemble */
@@ -333,7 +335,7 @@ void
 proto_register_hpfeeds(void)
 {
     static hf_register_info hf[] = {
-        
+
         { &hf_hpfeeds_opcode,
             { "Opcode", "hpfeeds.opcode",
             FT_UINT8, BASE_DEC_HEX,
@@ -414,7 +416,12 @@ proto_register_hpfeeds(void)
         &ett_hpfeeds
     };
 
+    static ei_register_info ei[] = {
+        { &ei_hpfeeds_opcode_unknown, { "hpfeeds.opcode.unknown", PI_PROTOCOL, PI_WARN, "Unknown value for opcode field", EXPFILL }},
+    };
+
     module_t *hpfeeds_module;
+    expert_module_t* expert_hpfeeds;
 
     proto_hpfeeds = proto_register_protocol (
         "HPFEEDS HoneyPot Feeds Protocol", /* name */
@@ -424,6 +431,8 @@ proto_register_hpfeeds(void)
 
     proto_register_field_array(proto_hpfeeds, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_hpfeeds = expert_register_protocol(proto_hpfeeds);
+    expert_register_field_array(expert_hpfeeds, ei, array_length(ei));
 
     hpfeeds_module = prefs_register_protocol(proto_hpfeeds, proto_reg_handoff_hpfeeds);
     prefs_register_bool_preference(hpfeeds_module, "desegment_hpfeeds_messages",
@@ -433,7 +442,7 @@ proto_register_hpfeeds(void)
         "To use this option, you must also enable \"Allow subdissectors to "
         "reassemble TCP streams\" in the TCP protocol settings.",
         &hpfeeds_desegment);
-    
+
     prefs_register_uint_preference(hpfeeds_module,
         "dissector_port",
         "Dissector TCP port",
@@ -447,7 +456,7 @@ proto_reg_handoff_hpfeeds(void)
     static dissector_handle_t hpfeeds_handle;
     static gboolean hpfeeds_prefs_initialized = FALSE;
     static gint16 hpfeeds_dissector_port;
-    
+
     if (!hpfeeds_prefs_initialized) {
         hpfeeds_handle = create_dissector_handle(dissect_hpfeeds, proto_hpfeeds);
         hpfeeds_prefs_initialized = TRUE;
@@ -459,7 +468,7 @@ proto_reg_handoff_hpfeeds(void)
     hpfeeds_dissector_port = hpfeeds_port_pref;
 
     dissector_add_uint("tcp.port", hpfeeds_dissector_port,  hpfeeds_handle);
-        
+
     json_hdl = find_dissector("json");
 }
 
