@@ -9,7 +9,7 @@
  * Copyright 2002, Tim Potter <tpot@samba.org>
  * Copyright 1999, Andrew Tridgell <tridge@samba.org>
  *
- * $Id$
+ * $Id: packet-http.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,6 +34,7 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
 #include <errno.h>
 
 #include <glib.h>
@@ -41,7 +42,6 @@
 #include <epan/packet.h>
 #include <epan/strutil.h>
 #include <epan/base64.h>
-#include <epan/emem.h>
 #include <epan/stats_tree.h>
 
 #include <epan/req_resp_hdrs.h>
@@ -126,10 +126,16 @@ static gint ett_http_chunk_data = -1;
 static gint ett_http_encoded_entity = -1;
 static gint ett_http_header_item = -1;
 
+static expert_field ei_http_chat = EI_INIT;
+static expert_field ei_http_chunked_and_length = EI_INIT;
+static expert_field ei_http_subdissector_failed = EI_INIT;
+
+static dissector_handle_t http_handle;
+
 static dissector_handle_t data_handle;
 static dissector_handle_t media_handle;
 static dissector_handle_t websocket_handle;
-static dissector_handle_t http_handle;
+static dissector_handle_t http2_handle;
 
 /* Stuff for generation/handling of fields for custom HTTP headers */
 typedef struct _header_field_t {
@@ -149,13 +155,13 @@ header_fields_update_cb(void *r, const char **err)
 	char c;
 
 	if (rec->header_name == NULL) {
-		*err = ep_strdup_printf("Header name can't be empty");
+		*err = wmem_strdup_printf(wmem_packet_scope(), "Header name can't be empty");
 		return;
 	}
 
 	g_strstrip(rec->header_name);
 	if (rec->header_name[0] == 0) {
-		*err = ep_strdup_printf("Header name can't be empty");
+		*err = wmem_strdup_printf(wmem_packet_scope(), "Header name can't be empty");
 		return;
 	}
 
@@ -164,7 +170,7 @@ header_fields_update_cb(void *r, const char **err)
 	 */
 	c = proto_check_field_name(rec->header_name);
 	if (c) {
-		*err = ep_strdup_printf("Header name can't contain '%c'", c);
+		*err = wmem_strdup_printf(wmem_packet_scope(), "Header name can't contain '%c'", c);
 		return;
 	}
 
@@ -249,6 +255,7 @@ static gboolean http_decompress_body = FALSE;
 #define SSL_DEFAULT_RANGE "443"
 
 #define UPGRADE_WEBSOCKET 1
+#define UPGRADE_HTTP2 2
 
 static range_t *global_http_tcp_range = NULL;
 static range_t *global_http_ssl_range = NULL;
@@ -707,7 +714,7 @@ dissect_http_message(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	first_linelen = tvb_find_line_end(tvb, offset,
 	    tvb_ensure_length_remaining(tvb, offset), &next_offset,
 	    TRUE);
-	
+
 	if (first_linelen == -1) {
 		/* No complete line was found in this segment, do
 		 * desegmentation if we're told to.
@@ -744,7 +751,7 @@ dissect_http_message(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		}
 	}
 
-	stat_info = ep_new(http_info_value_t);
+	stat_info = wmem_new(wmem_packet_scope(), http_info_value_t);
 	stat_info->framenum = pinfo->fd->num;
 	stat_info->response_code = 0;
 	stat_info->request_method = NULL;
@@ -762,26 +769,23 @@ dissect_http_message(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		break;
 	}
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, proto_tag);
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		/*
-		 * Put the first line from the buffer into the summary
-		 * if it's an HTTP request or reply (but leave out the
-		 * line terminator).
-		 * Otherwise, just call it a continuation.
-		 *
-		 * Note that "tvb_find_line_end()" will return a value that
-		 * is not longer than what's in the buffer, so the
-		 * "tvb_get_ptr()" call won't throw an exception.
-		 */
-		if (is_request_or_reply) {
-		    line = tvb_get_ptr(tvb, offset, first_linelen);
-			col_add_fstr(pinfo->cinfo, COL_INFO, "%s ", format_text(line, first_linelen));
-		}
-		else
-			col_set_str(pinfo->cinfo, COL_INFO, "Continuation or non-HTTP traffic");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, proto_tag);
+	/*
+	 * Put the first line from the buffer into the summary
+	 * if it's an HTTP request or reply (but leave out the
+	 * line terminator).
+	 * Otherwise, just call it a continuation.
+	 *
+	 * Note that "tvb_find_line_end()" will return a value that
+	 * is not longer than what's in the buffer, so the
+	 * "tvb_get_ptr()" call won't throw an exception.
+	 */
+	if (is_request_or_reply) {
+	    line = tvb_get_ptr(tvb, offset, first_linelen);
+		col_add_fstr(pinfo->cinfo, COL_INFO, "%s ", format_text(line, first_linelen));
 	}
+	else
+		col_set_str(pinfo->cinfo, COL_INFO, "Continuation or non-HTTP traffic");
 
 	orig_offset = offset;
 	if (tree) {
@@ -802,7 +806,7 @@ dissect_http_message(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	headers.transfer_encoding = NULL; /* transfer encoding not known yet */
 	headers.upgrade = 0; /* assume we're not upgrading */
 	saw_req_resp_or_header = FALSE;	/* haven't seen anything yet */
-	while (tvb_reported_length_remaining(tvb, offset) != 0) {
+	while (tvb_reported_length_remaining(tvb, offset) > 0) {
 		/*
 		 * Find the end of the line.
 		 * XXX - what if we don't find it because the packet
@@ -849,15 +853,20 @@ dissect_http_message(tvbuff_t *tvb, int offset, packet_info *pinfo,
 			c = *linep++;
 
 			/*
-			 * This must be a CHAR, and must not be a CTL,
-			 * to be part of a token; that means it must be
-			 * printable ASCII.
+			 * This must be a CHAR to be part of a token; that
+			 * means it must be ASCII.
+			 */
+			if (!isascii(c))
+				break;	/* not ASCII, thus not a CHAR */
+
+			/*
+			 * This mustn't be a CTL to be part of a token.
 			 *
 			 * XXX - what about leading LWS on continuation
 			 * lines of a header?
 			 */
-			if (!g_ascii_isprint(c))
-				break;
+			if (iscntrl(c))
+				break;	/* CTL, not part of a header */
 
 			/*
 			 * This mustn't be a SEP to be part of a token;
@@ -969,7 +978,7 @@ dissect_http_message(tvbuff_t *tvb, int offset, packet_info *pinfo,
 				hdr_item = proto_tree_add_text(http_tree, tvb,
 				    offset, next_offset - offset, "%s", text);
 			}
-			expert_add_info_format(pinfo, hdr_item, PI_SEQUENCE, PI_CHAT, "%s", text);
+			expert_add_info_format(pinfo, hdr_item, &ei_http_chat, "%s", text);
 			if (reqresp_dissector) {
 				if (tree) req_tree = proto_item_add_subtree(hdr_item, ett_http_request);
 				else req_tree = NULL;
@@ -990,9 +999,9 @@ dissect_http_message(tvbuff_t *tvb, int offset, packet_info *pinfo,
 
 	if (tree && stat_info->http_host && stat_info->request_uri) {
 		proto_item *e_ti;
-		gchar *uri = ep_strdup_printf("%s://%s%s",
+		gchar *uri = wmem_strdup_printf(wmem_packet_scope(), "%s://%s%s",
 			   "http",	/* XXX, https? */
-			    g_strstrip(ep_strdup(stat_info->http_host)), stat_info->request_uri);
+			    g_strstrip(wmem_strdup(wmem_packet_scope(), stat_info->http_host)), stat_info->request_uri);
 
 		e_ti = proto_tree_add_string(http_tree,
 					     hf_http_request_full_uri, tvb, 0,
@@ -1093,7 +1102,7 @@ dissect_http_message(tvbuff_t *tvb, int offset, packet_info *pinfo,
 			break;
 		}
 	}
-	
+
 	reported_datalen = tvb_reported_length_remaining(tvb, offset);
 	datalen = tvb_length_remaining(tvb, offset);
 
@@ -1338,7 +1347,7 @@ dissect_http_message(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		 * an active listener to process it (which happens when
 		 * the export object window is open). */
 		if(have_tap_listener(http_eo_tap)) {
-			eo_info = ep_new(http_eo_t);
+			eo_info = wmem_new(wmem_packet_scope(), http_eo_t);
 
 			eo_info->hostname = conv_data->http_host;
 			eo_info->filename = conv_data->request_uri;
@@ -1367,7 +1376,7 @@ dissect_http_message(tvbuff_t *tvb, int offset, packet_info *pinfo,
 			private_data_changed = TRUE;
 
 			if (headers.content_type_parameters)
-				pinfo->private_data = ep_strdup(headers.content_type_parameters);
+				pinfo->private_data = wmem_strdup(wmem_packet_scope(), headers.content_type_parameters);
 			else
 				pinfo->private_data = NULL;
 			/*
@@ -1406,8 +1415,7 @@ dissect_http_message(tvbuff_t *tvb, int offset, packet_info *pinfo,
 			 */
 			dissected = call_dissector_only(handle, next_tvb, pinfo, tree, NULL);
 			if (!dissected)
-				expert_add_info_format(pinfo, http_tree, PI_MALFORMED, PI_NOTE,
-						       "HTTP body subdissector failed, trying heuristic subdissector");
+				expert_add_info(pinfo, http_tree, &ei_http_subdissector_failed);
 		}
 
 		if (!dissected) {
@@ -1496,9 +1504,9 @@ basic_request_dissector(tvbuff_t *tvb, proto_tree *tree, int offset,
 	tokenlen = get_token_len(line, lineend, &next_token);
 
 	/* Save the request URI for various later uses */
-	request_uri = tvb_get_ephemeral_string(tvb, offset, tokenlen);
-	stat_info->request_uri = ep_strdup(request_uri);
- 	conv_data->request_uri = se_strdup(request_uri);
+	request_uri = tvb_get_string(wmem_packet_scope(), tvb, offset, tokenlen);
+	stat_info->request_uri = wmem_strdup(wmem_packet_scope(), request_uri);
+ 	conv_data->request_uri = wmem_strdup(wmem_file_scope(), request_uri);
 
 	proto_tree_add_string(tree, hf_http_request_uri, tvb, offset, tokenlen,
 			      request_uri);
@@ -1601,7 +1609,7 @@ chunked_encoding_dissector(tvbuff_t **tvb_ptr, packet_info *pinfo,
 	}
 
 
-	while (datalen != 0) {
+	while (datalen > 0) {
 		proto_item *chunk_ti = NULL;
 		proto_tree *chunk_subtree = NULL;
 		tvbuff_t *data_tvb = NULL; /*  */
@@ -1616,7 +1624,7 @@ chunked_encoding_dissector(tvbuff_t **tvb_ptr, packet_info *pinfo,
 			break;
 		}
 
-		chunk_string = tvb_get_ephemeral_string(tvb, offset, linelen);
+		chunk_string = tvb_get_string(wmem_packet_scope(), tvb, offset, linelen);
 
 		if (chunk_string == NULL) {
 			/* Can't get the chunk size line */
@@ -1788,12 +1796,12 @@ chunked_encoding_dissector(tvbuff_t **tvb_ptr, packet_info *pinfo,
 
         /* Dechunk the "chunked response" to a new memory buffer */
 	orig_datalen      = datalen;
-	raw_data	      = (guint8 *)g_malloc(datalen);
+	raw_data	      = (guint8 *)wmem_alloc(pinfo->pool, datalen);
 	raw_len		      = 0;
 	chunks_decoded	  = 0;
 	chunked_data_size = 0;
 
-	while (datalen != 0) {
+	while (datalen > 0) {
 		tvbuff_t *data_tvb;
 		guint32	  chunk_size;
 		gint	  chunk_offset;
@@ -1808,7 +1816,7 @@ chunked_encoding_dissector(tvbuff_t **tvb_ptr, packet_info *pinfo,
 			break;
 		}
 
-		chunk_string = tvb_get_ephemeral_string(tvb, offset, linelen);
+		chunk_string = tvb_get_string(wmem_packet_scope(), tvb, offset, linelen);
 
 		if (chunk_string == NULL) {
 			/* Can't get the chunk size line */
@@ -1888,14 +1896,12 @@ chunked_encoding_dissector(tvbuff_t **tvb_ptr, packet_info *pinfo,
 	if (chunked_data_size > 0) {
 		tvbuff_t *new_tvb;
 		new_tvb = tvb_new_child_real_data(tvb, raw_data, chunked_data_size, chunked_data_size);
-		tvb_set_free_cb(new_tvb, g_free);
 		*tvb_ptr = new_tvb;
 	} else {
 		/*
 		 * There was no actual chunk data, so don't allow sub dissectors
 		 * try to decode the non-existent entity body.
 		 */
-		g_free(raw_data);
 		chunks_decoded = -1;
 	}
 
@@ -2162,8 +2168,8 @@ is_http_request_or_reply(const gchar *data, int linelen, http_type_t *type,
 		if (isHttpRequestOrReply && reqresp_dissector) {
 			*reqresp_dissector = basic_request_dissector;
 
-			stat_info->request_method = ep_strndup(data, indx+1);
-			conv_data->request_method = se_strndup(data, indx+1);
+			stat_info->request_method = wmem_strndup(wmem_packet_scope(), data, indx+1);
+			conv_data->request_method = wmem_strndup(wmem_file_scope(), data, indx+1);
 		}
 
 
@@ -2257,10 +2263,14 @@ header_fields_initialize_cb(void)
 		/* Unregister all fields */
 		for (i = 0; i < hf_size; i++) {
 			proto_unregister_field (proto_http, *(hf[i].p_id));
+
 			g_free (hf[i].p_id);
+			g_free ((char *) hf[i].hfinfo.name);
+			g_free ((char *) hf[i].hfinfo.abbrev);
+			g_free ((char *) hf[i].hfinfo.blurb);
 		}
 		g_hash_table_destroy (header_fields_hash);
-		proto_add_deregistered_data (hf);
+		g_free (hf);
 		header_fields_hash = NULL;
 	}
 
@@ -2280,7 +2290,7 @@ header_fields_initialize_cb(void)
 			hf[i].hfinfo.display = BASE_NONE;
 			hf[i].hfinfo.strings = NULL;
 			hf[i].hfinfo.blurb = g_strdup(header_fields[i].header_desc);
-			hf[i].hfinfo.same_name_prev = NULL;
+			hf[i].hfinfo.same_name_prev_id = -1;
 			hf[i].hfinfo.same_name_next = NULL;
 
 			g_hash_table_insert(header_fields_hash, header_name, hf_id);
@@ -2314,7 +2324,7 @@ process_header(tvbuff_t *tvb, int offset, int next_offset,
 	len = next_offset - offset;
 	line_end_offset = offset + linelen;
 	header_len = colon_offset - offset;
-	header_name = se_strndup(&line[0], header_len);
+	header_name = wmem_strndup(wmem_file_scope(), &line[0], header_len);
 	hf_index = find_header_hf_value(tvb, offset, header_len);
 
 	/*
@@ -2337,7 +2347,7 @@ process_header(tvbuff_t *tvb, int offset, int next_offset,
 	 * has value_len bytes in it.
 	 */
 	value_len = line_end_offset - value_offset;
-	value = (char *)ep_alloc(value_len+1);
+	value = (char *)wmem_alloc(wmem_packet_scope(), value_len+1);
 	memcpy(value, &line[value_offset - offset], value_len);
 	value[value_len] = '\0';
 
@@ -2409,7 +2419,7 @@ process_header(tvbuff_t *tvb, int offset, int next_offset,
 			break;
 
 		case HDR_CONTENT_TYPE:
-			eh_ptr->content_type = (gchar*) ep_memdup((guint8*)value,value_len + 1);
+			eh_ptr->content_type = (gchar*) wmem_memdup(wmem_packet_scope(), (guint8*)value,value_len + 1);
 
 			for (i = 0; i < value_len; i++) {
 				c = value[i];
@@ -2457,7 +2467,7 @@ process_header(tvbuff_t *tvb, int offset, int next_offset,
 			if (eh_ptr->content_length < 0 ||
 			    p == value ||
 			    errno == ERANGE ||
-			    (*up != '\0' && !g_ascii_isspace(*up))) {
+			    (*up != '\0' && !isspace(*up))) {
 				/*
 				 * Content length not valid; pretend
 				 * we don't have it.
@@ -2474,25 +2484,38 @@ process_header(tvbuff_t *tvb, int offset, int next_offset,
 				tree_item = proto_tree_add_uint64(header_tree, hf_http_content_length,
 					tvb, offset, len, eh_ptr->content_length);
 				PROTO_ITEM_SET_GENERATED(tree_item);
+				if (eh_ptr->transfer_encoding != NULL &&
+						g_ascii_strncasecmp(eh_ptr->transfer_encoding, "chunked", 7) == 0) {
+					expert_add_info(pinfo, hdr_item, &ei_http_chunked_and_length);
+				}
 			}
 			break;
 
 		case HDR_CONTENT_ENCODING:
-			eh_ptr->content_encoding = ep_strndup(value, value_len);
+			eh_ptr->content_encoding = wmem_strndup(wmem_packet_scope(), value, value_len);
 			break;
 
 		case HDR_TRANSFER_ENCODING:
-			eh_ptr->transfer_encoding = ep_strndup(value, value_len);
+			eh_ptr->transfer_encoding = wmem_strndup(wmem_packet_scope(), value, value_len);
+			if (eh_ptr->have_content_length &&
+					g_ascii_strncasecmp(eh_ptr->transfer_encoding, "chunked", 7) == 0) {
+				expert_add_info(pinfo, hdr_item, &ei_http_chunked_and_length);
+			}
 			break;
 
 		case HDR_HOST:
-			stat_info->http_host = ep_strndup(value, value_len);
-			conv_data->http_host = se_strndup(value, value_len);
+			stat_info->http_host = wmem_strndup(wmem_packet_scope(), value, value_len);
+			conv_data->http_host = wmem_strndup(wmem_file_scope(), value, value_len);
 			break;
 
 		case HDR_UPGRADE:
-			if (g_ascii_strncasecmp(value, "WebSocket", value_len) == 0)
+			if (g_ascii_strncasecmp(value, "WebSocket", value_len) == 0){
 				eh_ptr->upgrade = UPGRADE_WEBSOCKET;
+			}
+			/* Check if upgrade is HTTP 2.0 (work for HTTP/2.0 and draft HTTP-draft-XX/2.0) */
+			if ( (g_str_has_prefix(value, "HTTP") && g_str_has_suffix(value, "/2.0")) == 1){
+				eh_ptr->upgrade = UPGRADE_HTTP2;
+			}
 			break;
 		}
 	}
@@ -2623,11 +2646,17 @@ dissect_http(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			conv_data->startframe = pinfo->fd->num;
 		http_payload_subdissector(tvb, tree, pinfo, conv_data);
 	} else {
-		while (tvb_reported_length_remaining(tvb, offset) != 0) {
+		while (tvb_reported_length_remaining(tvb, offset) > 0) {
 			if (conv_data->upgrade == UPGRADE_WEBSOCKET && pinfo->fd->num >= conv_data->startframe) {
+				/*g_warning("Go Websocket");*/
 				call_dissector_only(websocket_handle, tvb_new_subset_remaining(tvb, offset), pinfo, tree, NULL);
 				break;
 			}
+			if (conv_data->upgrade == UPGRADE_HTTP2 && pinfo->fd->num >= conv_data->startframe) {
+				/*g_warning("Go HTTP2");*/
+				call_dissector_only(http2_handle, tvb_new_subset_remaining(tvb, offset), pinfo, tree, NULL);
+				break;
+			}
 			len = dissect_http_message(tvb, offset, pinfo, tree, conv_data);
 			if (len == -1)
 				break;
@@ -2638,8 +2667,7 @@ dissect_http(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			 * first HTTP message; set a fence so that subsequent
 			 * HTTP messages don't overwrite the Info column.
 			 */
-			if (check_col(pinfo->cinfo, COL_INFO))
-				col_set_fence(pinfo->cinfo, COL_INFO);
+			col_set_fence(pinfo->cinfo, COL_INFO);
 		}
 	}
 }
@@ -2682,15 +2710,6 @@ dissect_http_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	dissect_http_message(tvb, 0, pinfo, tree, conv_data);
 }
 
-static void
-range_delete_http_tcp_callback(guint32 port) {
-	dissector_delete_uint("tcp.port", port, http_handle);
-}
-
-static void
-range_add_http_tcp_callback(guint32 port) {
-	dissector_add_uint("tcp.port", port, http_handle);
-}
 
 static void
 range_delete_http_ssl_callback(guint32 port) {
@@ -2703,10 +2722,10 @@ range_add_http_ssl_callback(guint32 port) {
 }
 
 static void reinit_http(void) {
-	range_foreach(http_tcp_range, range_delete_http_tcp_callback);
+	dissector_delete_uint_range("tcp.port", http_tcp_range, http_handle);
 	g_free(http_tcp_range);
 	http_tcp_range = range_copy(global_http_tcp_range);
-	range_foreach(http_tcp_range, range_add_http_tcp_callback);
+	dissector_add_uint_range("tcp.port", http_tcp_range, http_handle);
 
 	range_foreach(http_ssl_range, range_delete_http_ssl_callback);
 	g_free(http_ssl_range);
@@ -2924,6 +2943,13 @@ proto_register_http(void)
 		&ett_http_encoded_entity,
 		&ett_http_header_item
 	};
+
+	static ei_register_info ei[] = {
+		{ &ei_http_chat, { "http.chat", PI_SEQUENCE, PI_CHAT, "Formatted text", EXPFILL }},
+		{ &ei_http_chunked_and_length, { "http.chunkd_and_length", PI_MALFORMED, PI_WARN, "It is incorrect to specify a content-length header and chunked encoding together.", EXPFILL }},
+		{ &ei_http_subdissector_failed, { "http.subdissector_failed", PI_MALFORMED, PI_NOTE, "HTTP body subdissector failed, trying heuristic subdissector", EXPFILL }},
+	};
+
 	/* UAT for header fields */
 	static uat_field_t custom_header_uat_fields[] = {
 		UAT_FLD_CSTRING(header_fields, header_name, "Header name", "HTTP header name"),
@@ -2932,13 +2958,18 @@ proto_register_http(void)
 	};
 
 	module_t *http_module;
+	expert_module_t* expert_http;
 	uat_t* headers_uat;
 
 	proto_http = proto_register_protocol("Hypertext Transfer Protocol",
 	    "HTTP", "http");
 	proto_register_field_array(proto_http, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
-	register_dissector("http", dissect_http, proto_http);
+	expert_http = expert_register_protocol(proto_http);
+	expert_register_field_array(expert_http, ei, array_length(ei));
+
+	http_handle = register_dissector("http", dissect_http, proto_http);
+
 	http_module = prefs_register_protocol(proto_http, reinit_http);
 	prefs_register_bool_preference(http_module, "desegment_headers",
 	    "Reassemble HTTP headers spanning multiple TCP segments",
@@ -3003,8 +3034,6 @@ proto_register_http(void)
 	    "A table to define custom HTTP header for which fields can be setup and used for filtering/data extraction etc.",
 	   headers_uat);
 
-	http_handle = create_dissector_handle(dissect_http, proto_http);
-
 	/*
 	 * Dissectors shouldn't register themselves in this table;
 	 * instead, they should call "http_dissector_add()", and
@@ -3077,6 +3106,7 @@ proto_reg_handoff_http(void)
 	data_handle = find_dissector("data");
 	media_handle = find_dissector("media");
 	websocket_handle = find_dissector("websocket");
+	http2_handle = find_dissector("http2");
 	/*
 	 * XXX - is there anything to dissect in the body of an SSDP
 	 * request or reply?  I.e., should there be an SSDP dissector?
@@ -3113,7 +3143,7 @@ dissect_message_http(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		ti = proto_tree_add_item(tree, proto_message_http,
 				tvb, 0, -1, ENC_NA);
 		subtree = proto_item_add_subtree(ti, ett_message_http);
-		while (tvb_reported_length_remaining(tvb, offset) != 0) {
+		while (tvb_reported_length_remaining(tvb, offset) > 0) {
 			len = tvb_find_line_end(tvb, offset,
 					tvb_ensure_length_remaining(tvb, offset),
 					&next_offset, FALSE);
@@ -3166,6 +3196,6 @@ proto_reg_handoff_message_http(void)
  * indent-tabs-mode: true
  * End:
  *
- * vi: set shiftwidth=8 tabstop=8:
- * :indentSize=8:tabSize=8:
+ * vi: set shiftwidth=8 tabstop=8 noexpandtab:
+ * :indentSize=8:tabSize=8:noTabs=false:
  */
