@@ -3,7 +3,7 @@
  *
  * Pigeon Point Systems <www.pigeonpoint.com>
  *
- * $Id$
+ * $Id: packet-i2c.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -203,52 +203,44 @@ dissect_i2c(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	pinfo->ptype = PT_I2C;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-		if (is_event)
-			col_set_str(pinfo->cinfo, COL_PROTOCOL, "I2C Event");
-		else
-			col_add_fstr(pinfo->cinfo, COL_PROTOCOL, "I2C %s",
-					(flags & I2C_FLAG_RD) ? "Read" : "Write");
-	}
+	if (is_event)
+		col_set_str(pinfo->cinfo, COL_PROTOCOL, "I2C Event");
+	else
+		col_add_fstr(pinfo->cinfo, COL_PROTOCOL, "I2C %s",
+				(flags & I2C_FLAG_RD) ? "Read" : "Write");
 
-	if (check_col(pinfo->cinfo, COL_DEF_SRC)) {
-		col_add_fstr(pinfo->cinfo, COL_DEF_SRC, "I2C-%d", bus);
-	}
+	col_add_fstr(pinfo->cinfo, COL_DEF_SRC, "I2C-%d", bus);
 
-	if (check_col(pinfo->cinfo, COL_DEF_DST)) {
-		if (is_event)
-			col_add_fstr(pinfo->cinfo, COL_DEF_DST, "----");
-		else
-			col_add_fstr(pinfo->cinfo, COL_DEF_DST, "0x%02x", addr);
-	}
+	if (is_event)
+		col_add_fstr(pinfo->cinfo, COL_DEF_DST, "----");
+	else
+		col_add_fstr(pinfo->cinfo, COL_DEF_DST, "0x%02x", addr);
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		if (is_event)
-			col_add_fstr(pinfo->cinfo, COL_INFO, "%s",
-					i2c_get_event_desc(flags));
-		else
-			col_add_fstr(pinfo->cinfo, COL_INFO, "I2C %s, %d bytes",
+	if (is_event)
+		col_add_fstr(pinfo->cinfo, COL_INFO, "%s",
+				i2c_get_event_desc(flags));
+	else
+		col_add_fstr(pinfo->cinfo, COL_INFO, "I2C %s, %d bytes",
 					(flags & I2C_FLAG_RD) ? "Read" : "Write", len);
-	}
 
 	if (tree) {
 		ti = proto_tree_add_protocol_format(tree, proto_i2c, tvb, 0, -1,
 					"Inter-Integrated Circuit (%s)",
 					is_event ? "Event" : "Data");
-		
+
 		i2c_tree = proto_item_add_subtree(ti, ett_i2c);
 		proto_tree_add_uint_format(i2c_tree, hf_i2c_bus, tvb, 0, 0, bus,
 				"Bus: I2C-%d", bus);
 
 		if (is_event) {
-			proto_tree_add_uint_format(i2c_tree, hf_i2c_event, tvb, 0, 0,
-					flags, "Event: %s (0x%08x)",
+			proto_tree_add_uint_format_value(i2c_tree, hf_i2c_event, tvb, 0, 0,
+					flags, "%s (0x%08x)",
 					i2c_get_event_desc(flags), flags);
 		} else {
 			proto_tree_add_uint_format_value(i2c_tree, hf_i2c_addr, tvb, 0, 1,
 					addr, "0x%02x%s", addr, addr ? "" : " (General Call)");
-			proto_tree_add_uint_format(i2c_tree, hf_i2c_flags, tvb, 0, 0,
-					flags, "Flags: 0x%08x", flags);
+			proto_tree_add_uint_format_value(i2c_tree, hf_i2c_flags, tvb, 0, 0,
+					flags, "0x%08x", flags);
 		}
 	}
 
