@@ -1,7 +1,7 @@
 /* packet-iana-oui.c
  * Register an LLC dissector table for the IANA's OUI 00:00:5e
  *
- * $Id$
+ * $Id: packet-iana-oui.c 51952 2013-09-11 18:06:29Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -58,5 +58,5 @@ proto_register_iana_oui(void)
 	  }
 	};
 
-	llc_add_oui(OUI_IANA, "llc.iana_pid", "IANA OUI PID", hf);
+	llc_add_oui(OUI_IANA, "llc.iana_pid", "LLC IANA OUI PID", hf);
 }
