@@ -4,7 +4,7 @@
  *
  * Srishylam Simharajan simha@netapp.com
  *
- * $Id$
+ * $Id: packet-icap.c 49920 2013-06-14 01:02:11Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,6 +28,7 @@
 #include "config.h"
 
 #include <string.h>
+#include <ctype.h>
 
 #include <glib.h>
 #include <epan/packet.h>
@@ -71,27 +72,24 @@ dissect_icap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "ICAP");
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		/*
-		 * Put the first line from the buffer into the summary
-		 * if it's an ICAP header (but leave out the
-		 * line terminator).
-		 * Otherwise, just call it a continuation.
-		 *
-		 * Note that "tvb_find_line_end()" will return a value that
-		 * is not longer than what's in the buffer, so the
-		 * "tvb_get_ptr()" call won't throw an exception.
-		 */
-		linelen = tvb_find_line_end(tvb, offset, -1, &next_offset,
-		    FALSE);
-		line = tvb_get_ptr(tvb, offset, linelen);
-		icap_type = ICAP_OTHER;	/* type not known yet */
-		if (is_icap_message(line, linelen, &icap_type))
-			col_add_str(pinfo->cinfo, COL_INFO,
-			    format_text(line, linelen));
-		else
-			col_set_str(pinfo->cinfo, COL_INFO, "Continuation");
-	}
+	/*
+	 * Put the first line from the buffer into the summary
+	 * if it's an ICAP header (but leave out the
+	 * line terminator).
+	 * Otherwise, just call it a continuation.
+	 *
+	 * Note that "tvb_find_line_end()" will return a value that
+	 * is not longer than what's in the buffer, so the
+	 * "tvb_get_ptr()" call won't throw an exception.
+	 */
+	linelen = tvb_find_line_end(tvb, offset, -1, &next_offset, FALSE);
+	line = tvb_get_ptr(tvb, offset, linelen);
+	icap_type = ICAP_OTHER;	/* type not known yet */
+	if (is_icap_message(line, linelen, &icap_type))
+		col_add_str(pinfo->cinfo, COL_INFO,
+		    format_text(line, linelen));
+	else
+		col_set_str(pinfo->cinfo, COL_INFO, "Continuation");
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_icap, tvb, offset, -1,
@@ -141,16 +139,23 @@ dissect_icap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			c = *linep++;
 
 			/*
-			 * This must be a CHAR, and must not be a CTL, to be
-			 * part of a token; that means it must be printable
-			 * ASCII.
+			 * This must be a CHAR to be part of a token; that
+			 * means it must be ASCII.
+			 */
+			if (!isascii(c)) {
+				is_icap = FALSE;
+				break;	/* not ASCII, thus not a CHAR */
+			}
+
+			/*
+			 * This mustn't be a CTL to be part of a token.
 			 *
 			 * XXX - what about leading LWS on continuation
 			 * lines of a header?
 			 */
-			if (!g_ascii_isprint(c)) {
+			if (iscntrl(c)) {
 				is_icap = FALSE;
-				break;
+				break;	/* CTL, not part of a header */
 			}
 
 			switch (c) {
