@@ -1,7 +1,7 @@
 /* packet-icmp.c
  * Routines for ICMP - Internet Control Message Protocol
  *
- * $Id$
+ * $Id: packet-icmp.c 52045 2013-09-15 01:48:30Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -45,7 +45,7 @@
 #include "packet-ip.h"
 #include "packet-icmp.h"
 #include <epan/conversation.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/tap.h>
 
 static int icmp_tap = -1;
@@ -58,8 +58,8 @@ static int hf_icmp_data_time = -1;
 static int hf_icmp_data_time_relative = -1;
 
 typedef struct _icmp_conv_info_t {
-	emem_tree_t *unmatched_pdus;
-	emem_tree_t *matched_pdus;
+	wmem_tree_t *unmatched_pdus;
+	wmem_tree_t *matched_pdus;
 } icmp_conv_info_t;
 
 static icmp_transaction_t *transaction_start(packet_info * pinfo,
@@ -826,7 +826,6 @@ dissect_extensions(tvbuff_t * tvb, gint offset, proto_tree * tree)
 	guint8 version;
 	guint8 class_num;
 	guint8 c_type;
-	guint16 reserved;
 	guint16 cksum, computed_cksum;
 	guint16 obj_length, obj_trunc_length;
 	proto_item *ti, *tf_object, *hidden_item;
@@ -864,10 +863,8 @@ dissect_extensions(tvbuff_t * tvb, gint offset, proto_tree * tree)
 			    version);
 
 	/* Reserved */
-	reserved = tvb_get_ntohs(tvb, offset) & 0x0fff;
-	proto_tree_add_uint_format(ext_tree, hf_icmp_ext_reserved,
-				   tvb, offset, 2, reserved,
-				   "Reserved: 0x%03x", reserved);
+	proto_tree_add_item(ext_tree, hf_icmp_ext_reserved,
+				   tvb, offset, 2, ENC_BIG_ENDIAN);
 
 	/* Checksum */
 	cksum = tvb_get_ntohs(tvb, offset + 2);
@@ -877,18 +874,18 @@ dissect_extensions(tvbuff_t * tvb, gint offset, proto_tree * tree)
 			reported_length);
 
 	if (computed_cksum == 0) {
-		proto_tree_add_uint_format(ext_tree, hf_icmp_ext_checksum,
+		proto_tree_add_uint_format_value(ext_tree, hf_icmp_ext_checksum,
 					   tvb, offset + 2, 2, cksum,
-					   "Checksum: 0x%04x [correct]",
+					   "0x%04x [correct]",
 					   cksum);
 		hidden_item =
 		    proto_tree_add_boolean(ext_tree,
 					   hf_icmp_ext_checksum_bad, tvb,
 					   offset + 2, 2, FALSE);
 	} else {
-		proto_tree_add_uint_format(ext_tree, hf_icmp_ext_checksum,
+		proto_tree_add_uint_format_value(ext_tree, hf_icmp_ext_checksum,
 					   tvb, offset + 2, 2, cksum,
-					   "Checksum: 0x%04x [incorrect, should be 0x%04x]",
+					   "0x%04x [incorrect, should be 0x%04x]",
 					   cksum, in_cksum_shouldbe(cksum,
 								    computed_cksum));
 		hidden_item =
@@ -1017,20 +1014,16 @@ static icmp_transaction_t *transaction_start(packet_info * pinfo,
 	conversation_t *conversation;
 	icmp_conv_info_t *icmp_info;
 	icmp_transaction_t *icmp_trans;
-	emem_tree_key_t icmp_key[3];
+	wmem_tree_key_t icmp_key[3];
 	proto_item *it;
 
 	/* Handle the conversation tracking */
 	conversation = _find_or_create_conversation(pinfo);
 	icmp_info = (icmp_conv_info_t *)conversation_get_proto_data(conversation, proto_icmp);
 	if (icmp_info == NULL) {
-		icmp_info = se_new(icmp_conv_info_t);
-		icmp_info->unmatched_pdus =
-		    se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK,
-						  "icmp_unmatched_pdus");
-		icmp_info->matched_pdus =
-		    se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK,
-						  "icmp_matched_pdus");
+		icmp_info = wmem_new(wmem_file_scope(), icmp_conv_info_t);
+		icmp_info->unmatched_pdus = wmem_tree_new(wmem_file_scope());
+		icmp_info->matched_pdus   = wmem_tree_new(wmem_file_scope());
 		conversation_add_proto_data(conversation, proto_icmp,
 					    icmp_info);
 	}
@@ -1044,12 +1037,12 @@ static icmp_transaction_t *transaction_start(packet_info * pinfo,
 		icmp_key[1].length = 0;
 		icmp_key[1].key = NULL;
 
-		icmp_trans = se_new(icmp_transaction_t);
+		icmp_trans = wmem_new(wmem_file_scope(), icmp_transaction_t);
 		icmp_trans->rqst_frame = PINFO_FD_NUM(pinfo);
 		icmp_trans->resp_frame = 0;
 		icmp_trans->rqst_time = pinfo->fd->abs_ts;
 		nstime_set_zero(&icmp_trans->resp_time);
-		se_tree_insert32_array(icmp_info->unmatched_pdus, icmp_key,
+		wmem_tree_insert32_array(icmp_info->unmatched_pdus, icmp_key,
 				       (void *) icmp_trans);
 	} else {
 		/* Already visited this frame */
@@ -1063,7 +1056,7 @@ static icmp_transaction_t *transaction_start(packet_info * pinfo,
 		icmp_key[2].key = NULL;
 
 		icmp_trans =
-		    (icmp_transaction_t *)se_tree_lookup32_array(icmp_info->matched_pdus,
+		    (icmp_transaction_t *)wmem_tree_lookup32_array(icmp_info->matched_pdus,
 					   icmp_key);
 	}
 	if (icmp_trans == NULL) {
@@ -1092,7 +1085,7 @@ static icmp_transaction_t *transaction_end(packet_info * pinfo,
 	conversation_t *conversation;
 	icmp_conv_info_t *icmp_info;
 	icmp_transaction_t *icmp_trans;
-	emem_tree_key_t icmp_key[3];
+	wmem_tree_key_t icmp_key[3];
 	proto_item *it;
 	nstime_t ns;
 	double resp_time;
@@ -1117,7 +1110,7 @@ static icmp_transaction_t *transaction_end(packet_info * pinfo,
 		icmp_key[1].length = 0;
 		icmp_key[1].key = NULL;
 		icmp_trans =
-		    (icmp_transaction_t *)se_tree_lookup32_array(icmp_info->unmatched_pdus,
+		    (icmp_transaction_t *)wmem_tree_lookup32_array(icmp_info->unmatched_pdus,
 					   icmp_key);
 		if (icmp_trans == NULL) {
 			return NULL;
@@ -1140,11 +1133,11 @@ static icmp_transaction_t *transaction_end(packet_info * pinfo,
 		icmp_key[2].key = NULL;
 
 		frame_num = icmp_trans->rqst_frame;
-		se_tree_insert32_array(icmp_info->matched_pdus, icmp_key,
+		wmem_tree_insert32_array(icmp_info->matched_pdus, icmp_key,
 				       (void *) icmp_trans);
 
 		frame_num = icmp_trans->resp_frame;
-		se_tree_insert32_array(icmp_info->matched_pdus, icmp_key,
+		wmem_tree_insert32_array(icmp_info->matched_pdus, icmp_key,
 				       (void *) icmp_trans);
 	} else {
 		/* Already visited this frame */
@@ -1158,7 +1151,7 @@ static icmp_transaction_t *transaction_end(packet_info * pinfo,
 		icmp_key[2].key = NULL;
 
 		icmp_trans =
-		    (icmp_transaction_t *)se_tree_lookup32_array(icmp_info->matched_pdus,
+		    (icmp_transaction_t *)wmem_tree_lookup32_array(icmp_info->matched_pdus,
 					   icmp_key);
 
 		if (icmp_trans == NULL) {
@@ -1297,7 +1290,6 @@ dissect_icmp(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 		code_str =
 		    val_to_str(icmp_code, alt_host_code_str,
 			       "Unknown code: %u");
-		icmp_original_dgram_length = 0;
 		break;
 	case ICMP_RTRADVERT:
 		switch (icmp_code) {
@@ -1361,10 +1353,10 @@ dissect_icmp(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 		    ip_checksum(tvb_get_ptr(tvb, 0, reported_length),
 				reported_length);
 		if (computed_cksum == 0) {
-			proto_tree_add_uint_format(icmp_tree,
+			proto_tree_add_uint_format_value(icmp_tree,
 						   hf_icmp_checksum, tvb,
 						   2, 2, cksum,
-						   "Checksum: 0x%04x [correct]",
+						   "0x%04x [correct]",
 						   cksum);
 			item =
 			    proto_tree_add_boolean(icmp_tree,
@@ -1372,10 +1364,10 @@ dissect_icmp(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 						   tvb, 2, 2, FALSE);
 			PROTO_ITEM_SET_HIDDEN(item);
 		} else {
-			proto_tree_add_uint_format(icmp_tree,
+			proto_tree_add_uint_format_value(icmp_tree,
 						   hf_icmp_checksum, tvb,
 						   2, 2, cksum,
-						   "Checksum: 0x%04x [incorrect, should be 0x%04x]",
+						   "0x%04x [incorrect, should be 0x%04x]",
 						   cksum,
 						   in_cksum_shouldbe(cksum,
 								     computed_cksum));
@@ -1505,18 +1497,13 @@ dissect_icmp(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 		 * icmp_original_dgram_length*4 bytes of original IP packet that needs
 		 * to be decoded, followed by extension objects.
 		 */
-
-		if (icmp_type == ICMP_REDIRECT) {
-			/* No icmp_original_dgram_length is available for redirect message,
-			 * we expect a max of Internet Header + 64 bits of Original Data Datagram */
-			set_actual_length(next_tvb, ((tvb_get_guint8(tvb, 8) & 0x0f) * 4) + 8);
-		} else if (icmp_original_dgram_length
+		if (icmp_original_dgram_length
 		    && (tvb_reported_length(tvb) >
 			(guint) (8 + icmp_original_dgram_length * 4))
 		    && (tvb_get_ntohs(tvb, 8 + 2) >
 			(guint) icmp_original_dgram_length * 4)) {
 			set_actual_length(next_tvb,
-					  ((tvb_get_guint8(tvb, 8) & 0x0f) + icmp_original_dgram_length) * 4);
+					  icmp_original_dgram_length * 4);
 		} else {
 			/* There is a collision between RFC 1812 and draft-ietf-mpls-icmp-02.
 			   We don't know how to decode the 128th and following bytes of the ICMP payload.
@@ -1865,7 +1852,7 @@ void proto_register_icmp(void)
 
 		{&hf_icmp_ext_reserved,
 		 {"Reserved", "icmp.ext.res", FT_UINT16, BASE_HEX, NULL,
-		  0x0,
+		  0x0fff,
 		  NULL, HFILL}},
 
 		{&hf_icmp_ext_checksum,
