@@ -6,7 +6,7 @@
  *
  * Copyright 2011, Thomas Bottom <tom.bottom@labxtechnologies.com>
  *
- * $Id$
+ * $Id: packet-ieee1722.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -150,7 +150,7 @@ dissect_1722(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         proto_tree_add_item(ieee1722_tree, hf_1722_svfield, tvb, IEEE_1722_VERSION_OFFSET, 1, ENC_BIG_ENDIAN);
         proto_tree_add_item(ieee1722_tree, hf_1722_verfield, tvb, IEEE_1722_VERSION_OFFSET, 1, ENC_BIG_ENDIAN);
     }
-        
+
 
     /* Version field ends the common AVTPDU. Now parse the specfic packet type */
     subtype = tvb_get_guint8(tvb, IEEE_1722_CD_OFFSET);
@@ -163,7 +163,7 @@ dissect_1722(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         proto_tree_add_item(ieee1722_tree, hf_1722_mrfield, tvb, IEEE_1722_VERSION_OFFSET, 1, ENC_BIG_ENDIAN);
         proto_tree_add_item(ieee1722_tree, hf_1722_gvfield, tvb, IEEE_1722_VERSION_OFFSET, 1, ENC_BIG_ENDIAN);
         proto_tree_add_item(ieee1722_tree, hf_1722_tvfield, tvb, IEEE_1722_VERSION_OFFSET, 1, ENC_BIG_ENDIAN);
-        
+
         /* Add the rest of the packet fields */
         proto_tree_add_item(ieee1722_tree, hf_1722_seqnum, tvb,
                             IEEE_1722_SEQ_NUM_OFFSET, 1, ENC_BIG_ENDIAN);
@@ -388,10 +388,10 @@ void proto_register_1722(void)
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_1722, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
-    
+
     /* Sub-dissector for 1772.1 */
     avb_dissector_table = register_dissector_table("ieee1722.subtype",
-                          "AVBTP Subtype", FT_UINT8, BASE_HEX);
+                          "IEEE1722 AVBTP Subtype", FT_UINT8, BASE_HEX);
 }
 
 void proto_reg_handoff_1722(void)
