@@ -1,7 +1,7 @@
 /* packet-ieee80211-prism.c
  * Routines for Prism monitoring mode header dissection
  *
- * $Id$
+ * $Id: packet-ieee80211-prism.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,6 +27,7 @@
 #include "config.h"
 
 #include <epan/packet.h>
+#include <epan/wmem/wmem.h>
 #include "packet-ieee80211.h"
 
 #define SHORT_STR 256
@@ -153,7 +154,7 @@ static gint ett_prism_did = -1;
 #define PRISM_TYPE1_MACTIME      0x00020044      /* Mac time element */
 #define PRISM_TYPE2_MACTIME      0x00002041
 #define PRISM_TYPE1_CHANNEL      0x00030044      /* Channel element */
-#define PRISM_TYPE2_CHANNEL      0x00003041 
+#define PRISM_TYPE2_CHANNEL      0x00003041
 #define PRISM_TYPE1_RSSI         0x00040044      /* RSSI element */
 #define PRISM_TYPE2_RSSI         0x00004041
 #define PRISM_TYPE1_SQ           0x00050044      /* SQ element */
@@ -223,7 +224,7 @@ static gchar *
 prism_rate_return(guint32 rate)
 {
   gchar *result=NULL;
-  result = (gchar *)ep_alloc(SHORT_STR);
+  result = (gchar *)wmem_alloc(wmem_packet_scope(), SHORT_STR);
   result[0] = '\0';
   prism_rate_base_custom(result, rate);
 
@@ -260,24 +261,6 @@ capture_prism(const guchar *pd, int offset, int len, packet_counts *ld)
   capture_ieee80211(pd, offset, len, ld);
 }
 
-static guint16
-tvb_get_enctohs(tvbuff_t *tvb, int offset, guint encoding)
-{
-    if (encoding == ENC_BIG_ENDIAN)
-        return tvb_get_ntohs(tvb, offset);
-    else
-        return tvb_get_letohs(tvb, offset);
-}
-
-static guint32
-tvb_get_enctohl(tvbuff_t *tvb, int offset, guint encoding)
-{
-    if (encoding == ENC_BIG_ENDIAN)
-        return tvb_get_ntohl(tvb, offset);
-    else
-        return tvb_get_letohl(tvb, offset);
-}
-
 static void
 dissect_prism(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
@@ -286,7 +269,6 @@ dissect_prism(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     tvbuff_t *next_tvb;
     int offset;
     guint32 msgcode, msglen, did;
-    guint byte_order;
     guint16 status;
     guint8 *devname_p;
 
@@ -307,18 +289,12 @@ dissect_prism(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
      * at least one capture has AVS headers on some packets and no
      * radio headers on others (incoming vs. outgoing?).
      *
-     * Check for both byte orders and use that to determine
-     * the byte order of the fields in the Prism header.
+     * XXX - check for both byte orders and use that to determine
+     * the byte order of the fields in the Prism header?
      */
-    if ((msgcode == PRISM_TYPE1_MSGCODE) || (msgcode == PRISM_TYPE2_MSGCODE)) {
-        /* big-endian fetch matched */
-        byte_order = ENC_BIG_ENDIAN;
-    } else if (((msgcode = tvb_get_letohl(tvb, offset)) == PRISM_TYPE1_MSGCODE) ||
-                                               (msgcode == PRISM_TYPE2_MSGCODE)) {
-        /* little-endian fetch matched */
-        byte_order = ENC_LITTLE_ENDIAN;
-    } else {
-        /* neither matched - try it as just 802.11 with no Prism header */
+    msgcode = tvb_get_letohl(tvb, offset);
+    if ((msgcode != PRISM_TYPE1_MSGCODE) &&
+        (msgcode != PRISM_TYPE2_MSGCODE)) {
         call_dissector(ieee80211_handle, tvb, pinfo, tree);
         return;
     }
@@ -333,27 +309,28 @@ dissect_prism(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     /* Message Code */
     if(tree) {
-        proto_tree_add_item(prism_tree, hf_ieee80211_prism_msgcode, tvb, offset, 4, byte_order);
+        proto_tree_add_item(prism_tree, hf_ieee80211_prism_msgcode, tvb, offset, 4, ENC_LITTLE_ENDIAN);
     }
-    msgcode = tvb_get_enctohl(tvb, offset, byte_order);
+    msgcode = tvb_get_letohl(tvb, offset);
     offset += 4;
 
     /* Message Length */
     if(tree) {
-        proto_tree_add_item(prism_tree, hf_ieee80211_prism_msglen, tvb, offset, 4, byte_order);
+        proto_tree_add_item(prism_tree, hf_ieee80211_prism_msglen, tvb, offset, 4, ENC_LITTLE_ENDIAN);
     }
-    msglen = tvb_get_enctohl(tvb, offset, byte_order);
+    msglen = tvb_get_letohl(tvb, offset);
     offset += 4;
 
     /* Device Name */
     if(tree) {
        proto_tree_add_item(prism_tree, hf_ieee80211_prism_devname, tvb, offset, 16, ENC_ASCII|ENC_NA);
     }
-    devname_p = tvb_get_ephemeral_string(tvb, offset, 16);
+    devname_p = tvb_get_string(wmem_packet_scope(), tvb, offset, 16);
     offset += 16;
 
     col_add_fstr(pinfo->cinfo, COL_INFO, "Device: %s, Message 0x%x, Length %d", devname_p, msgcode, msglen);
 
+
     while(offset < PRISM_HEADER_LENGTH)
     {
         /* DID */
@@ -361,23 +338,23 @@ dissect_prism(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             ti_did = proto_tree_add_item(prism_tree, hf_ieee80211_prism_did, tvb, offset, 12, ENC_NA);
             prism_did_tree = proto_item_add_subtree(ti_did, ett_prism_did);
 
-            proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_type, tvb, offset, 4, byte_order);
-            did = tvb_get_enctohl(tvb, offset, byte_order);
+            proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_type, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+            did = tvb_get_letohl(tvb, offset);
             proto_item_append_text(ti_did, " %s", val_to_str(did, prism_did_vals, "Unknown %x") );
         }
         offset += 4;
 
 
         /* Status */
-        status = tvb_get_enctohs(tvb, offset, byte_order);
+        status = tvb_get_letohs(tvb, offset);
         if(tree) {
-            proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_status, tvb, offset, 2, byte_order);
+            proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_status, tvb, offset, 2, ENC_LITTLE_ENDIAN);
         }
         offset += 2;
 
         /* Length */
         if(tree) {
-            proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_length, tvb, offset, 2, byte_order);
+            proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_length, tvb, offset, 2, ENC_LITTLE_ENDIAN);
         }
         offset += 2;
 
@@ -387,89 +364,89 @@ dissect_prism(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
               case PRISM_TYPE1_HOSTTIME:
               case PRISM_TYPE2_HOSTTIME:
                 if(tree){
-                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_hosttime, tvb, offset, 4, byte_order);
-                    proto_item_append_text(ti_did, " %d", tvb_get_enctohl(tvb, offset, byte_order) );
+                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_hosttime, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+                    proto_item_append_text(ti_did, " %d", tvb_get_letohl(tvb, offset) );
                 }
               break;
 
               case PRISM_TYPE1_MACTIME:
               case PRISM_TYPE2_MACTIME:
                 if(tree){
-                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_mactime, tvb, offset, 4, byte_order);
-                    proto_item_append_text(ti_did, " %d", tvb_get_enctohl(tvb, offset, byte_order) );
+                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_mactime, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+                    proto_item_append_text(ti_did, " %d", tvb_get_letohl(tvb, offset) );
                 }
               break;
 
               case PRISM_TYPE1_CHANNEL:
               case PRISM_TYPE2_CHANNEL:
                 if(tree){
-                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_channel, tvb, offset, 4, byte_order);
-                    proto_item_append_text(ti_did, " %d", tvb_get_enctohl(tvb, offset, byte_order) );
+                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_channel, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+                    proto_item_append_text(ti_did, " %d", tvb_get_letohl(tvb, offset) );
                 }
-                col_add_fstr(pinfo->cinfo, COL_FREQ_CHAN, "%u", tvb_get_enctohl(tvb, offset, byte_order));
+                col_add_fstr(pinfo->cinfo, COL_FREQ_CHAN, "%u", tvb_get_letohl(tvb, offset));
               break;
 
               case PRISM_TYPE1_RSSI:
               case PRISM_TYPE2_RSSI:
                 if(tree){
-                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_rssi, tvb, offset, 4, byte_order);
-                    proto_item_append_text(ti_did, " 0x%x", tvb_get_enctohl(tvb, offset, byte_order) );
+                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_rssi, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+                    proto_item_append_text(ti_did, " 0x%x", tvb_get_letohl(tvb, offset) );
                 }
-                col_add_fstr(pinfo->cinfo, COL_RSSI, "%d", tvb_get_enctohl(tvb, offset, byte_order));
+                col_add_fstr(pinfo->cinfo, COL_RSSI, "%d", tvb_get_letohl(tvb, offset));
               break;
 
               case PRISM_TYPE1_SQ:
               case PRISM_TYPE2_SQ:
                  if(tree){
-                      proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_sq, tvb, offset, 4, byte_order);
-                      proto_item_append_text(ti_did, " 0x%x", tvb_get_enctohl(tvb, offset, byte_order) );
+                      proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_sq, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+                      proto_item_append_text(ti_did, " 0x%x", tvb_get_letohl(tvb, offset) );
                 }
               break;
 
               case PRISM_TYPE1_SIGNAL:
               case PRISM_TYPE2_SIGNAL:
                 if(tree){
-                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_signal, tvb, offset, 4, byte_order);
-                    proto_item_append_text(ti_did, " 0x%x", tvb_get_enctohl(tvb, offset, byte_order) );
+                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_signal, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+                    proto_item_append_text(ti_did, " 0x%x", tvb_get_letohl(tvb, offset) );
                 }
               break;
 
               case PRISM_TYPE1_NOISE:
               case PRISM_TYPE2_NOISE:
                 if(tree){
-                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_noise, tvb, offset, 4, byte_order);
-                    proto_item_append_text(ti_did, " 0x%x", tvb_get_enctohl(tvb, offset, byte_order) );
+                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_noise, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+                    proto_item_append_text(ti_did, " 0x%x", tvb_get_letohl(tvb, offset) );
                 }
               break;
 
               case PRISM_TYPE1_RATE:
               case PRISM_TYPE2_RATE:
                 if(tree){
-                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_rate, tvb, offset, 4, byte_order);
-                    proto_item_append_text(ti_did, " %s Mb/s", prism_rate_return(tvb_get_enctohl(tvb, offset, byte_order)) );
+                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_rate, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+                    proto_item_append_text(ti_did, " %s Mb/s", prism_rate_return(tvb_get_letohl(tvb, offset)) );
                 }
-                col_add_fstr(pinfo->cinfo, COL_TX_RATE, "%s", prism_rate_return(tvb_get_enctohl(tvb, offset, byte_order)) );
+                col_add_fstr(pinfo->cinfo, COL_TX_RATE, "%s", prism_rate_return(tvb_get_letohl(tvb, offset)) );
               break;
 
               case PRISM_TYPE1_ISTX:
               case PRISM_TYPE2_ISTX:
                 if(tree){
-                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_istx, tvb, offset, 4, byte_order);
-                    proto_item_append_text(ti_did, " 0x%x", tvb_get_enctohl(tvb, offset, byte_order) );
+                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_istx, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+                    proto_item_append_text(ti_did, " 0x%x", tvb_get_letohl(tvb, offset) );
                 }
               break;
 
               case PRISM_TYPE1_FRMLEN:
               case PRISM_TYPE2_FRMLEN:
                 if(tree){
-                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_frmlen, tvb, offset, 4, byte_order);
-                    proto_item_append_text(ti_did, " %d", tvb_get_enctohl(tvb, offset, byte_order));
+                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_frmlen, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+                    proto_item_append_text(ti_did, " %d", tvb_get_letohl(tvb, offset) );
                 }
               break;
 
               default:
                 if(tree){
-                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_unknown, tvb, offset, 4, byte_order);
+                    proto_tree_add_item(prism_did_tree, hf_ieee80211_prism_did_unknown, tvb, offset, 4, ENC_LITTLE_ENDIAN);
                 }
               break;
             }
