@@ -1,7 +1,7 @@
 /* packet-ieee80211-radio.c
  * Routines for pseudo 802.11 header dissection
  *
- * $Id$
+ * $Id: packet-ieee80211-radio.c 52299 2013-09-30 15:52:24Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -79,18 +79,18 @@ dissect_radio (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
     ti = proto_tree_add_item(tree, proto_radio, tvb, 0, 0, ENC_NA);
     radio_tree = proto_item_add_subtree (ti, ett_radio);
 
-    proto_tree_add_uint64_format(radio_tree, hf_data_rate, tvb, 0, 0,
+    proto_tree_add_uint64_format_value(radio_tree, hf_data_rate, tvb, 0, 0,
              (guint64)pinfo->pseudo_header->ieee_802_11.data_rate * 500000,
-             "Data Rate: %u.%u Mb/s",
+             "%u.%u Mb/s",
              pinfo->pseudo_header->ieee_802_11.data_rate / 2,
              pinfo->pseudo_header->ieee_802_11.data_rate & 1 ? 5 : 0);
 
     proto_tree_add_uint(radio_tree, hf_channel, tvb, 0, 0,
             pinfo->pseudo_header->ieee_802_11.channel);
 
-    proto_tree_add_uint_format(radio_tree, hf_signal_strength, tvb, 0, 0,
+    proto_tree_add_uint_format_value(radio_tree, hf_signal_strength, tvb, 0, 0,
             pinfo->pseudo_header->ieee_802_11.signal_level,
-            "Signal Strength: %u%%",
+            "%u%%",
             pinfo->pseudo_header->ieee_802_11.signal_level);
   }
 
