@@ -1,7 +1,7 @@
 /* packet-ieee80211-wlancap.c
  * Routines for AVS linux-wlan monitoring mode header dissection
  *
- * $Id$
+ * $Id: packet-ieee80211-wlancap.c 52299 2013-09-30 15:52:24Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -418,9 +418,9 @@ dissect_wlancap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                    datarate / 1000000,
                    ((datarate % 1000000) > 500000) ? 5 : 0);
     if (tree) {
-      proto_tree_add_uint64_format(wlan_tree, hf_data_rate, tvb, offset, 4,
+      proto_tree_add_uint64_format_value(wlan_tree, hf_data_rate, tvb, offset, 4,
                                    datarate,
-                                   "Data Rate: %u.%u Mb/s",
+                                   "%u.%u Mb/s",
                                    datarate/1000000,
                                    ((datarate % 1000000) > 500000) ? 5 : 0);
     }
@@ -512,7 +512,7 @@ dissect_wlancap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       offset+=6;
       if (tree)
         proto_tree_add_item(wlan_tree, hf_wlan_padding, tvb, offset, 2, ENC_NA);
-      offset+=2;
+      /*offset+=2;*/
     }
 
 
