@@ -2,7 +2,7 @@
  * Declaration of routine for dissecting 802.3 (as opposed to D/I/X Ethernet)
  * packets.
  *
- * $Id$
+ * $Id: packet-ieee8023.h 51761 2013-09-05 01:39:35Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,6 +29,6 @@
 
 void dissect_802_3(volatile int length, gboolean is_802_2, tvbuff_t *tvb,
     int offset_after_length, packet_info *pinfo, proto_tree *tree,
-    proto_tree *fh_tree, int length_id, int trailer_id, int fcs_len);
+    proto_tree *fh_tree, int length_id, int trailer_id, expert_field* ei_len, int fcs_len);
 
 #endif
