@@ -4,7 +4,7 @@
  * 2007 Thomas Morin
  * <See AUTHORS for emails>
  *
- * $Id$
+ * $Id: packet-igmp.c 52098 2013-09-16 10:39:06Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -409,8 +409,8 @@ dissect_v3_max_resp(tvbuff_t *tvb, proto_tree *parent_tree, int offset)
 		tsecs = bits;
 	}
 
-	item = proto_tree_add_uint_format(parent_tree, hf_max_resp, tvb,
-			offset, 1, tsecs, "Max Response Time: %.1f sec (0x%02x)",tsecs*0.1,bits);
+	item = proto_tree_add_uint_format_value(parent_tree, hf_max_resp, tvb,
+			offset, 1, tsecs, "%.1f sec (0x%02x)",tsecs*0.1,bits);
 
 	if (bits&0x80) {
 		tree = proto_item_add_subtree(item, ett_max_resp);
@@ -551,10 +551,9 @@ dissect_v3_group_record(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tr
 
 	/* source addresses */
 	while(num--){
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_append_fstr(pinfo->cinfo, COL_INFO, "%s%s",
+		col_append_fstr(pinfo->cinfo, COL_INFO, "%s%s",
 				tvb_ip_to_str(tvb, offset), (num?", ":"}"));
-		}
+
 		proto_tree_add_item(tree, hf_saddr, tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset += 4;
 	}
@@ -644,8 +643,7 @@ dissect_igmp_v3_query(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int t
 	offset += 2;
 
 	while(num--){
-		if (check_col(pinfo->cinfo, COL_INFO))
-			col_append_fstr(pinfo->cinfo, COL_INFO, "%s%s", tvb_ip_to_str(tvb, offset), (num?", ":"}"));
+		col_append_fstr(pinfo->cinfo, COL_INFO, "%s%s", tvb_ip_to_str(tvb, offset), (num?", ":"}"));
 		proto_tree_add_item(tree, hf_saddr, tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset += 4;
 	}
@@ -664,8 +662,8 @@ dissect_igmp_v2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int type, i
 
 	/* max resp time */
 	tsecs = tvb_get_guint8(tvb, offset);
-	proto_tree_add_uint_format(tree, hf_max_resp, tvb,
-		offset, 1, tsecs, "Max Response Time: %.1f sec (0x%02x)", tsecs*0.1,tsecs);
+	proto_tree_add_uint_format_value(tree, hf_max_resp, tvb,
+		offset, 1, tsecs, "%.1f sec (0x%02x)", tsecs*0.1,tsecs);
 	offset += 1;
 
 	/* checksum */
@@ -784,8 +782,8 @@ dissect_igmp_mtrace(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int typ
 	if (blocks)
 		col_append_str(pinfo->cinfo, COL_INFO, blocks);
 
-	proto_tree_add_uint_format(tree, hf_type, tvb, offset, 1, type,
-		"Type: %s (0x%02x)", typestr, type);
+	proto_tree_add_uint_format_value(tree, hf_type, tvb, offset, 1, type,
+		"%s (0x%02x)", typestr, type);
 	offset += 1;
 
 	/* maximum number of hops that the requester wants to trace */
