@@ -6,7 +6,7 @@
  *
  *	http://www.cisco.com/en/US/tech/tk365/technologies_white_paper09186a00800c8ae1.shtml
  *
- * $Id$
+ * $Id: packet-igrp.c 49920 2013-06-14 01:02:11Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -65,17 +65,15 @@ static void dissect_igrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   ver_and_opcode = tvb_get_guint8(tvb,0);
 
 
-  if (check_col(pinfo->cinfo, COL_INFO)) {
-    switch (ver_and_opcode) {
-    case 0x11:
+  switch (ver_and_opcode) {
+  case 0x11:
 	col_set_str(pinfo->cinfo, COL_INFO, "Response" );
 	break;
-    case 0x12:
-    	col_set_str(pinfo->cinfo, COL_INFO, "Request" );
-        break;
-    default:
-        col_set_str(pinfo->cinfo, COL_INFO, "Unknown version or opcode");
-    }
+  case 0x12:
+	col_set_str(pinfo->cinfo, COL_INFO, "Request" );
+	break;
+  default:
+	col_set_str(pinfo->cinfo, COL_INFO, "Unknown version or opcode");
   }
 
 
