@@ -2,7 +2,7 @@
  * Routines for imap packet dissection
  * Copyright 1999, Richard Sharpe <rsharpe@ns.aus.com>
  *
- * $Id$
+ * $Id: packet-imap.c 52002 2013-09-13 10:13:19Z jmayer $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,9 +29,11 @@
 
 #include <epan/packet.h>
 #include <epan/strutil.h>
+#include <epan/wmem/wmem.h>
 #include "packet-ssl.h"
 
 #include <stdio.h>
+#include <ctype.h>
 
 static int proto_imap = -1;
 static int hf_imap_isrequest = -1;
@@ -48,6 +50,8 @@ static int hf_imap_request_uid = -1;
 static gint ett_imap = -1;
 static gint ett_imap_reqresp = -1;
 
+static dissector_handle_t imap_handle;
+
 #define TCP_PORT_IMAP			143
 #define TCP_PORT_SSL_IMAP		993
 #define MAX_BUFFER                      1024
@@ -77,8 +81,8 @@ dissect_imap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	int             iter;
 	int             commandlen;
 
-	tokenbuf = (guchar *)ep_alloc(MAX_BUFFER);
-	command_token = (guchar *)ep_alloc(MAX_BUFFER);
+	tokenbuf = (guchar *)wmem_alloc(wmem_packet_scope(), MAX_BUFFER);
+	command_token = (guchar *)wmem_alloc(wmem_packet_scope(), MAX_BUFFER);
 	memset(tokenbuf, '\0', MAX_BUFFER);
 	memset(command_token, '\0', MAX_BUFFER);
 	commandlen = 0;
@@ -93,18 +97,16 @@ dissect_imap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	else
 		is_request = FALSE;
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		/*
-		 * Put the first line from the buffer into the summary
-		 * (but leave out the line terminator).
-		 */
-		linelen = tvb_find_line_end(tvb, offset, -1, &next_offset, FALSE);
-		line = tvb_get_ptr(tvb, offset, linelen);
+	/*
+	 * Put the first line from the buffer into the summary
+	 * (but leave out the line terminator).
+	 */
+	linelen = tvb_find_line_end(tvb, offset, -1, &next_offset, FALSE);
+	line = tvb_get_ptr(tvb, offset, linelen);
 
-		col_add_fstr(pinfo->cinfo, COL_INFO, "%s: %s",
+	col_add_fstr(pinfo->cinfo, COL_INFO, "%s: %s",
 			     is_request ? "Request" : "Response",
 			     format_text(line, linelen));
-	}
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_imap, tvb, offset, -1, ENC_NA);
@@ -157,18 +159,18 @@ dissect_imap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			  }
 
 			  /*
-			   * Extract second token, and, if there is a second 
+			   * Extract second token, and, if there is a second
 			   * token, and it's not uid, add it as the request or reply command.
 			   */
 			  tokenlen = get_token_len(line, line + linelen, &next_token);
 			  if (tokenlen != 0) {
 			    for (iter = 0; iter < tokenlen && iter < MAX_BUFFER-1; iter++) {
-			      tokenbuf[iter] = g_ascii_tolower(line[iter]);
+			      tokenbuf[iter] = tolower(line[iter]);
 			    }
 			    if ( TRUE == is_request && strncmp(tokenbuf,"uid",tokenlen) == 0) {
 			      proto_tree_add_item(reqresp_tree, hf_imap_request_uid, tvb, offset, tokenlen, ENC_ASCII|ENC_NA);
 			      /*
-			       * UID is a precursor to a command, if following the tag, 
+			       * UID is a precursor to a command, if following the tag,
                                * so move to next token to grab the actual command.
                                */
 			      uid_offset = offset;
@@ -183,7 +185,7 @@ dissect_imap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				 * Save command string to do specialized processing.
 				 */
 				for (iter = 0; iter < uid_tokenlen && iter < MAX_BUFFER-1; iter++) {
-				  command_token[iter] = g_ascii_tolower(uid_line[iter]);
+				  command_token[iter] = tolower(uid_line[iter]);
 				}
 				commandlen = uid_tokenlen;
 
@@ -204,7 +206,7 @@ dissect_imap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				 * Save command string to do specialized processing.
 				 */
 				for (iter = 0; iter < tokenlen && iter < 256; iter++) {
-				  command_token[iter] = g_ascii_tolower(line[iter]);
+				  command_token[iter] = tolower(line[iter]);
 				}
 				commandlen = tokenlen;
 
@@ -288,7 +290,9 @@ proto_register_imap(void)
 
 	proto_imap = proto_register_protocol("Internet Message Access Protocol",
 					   "IMAP", "imap");
-	register_dissector("imap", dissect_imap, proto_imap);
+
+	imap_handle = register_dissector("imap", dissect_imap, proto_imap);
+
 	proto_register_field_array(proto_imap, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 }
@@ -296,9 +300,6 @@ proto_register_imap(void)
 void
 proto_reg_handoff_imap(void)
 {
-	dissector_handle_t imap_handle;
-
-	imap_handle = create_dissector_handle(dissect_imap, proto_imap);
 	dissector_add_uint("tcp.port", TCP_PORT_IMAP, imap_handle);
 	ssl_dissector_add(TCP_PORT_SSL_IMAP, "imap", TRUE);
 }
