@@ -1,7 +1,7 @@
 /* packet-imf.c
  * Routines for Internet Message Format (IMF) packet disassembly
  *
- * $Id$
+ * $Id: packet-imf.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Copyright (c) 2007 by Graeme Lunt
  *
@@ -26,6 +26,8 @@
 
 #include "config.h"
 
+#include <ctype.h>
+
 #include <epan/packet.h>
 #include <epan/addr_resolv.h>
 #include <epan/strutil.h>
@@ -33,6 +35,7 @@
 #include <epan/uat.h>
 #include <epan/base64.h>
 #include <epan/expert.h>
+#include <epan/wmem/wmem.h>
 
 #include <wsutil/str_util.h>
 
@@ -148,6 +151,10 @@ static int ett_imf_siolabel = -1;
 static int ett_imf_extension = -1;
 static int ett_imf_message_text = -1;
 
+static dissector_handle_t imf_handle;
+
+static expert_field ei_imf_unknown_param = EI_INIT;
+
 struct imf_field {
   const char   *name;           /* field name - in lower case for matching purposes */
   int          *hf_id;          /* wireshark field */
@@ -358,7 +365,7 @@ dissect_imf_address(tvbuff_t *tvb, int offset, int length, proto_item *item, pac
 
     /* consume any whitespace */
     for(addr_pos++ ;addr_pos < (offset + length); addr_pos++) {
-      if(!g_ascii_isspace(tvb_get_guint8(tvb, addr_pos))) {
+      if(!isspace(tvb_get_guint8(tvb, addr_pos))) {
         break;
       }
     }
@@ -398,7 +405,7 @@ dissect_imf_mailbox(tvbuff_t *tvb, int offset, int length, proto_item *item, pac
     /* XXX: the '<' could be in the display name */
 
     for(; offset < addr_pos; offset++) {
-      if(!g_ascii_isspace(tvb_get_guint8(tvb, offset))) {
+      if(!isspace(tvb_get_guint8(tvb, offset))) {
         break;
       }
     }
@@ -502,7 +509,7 @@ dissect_imf_siolabel(tvbuff_t *tvb, int offset, int length, proto_item *item, pa
   int         end_offset;
   tvbuff_t   *label_tvb;
   gchar      *type = NULL;
-  emem_strbuf_t  *label_string = ep_strbuf_new("");
+  wmem_strbuf_t  *label_string = wmem_strbuf_new(wmem_packet_scope(), "");
 
   /* a semicolon separated list of attributes */
   tree = proto_item_add_subtree(item, ett_imf_siolabel);
@@ -512,7 +519,7 @@ dissect_imf_siolabel(tvbuff_t *tvb, int offset, int length, proto_item *item, pa
     end_offset = tvb_find_guint8(tvb, item_offset, length - (item_offset - offset), ';');
 
     /* skip leading space */
-    while (g_ascii_isspace(tvb_get_guint8(tvb, item_offset))) {
+    while (isspace(tvb_get_guint8(tvb, item_offset))) {
       item_offset++;
     }
 
@@ -524,17 +531,17 @@ dissect_imf_siolabel(tvbuff_t *tvb, int offset, int length, proto_item *item, pa
     }
 
     value_offset = tvb_find_guint8(tvb, item_offset, length - (item_offset - offset), '=') + 1;
-    while (g_ascii_isspace(tvb_get_guint8(tvb, value_offset))) {
+    while (isspace(tvb_get_guint8(tvb, value_offset))) {
       value_offset++;
     }
 
     value_length = item_length - (value_offset - item_offset);
-    while (g_ascii_isspace(tvb_get_guint8(tvb, value_offset + value_length - 1))) {
+    while (isspace(tvb_get_guint8(tvb, value_offset + value_length - 1))) {
       value_length--;
     }
 
     if (tvb_strneql(tvb, item_offset, "marking", 7) == 0) {
-      proto_item_append_text(item, ": %s", tvb_get_ephemeral_string(tvb, value_offset, value_length));
+      proto_item_append_text(item, ": %s", tvb_get_string(wmem_packet_scope(), tvb, value_offset, value_length));
       proto_tree_add_item(tree, hf_imf_siolabel_marking, tvb, value_offset, value_length, ENC_ASCII|ENC_NA);
 
     } else if (tvb_strneql(tvb, item_offset, "fgcolor", 7) == 0) {
@@ -544,15 +551,15 @@ dissect_imf_siolabel(tvbuff_t *tvb, int offset, int length, proto_item *item, pa
       proto_tree_add_item(tree, hf_imf_siolabel_bgcolor, tvb, value_offset, value_length, ENC_ASCII|ENC_NA);
 
     } else if (tvb_strneql(tvb, item_offset, "type", 4) == 0) {
-      type = tvb_get_ephemeral_string(tvb, value_offset + 1, value_length - 2); /* quoted */
+      type = tvb_get_string(wmem_packet_scope(), tvb, value_offset + 1, value_length - 2); /* quoted */
       proto_tree_add_item(tree, hf_imf_siolabel_type, tvb, value_offset, value_length, ENC_ASCII|ENC_NA);
 
     } else if (tvb_strneql(tvb, item_offset, "label", 5) == 0) {
-      gchar *label = tvb_get_ephemeral_string(tvb, value_offset + 1, value_length - 2); /* quoted */
-      label_string = ep_strbuf_append(label_string, label);
+      gchar *label = tvb_get_string(wmem_packet_scope(), tvb, value_offset + 1, value_length - 2); /* quoted */
+      wmem_strbuf_append(label_string, label);
 
       if (tvb_get_guint8(tvb, item_offset + 5) == '*') { /* continuations */
-        int num = (int)strtol(tvb_get_ephemeral_string(tvb, item_offset + 6, value_offset - item_offset + 6), NULL, 10);
+        int num = (int)strtol(tvb_get_string(wmem_packet_scope(), tvb, item_offset + 6, value_offset - item_offset + 6), NULL, 10);
         proto_tree_add_string_format(tree, hf_imf_siolabel_label, tvb, value_offset, value_length,
                                      label, "Label[%d]: \"%s\"", num, label);
       } else {
@@ -561,7 +568,7 @@ dissect_imf_siolabel(tvbuff_t *tvb, int offset, int length, proto_item *item, pa
 
     } else {
       sub_item = proto_tree_add_item(tree, hf_imf_siolabel_unknown, tvb, item_offset, item_length, ENC_ASCII|ENC_NA);
-      expert_add_info_format(pinfo, sub_item, PI_PROTOCOL, PI_WARN, "Unknown parameter");
+      expert_add_info(pinfo, sub_item, &ei_imf_unknown_param);
     }
 
     if (end_offset != -1) {
@@ -569,13 +576,13 @@ dissect_imf_siolabel(tvbuff_t *tvb, int offset, int length, proto_item *item, pa
     }
   } while (end_offset != -1);
 
-  if (type && label_string->len > 0) {
+  if (type && wmem_strbuf_get_len(label_string) > 0) {
     if (strcmp (type, ":ess") == 0) {
-      label_tvb = base64_to_tvb(tvb, label_string->str);
+      label_tvb = base64_to_tvb(tvb, wmem_strbuf_get_str(label_string));
       add_new_data_source(pinfo, label_tvb, "ESS Security Label");
       dissect_ess_ESSSecurityLabel_PDU(label_tvb, pinfo, tree);
     } else if (strcmp (type, ":x411") == 0) {
-      label_tvb = base64_to_tvb(tvb, label_string->str);
+      label_tvb = base64_to_tvb(tvb, wmem_strbuf_get_str(label_string));
       add_new_data_source(pinfo, label_tvb, "X.411 Security Label");
       dissect_p1_MessageSecurityLabel_PDU(label_tvb, pinfo, tree);
     }
@@ -593,7 +600,7 @@ dissect_imf_content_type(tvbuff_t *tvb, int offset, int length, proto_item *item
 
   /* first strip any whitespace */
   for(i = 0; i < length; i++) {
-    if(!g_ascii_isspace(tvb_get_guint8(tvb, offset + i))) {
+    if(!isspace(tvb_get_guint8(tvb, offset + i))) {
       offset += i;
       break;
     }
@@ -609,13 +616,13 @@ dissect_imf_content_type(tvbuff_t *tvb, int offset, int length, proto_item *item
     proto_tree_add_item(ct_tree, hf_imf_content_type_type, tvb, offset, len, ENC_ASCII|ENC_NA);
     if(type) {
       /* This string will be automatically freed */
-      (*type) = tvb_get_ephemeral_string(tvb, offset, len);
+      (*type) = tvb_get_string(wmem_packet_scope(), tvb, offset, len);
     }
     len = tvb_find_line_end(tvb, first_colon + 1, length, NULL, FALSE);
     proto_tree_add_item(ct_tree, hf_imf_content_type_parameters, tvb, first_colon + 1, len, ENC_ASCII|ENC_NA);
     if(parameters) {
       /* This string will be automatically freed */
-      (*parameters) = tvb_get_ephemeral_string(tvb, first_colon + 1, len);
+      (*parameters) = tvb_get_string(wmem_packet_scope(), tvb, first_colon + 1, len);
     }
   }
 }
@@ -707,7 +714,7 @@ dissect_imf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       /* XXX: flag an error */
       break;
     } else {
-      key = tvb_get_ephemeral_string(tvb, start_offset, end_offset - start_offset);
+      key = tvb_get_string(wmem_packet_scope(), tvb, start_offset, end_offset - start_offset);
 
       /* convert to lower case */
       ascii_strdown_inplace (key);
@@ -739,7 +746,7 @@ dissect_imf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       /* remove any leading whitespace */
 
       for(value_offset = start_offset; value_offset < end_offset; value_offset++)
-        if(!g_ascii_isspace(tvb_get_guint8(tvb, value_offset))) {
+        if(!isspace(tvb_get_guint8(tvb, value_offset))) {
           break;
         }
 
@@ -766,7 +773,7 @@ dissect_imf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         /* remove 2 bytes to take off the final CRLF to make things a little prettier */
         item = proto_tree_add_item(tree, hf_id, tvb, value_offset, end_offset - value_offset - 2, ENC_ASCII|ENC_NA);
       }
-      if(f_info->add_to_col_info && check_col(pinfo->cinfo, COL_INFO)) {
+      if(f_info->add_to_col_info) {
 
         col_append_fstr(pinfo->cinfo, COL_INFO, "%s: %s, ", f_info->name,
                         tvb_format_text(tvb, value_offset, end_offset - value_offset - 2));
@@ -862,10 +869,14 @@ header_fields_initialize_cb (void)
     /* Unregister all fields */
     for (i = 0; i < hf_size; i++) {
       proto_unregister_field (proto_imf, *(hf[i].p_id));
+
       g_free (hf[i].p_id);
+      g_free ((char *) hf[i].hfinfo.name);
+      g_free ((char *) hf[i].hfinfo.abbrev);
+      g_free ((char *) hf[i].hfinfo.blurb);
     }
     g_hash_table_destroy (custom_field_table);
-    proto_add_deregistered_data (hf);
+    g_free (hf);
     custom_field_table = NULL;
   }
 
@@ -885,7 +896,7 @@ header_fields_initialize_cb (void)
       hf[i].hfinfo.display = BASE_NONE;
       hf[i].hfinfo.strings = NULL;
       hf[i].hfinfo.blurb = g_strdup (header_fields[i].description);
-      hf[i].hfinfo.same_name_prev = NULL;
+      hf[i].hfinfo.same_name_prev_id = -1;
       hf[i].hfinfo.same_name_next = NULL;
 
       imffield = (struct imf_field *)g_malloc (sizeof (struct imf_field));
@@ -1196,6 +1207,10 @@ proto_register_imf(void)
     &ett_imf_message_text,
   };
 
+  static ei_register_info ei[] = {
+     { &ei_imf_unknown_param, { "imf.unknown_param", PI_PROTOCOL, PI_WARN, "Unknown parameter", EXPFILL }},
+  };
+
   static uat_field_t attributes_flds[] = {
     UAT_FLD_CSTRING(header_fields, header_name, "Header name", "IMF header name"),
     UAT_FLD_CSTRING(header_fields, description, "Description", "Description of the value contained in the header"),
@@ -1221,15 +1236,18 @@ proto_register_imf(void)
                                attributes_flds);
 
   module_t *imf_module;
+  expert_module_t* expert_imf;
   struct imf_field *f;
 
   proto_imf = proto_register_protocol(PNAME, PSNAME, PFNAME);
 
   proto_register_field_array(proto_imf, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
+  expert_imf = expert_register_protocol(proto_imf);
+  expert_register_field_array(expert_imf, ei, array_length(ei));
 
   /* Allow dissector to find be found by name. */
-  register_dissector(PFNAME, dissect_imf, proto_imf);
+  imf_handle = register_dissector(PFNAME, dissect_imf, proto_imf);
 
   imf_module = prefs_register_protocol(proto_imf, NULL);
   prefs_register_uat_preference(imf_module, "custom_header_fields", "Custom IMF headers",
@@ -1249,14 +1267,10 @@ proto_register_imf(void)
 void
 proto_reg_handoff_imf(void)
 {
-  dissector_handle_t imf_handle;
-
-  imf_handle = find_dissector(PFNAME);
-
   dissector_add_string("media_type",
                        "message/rfc822", imf_handle);
 
-  register_ber_oid_dissector("1.2.840.113549.1.7.1", dissect_imf, proto_imf, "id-data");
+  register_ber_oid_dissector_handle("1.2.840.113549.1.7.1", imf_handle, proto_imf, "id-data");
 
   /*
    * Get the content type and Internet media type table
