@@ -3,7 +3,7 @@
  * Copyright 2010, Mellanox Technologies Ltd.
  * Code by Amir Vadai and Slava Koyfman.
  *
- * $Id$
+ * $Id: packet-infiniband_sdp.c 52003 2013-09-13 14:14:23Z jmayer $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,6 +31,7 @@
 #include <epan/packet.h>
 #include <epan/prefs.h>
 #include <epan/conversation.h>
+#include <epan/wmem/wmem.h>
 #include <stdlib.h>
 #include <errno.h>
 
@@ -529,8 +530,8 @@ proto_reg_handoff_ib_sdp(void)
         heur_dissector_add("infiniband.mad.cm.private", dissect_ib_sdp, proto_ib_sdp);
 
         /* allocate enough space in the addresses to store the largest address (a GID) */
-        manual_addr_data[0] = se_alloc(GID_SIZE);
-        manual_addr_data[1] = se_alloc(GID_SIZE);
+        manual_addr_data[0] = wmem_alloc(wmem_epan_scope(), GID_SIZE);
+        manual_addr_data[1] = wmem_alloc(wmem_epan_scope(), GID_SIZE);
 
         initialized = TRUE;
     }
@@ -542,9 +543,7 @@ proto_reg_handoff_ib_sdp(void)
         int i;
 
         for (i = 0; i < 2; i++) {
-            if (gPREF_ID[i][0] == '\0') {
-                error_occured = TRUE;
-            } else if (gPREF_TYPE[i] == 0) {   /* LID */
+            if (gPREF_TYPE[i] == 0) {   /* LID */
                 errno = 0;  /* reset any previous error indicators */
                 *((guint16*)manual_addr_data[i]) = (guint16)strtoul(gPREF_ID[i], &not_parsed, 0);
                 if (errno || *not_parsed != '\0') {
@@ -553,7 +552,7 @@ proto_reg_handoff_ib_sdp(void)
                     SET_ADDRESS(&manual_addr[i], AT_IB, sizeof(guint16), manual_addr_data[i]);
                 }
             } else {    /* GID */
-                if (! inet_pton(AF_INET6, gPREF_ID[i], manual_addr_data[i]) ) {
+                if (inet_pton(AF_INET6, gPREF_ID[i], manual_addr_data[i]) <= 0) {
                     error_occured = TRUE;
                 } else {
                     SET_ADDRESS(&manual_addr[i], AT_IB, GID_SIZE, manual_addr_data[i]);
@@ -569,4 +568,3 @@ proto_reg_handoff_ib_sdp(void)
 
     }
 }
-
