@@ -2,7 +2,7 @@
  * Routines for IPARS/ALC (International Passenger Airline Reservation System/Airline Link Control) WAN protocol dissection
  * Copyright 2007, Fulko Hew, SITA INC Canada, Inc.
  *
- * $Id$
+ * $Id: packet-ipars.c 52002 2013-09-13 10:13:19Z jmayer $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,7 +31,7 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 
 static int      proto_ipars     = -1;
 static guint8   ipars_eomtype   = G_MAXUINT8;
@@ -58,7 +58,7 @@ dissect_ipars(tvbuff_t *tvb, packet_info *pinfo _U_ , proto_tree *tree)
     int         offset = 0;
     gchar       *eom_msg;
 
-    eom_msg = (gchar *)ep_alloc(MAX_EOM_MSG_SIZE);
+    eom_msg = (gchar *)wmem_alloc(wmem_packet_scope(), MAX_EOM_MSG_SIZE);
     eom_msg[0] = 0;
 
     col_clear(pinfo->cinfo, COL_INFO);
@@ -77,35 +77,28 @@ dissect_ipars(tvbuff_t *tvb, packet_info *pinfo _U_ , proto_tree *tree)
 
     if (ia == 0x83 || ia == 0x43 || ia == GA) { /* if it's an FPGA or 'corresponsdance code' 'go ahead'... */
         if (tvb_length_remaining(tvb, offset) > 2) { /* if the msg is long, it must have been a 'poll' */
-            if (check_col(pinfo->cinfo, COL_INFO))
-                col_add_fstr(pinfo->cinfo, COL_INFO, "Poll IA: %2.2X", ta);
+            col_add_fstr(pinfo->cinfo, COL_INFO, "Poll IA: %2.2X", ta);
         } else { /* if it's short, then it was a 'no traffic' response */
             if (tvb_length_remaining(tvb, offset) >= 2 ) {
-                if (check_col(pinfo->cinfo, COL_INFO))
-                    col_add_fstr(pinfo->cinfo, COL_INFO, "GoAhead NextIA (0x%2.2X)", ta);
+                col_add_fstr(pinfo->cinfo, COL_INFO, "GoAhead NextIA (0x%2.2X)", ta);
             } else {
-                if (check_col(pinfo->cinfo, COL_INFO))
-                    col_set_str(pinfo->cinfo, COL_INFO, "GoAhead NextIA");
+                col_set_str(pinfo->cinfo, COL_INFO, "GoAhead NextIA");
             }
         }
     } else { /* if it's not a 'go ahead'... it must be some kind of data message */
         ia &= 0x3f;
         ta &= 0x3f;
         if (ta == 0x20) {
-            if (check_col(pinfo->cinfo, COL_INFO))
-                col_add_fstr(pinfo->cinfo, COL_INFO, "Reset IA: %2.2X", ia); /* the TA character was the 'reset' command */
+            col_add_fstr(pinfo->cinfo, COL_INFO, "Reset IA: %2.2X", ia); /* the TA character was the 'reset' command */
         }
         if (tvb_length_remaining(tvb, offset) >= 3) cmd = tvb_get_guint8(tvb, offset + 2) & 0x3f;   /* get the first two bytes of the data message */
         if (tvb_length_remaining(tvb, offset) >= 4) la  = tvb_get_guint8(tvb, offset + 3) & 0x3f;
         if (cmd == 0x1f && la == 0x38) {
-            if (check_col(pinfo->cinfo, COL_INFO))
-                col_add_fstr(pinfo->cinfo, COL_INFO, "Please Resend - IA: %2.2X TA: %2.2X", ia, ta); /* light the resend indicator */
+            col_add_fstr(pinfo->cinfo, COL_INFO, "Please Resend - IA: %2.2X TA: %2.2X", ia, ta); /* light the resend indicator */
         } else if (cmd == 0x2a && la == 0x05) {
-            if (check_col(pinfo->cinfo, COL_INFO))
-                col_add_fstr(pinfo->cinfo, COL_INFO, "Unsolicited Msg Indicator - IA: %2.2X TA: %2.2X", ia, ta);    /* light the unsolicited msg indicator */
+            col_add_fstr(pinfo->cinfo, COL_INFO, "Unsolicited Msg Indicator - IA: %2.2X TA: %2.2X", ia, ta);    /* light the unsolicited msg indicator */
         } else {
-            if (check_col(pinfo->cinfo, COL_INFO))
-                col_add_fstr(pinfo->cinfo, COL_INFO, "Data Msg - IA: %2.2X TA: %2.2X", ia, ta); /* it was a data message (display or printer */
+            col_add_fstr(pinfo->cinfo, COL_INFO, "Data Msg - IA: %2.2X TA: %2.2X", ia, ta); /* it was a data message (display or printer */
         }
     }
 
@@ -119,8 +112,7 @@ dissect_ipars(tvbuff_t *tvb, packet_info *pinfo _U_ , proto_tree *tree)
 
             if (ia == 0x03) {
                 proto_tree_add_protocol_format(ipars_tree, proto_ipars, tvb, 0, 1, "GoAhead Next IA");
-                if (check_col(pinfo->cinfo, COL_INFO))
-                    col_set_str(pinfo->cinfo, COL_INFO, "GoAhead");
+                col_set_str(pinfo->cinfo, COL_INFO, "GoAhead");
                 return;
             } else if (ia != S1) {
                 proto_tree_add_protocol_format(ipars_tree, proto_ipars, tvb,
@@ -152,7 +144,6 @@ dissect_ipars(tvbuff_t *tvb, packet_info *pinfo _U_ , proto_tree *tree)
                     default:    g_snprintf(eom_msg, MAX_EOM_MSG_SIZE, "Unknown EOM type (0x%2.2X)", ia);    break;
                 }
                 proto_tree_add_protocol_format(ipars_tree, proto_ipars, tvb, 4, 1, "%s", eom_msg);
-                ia = tvb_get_guint8(tvb, 5) & 0x3f;
                 proto_tree_add_protocol_format(ipars_tree, proto_ipars, tvb, 5, 1, "Good BCC");
             } else {
                 next_tvb = tvb_new_subset_remaining(tvb, 3);
@@ -179,3 +170,16 @@ proto_register_ipars(void)
 
     register_dissector("ipars", dissect_ipars, proto_ipars);
 }
+
+/*
+ * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ *
+ * Local variables:
+ * c-basic-offset: 4
+ * tab-width: 4
+ * indent-tabs-mode: nil
+ * End:
+ *
+ * vi: set shiftwidth=4 tabstop=4 expandtab:
+ * :indentSize=4:tabSize=8:noTabs=true:
+ */
