@@ -1,7 +1,7 @@
 /* packet-ipsec.c
  * Routines for IPsec/IPComp packet disassembly
  *
- * $Id$
+ * $Id: packet-ipsec.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -82,6 +82,8 @@ ADD: Additional generic (non-checked) ICV length of 128, 192 and 256.
 #include <epan/addr_resolv.h>
 #include <epan/ipproto.h>
 #include <epan/prefs.h>
+#include <epan/tap.h>
+#include <epan/exported_pdu.h>
 
 #include <ctype.h>
 
@@ -113,6 +115,8 @@ static gint ett_esp = -1;
 static gint ett_esp_icv = -1;
 static gint ett_ipcomp = -1;
 
+static gint exported_pdu_tap = -1;
+
 static dissector_handle_t data_handle;
 
 static dissector_table_t ip_dissector_table;
@@ -366,7 +370,7 @@ static int get_ipv6_suffix(char* ipv6_suffix, char *ipv6_address)
 	    }
 	  else
 	    {
-	      suffix[IPSEC_STRLEN_IPV6 -1 -cpt_suffix] = g_ascii_toupper(ipv6_address[ipv6_len - cpt - 1]);
+	      suffix[IPSEC_STRLEN_IPV6 -1 -cpt_suffix] = toupper(ipv6_address[ipv6_len - cpt - 1]);
 	      cpt_seg ++;
 	      cpt_suffix ++;
 	      cpt++;
@@ -853,6 +857,23 @@ get_esp_sa(gint protocol_typ, gchar *src,  gchar *dst,  gint spi,
 }
 #endif
 
+static void
+export_ipsec_pdu(dissector_handle_t dissector_handle, packet_info *pinfo, tvbuff_t *tvb)
+{
+  if (have_tap_listener(exported_pdu_tap)) {
+    exp_pdu_data_t *exp_pdu_data;
+
+    exp_pdu_data = load_export_pdu_tags(pinfo, dissector_handle_get_dissector_name(dissector_handle), -1,
+                                        (EXP_PDU_TAG_IP_SRC_BIT | EXP_PDU_TAG_IP_DST_BIT | EXP_PDU_TAG_SRC_PORT_BIT |
+                                         EXP_PDU_TAG_DST_PORT_BIT | EXP_PDU_TAG_ORIG_FNO_BIT));
+
+    exp_pdu_data->tvb_length = tvb_length(tvb);
+    exp_pdu_data->pdu_tvb = tvb;
+
+    tap_queue_packet(exported_pdu_tap, pinfo, exp_pdu_data);
+  }
+}
+
 static void
 dissect_ah(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
@@ -860,6 +881,8 @@ dissect_ah(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   guint8 nxt;
   tvbuff_t *next_tvb;
   int advance;
+  dissector_handle_t dissector_handle;
+  guint32 saved_match_uint;
 
   advance = dissect_ah_header(tvb, pinfo, tree, &nxt, &next_tree);
   next_tvb = tvb_new_subset_remaining(tvb, advance);
@@ -869,9 +892,16 @@ dissect_ah(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   }
 
   /* do lookup with the subdissector table */
-  if (!dissector_try_uint(ip_dissector_table, nxt, next_tvb, pinfo, tree)) {
-    call_dissector(data_handle,next_tvb, pinfo, next_tree);
+  saved_match_uint  = pinfo->match_uint;
+  dissector_handle = dissector_get_uint_handle(ip_dissector_table, nxt);
+  if (dissector_handle) {
+    pinfo->match_uint = nxt;
+  } else {
+    dissector_handle = data_handle;
   }
+  export_ipsec_pdu(dissector_handle, pinfo, next_tvb);
+  call_dissector(dissector_handle, next_tvb, pinfo, next_tree);
+  pinfo->match_uint = saved_match_uint;
 }
 
 int
@@ -889,10 +919,8 @@ dissect_ah_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     tvb_memcpy(tvb, (guint8 *)&ah, 0, sizeof(ah));
     advance = (int)sizeof(ah) + ((ah.ah_len - 1) << 2);
 
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-        col_add_fstr(pinfo->cinfo, COL_INFO, "AH (SPI=0x%08x)",
+    col_add_fstr(pinfo->cinfo, COL_INFO, "AH (SPI=0x%08x)",
             (guint32)g_ntohl(ah.ah_spi));
-    }
 
     if (tree) {
         /* !!! specify length */
@@ -1031,6 +1059,9 @@ dissect_esp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     guint encapsulated_protocol = 0;
     gboolean decrypt_dissect_ok = FALSE;
+    tvbuff_t *next_tvb;
+    dissector_handle_t dissector_handle;
+    guint32 saved_match_uint;
 
 #ifdef HAVE_LIBGCRYPT
     gboolean get_address_ok = FALSE;
@@ -1089,10 +1120,8 @@ dissect_esp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     tvb_memcpy(tvb, (guint8 *)&esp, 0, sizeof(esp));
 
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-        col_add_fstr(pinfo->cinfo, COL_INFO, "ESP (SPI=0x%08x)",
-            (guint32)g_ntohl(esp.esp_spi));
-    }
+    col_add_fstr(pinfo->cinfo, COL_INFO, "ESP (SPI=0x%08x)",
+        (guint32)g_ntohl(esp.esp_spi));
 
 
     /*
@@ -1797,15 +1826,17 @@ dissect_esp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                                 /* Get the encapsulated protocol */
                                 encapsulated_protocol = tvb_get_guint8(tvb_decrypted, decrypted_len - esp_iv_len - esp_auth_len - 1);
 
-                                if(dissector_try_uint(ip_dissector_table,
-                                    encapsulated_protocol,
-                                    tvb_new_subset(tvb_decrypted, 0,
-                                    decrypted_len - esp_auth_len - esp_pad_len - esp_iv_len - 2,
-                                    decrypted_len - esp_auth_len - esp_pad_len - esp_iv_len - 2),
-                                    pinfo,
-                                    tree))
-                                {
-                                    decrypt_dissect_ok = TRUE;
+                                dissector_handle = dissector_get_uint_handle(ip_dissector_table, encapsulated_protocol);
+                                if (dissector_handle) {
+                                  saved_match_uint  = pinfo->match_uint;
+                                  pinfo->match_uint = encapsulated_protocol;
+                                  next_tvb = tvb_new_subset(tvb_decrypted, 0,
+                                                            decrypted_len - esp_auth_len - esp_pad_len - esp_iv_len - 2,
+                                                            decrypted_len - esp_auth_len - esp_pad_len - esp_iv_len - 2);
+                                  export_ipsec_pdu(dissector_handle, pinfo, next_tvb);
+                                  call_dissector(dissector_handle, next_tvb, pinfo, tree);
+                                  pinfo->match_uint = saved_match_uint;
+                                  decrypt_dissect_ok = TRUE;
                                 }
                             }
                         }
@@ -1842,11 +1873,11 @@ dissect_esp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                         }
                         else
                         {
-                            call_dissector(data_handle,
-                                tvb_new_subset(tvb_decrypted, 0,
+                            next_tvb = tvb_new_subset(tvb_decrypted, 0,
                                 decrypted_len - esp_iv_len - esp_auth_len,
-                                decrypted_len - esp_iv_len - esp_auth_len),
-                                pinfo, esp_tree);
+                                decrypted_len - esp_iv_len - esp_auth_len);
+                            export_ipsec_pdu(data_handle, pinfo, next_tvb);
+                            call_dissector(data_handle, next_tvb, pinfo, esp_tree);
 
                             if(esp_tree)
                                 dissect_esp_authentication(esp_tree,
@@ -1876,9 +1907,9 @@ dissect_esp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     */
     if(!g_esp_enable_encryption_decode && g_esp_enable_authentication_check && sad_is_present)
     {
-        call_dissector(data_handle,
-            tvb_new_subset(tvb, (int)sizeof(struct newesp), len - (int)sizeof(struct newesp) - esp_auth_len, -1),
-            pinfo, esp_tree);
+        next_tvb = tvb_new_subset(tvb, (int)sizeof(struct newesp), len - (int)sizeof(struct newesp) - esp_auth_len, -1);
+        export_ipsec_pdu(data_handle, pinfo, next_tvb);
+        call_dissector(data_handle, next_tvb, pinfo, esp_tree);
 
         if(esp_tree)
             dissect_esp_authentication(esp_tree, tvb, len ,
@@ -1902,16 +1933,16 @@ dissect_esp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             {
                 esp_pad_len = tvb_get_guint8(tvb, len - 14);
                 encapsulated_protocol = tvb_get_guint8(tvb, len - 13);
-                if(dissector_try_uint(ip_dissector_table,
-                    encapsulated_protocol,
-                    tvb_new_subset(tvb,
-                    (int)sizeof(struct newesp),
-                    -1,
-                    len - (int)sizeof(struct newesp) - 14 - esp_pad_len),
-                    pinfo,
-                    tree))
-                {
-                    decrypt_dissect_ok = TRUE;
+                dissector_handle = dissector_get_uint_handle(ip_dissector_table, encapsulated_protocol);
+                if (dissector_handle) {
+                  saved_match_uint  = pinfo->match_uint;
+                  pinfo->match_uint = encapsulated_protocol;
+                  next_tvb = tvb_new_subset(tvb, (int)sizeof(struct newesp), -1,
+                                            len - (int)sizeof(struct newesp) - 14 - esp_pad_len);
+                  export_ipsec_pdu(dissector_handle, pinfo, next_tvb);
+                  call_dissector(dissector_handle, next_tvb, pinfo, tree);
+                  pinfo->match_uint = saved_match_uint;
+                  decrypt_dissect_ok = TRUE;
                 }
             }
         }
@@ -1956,6 +1987,8 @@ dissect_ipcomp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   proto_item *ti;
   struct ipcomp ipcomp;
   const char *p;
+  dissector_handle_t dissector_handle;
+  guint32 saved_match_uint;
 
   /*
    * load the top pane info. This should be overwritten by
@@ -1966,13 +1999,11 @@ dissect_ipcomp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   tvb_memcpy(tvb, (guint8 *)&ipcomp, 0, sizeof(ipcomp));
 
-  if (check_col(pinfo->cinfo, COL_INFO)) {
-    p = try_val_to_str(g_ntohs(ipcomp.comp_cpi), cpi2val);
-    if (p == NULL) {
-      col_add_fstr(pinfo->cinfo, COL_INFO, "IPComp (CPI=0x%04x)",
-		   g_ntohs(ipcomp.comp_cpi));
-    } else
-      col_add_fstr(pinfo->cinfo, COL_INFO, "IPComp (CPI=%s)", p);
+  p = try_val_to_str(g_ntohs(ipcomp.comp_cpi), cpi2val);
+  if (p == NULL) {
+    col_add_fstr(pinfo->cinfo, COL_INFO, "IPComp (CPI=0x%04x)", g_ntohs(ipcomp.comp_cpi));
+  } else {
+    col_add_fstr(pinfo->cinfo, COL_INFO, "IPComp (CPI=%s)", p);
   }
 
   /*
@@ -1997,6 +2028,7 @@ dissect_ipcomp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			g_ntohs(ipcomp.comp_cpi));
 
     data = tvb_new_subset_remaining(tvb, sizeof(struct ipcomp));
+    export_ipsec_pdu(data_handle, pinfo, data);
     call_dissector(data_handle, data, pinfo, ipcomp_tree);
 
     /*
@@ -2007,8 +2039,16 @@ dissect_ipcomp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     decomp = tvb_child_uncompress(data, data, 0, tvb_length(data));
     if (decomp) {
         add_new_data_source(pinfo, decomp, "IPcomp inflated data");
-        if (!dissector_try_uint(ip_dissector_table, ipcomp.comp_nxt, decomp, pinfo, tree))
-            call_dissector(data_handle, decomp, pinfo, tree);
+        saved_match_uint  = pinfo->match_uint;
+        dissector_handle = dissector_get_uint_handle(ip_dissector_table, ipcomp.comp_nxt);
+        if (dissector_handle) {
+          pinfo->match_uint = ipcomp.comp_nxt;
+        } else {
+          dissector_handle = data_handle;
+        }
+        export_ipsec_pdu(dissector_handle, pinfo, decomp);
+        call_dissector(dissector_handle, decomp, pinfo, tree);
+        pinfo->match_uint = saved_match_uint;
     }
   }
 }
@@ -2205,7 +2245,6 @@ proto_reg_handoff_ipsec(void)
   dissector_add_uint("ip.proto", IP_PROTO_IPCOMP, ipcomp_handle);
 
   ip_dissector_table = find_dissector_table("ip.proto");
+
+  exported_pdu_tap = find_tap_id(EXPORT_PDU_TAP_NAME_LAYER_3);
 }
-
-
-
