@@ -6,7 +6,7 @@
  * Portions Copyright (c) 2000-2002 by Gilbert Ramirez.
  * Portions Copyright (c) Novell, Inc. 2002-2003
  *
- * $Id$
+ * $Id: packet-ipx.c 52098 2013-09-16 10:39:06Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -41,7 +41,7 @@
 #include <epan/arcnet_pids.h>
 #include <epan/conversation.h>
 #include <epan/tap.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 
 static int ipx_tap = -1;
 
@@ -282,8 +282,7 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	SET_ADDRESS(&pinfo->dst,	AT_IPX, 10, dst_net_node);
 	SET_ADDRESS(&ipxh->ipx_dst,	AT_IPX, 10, dst_net_node);
 
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_add_fstr(pinfo->cinfo, COL_INFO, "%s (0x%04x)",
+	col_add_fstr(pinfo->cinfo, COL_INFO, "%s (0x%04x)",
 				socket_text(ipxh->ipx_dsocket), ipxh->ipx_dsocket);
 
 	if (tree) {
@@ -304,8 +303,8 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	PROTO_ITEM_SET_HIDDEN(hidden_item);
 
 	proto_tree_add_item(ipx_tree, hf_ipx_checksum, tvb, 0, 2, ENC_BIG_ENDIAN);
-	proto_tree_add_uint_format(ipx_tree, hf_ipx_len, tvb, 2, 2, ipxh->ipx_length,
-		"Length: %d bytes", ipxh->ipx_length);
+	proto_tree_add_uint_format_value(ipx_tree, hf_ipx_len, tvb, 2, 2, ipxh->ipx_length,
+		"%d bytes", ipxh->ipx_length);
 	ipx_hops = tvb_get_guint8(tvb, 4);
 	proto_tree_add_uint_format(ipx_tree, hf_ipx_hops, tvb, 4, 1, ipx_hops,
 		"Transport Control: %d hops", ipx_hops);
@@ -488,12 +487,12 @@ spx_hash_insert(conversation_t *conversation, guint32 spx_src, guint16 spx_seq)
 	spx_hash_value		*value;
 
 	/* Now remember the packet, so we can find it if we later. */
-	key = se_new(spx_hash_key);
+	key = wmem_new(wmem_file_scope(), spx_hash_key);
 	key->conversation = conversation;
 	key->spx_src = spx_src;
 	key->spx_seq = spx_seq;
 
-	value = se_new0(spx_hash_value);
+	value = wmem_new0(wmem_file_scope(), spx_hash_value);
 
 	g_hash_table_insert(spx_hash, key, value);
 
@@ -592,12 +591,11 @@ dissect_spx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	conn_ctrl = tvb_get_guint8(tvb, 0);
 	spx_msg_string = spx_conn_ctrl(conn_ctrl);
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_append_fstr(pinfo->cinfo, COL_INFO, " %s", spx_msg_string);
+	col_append_fstr(pinfo->cinfo, COL_INFO, " %s", spx_msg_string);
 	if (tree) {
-		ti = proto_tree_add_uint_format(spx_tree, hf_spx_connection_control, tvb,
+		ti = proto_tree_add_uint_format_value(spx_tree, hf_spx_connection_control, tvb,
 						0, 1, conn_ctrl,
-						"Connection Control: %s (0x%02X)",
+						"%s (0x%02X)",
 						spx_msg_string, conn_ctrl);
 		cc_tree = proto_item_add_subtree(ti, ett_spx_connctrl);
 		proto_tree_add_boolean(cc_tree, hf_spx_connection_control_sys, tvb,
@@ -613,21 +611,20 @@ dissect_spx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	datastream_type = tvb_get_guint8(tvb, 1);
 	datastream_type_string = spx_datastream(datastream_type);
 	if (datastream_type_string != NULL) {
-		if (check_col(pinfo->cinfo, COL_INFO))
-			col_append_fstr(pinfo->cinfo, COL_INFO, " (%s)",
+		col_append_fstr(pinfo->cinfo, COL_INFO, " (%s)",
 			    datastream_type_string);
 	}
 	if (tree) {
 		if (datastream_type_string != NULL) {
-			proto_tree_add_uint_format(spx_tree, hf_spx_datastream_type, tvb,
+			proto_tree_add_uint_format_value(spx_tree, hf_spx_datastream_type, tvb,
 						   1, 1, datastream_type,
-						   "Datastream Type: %s (0x%02X)",
+						   "%s (0x%02X)",
 						   datastream_type_string,
 						   datastream_type);
 		} else {
-			proto_tree_add_uint_format(spx_tree, hf_spx_datastream_type, tvb,
+			proto_tree_add_uint_format_value(spx_tree, hf_spx_datastream_type, tvb,
 						   1, 1, datastream_type,
-						   "Datastream Type: 0x%02X",
+						   "0x%02X",
 						   datastream_type);
 		}
 		proto_tree_add_item(spx_tree, hf_spx_src_id, tvb,  2, 2, ENC_BIG_ENDIAN);
@@ -728,7 +725,7 @@ dissect_spx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				 * Found in the hash table.  Mark this frame as
 				 * a retransmission.
 				 */
-				spx_rexmit_info_p = se_new(spx_rexmit_info);
+				spx_rexmit_info_p = wmem_new(wmem_file_scope(), spx_rexmit_info);
 				spx_rexmit_info_p->num = pkt_value->num;
 				p_add_proto_data(pinfo->fd, proto_spx, 0,
 				    spx_rexmit_info_p);
@@ -751,11 +748,10 @@ dissect_spx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	 * subdissector.
 	 */
 	if (spx_rexmit_info_p != NULL) {
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_add_fstr(pinfo->cinfo, COL_INFO,
+		col_add_fstr(pinfo->cinfo, COL_INFO,
 			    "[Retransmission] Original Packet %u",
 			    spx_rexmit_info_p->num);
-		}
+
 		if (tree) {
 			proto_tree_add_uint_format(spx_tree, hf_spx_rexmt_frame,
 			    tvb, 0, 0, spx_rexmit_info_p->num,
@@ -837,11 +833,9 @@ dissect_ipxmsg(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	conn_number = tvb_get_guint8(tvb, 0);
 	sig_char = tvb_get_guint8(tvb, 1);
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_add_fstr(pinfo->cinfo, COL_INFO,
+	col_add_fstr(pinfo->cinfo, COL_INFO,
 			"%s, Connection %d",
 			val_to_str_const(sig_char, ipxmsg_sigchar_vals, "Unknown Signature Char"), conn_number);
-	}
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_ipxmsg, tvb, 0, -1, ENC_NA);
@@ -873,10 +867,8 @@ dissect_ipxrip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	operation = tvb_get_ntohs(tvb, 0) - 1;
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		/* rip_types 0 and 1 are valid, anything else becomes 2 or "Unknown" */
-		col_set_str(pinfo->cinfo, COL_INFO, rip_type[MIN(operation, 2)]);
-	}
+	/* rip_types 0 and 1 are valid, anything else becomes 2 or "Unknown" */
+	col_set_str(pinfo->cinfo, COL_INFO, rip_type[MIN(operation, 2)]);
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_ipxrip, tvb, 0, -1, ENC_NA);
@@ -945,15 +937,11 @@ dissect_serialization(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		ser_tree = proto_item_add_subtree(ti, ett_serialization);
 	}
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_add_fstr(pinfo->cinfo, COL_INFO, "Serial number %s",
+	col_add_fstr(pinfo->cinfo, COL_INFO, "Serial number %s",
 		    tvb_bytes_to_str(tvb, 0, 6));
-	}
 
-	if (tree) {
-		proto_tree_add_text(ser_tree, tvb, 0, 6,
+	proto_tree_add_text(ser_tree, tvb, 0, 6,
 		      "Serial number: %s", tvb_bytes_to_str(tvb, 0, 6));
-	}
 }
 
 /*
@@ -1215,13 +1203,11 @@ dissect_ipxsap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	query.query_type = tvb_get_ntohs(tvb, 0);
 	query.server_type = tvb_get_ntohs(tvb, 2);
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		if (query.query_type >= 1 && query.query_type <= 4) {
-			col_set_str(pinfo->cinfo, COL_INFO, sap_type[query.query_type - 1]);
-		}
-		else {
-			col_set_str(pinfo->cinfo, COL_INFO, "Unknown Packet Type");
-		}
+	if (query.query_type >= 1 && query.query_type <= 4) {
+		col_set_str(pinfo->cinfo, COL_INFO, sap_type[query.query_type - 1]);
+	}
+	else {
+		col_set_str(pinfo->cinfo, COL_INFO, "Unknown Packet Type");
 	}
 
 	if (tree) {
@@ -1382,7 +1368,7 @@ proto_register_ipx(void)
 		  NULL, HFILL }},
 
 		{ &hf_spx_datastream_type,
-		{ "Datastream type",	       	"spx.type",
+		{ "Datastream Type",	       	"spx.type",
 		  FT_UINT8,	BASE_HEX,	NULL,	0x0,
 		  NULL, HFILL }},
 
@@ -1515,7 +1501,7 @@ proto_reg_handoff_ipx(void)
 	ipx_handle = find_dissector("ipx");
 	dissector_add_uint("udp.port", UDP_PORT_IPX, ipx_handle);
 	dissector_add_uint("ethertype", ETHERTYPE_IPX, ipx_handle);
-	dissector_add_uint("chdlctype", ETHERTYPE_IPX, ipx_handle);
+    dissector_add_uint("chdlc.protocol", ETHERTYPE_IPX, ipx_handle);
 	dissector_add_uint("ppp.protocol", PPP_IPX, ipx_handle);
 	dissector_add_uint("llc.dsap", SAP_NETWARE1, ipx_handle);
 	dissector_add_uint("llc.dsap", SAP_NETWARE2, ipx_handle);
