@@ -1,6 +1,6 @@
 /* packet-irc.c
  *
- * $Id$
+ * $Id: packet-irc.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -43,6 +43,7 @@
 #include "config.h"
 
 #include <glib.h>
+#include <ctype.h>
 #include <epan/packet.h>
 #include <epan/expert.h>
 
@@ -66,6 +67,13 @@ static gint ett_irc_request_command = -1;
 static gint ett_irc_response = -1;
 static gint ett_irc_response_command = -1;
 
+static expert_field ei_irc_missing_end_delimiter = EI_INIT;
+static expert_field ei_irc_numeric_request_command = EI_INIT;
+static expert_field ei_irc_response_command = EI_INIT;
+static expert_field ei_irc_prefix_missing_ending_space = EI_INIT;
+static expert_field ei_irc_request_command = EI_INIT;
+static expert_field ei_irc_tag_data_invalid = EI_INIT;
+
 /* This must be a null-terminated string */
 static const guint8 TAG_DELIMITER[] = {0x01, 0x00};
 
@@ -91,14 +99,14 @@ dissect_irc_tag_data(proto_tree *tree, proto_item *item, tvbuff_t *tvb, int offs
     tag_end_offset = tvb_pbrk_guint8(tvb, offset, datalen-offset, TAG_DELIMITER, &found_end_needle);
     if (tag_end_offset == -1)
     {
-        expert_add_info_format(pinfo, item, PI_MALFORMED, PI_ERROR, "Missing ending tag delimited (0x01)");
+        expert_add_info(pinfo, item, &ei_irc_missing_end_delimiter);
         return;
     }
 
     if ((strcmp(command, "NOTICE") != 0) &&
        (strcmp(command, "PRIVMSG") != 0))
     {
-        expert_add_info_format(pinfo, item, PI_PROTOCOL, PI_WARN, "Tag data outside of NOTICE or PRIVMSG command");
+        expert_add_info(pinfo, item, &ei_irc_tag_data_invalid);
     }
 
     /* Placeholder to call CTCP dissector, strip out delimiter */
@@ -134,7 +142,7 @@ dissect_irc_request(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int off
         eop_offset = tvb_pbrk_guint8(tvb, offset+1, linelen-1, " ", &found_needle);
         if (eop_offset == -1)
         {
-            expert_add_info_format(pinfo, request_item, PI_MALFORMED, PI_ERROR, "Prefix missing ending <space>");
+            expert_add_info(pinfo, request_item, &ei_irc_prefix_missing_ending_space);
             return;
         }
 
@@ -150,7 +158,7 @@ dissect_irc_request(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int off
     }
     if (offset == end_offset)
     {
-        expert_add_info_format(pinfo, request_item, PI_MALFORMED, PI_ERROR, "Request has no command");
+        expert_add_info(pinfo, request_item, &ei_irc_request_command);
         return;
     }
 
@@ -158,30 +166,30 @@ dissect_irc_request(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int off
     if (eoc_offset == -1)
     {
         proto_tree_add_item(request_tree, hf_irc_request_command, tvb, offset, end_offset-offset, ENC_ASCII|ENC_NA);
-        col_append_fstr( pinfo->cinfo, COL_INFO, " (%s)", tvb_get_ephemeral_string(tvb, offset, end_offset-offset));
+        col_append_fstr( pinfo->cinfo, COL_INFO, " (%s)", tvb_get_string(wmem_packet_scope(), tvb, offset, end_offset-offset));
 
         /* Warn if there is a "numeric" command */
         if ((end_offset-offset == 3) &&
-            (g_ascii_isdigit(tvb_get_guint8(tvb, offset))) &&
-            (g_ascii_isdigit(tvb_get_guint8(tvb, offset+1))) &&
-            (g_ascii_isdigit(tvb_get_guint8(tvb, offset+2))))
+            (isdigit(tvb_get_guint8(tvb, offset))) &&
+            (isdigit(tvb_get_guint8(tvb, offset+1))) &&
+            (isdigit(tvb_get_guint8(tvb, offset+2))))
         {
-            expert_add_info_format(pinfo, request_item, PI_PROTOCOL, PI_WARN, "Numeric command not allowed in request");
+            expert_add_info(pinfo, request_item, &ei_irc_numeric_request_command);
         }
         return;
     }
 
     proto_tree_add_item(request_tree, hf_irc_request_command, tvb, offset, eoc_offset-offset, ENC_ASCII|ENC_NA);
-    str_command = tvb_get_ephemeral_string(tvb, offset, eoc_offset-offset);
+    str_command = tvb_get_string(wmem_packet_scope(), tvb, offset, eoc_offset-offset);
     col_append_fstr( pinfo->cinfo, COL_INFO, " (%s)", str_command);
 
     /* Warn if there is a "numeric" command */
     if ((eoc_offset-offset == 3) &&
-       (g_ascii_isdigit(tvb_get_guint8(tvb, offset))) &&
-       (g_ascii_isdigit(tvb_get_guint8(tvb, offset+1))) &&
-       (g_ascii_isdigit(tvb_get_guint8(tvb, offset+2))))
+       (isdigit(tvb_get_guint8(tvb, offset))) &&
+       (isdigit(tvb_get_guint8(tvb, offset+1))) &&
+       (isdigit(tvb_get_guint8(tvb, offset+2))))
     {
-        expert_add_info_format(pinfo, request_item, PI_PROTOCOL, PI_WARN, "Numeric command not allowed in request");
+        expert_add_info(pinfo, request_item, &ei_irc_numeric_request_command);
     }
 
     found_needle = 0;
@@ -262,7 +270,7 @@ dissect_irc_request(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int off
             tag_end_offset = tvb_pbrk_guint8(tvb, tag_start_offset+1, end_offset-tag_start_offset-1, TAG_DELIMITER, &found_tag_needle);
             if (tag_end_offset == -1)
             {
-                expert_add_info_format(pinfo, request_item, PI_MALFORMED, PI_ERROR, "Missing ending tag delimited (0x01)");
+                expert_add_info(pinfo, request_item, &ei_irc_missing_end_delimiter);
                 return;
             }
 
@@ -302,7 +310,7 @@ dissect_irc_response(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int of
         eop_offset = tvb_pbrk_guint8(tvb, offset+1, linelen-1, " ", &found_needle);
         if (eop_offset == -1)
         {
-            expert_add_info_format(pinfo, response_item, PI_MALFORMED, PI_ERROR, "Prefix missing ending <space>");
+            expert_add_info(pinfo, response_item, &ei_irc_prefix_missing_ending_space);
             return;
         }
 
@@ -318,7 +326,7 @@ dissect_irc_response(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int of
     }
     if (offset == end_offset)
     {
-        expert_add_info_format(pinfo, response_item, PI_MALFORMED, PI_ERROR, "Response has no command");
+        expert_add_info(pinfo, response_item, &ei_irc_response_command);
         return;
     }
 
@@ -326,13 +334,13 @@ dissect_irc_response(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int of
     if (eoc_offset == -1)
     {
         proto_tree_add_item(response_tree, hf_irc_response_command, tvb, offset, end_offset-offset, ENC_ASCII|ENC_NA);
-        col_append_fstr( pinfo->cinfo, COL_INFO, " (%s)", tvb_get_ephemeral_string(tvb, offset, end_offset-offset));
+        col_append_fstr( pinfo->cinfo, COL_INFO, " (%s)", tvb_get_string(wmem_packet_scope(), tvb, offset, end_offset-offset));
 
         /* if response command is numeric, allow it to be filtered as an integer */
         if ((end_offset-offset == 3) &&
-            (g_ascii_isdigit(tvb_get_guint8(tvb, offset))) &&
-            (g_ascii_isdigit(tvb_get_guint8(tvb, offset+1))) &&
-            (g_ascii_isdigit(tvb_get_guint8(tvb, offset+2))))
+            (isdigit(tvb_get_guint8(tvb, offset))) &&
+            (isdigit(tvb_get_guint8(tvb, offset+1))) &&
+            (isdigit(tvb_get_guint8(tvb, offset+2))))
         {
             num_command = ((tvb_get_guint8(tvb, offset)-0x30)*100) + ((tvb_get_guint8(tvb, offset+1)-0x30)*10) + (tvb_get_guint8(tvb, offset+2)-0x30);
             hidden_item = proto_tree_add_uint(response_tree, hf_irc_response_num_command, tvb, offset, end_offset-offset, num_command);
@@ -342,14 +350,14 @@ dissect_irc_response(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int of
     }
 
     proto_tree_add_item(response_tree, hf_irc_response_command, tvb, offset, eoc_offset-offset, ENC_ASCII|ENC_NA);
-    str_command = tvb_get_ephemeral_string(tvb, offset, eoc_offset-offset);
+    str_command = tvb_get_string(wmem_packet_scope(), tvb, offset, eoc_offset-offset);
     col_append_fstr( pinfo->cinfo, COL_INFO, " (%s)", str_command);
 
     /* if response command is numeric, allow it to be filtered as an integer */
     if ((eoc_offset-offset == 3) &&
-       (g_ascii_isdigit(tvb_get_guint8(tvb, offset))) &&
-       (g_ascii_isdigit(tvb_get_guint8(tvb, offset+1))) &&
-       (g_ascii_isdigit(tvb_get_guint8(tvb, offset+2))))
+       (isdigit(tvb_get_guint8(tvb, offset))) &&
+       (isdigit(tvb_get_guint8(tvb, offset+1))) &&
+       (isdigit(tvb_get_guint8(tvb, offset+2))))
     {
         num_command = ((tvb_get_guint8(tvb, offset)-0x30)*100) + ((tvb_get_guint8(tvb, offset+1)-0x30)*10) + (tvb_get_guint8(tvb, offset+2)-0x30);
         hidden_item = proto_tree_add_uint(response_tree, hf_irc_response_num_command, tvb, offset, eoc_offset-offset, num_command);
@@ -431,7 +439,7 @@ dissect_irc_response(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int of
             tag_end_offset = tvb_pbrk_guint8(tvb, tag_start_offset+1, end_offset-tag_start_offset-1, TAG_DELIMITER, &found_tag_needle);
             if (tag_end_offset == -1)
             {
-                expert_add_info_format(pinfo, response_item, PI_MALFORMED, PI_ERROR, "Missing ending tag delimited (0x01)");
+                expert_add_info(pinfo, response_item, &ei_irc_missing_end_delimiter);
                 return;
             }
 
@@ -451,11 +459,8 @@ dissect_irc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "IRC");
 
-    if (check_col(pinfo->cinfo, COL_INFO))
-    {
-        col_set_str(pinfo->cinfo, COL_INFO,
-            (pinfo->match_uint == pinfo->destport) ? "Request" : "Response");
-    }
+    col_set_str(pinfo->cinfo, COL_INFO,
+        (pinfo->match_uint == pinfo->destport) ? "Request" : "Response");
 
     ti = proto_tree_add_item(tree, proto_irc, tvb, 0, -1, ENC_NA);
     irc_tree = proto_item_add_subtree(ti, ett_irc);
@@ -524,7 +529,7 @@ proto_register_irc(void)
         { &hf_irc_response_command, { "Command", "irc.response.command", FT_STRING, BASE_NONE,
           NULL, 0x0, "Response command", HFILL }},
 
-        { &hf_irc_response_num_command, { "Command", "irc.response.num_command", FT_UINT16, BASE_DEC,
+        { &hf_irc_response_num_command, { "Command", "irc.response.command", FT_UINT16, BASE_DEC,
           NULL, 0x0, "Response (numeric) command", HFILL }},
 
         { &hf_irc_response_command_param, { "Parameter", "irc.response.command_parameter", FT_STRING, BASE_NONE,
@@ -545,9 +550,22 @@ proto_register_irc(void)
         &ett_irc_response_command
     };
 
+    static ei_register_info ei[] = {
+        { &ei_irc_missing_end_delimiter, { "irc.missing_end_delimiter", PI_MALFORMED, PI_ERROR, "Missing ending tag delimiter (0x01)", EXPFILL }},
+        { &ei_irc_tag_data_invalid, { "irc.tag_data_invalid", PI_PROTOCOL, PI_WARN, "Tag data outside of NOTICE or PRIVMSG command", EXPFILL }},
+        { &ei_irc_prefix_missing_ending_space, { "irc.prefix_missing_ending_space", PI_MALFORMED, PI_ERROR, "Prefix missing ending <space>", EXPFILL }},
+        { &ei_irc_request_command, { "irc.request.command.missing", PI_MALFORMED, PI_ERROR, "Request has no command", EXPFILL }},
+        { &ei_irc_numeric_request_command, { "irc.request.command.numeric", PI_PROTOCOL, PI_WARN, "Numeric command not allowed in request", EXPFILL }},
+        { &ei_irc_response_command, { "irc.response.command.missing", PI_MALFORMED, PI_ERROR, "Response has no command", EXPFILL }},
+    };
+
+    expert_module_t* expert_irc;
+
     proto_irc = proto_register_protocol("Internet Relay Chat", "IRC", "irc");
     proto_register_field_array(proto_irc, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_irc = expert_register_protocol(proto_irc);
+    expert_register_field_array(expert_irc, ei, array_length(ei));
 }
 
 void
