@@ -1,7 +1,7 @@
 /* packet-isis-clv.c
  * Common CLV decode routines.
  *
- * $Id$
+ * $Id: packet-isis-clv.c 52172 2013-09-22 15:50:55Z pascal $
  * Stuart Stanley <stuarts@mxmail.net>
  *
  * Wireshark - Network traffic analyzer
@@ -209,7 +209,7 @@ isis_dissect_ip_authentication_clv(tvbuff_t *tvb, proto_tree *tree, int offset,
         if ( length != 0 ) {
                 proto_tree_add_text ( tree, tvb, offset, length,
                         "IP Authentication: %.*s", length,
-                        tvb_get_ephemeral_string(tvb, offset, length) );
+                        tvb_get_string(wmem_packet_scope(), tvb, offset, length) );
         }
 }
 
@@ -243,7 +243,7 @@ isis_dissect_hostname_clv(tvbuff_t *tvb, proto_tree *tree, int offset,
                 proto_tree_add_text ( tree, tvb, offset, length,
                         "Hostname: --none--" );
         } else {
-		const char* value = tvb_get_ephemeral_string(tvb, offset, length);
+		const char* value = tvb_get_string(wmem_packet_scope(), tvb, offset, length);
                 proto_tree_add_string_format ( tree, tree_id,
 			tvb, offset, length,
                         value, "Hostname: %.*s", length, value);
@@ -290,10 +290,10 @@ isis_dissect_mt_clv(tvbuff_t *tvb, proto_tree *tree, int offset, int length,
 		}
 		proto_tree_add_uint_format ( tree, tree_id, tvb, offset, 2,
 			mt_block,
-			"%s Topology (0x%03x)%s%s",
+			"%s Topology (0x%03x), %ssubTLVs present%s",
 				      mt_desc,
 				      mt_block&0xfff,
-				      (mt_block&0x8000) ? "" : ", no sub-TLVs present",
+				      (mt_block&0x8000) ? "" : "no ",
 				      (mt_block&0x4000) ? ", ATT bit set" : "" );
 	    } else {
 		proto_tree_add_text ( tree, tvb, offset, 1,
