@@ -1,7 +1,7 @@
 /* packet-isis-lsp.c
  * Routines for decoding isis lsp packets and their CLVs
  *
- * $Id$
+ * $Id: packet-isis-lsp.c 52591 2013-10-13 19:56:52Z wmeier $
  * Stuart Stanley <stuarts@mxmail.net>
  *
  * Wireshark - Network traffic analyzer
@@ -124,6 +124,8 @@ static gint ett_isis_lsp_clv_rt_capable_IPv4_prefx = -1;   /* CLV 242 */
 static gint ett_isis_lsp_clv_grp_address_IPv4_prefx = -1;  /* CLV 142 */
 static gint ett_isis_lsp_clv_mt_cap_spbv_mac_address = -1;
 
+static expert_field ie_isis_lsp_checksum_bad = EI_INIT;
+
 static const value_string isis_lsp_istype_vals[] = {
 	{ ISIS_LSP_TYPE_UNUSED0,	"Unused 0x0 (invalid)"},
 	{ ISIS_LSP_TYPE_LEVEL_1,	"Level 1"},
@@ -2379,7 +2381,7 @@ dissect_lsp_ext_is_reachability_clv(tvbuff_t *tvb, proto_tree *tree,
 						tvb_get_ntoh24(tvb, offset+13+i) );
 					break;
 				case 29:
-					dissect_subclv_spb_link_metric(tvb, ntree, 
+					dissect_subclv_spb_link_metric(tvb, ntree,
 						offset+13+i, clv_code, clv_len);
 					break;
 				case 250:
@@ -2642,7 +2644,7 @@ static void isis_lsp_checkum_additional_info(tvbuff_t * tvb, packet_info * pinfo
 	                              offset, 2, !is_cksum_correct);
 	PROTO_ITEM_SET_GENERATED(item);
 	if (!is_cksum_correct) {
-		expert_add_info_format(pinfo, item, PI_CHECKSUM, PI_ERROR, "Bad checksum");
+		expert_add_info(pinfo, item, &ie_isis_lsp_checksum_bad);
 		col_append_str(pinfo->cinfo, COL_INFO, " [ISIS CHECKSUM INCORRECT]");
 	}
 }
@@ -2701,26 +2703,23 @@ isis_dissect_isis_lsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int o
 	if (tree) {
 	        char* value = print_system_id( tvb_get_ptr(tvb, offset, id_length+2),
 				    id_length+2);
-		proto_tree_add_string_format(lsp_tree, hf_isis_lsp_lsp_id,
+		proto_tree_add_string_format_value(lsp_tree, hf_isis_lsp_lsp_id,
 			tvb, offset, id_length + 2,
-			value, "LSP-ID: %s", value);
+			value, "%s", value);
 	}
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO, ", LSP-ID: %s",
+	col_append_fstr(pinfo->cinfo, COL_INFO, ", LSP-ID: %s",
 			print_system_id( tvb_get_ptr(tvb, offset, id_length+2), id_length+2 ) );
-	}
+
 	offset += id_length + 2;
 
-	if (tree) {
-		proto_tree_add_item(lsp_tree, hf_isis_lsp_sequence_number,
+	proto_tree_add_item(lsp_tree, hf_isis_lsp_sequence_number,
 			tvb, offset, 4, ENC_BIG_ENDIAN);
-	}
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO, ", Sequence: 0x%08x, Lifetime: %5us",
+
+	col_append_fstr(pinfo->cinfo, COL_INFO, ", Sequence: 0x%08x, Lifetime: %5us",
 			tvb_get_ntohl(tvb, offset),
 			tvb_get_ntohs(tvb, offset - (id_length+2+2)));
-	}
+
 	offset += 4;
 
 	if (tree) {
@@ -2728,8 +2727,8 @@ isis_dissect_isis_lsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int o
 		switch (check_and_get_checksum(tvb, offset_checksum, pdu_length-12, checksum, offset, &cacl_checksum)) {
 			case NO_CKSUM :
 				checksum = tvb_get_ntohs(tvb, offset);
-				proto_tree_add_uint_format(lsp_tree, hf_isis_lsp_checksum, tvb, offset, 2, checksum,
-					"Checksum: 0x%04x [unused]", checksum);
+				proto_tree_add_uint_format_value(lsp_tree, hf_isis_lsp_checksum, tvb, offset, 2, checksum,
+					"0x%04x [unused]", checksum);
 			break;
 			case DATA_MISSING :
 				isis_dissect_unknown(tvb, tree, offset,
@@ -2737,14 +2736,14 @@ isis_dissect_isis_lsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int o
 			 		tvb_length_remaining(tvb, offset_checksum));
 			break;
 			case CKSUM_NOT_OK :
-				it_cksum = proto_tree_add_uint_format(lsp_tree, hf_isis_lsp_checksum, tvb, offset, 2, checksum,
-					"Checksum: 0x%04x [incorrect, should be 0x%04x]",
+				it_cksum = proto_tree_add_uint_format_value(lsp_tree, hf_isis_lsp_checksum, tvb, offset, 2, checksum,
+					"0x%04x [incorrect, should be 0x%04x]",
 					checksum, cacl_checksum);
 				isis_lsp_checkum_additional_info(tvb, pinfo, it_cksum, offset, FALSE);
 			break;
 			case CKSUM_OK :
-				it_cksum = proto_tree_add_uint_format(lsp_tree, hf_isis_lsp_checksum, tvb, offset, 2, checksum,
-					"Checksum: 0x%04x [correct]", checksum);
+				it_cksum = proto_tree_add_uint_format_value(lsp_tree, hf_isis_lsp_checksum, tvb, offset, 2, checksum,
+					"0x%04x [correct]", checksum);
 				isis_lsp_checkum_additional_info(tvb, pinfo, it_cksum, offset, TRUE);
 			break;
 			default :
@@ -2955,6 +2954,14 @@ isis_register_lsp(int proto_isis) {
 		&ett_isis_lsp_clv_mt_cap_spbv_mac_address
 	};
 
+	static ei_register_info ei[] = {
+		{ &ie_isis_lsp_checksum_bad, { "isis.lsp.checksum_bad.expert", PI_CHECKSUM, PI_ERROR, "Bad checksum", EXPFILL }},
+	};
+
+	expert_module_t* expert_isis;
+
 	proto_register_field_array(proto_isis, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	expert_isis = expert_register_protocol(proto_isis);
+	expert_register_field_array(expert_isis, ei, array_length(ei));
 }
