@@ -2,7 +2,7 @@
  * Routines for packet dissection of generic ISO 7816 smart card messages
  * Copyright 2012-2013 by Martin Kaiser <martin@kaiser.cx>
  *
- * $Id$
+ * $Id: packet-iso7816.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -38,13 +38,14 @@
 
 #include <epan/packet.h>
 #include <epan/expert.h>
+#include <epan/wmem/wmem.h>
 
 static int proto_iso7816 = -1;
 static int proto_iso7816_atr = -1;
 
 static dissector_handle_t iso7816_atr_handle;
 
-static emem_tree_t *transactions = NULL;
+static wmem_tree_t *transactions = NULL;
 
 static int ett_iso7816 = -1;
 static int ett_iso7816_class = -1;
@@ -86,6 +87,8 @@ static int hf_iso7816_sel_file_ctrl = -1;
 static int hf_iso7816_sel_file_fci_req = -1;
 static int hf_iso7816_sel_file_occ = -1;
 
+static expert_field ie_iso7816_atr_tck_not1 = EI_INIT;
+
 #define ADDR_INTF "Interface"
 #define ADDR_CARD "Card"
 
@@ -199,15 +202,6 @@ static const range_string iso7816_sw1[] = {
   { 0,0,  NULL }
 };
 
-
-static void
-iso7816_init(void)
-{
-    transactions = se_tree_create_non_persistent(
-            EMEM_TREE_TYPE_RED_BLACK, "iso7816_transactions");
-}
-
-
 static int
 dissect_iso7816_atr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
@@ -326,8 +320,7 @@ dissect_iso7816_atr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *d
     else if (tck_len>1) {
         err_it = proto_tree_add_text(proto_tr, tvb, offset, tck_len,
                 "Invalid TCK byte");
-        expert_add_info_format(pinfo, err_it, PI_PROTOCOL, PI_WARN,
-                "TCK byte must either be absent or exactly one byte");
+        expert_add_info(pinfo, err_it, &ie_iso7816_atr_tck_not1);
     }
 
     proto_item_set_len(proto_it, offset);
@@ -510,7 +503,7 @@ dissect_iso7816_cmd_apdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 
     if (PINFO_FD_VISITED(pinfo)) {
-        iso7816_trans = (iso7816_transaction_t *)se_tree_lookup32(
+        iso7816_trans = (iso7816_transaction_t *)wmem_tree_lookup32(
                 transactions, PINFO_FD_NUM(pinfo));
         if (iso7816_trans && iso7816_trans->cmd_frame==PINFO_FD_NUM(pinfo) &&
                 iso7816_trans->resp_frame!=0) {
@@ -522,17 +515,16 @@ dissect_iso7816_cmd_apdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     }
     else {
         if (transactions) {
-            iso7816_trans = (iso7816_transaction_t *)se_alloc(
-                    sizeof(iso7816_transaction_t));
+            iso7816_trans = wmem_new(wmem_file_scope(), iso7816_transaction_t);
             iso7816_trans->cmd_frame = PINFO_FD_NUM(pinfo);
             iso7816_trans->resp_frame = 0;
             iso7816_trans->cmd_ins = INS_INVALID;
 
-            se_tree_insert32(transactions,
+            wmem_tree_insert32(transactions,
                     iso7816_trans->cmd_frame, (void *)iso7816_trans);
         }
     }
- 
+
     ret = dissect_iso7816_class(tvb, offset, pinfo, tree);
     if (ret==-1) {
         /* the class byte says that the remaining APDU is not
@@ -596,7 +588,7 @@ dissect_iso7816_resp_apdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     if (transactions) {
         /* receive the largest key that is less than or equal to our frame
            number */
-        iso7816_trans = (iso7816_transaction_t *)se_tree_lookup32_le(
+        iso7816_trans = (iso7816_transaction_t *)wmem_tree_lookup32_le(
                 transactions, PINFO_FD_NUM(pinfo));
         if (iso7816_trans) {
             if (iso7816_trans->resp_frame==0) {
@@ -619,7 +611,7 @@ dissect_iso7816_resp_apdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             }
         }
     }
-           
+
     /* - 2 bytes SW1, SW2 */
     body_len = tvb_reported_length_remaining(tvb, offset) - 2;
 
@@ -830,13 +822,22 @@ proto_register_iso7816(void)
         &ett_iso7816_atr_td
     };
 
+    static ei_register_info ei[] = {
+        { &ie_iso7816_atr_tck_not1, { "iso7816.atr.tck.not1", PI_PROTOCOL, PI_WARN, "TCK byte must either be absent or exactly one byte", EXPFILL }}
+    };
+
+    expert_module_t* expert_iso7816;
+
     proto_iso7816 = proto_register_protocol(
             "ISO/IEC 7816", "ISO 7816", "iso7816");
     proto_register_field_array(proto_iso7816, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_iso7816 = expert_register_protocol(proto_iso7816);
+    expert_register_field_array(expert_iso7816, ei, array_length(ei));
 
     new_register_dissector("iso7816", dissect_iso7816, proto_iso7816);
-    register_init_routine(iso7816_init);
+
+    transactions = wmem_tree_new_autoreset(wmem_epan_scope(), wmem_file_scope());
 
     proto_iso7816_atr = proto_register_protocol(
             "ISO/IEC 7816-3", "ISO 7816-3", "iso7816.atr");
