@@ -6,7 +6,7 @@
  *
  * Copyright 2010, Jakub Zawadzki <darkjames-ws@darkjames.pl>
  *
- * $Id$
+ * $Id: packet-json.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,31 +27,55 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#define NEW_PROTO_TREE_API
+
 #include "config.h"
 
 #include <glib.h>
 
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/packet.h>
 #include <epan/tvbparse.h>
 
-static gint proto_json = -1;
-
 static gint ett_json = -1;
 static gint ett_json_array = -1;
 static gint ett_json_object = -1;
 static gint ett_json_member = -1;
 
-static gint hf_json_array = -1;
-static gint hf_json_object = -1;
-static gint hf_json_member = -1;
-/* XXX, static gint hf_json_member_key = -1; */
+static header_field_info *hfi_json = NULL;
+
+#define JSON_HFI_INIT HFI_INIT(proto_json)
+
+static header_field_info hfi_json_array JSON_HFI_INIT =
+	{ "Array", "json.array", FT_NONE, BASE_NONE, NULL, 0x00, "JSON array", HFILL };
+
+static header_field_info hfi_json_object JSON_HFI_INIT =
+	{ "Object", "json.object", FT_NONE, BASE_NONE, NULL, 0x00, "JSON object", HFILL };
+
+static header_field_info hfi_json_member JSON_HFI_INIT =
+	{ "Member", "json.member", FT_NONE, BASE_NONE, NULL, 0x00, "JSON object member", HFILL };
+
+#if 0
+/* XXX */
+static header_field_info hfi_json_member_key JSON_HFI_INIT =
+	{ "Key", "json.member.key", FT_NONE, BASE_NONE, NULL, 0x00, NULL, HFILL };
+#endif
+
+static header_field_info hfi_json_value_string JSON_HFI_INIT = /* FT_STRINGZ? */
+	{ "String value", "json.value.string", FT_STRING, BASE_NONE, NULL, 0x00, "JSON string value", HFILL };
+
+static header_field_info hfi_json_value_number JSON_HFI_INIT = /* FT_DOUBLE/ FT_INT64? */
+	{ "Number value", "json.value.number", FT_STRING, BASE_NONE, NULL, 0x00, "JSON number value", HFILL };
+
+static header_field_info hfi_json_value_false JSON_HFI_INIT =
+	{ "False value", "json.value.false", FT_NONE, BASE_NONE, NULL, 0x00, "JSON false value", HFILL };
+
+static header_field_info hfi_json_value_null JSON_HFI_INIT =
+	{ "Null value", "json.value.null", FT_NONE, BASE_NONE, NULL, 0x00, "JSON null value", HFILL };
+
+static header_field_info hfi_json_value_true JSON_HFI_INIT =
+	{ "True value", "json.value.true", FT_NONE, BASE_NONE, NULL, 0x00, "JSON true value", HFILL };
 
-static gint hf_json_value_string = -1;
-static gint hf_json_value_number = -1;
-static gint hf_json_value_false = -1;
-static gint hf_json_value_null = -1;
-static gint hf_json_value_true = -1;
 
 static tvbparse_wanted_t* want;
 static tvbparse_wanted_t* want_ignore;
@@ -73,7 +97,7 @@ typedef enum {
 } json_token_type_t;
 
 typedef struct {
-	ep_stack_t stack;
+	wmem_stack_t *stack;
 
 } json_parser_data_t;
 
@@ -104,7 +128,7 @@ dissect_json(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	}
 
 	if (tree) {
-		ti = proto_tree_add_item(tree, proto_json, tvb, 0, -1, ENC_NA);
+		ti = proto_tree_add_item(tree, hfi_json, tvb, 0, -1, ENC_NA);
 		json_tree = proto_item_add_subtree(ti, ett_json);
 
 		if (data_name)
@@ -112,9 +136,9 @@ dissect_json(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	}
 
 	offset = 0;
-	
-	parser_data.stack = ep_stack_new();
-	ep_stack_push(parser_data.stack, json_tree);
+
+	parser_data.stack = wmem_stack_new(wmem_packet_scope());
+	wmem_stack_push(parser_data.stack, json_tree);
 
 	tt = tvbparse_init(tvb, offset, -1, &parser_data, want_ignore);
 
@@ -130,7 +154,7 @@ dissect_json(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if (tvb_length_remaining(tvb, offset) > 0) {
 		int datalen, reported_datalen;
 		tvbuff_t *next_tvb;
-		
+
 		datalen = tvb_length_remaining(tvb, offset);
 		reported_datalen = tvb_reported_length_remaining(tvb, offset);
 
@@ -145,69 +169,69 @@ dissect_json(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 static void before_object(void *tvbparse_data, const void *wanted_data _U_, tvbparse_elem_t *tok) {
 	json_parser_data_t *data = (json_parser_data_t *) tvbparse_data;
 
-	proto_tree *tree = (proto_tree *)ep_stack_peek(data->stack);
+	proto_tree *tree = (proto_tree *)wmem_stack_peek(data->stack);
 	proto_tree *subtree;
 	proto_item *ti;
 
-	ti = proto_tree_add_item(tree, hf_json_object, tok->tvb, tok->offset, tok->len, ENC_NA);
+	ti = proto_tree_add_item(tree, &hfi_json_object, tok->tvb, tok->offset, tok->len, ENC_NA);
 
 	subtree = proto_item_add_subtree(ti, ett_json_object);
-	ep_stack_push(data->stack, subtree);
+	wmem_stack_push(data->stack, subtree);
 }
 
 static void after_object(void *tvbparse_data, const void *wanted_data _U_, tvbparse_elem_t *elem _U_) {
 	json_parser_data_t *data = (json_parser_data_t *) tvbparse_data;
 
-	ep_stack_pop(data->stack);
+	wmem_stack_pop(data->stack);
 }
 
 static void before_member(void *tvbparse_data, const void *wanted_data _U_, tvbparse_elem_t *tok) {
 	json_parser_data_t *data = (json_parser_data_t *) tvbparse_data;
 
-	proto_tree *tree = (proto_tree *)ep_stack_peek(data->stack);
+	proto_tree *tree = (proto_tree *)wmem_stack_peek(data->stack);
 	proto_tree *subtree;
 	proto_item *ti;
 
-	ti = proto_tree_add_item(tree, hf_json_member, tok->tvb, tok->offset, tok->len, ENC_NA);
+	ti = proto_tree_add_item(tree, &hfi_json_member, tok->tvb, tok->offset, tok->len, ENC_NA);
 
 	subtree = proto_item_add_subtree(ti, ett_json_member);
-	ep_stack_push(data->stack, subtree);
+	wmem_stack_push(data->stack, subtree);
 }
 
 static void after_member(void *tvbparse_data, const void *wanted_data _U_, tvbparse_elem_t *tok) {
 	json_parser_data_t *data = (json_parser_data_t *) tvbparse_data;
 
-	proto_tree *tree = (proto_tree *)ep_stack_pop(data->stack);
+	proto_tree *tree = (proto_tree *)wmem_stack_pop(data->stack);
 
 	if (tree) {
 		tvbparse_elem_t *key_tok = tok->sub;
 
 		if (key_tok && key_tok->id == JSON_TOKEN_STRING) {
-			char *key = tvb_get_ephemeral_string(key_tok->tvb, key_tok->offset, key_tok->len);
+			char *key = tvb_get_string(wmem_packet_scope(), key_tok->tvb, key_tok->offset, key_tok->len);
 
 			proto_item_append_text(tree, " Key: %s", key);
 		}
-		/* XXX, hf_json_member_key */
+		/* XXX, &hfi_json_member_key */
 	}
 }
 
 static void before_array(void *tvbparse_data, const void *wanted_data _U_, tvbparse_elem_t *tok) {
 	json_parser_data_t *data = (json_parser_data_t *) tvbparse_data;
 
-	proto_tree *tree = (proto_tree *)ep_stack_peek(data->stack);
+	proto_tree *tree = (proto_tree *)wmem_stack_peek(data->stack);
 	proto_tree *subtree;
 	proto_item *ti;
 
-	ti = proto_tree_add_item(tree, hf_json_array, tok->tvb, tok->offset, tok->len, ENC_NA);
+	ti = proto_tree_add_item(tree, &hfi_json_array, tok->tvb, tok->offset, tok->len, ENC_NA);
 
 	subtree = proto_item_add_subtree(ti, ett_json_array);
-	ep_stack_push(data->stack, subtree);
+	wmem_stack_push(data->stack, subtree);
 }
 
 static void after_array(void *tvbparse_data, const void *wanted_data _U_, tvbparse_elem_t *elem _U_) {
 	json_parser_data_t *data = (json_parser_data_t *) tvbparse_data;
 
-	ep_stack_pop(data->stack);
+	wmem_stack_pop(data->stack);
 }
 
 /*
@@ -226,7 +250,7 @@ static void after_array(void *tvbparse_data, const void *wanted_data _U_, tvbpar
 
 static char *json_string_unescape(tvbparse_elem_t *tok)
 {
-	char *str = (char *)ep_alloc(tok->len - 1);
+	char *str = (char *)wmem_alloc(wmem_packet_scope(), tok->len - 1);
 	int i, j;
 
 	j = 0;
@@ -338,7 +362,7 @@ static char *json_string_unescape(tvbparse_elem_t *tok)
 				}
 			}
 
-		} else 
+		} else
 			str[j++] = ch;
 
 	}
@@ -350,7 +374,7 @@ static char *json_string_unescape(tvbparse_elem_t *tok)
 static void after_value(void *tvbparse_data, const void *wanted_data _U_, tvbparse_elem_t *tok) {
 	json_parser_data_t *data = (json_parser_data_t *) tvbparse_data;
 
-	proto_tree *tree = (proto_tree *)ep_stack_peek(data->stack);
+	proto_tree *tree = (proto_tree *)wmem_stack_peek(data->stack);
 	json_token_type_t value_id = JSON_TOKEN_INVALID;
 
 	if (tok->sub)
@@ -359,26 +383,26 @@ static void after_value(void *tvbparse_data, const void *wanted_data _U_, tvbpar
 	switch (value_id) {
 		case JSON_TOKEN_STRING:
 			if (tok->len >= 2)
-				proto_tree_add_unicode_string(tree, hf_json_value_string, tok->tvb, tok->offset, tok->len, json_string_unescape(tok));
+				proto_tree_add_unicode_string(tree, hfi_json_value_string.id, tok->tvb, tok->offset, tok->len, json_string_unescape(tok));
 			else
-				proto_tree_add_item(tree, hf_json_value_string, tok->tvb, tok->offset, tok->len, ENC_ASCII|ENC_NA);
+				proto_tree_add_item(tree, &hfi_json_value_string, tok->tvb, tok->offset, tok->len, ENC_ASCII|ENC_NA);
 			break;
 
 		case JSON_TOKEN_NUMBER:
 			/* XXX, convert to number */
-			proto_tree_add_item(tree, hf_json_value_number, tok->tvb, tok->offset, tok->len, ENC_ASCII|ENC_NA);
+			proto_tree_add_item(tree, &hfi_json_value_number, tok->tvb, tok->offset, tok->len, ENC_ASCII|ENC_NA);
 			break;
 
 		case JSON_TOKEN_FALSE:
-			proto_tree_add_item(tree, hf_json_value_false, tok->tvb, tok->offset, tok->len, ENC_NA);
+			proto_tree_add_item(tree, &hfi_json_value_false, tok->tvb, tok->offset, tok->len, ENC_NA);
 			break;
 
 		case JSON_TOKEN_NULL:
-			proto_tree_add_item(tree, hf_json_value_null, tok->tvb, tok->offset, tok->len, ENC_NA);
+			proto_tree_add_item(tree, &hfi_json_value_null, tok->tvb, tok->offset, tok->len, ENC_NA);
 			break;
 
 		case JSON_TOKEN_TRUE:
-			proto_tree_add_item(tree, hf_json_value_true, tok->tvb, tok->offset, tok->len, ENC_NA);
+			proto_tree_add_item(tree, &hfi_json_value_true, tok->tvb, tok->offset, tok->len, ENC_NA);
 			break;
 
 		case JSON_OBJECT:
@@ -478,7 +502,7 @@ static void init_json_parser(void) {
 			tvbparse_optional(-1, NULL, NULL, NULL,
 				tvbparse_set_seq(-1, NULL, NULL, NULL,
 					want_value,
-					tvbparse_some(-1, 0, G_MAXINT, NULL, NULL, NULL, 
+					tvbparse_some(-1, 0, G_MAXINT, NULL, NULL, NULL,
 						tvbparse_set_seq(-1, NULL, NULL, NULL,
 							want_value_separator,
 							want_value,
@@ -502,7 +526,7 @@ static void init_json_parser(void) {
 			tvbparse_optional(-1, NULL, NULL, NULL,
 				tvbparse_set_seq(-1, NULL, NULL, NULL,
 					want_member,
-					tvbparse_some(-1, 0, G_MAXINT, NULL, NULL, NULL, 
+					tvbparse_some(-1, 0, G_MAXINT, NULL, NULL, NULL,
 						tvbparse_set_seq(-1, NULL, NULL, NULL,
 							want_value_separator,
 							want_member,
@@ -534,42 +558,24 @@ proto_register_json(void) {
 		&ett_json_member
 	};
 
-	static hf_register_info hf[] = {
-		{ &hf_json_array,
-			{ "Array", "json.array", FT_NONE, BASE_NONE, NULL, 0x00, "JSON array", HFILL }
-		}, 
-		{ &hf_json_object,
-			{ "Object", "json.object", FT_NONE, BASE_NONE, NULL, 0x00, "JSON object", HFILL }
-		}, 
-		{ &hf_json_member,
-			{ "Member", "json.member", FT_NONE, BASE_NONE, NULL, 0x00, "JSON object member", HFILL },
-		},
-/* XXX
-		{ &hf_json_member_key,
-			{ "Key", "json.member.key", FT_NONE, BASE_NONE, NULL, 0x00, NULL, HFILL },
-		},
-*/
-		{ &hf_json_value_string, /* FT_STRINGZ? */
-			{ "String value", "json.value.string", FT_STRING, BASE_NONE, NULL, 0x00, "JSON string value", HFILL },
-		},
-		{ &hf_json_value_number, /* FT_DOUBLE/ FT_INT64? */
-			{ "Number value", "json.value.number", FT_STRING, BASE_NONE, NULL, 0x00, "JSON number value", HFILL },
-		},
-		{ &hf_json_value_false,
-			{ "False value", "json.value.false", FT_NONE, BASE_NONE, NULL, 0x00, "JSON false value", HFILL },
-		},
-		{ &hf_json_value_null,
-			{ "Null value", "json.value.null", FT_NONE, BASE_NONE, NULL, 0x00, "JSON null value", HFILL },
-		},
-		{ &hf_json_value_true,
-			{ "True value", "json.value.true", FT_NONE, BASE_NONE, NULL, 0x00, "JSON true value", HFILL },
-		},
-
+	static header_field_info *hfi[] = {
+		&hfi_json_array,
+		&hfi_json_object,
+		&hfi_json_member,
+		/* &hfi_json_member_key, */
+		&hfi_json_value_string,
+		&hfi_json_value_number,
+		&hfi_json_value_false,
+		&hfi_json_value_null,
+		&hfi_json_value_true,
 	};
 
-	proto_json = proto_register_protocol("JavaScript Object Notation", "JSON", "json");
+	int proto_json;
 
-	proto_register_field_array(proto_json, hf, array_length(hf));
+	proto_json = proto_register_protocol("JavaScript Object Notation", "JSON", "json");
+	hfi_json = proto_registrar_get_nth(proto_json);
+
+	proto_register_fields(proto_json, hfi, array_length(hfi));
 	proto_register_subtree_array(ett, array_length(ett));
 
 	register_dissector("json", dissect_json, proto_json);
