@@ -2,7 +2,7 @@
  * Routines for Juniper Networks, Inc. packet disassembly
  * Copyright 2005 Hannes Gredler <hannes@juniper.net>
  *
- * $Id$
+ * $Id: packet-juniper.c 52100 2013-09-16 14:08:43Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -387,7 +387,7 @@ static dissector_handle_t frelay_handle;
 static dissector_handle_t chdlc_handle;
 static dissector_handle_t data_handle;
 
-static dissector_table_t osinl_subdissector_table;
+static dissector_table_t osinl_incl_subdissector_table;
 static dissector_table_t osinl_excl_subdissector_table;
 
 static int dissect_juniper_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, proto_item *ti, guint8 *flags);
@@ -502,7 +502,7 @@ static int
 dissect_juniper_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, proto_item *ti, guint8 *flags)
 {
   proto_item *tisub;
-  guint8     direction,l2hdr_presence,proto,ext_type,ext_len;
+  guint8     l2hdr_presence,proto,ext_type,ext_len;
   guint16    ext_total_len,ext_offset=6,hdr_len;
   guint32    magic_number,ext_val;
 
@@ -510,7 +510,6 @@ dissect_juniper_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, prot
 
   magic_number = tvb_get_ntoh24(tvb, 0);
   *flags = tvb_get_guint8(tvb, 3);
-  direction = *flags & JUNIPER_FLAG_PKT_IN;
   l2hdr_presence = *flags & JUNIPER_FLAG_NO_L2;
 
   juniper_subtree = proto_item_add_subtree(ti, ett_juniper);
@@ -526,9 +525,7 @@ dissect_juniper_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, prot
   proto_tree_add_text (juniper_subtree, tvb, 0, 3,
                        "Magic-Number: 0x%06x", magic_number);
 
-  proto_tree_add_uint_format (juniper_subtree, hf_juniper_direction, tvb, 3, 1,
-                              direction, "Direction: %s",
-                              val_to_str_const(direction,juniper_direction_vals,"Unknown"));
+  proto_tree_add_item(juniper_subtree, hf_juniper_direction, tvb, 3, 1, ENC_NA);
 
   proto_tree_add_uint_format (juniper_subtree, hf_juniper_l2hdr_presence, tvb, 3, 1,
                               l2hdr_presence, "L2-header: %s",
@@ -657,7 +654,7 @@ dissect_juniper_payload_proto(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
   case PROTO_CLNP:
   case PROTO_MPLS_CLNP:
     nlpid = tvb_get_guint8(tvb, offset);
-    if(dissector_try_uint(osinl_subdissector_table, nlpid, next_tvb, pinfo, tree))
+    if(dissector_try_uint(osinl_incl_subdissector_table, nlpid, next_tvb, pinfo, tree))
       return 0;
     next_tvb = tvb_new_subset_remaining(tvb, offset+1);
     if(dissector_try_uint(osinl_excl_subdissector_table, nlpid, next_tvb, pinfo, tree))
@@ -1478,7 +1475,7 @@ proto_reg_handoff_juniper(void)
   dissector_handle_t juniper_vp_handle;
   dissector_handle_t juniper_svcs_handle;
 
-  osinl_subdissector_table = find_dissector_table("osinl");
+  osinl_incl_subdissector_table = find_dissector_table("osinl.incl");
   osinl_excl_subdissector_table = find_dissector_table("osinl.excl");
 
   eth_handle    = find_dissector("eth_withoutfcs");
