@@ -3,7 +3,7 @@
 *
 * Luis E. Garcia Ontanon <luis@ontanon.org>
 *
-* $Id$
+* $Id: packet-k12.c 51512 2013-08-25 14:23:13Z eapache $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
@@ -32,8 +32,8 @@
 #include <epan/packet.h>
 #include <epan/conversation.h>
 #include <prefs.h>
-#include <epan/report_err.h>
 #include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/uat.h>
 #include <epan/expert.h>
 #include <epan/strutil.h>
@@ -62,6 +62,8 @@ static gint ett_k12 = -1;
 static gint ett_port = -1;
 static gint ett_stack_item = -1;
 
+static expert_field ei_k12_unmatched_stk_file = EI_INIT;
+
 static dissector_handle_t k12_handle;
 static dissector_handle_t data_handle;
 static dissector_handle_t sscop_handle;
@@ -70,7 +72,7 @@ static dissector_handle_t fp_handle;
 extern int proto_sscop;
 extern int proto_fp;
 
-static emem_tree_t* port_handles = NULL;
+static wmem_tree_t* port_handles = NULL;
 static uat_t* k12_uat = NULL;
 static k12_handles_t* k12_handles = NULL;
 static guint nk12_handles = 0;
@@ -211,7 +213,7 @@ dissect_k12(tvbuff_t* tvb,packet_info* pinfo,proto_tree* tree)
 			break;
 		case K12_PORT_ATMPVC:
 		{
-		gchar* circuit_str = ep_strdup_printf("%u:%u:%u",
+		gchar* circuit_str = wmem_strdup_printf(wmem_packet_scope(), "%u:%u:%u",
 						      (guint)pinfo->pseudo_header->k12.input_info.atm.vp,
 						      (guint)pinfo->pseudo_header->k12.input_info.atm.vc,
 						      (guint)pinfo->pseudo_header->k12.input_info.atm.cid);
@@ -235,7 +237,7 @@ dissect_k12(tvbuff_t* tvb,packet_info* pinfo,proto_tree* tree)
 			break;
 	}
 
-	handles = (dissector_handle_t *)se_tree_lookup32(port_handles, pinfo->pseudo_header->k12.input);
+	handles = (dissector_handle_t *)wmem_tree_lookup32(port_handles, pinfo->pseudo_header->k12.input);
 
 	if (! handles ) {
 		for (i=0 ; i < nk12_handles; i++) {
@@ -251,18 +253,15 @@ dissect_k12(tvbuff_t* tvb,packet_info* pinfo,proto_tree* tree)
 			handles = data_handles;
 		}
 
-		se_tree_insert32(port_handles, pinfo->pseudo_header->k12.input, handles);
+		wmem_tree_insert32(port_handles, pinfo->pseudo_header->k12.input, handles);
 
 	}
 
 	if (handles == data_handles) {
-		proto_tree* stack_tree = proto_item_add_subtree(stack_item,ett_stack_item);
+		proto_tree* stack_tree = proto_item_add_subtree(stack_item, ett_stack_item);
 		proto_item* item;
 
-		item = proto_tree_add_text(stack_tree,tvb,0,0,
-					   "Warning: stk file not matched in the 'K12 Protocols' table");
-		PROTO_ITEM_SET_GENERATED(item);
-		expert_add_info_format(pinfo, item, PI_UNDECODED, PI_WARN, "unmatched stk file");
+		expert_add_info(pinfo, stack_item, &ei_k12_unmatched_stk_file);
 
 		item = proto_tree_add_text(stack_tree,tvb,0,0,
 					   "Info: You can edit the 'K12 Protocols' table from Preferences->Protocols->k12xx");
@@ -278,7 +277,7 @@ dissect_k12(tvbuff_t* tvb,packet_info* pinfo,proto_tree* tree)
 		if (handles[i] == sscop_handle) {
 			sscop_payload_info *p_sscop_info = (sscop_payload_info *)p_get_proto_data(pinfo->fd, proto_sscop, 0);
 			if (!p_sscop_info) {
-				p_sscop_info = se_new0(sscop_payload_info);
+				p_sscop_info = wmem_new0(wmem_file_scope(), sscop_payload_info);
                 p_add_proto_data(pinfo->fd, proto_sscop, 0, p_sscop_info);
                 p_sscop_info->subdissector = handles[i+1];
 			}
@@ -292,7 +291,7 @@ dissect_k12(tvbuff_t* tvb,packet_info* pinfo,proto_tree* tree)
 	if (sub_handle == fp_handle) {
 		fp_info *p_fp_info = (fp_info *)p_get_proto_data(pinfo->fd, proto_fp, 0);
 		if (!p_fp_info) {
-			p_fp_info = se_new0(fp_info);
+			p_fp_info = wmem_new0(wmem_file_scope(), fp_info);
             p_add_proto_data(pinfo->fd, proto_fp, 0, p_fp_info);
 
             fill_fp_info(p_fp_info,
@@ -432,6 +431,10 @@ proto_register_k12(void)
 	  &ett_stack_item
   };
 
+  static ei_register_info ei[] = {
+     { &ei_k12_unmatched_stk_file, { "k12.unmatched_stk_file", PI_UNDECODED, PI_WARN, "Warning: stk file not matched in the 'K12 Protocols' table", EXPFILL }},
+  };
+
   static uat_field_t uat_k12_flds[] = {
       UAT_FLD_CSTRING_ISPRINT(k12,match,"Match string",
 			      "A string that will be matched (a=A) against an .stk filename or the name of a port.\n"
@@ -443,10 +446,13 @@ proto_register_k12(void)
   };
 
   module_t *k12_module;
+  expert_module_t* expert_k12;
 
   proto_k12 = proto_register_protocol("K12xx", "K12xx", "k12");
   proto_register_field_array(proto_k12, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
+  expert_k12 = expert_register_protocol(proto_k12);
+  expert_register_field_array(expert_k12, ei, array_length(ei));
   register_dissector("k12", dissect_k12, proto_k12);
 
   k12_uat = uat_new("K12 Protocols",
@@ -472,6 +478,6 @@ proto_register_k12(void)
 				"A table of matches vs stack filenames and relative protocols",
 				k12_uat);
 
-  port_handles = se_tree_create(EMEM_TREE_TYPE_RED_BLACK, "k12_port_handles");
+  port_handles = wmem_tree_new_autoreset(wmem_epan_scope(), wmem_file_scope());
 
 }
