@@ -3,7 +3,7 @@
  * Kari Vatjus-Anttila <kari.vatjus-anttila@cie.fi>
  * Ville Saarinen <ville.saarinen@cie.fi>
  *
- * $Id$
+ * $Id: packet-knet.c 52272 2013-09-29 18:19:29Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -28,6 +28,7 @@
 
 #include <epan/packet.h>
 #include <epan/prefs.h>
+#include <epan/wmem/wmem.h>
 #include <epan/dissectors/packet-tcp.h>
 
 #define PROTO_TAG_KNET      "KNET"    /*!< Definition of kNet Protocol */
@@ -111,6 +112,10 @@ static gint ett_knet_datagram =      -1;
 static gint ett_knet_flags =         -1;
 /**@}*/
 
+static dissector_handle_t knet_handle_sctp;
+static dissector_handle_t knet_handle_tcp;
+static dissector_handle_t knet_handle_udp;
+
 /* Few Utility Variables */
 static int messageindex =         0; /*!< Index of the kNet message inside a datagram */
 static int current_protocol =     0; /*!< Protocol currently dissected */
@@ -292,8 +297,6 @@ dissect_content_length(tvbuff_t *buffer, int offset, proto_tree *tree)
     proto_tree *msgflags_tree;
     guint32     length;
 
-    msgflags_tree = NULL;
-
     length  = tvb_get_bits8(buffer, offset * 8 + 12, 4) << 8;
     length += tvb_get_bits8(buffer, offset * 8, 8);
 
@@ -301,15 +304,15 @@ dissect_content_length(tvbuff_t *buffer, int offset, proto_tree *tree)
     {
         msgflags_ti   = proto_tree_add_item(tree, hf_knet_msg_flags, buffer, offset + 1, 1, ENC_NA);
         msgflags_tree = proto_item_add_subtree(msgflags_ti, ett_knet_message_flags);
+
+        proto_tree_add_bits_item(msgflags_tree, hf_knet_msg_fs, buffer, offset * 8 + 8, 1, ENC_LITTLE_ENDIAN); /* Fragment start flag */
+        proto_tree_add_bits_item(msgflags_tree, hf_knet_msg_ff, buffer, offset * 8 + 9, 1, ENC_LITTLE_ENDIAN);  /* Fragment flag */
+        proto_tree_add_bits_item(msgflags_tree, hf_knet_msg_inorder, buffer, offset * 8 + 10, 1, ENC_LITTLE_ENDIAN); /* Inorder flag */
+        proto_tree_add_bits_item(msgflags_tree, hf_knet_msg_reliable, buffer, offset * 8 + 11, 1, ENC_LITTLE_ENDIAN); /* Reliable flag */
+
+        proto_tree_add_uint(tree, hf_knet_content_length, buffer, offset, 2, length);
     }
 
-    proto_tree_add_bits_item(msgflags_tree, hf_knet_msg_fs, buffer, offset * 8 + 8, 1, ENC_LITTLE_ENDIAN); /* Fragment start flag */
-    proto_tree_add_bits_item(msgflags_tree, hf_knet_msg_ff, buffer, offset * 8 + 9, 1, ENC_LITTLE_ENDIAN);  /* Fragment flag */
-    proto_tree_add_bits_item(msgflags_tree, hf_knet_msg_inorder, buffer, offset * 8 + 10, 1, ENC_LITTLE_ENDIAN); /* Inorder flag */
-    proto_tree_add_bits_item(msgflags_tree, hf_knet_msg_reliable, buffer, offset * 8 + 11, 1, ENC_LITTLE_ENDIAN); /* Reliable flag */
-
-    proto_tree_add_uint(tree, hf_knet_content_length, buffer, offset, 2, length);
-
     return length;
 }
 
@@ -361,7 +364,7 @@ dissect_reliable_message_number(tvbuff_t *buffer, int offset, proto_tree *tree)
  *
  */
 static int
-dissect_messageid(tvbuff_t *buffer, int *offset, proto_tree *tree, packet_info *pinfo, emem_strbuf_t* info_field)
+dissect_messageid(tvbuff_t *buffer, int *offset, proto_tree *tree, packet_info *pinfo, wmem_strbuf_t* info_field)
 {
     gint   messageid_length;
     guint8 messageid;
@@ -382,14 +385,14 @@ dissect_messageid(tvbuff_t *buffer, int *offset, proto_tree *tree, packet_info *
         break;
     }
 
-    proto_tree_add_bytes_format(tree, hf_knet_messageid, buffer, *offset, messageid_length, NULL,
-    "Message ID: %s (%d)", val_to_str_const(messageid, packettypenames, "AppData or Malformed Message ID"), messageid);
+    proto_tree_add_bytes_format_value(tree, hf_knet_messageid, buffer, *offset, messageid_length, NULL,
+    "%s (%d)", val_to_str_const(messageid, packettypenames, "AppData or Malformed Message ID"), messageid);
 
     col_append_fstr(pinfo->cinfo, COL_INFO, "%s ", val_to_str_const(messageid, packettypenames, "AppData "));
 
     *offset += messageid_length;
 
-    ep_strbuf_append_printf(info_field, "Msg ID (%d) ", messageid);
+    wmem_strbuf_append_printf(info_field, "Msg ID (%d) ", messageid);
 
     return messageid;
 }
@@ -461,11 +464,10 @@ dissect_payload(tvbuff_t *buffer, int offset, int messageid, proto_tree *tree, i
  * @param tvb the buffer to the data
  * @param pinfo the packet info structure
  * @param tree the parent tree where the dissected data is going to be inserted
- * @return void
  *
  */
 static void
-dissect_knet_message(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, emem_strbuf_t* info_field)
+dissect_knet_message(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, wmem_strbuf_t* info_field)
 {
     int offset;
     int content_length;
@@ -487,7 +489,7 @@ dissect_knet_message(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, em
 
     content_length = dissect_content_length(tvb, offset, msgblock_tree); /* Calculates the Content Length of this packet. */
 
-    ep_strbuf_append_printf(info_field, "%d: ", messageindex + 1);
+    wmem_strbuf_append_printf(info_field, "%d: ", messageindex + 1);
 
     offset += 2; /* Move the offset the amount of contentlength and flags fields */
 
@@ -513,7 +515,6 @@ dissect_knet_message(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, em
  * @param tvb the buffer to the data
  * @param pinfo the packet info structure
  * @param tree the parent tree where the dissected data is going to be inserted
- * @return void
  *
  */
 static void
@@ -537,7 +538,7 @@ dissect_knet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     gboolean    bytes_left;
 
     /* String that is going to be displayed in the info column in Wireshark */
-    emem_strbuf_t *info_field = ep_strbuf_new("");
+    wmem_strbuf_t *info_field = wmem_strbuf_new(wmem_packet_scope(), "");
 
     int offset;
     int length;
@@ -575,7 +576,7 @@ dissect_knet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             if(tree == NULL)
                 offset += count_vle_bytes(next_tvb, offset);
 
-            ep_strbuf_append_printf(info_field, "%d: ", messageindex + 1);
+            wmem_strbuf_append_printf(info_field, "%d: ", messageindex + 1);
 
             messageid = dissect_messageid(next_tvb, &offset, message_tree, pinfo, info_field); /* Calculate messageid and add it to the tree-view */
 
@@ -603,7 +604,7 @@ dissect_knet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
         packetid = dissect_packetid(tvb, 0, datagram_tree); /* Lets calculate our packetid! */
 
-        ep_strbuf_append_printf(info_field, "Packet ID: %d ", packetid);
+        wmem_strbuf_append_printf(info_field, "Packet ID: %d ", packetid);
 
         offset += 3;
 
@@ -644,7 +645,7 @@ dissect_knet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     if(current_protocol == KNET_TCP_PACKET && ((struct tcpinfo*)(pinfo->private_data))->is_reassembled)
         col_add_str(pinfo->cinfo, COL_INFO, "REASSEMBLED PACKET");
     else
-        col_add_fstr(pinfo->cinfo, COL_INFO, "Messages: %d %s", messageindex + 1,  info_field->str);
+        col_add_fstr(pinfo->cinfo, COL_INFO, "Messages: %d %s", messageindex + 1, wmem_strbuf_get_str(info_field));
 
     messageindex++;
 }
@@ -672,7 +673,6 @@ get_knet_pdu_len(packet_info *pinfo _U_, tvbuff_t *tvb, int offset)
  * @param tvb the buffer to the data
  * @param pinfo the packet info structure
  * @param tree the parent tree where the dissected data is going to be inserted
- * @return void
  *
  */
 static void
@@ -687,12 +687,9 @@ dissect_knet_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
  * dissect_knet_sctp is the dissector which is called
  * by Wireshark when kNet STCP packets are captured.
  *
-
  * @param tvb the buffer to the data
  * @param pinfo the packet info structure
  * @param tree the parent tree where the dissected data is going to be inserted
-
- * @return void
  *
  */
 static void
@@ -707,12 +704,9 @@ dissect_knet_sctp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
  * dissect_knet_udp is the dissector which is called
  * by Wireshark when kNet UDP packets are captured.
  *
-
  * @param tvb the buffer to the data
  * @param pinfo the packet info structure
  * @param tree the parent tree where the dissected data is going to be inserted
-
- * @return void
  *
  */
 static void
@@ -726,8 +720,6 @@ dissect_knet_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
  * proto_register_knet registers our kNet protocol,
  * headerfield- and subtree-array to Wireshark.
  *
- * @return void
- *
  */
 void
 proto_register_knet(void)
@@ -823,9 +815,9 @@ proto_register_knet(void)
     /* Register protocols */
     proto_knet = proto_register_protocol ("kNet Protocol", "KNET", "knet");
 
-    register_dissector("knetsctp", dissect_knet_sctp, proto_knet);
-    register_dissector("knettcp",  dissect_knet_tcp, proto_knet);
-    register_dissector("knetudp",  dissect_knet_udp, proto_knet);
+    knet_handle_sctp = register_dissector("knetsctp", dissect_knet_sctp, proto_knet);
+    knet_handle_tcp = register_dissector("knettcp",  dissect_knet_tcp, proto_knet);
+    knet_handle_udp = register_dissector("knetudp",  dissect_knet_udp, proto_knet);
 
     knet_module = prefs_register_protocol(proto_knet, proto_reg_handoff_knet);
 
@@ -843,9 +835,7 @@ proto_register_knet(void)
 }
 
 /**
- * proto_reg_handoff_knet registers our kNet dissectors to Wireshark.
- *
- * @return void
+ * proto_reg_handoff_knet registers our kNet dissectors to Wireshark
  *
  */
 void
@@ -853,20 +843,12 @@ proto_reg_handoff_knet(void)
 {
     static gboolean initialized = FALSE;
 
-    static dissector_handle_t knet_handle_sctp = 0;
-    static dissector_handle_t knet_handle_tcp = 0;
-    static dissector_handle_t knet_handle_udp = 0;
-
     static guint current_sctp_port;
     static guint current_tcp_port;
     static guint current_udp_port;
 
     if(!initialized)
     {
-        knet_handle_sctp = create_dissector_handle(dissect_knet_sctp, proto_knet);
-        knet_handle_tcp  = create_dissector_handle(dissect_knet_tcp, proto_knet);
-        knet_handle_udp  = create_dissector_handle(dissect_knet_udp, proto_knet);
-
         initialized = TRUE;
     }
     else
