@@ -2,7 +2,7 @@
  * Routines for LAPD frame disassembly
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id$
+ * $Id: packet-lapd.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -48,6 +48,7 @@
 #include <epan/prefs.h>
 #include <epan/lapd_sapi.h>
 #include <epan/expert.h>
+#include <epan/wmem/wmem.h>
 
 static int proto_lapd = -1;
 static int hf_lapd_direction = -1;
@@ -74,7 +75,6 @@ static int hf_lapd_ftype_s_u_ext = -1;
 static int hf_lapd_checksum = -1;
 static int hf_lapd_checksum_good = -1;
 static int hf_lapd_checksum_bad = -1;
-static int hf_lapd_abort = -1;
 
 static gint ett_lapd = -1;
 static gint ett_lapd_address = -1;
@@ -82,6 +82,9 @@ static gint ett_lapd_control = -1;
 static gint ett_lapd_checksum = -1;
 static gint pref_lapd_rtp_payload_type = 0;
 
+static expert_field ei_lapd_abort = EI_INIT;
+static expert_field ei_lapd_checksum_bad = EI_INIT;
+
 static dissector_table_t lapd_sapi_dissector_table;
 static dissector_table_t lapd_gsm_sapi_dissector_table;
 
@@ -209,14 +212,11 @@ static void new_byte(char full_byte, char data[], int *data_len) {
 
 static void
 lapd_log_abort(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint offset, const char *msg)
-{	proto_tree *lapd_tree;
-	proto_item *lapd_ti, *pi;
+{
+	proto_item *ti;
 
-	lapd_ti = proto_tree_add_item(tree, proto_lapd, tvb, offset, 1,
-	    ENC_NA);
-	lapd_tree = proto_item_add_subtree(lapd_ti, ett_lapd);
-	pi = proto_tree_add_boolean(lapd_tree, hf_lapd_abort, tvb, offset, 1, TRUE);
-	expert_add_info_format(pinfo, pi, PI_PROTOCOL, PI_ERROR, "%s", msg);
+	ti = proto_tree_add_item(tree, proto_lapd, tvb, offset, 1, ENC_NA);
+	expert_add_info_format(pinfo, ti, &ei_lapd_abort, "%s", msg);
 }
 
 static void
@@ -317,7 +317,7 @@ dissect_lapd_bitstream(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					data_len = 0;
 					state = OUT_OF_SYNC;
 					bit_offset++;
-					
+
 					lapd_log_abort(tvb, pinfo, tree, offset, "Abort! 7 ones!");
 				} else {
 					bit_offset++;
@@ -364,7 +364,7 @@ dissect_lapd_bitstream(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	{
 		if (NULL == p_get_proto_data(pinfo->fd, proto_lapd, 0)) {
 			/* Per packet information */
-			lapd_ppi = se_new(lapd_ppi_t);
+			lapd_ppi = wmem_new(wmem_file_scope(), lapd_ppi_t);
 			lapd_ppi->has_crc = TRUE;
 			if (prev_byte_state)
 				fill_lapd_byte_state(&lapd_ppi->start_byte_state, prev_byte_state->state,
@@ -384,13 +384,13 @@ dissect_lapd_bitstream(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 						fill_lapd_byte_state(convo_data->byte_state_a, state, full_byte, bit_offset, ones, data, data_len);
 					else {
 						if (!convo_data->byte_state_b)
-							convo_data->byte_state_b = se_new(lapd_byte_state_t);
+							convo_data->byte_state_b = wmem_new(wmem_file_scope(), lapd_byte_state_t);
 						fill_lapd_byte_state(convo_data->byte_state_b, state, full_byte, bit_offset, ones, data, data_len);
 					}
 				} else { /* lapd convo data has to be created */
-					lapd_byte_state = se_new(lapd_byte_state_t);
+					lapd_byte_state = wmem_new(wmem_file_scope(), lapd_byte_state_t);
 					fill_lapd_byte_state(lapd_byte_state, state, full_byte, bit_offset, ones, data, data_len);
-					convo_data = se_new(lapd_convo_data_t);
+					convo_data = wmem_new(wmem_file_scope(), lapd_convo_data_t);
 					COPY_ADDRESS(&convo_data->addr_a, &pinfo->src);
 					COPY_ADDRESS(&convo_data->addr_b, &pinfo->dst);
 					convo_data->port_a = pinfo->srcport;
@@ -433,8 +433,7 @@ dissect_lapd_full(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
 	sapi = (addr & LAPD_SAPI) >> LAPD_SAPI_SHIFT;
 	lapd_header_len = 2;	/* addr */
 
-	if (check_col(pinfo->cinfo, COL_TEI))
-		col_add_fstr(pinfo->cinfo, COL_TEI, "%u", tei);
+	col_add_fstr(pinfo->cinfo, COL_TEI, "%u", tei);
 
 	/* Append TEI to info field */
 	col_append_fstr(pinfo->cinfo, COL_INFO, "TEI:%02u ", tei);
@@ -547,17 +546,17 @@ dissect_lapd_full(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
 		checksum_calculated = g_htons(checksum_calculated);  /* Note: g_htons() macro may eval arg multiple times */
 
 		if (checksum == checksum_calculated) {
-			checksum_ti = proto_tree_add_uint_format(lapd_tree, hf_lapd_checksum, tvb, checksum_offset, 2, 0,"Checksum: 0x%04x [correct]", checksum);
+			checksum_ti = proto_tree_add_uint_format_value(lapd_tree, hf_lapd_checksum, tvb, checksum_offset, 2, 0,"0x%04x [correct]", checksum);
 			checksum_tree = proto_item_add_subtree(checksum_ti, ett_lapd_checksum);
 			proto_tree_add_boolean(checksum_tree, hf_lapd_checksum_good, tvb, checksum_offset, 2, TRUE);
 			proto_tree_add_boolean(checksum_tree, hf_lapd_checksum_bad, tvb, checksum_offset, 2, FALSE);
 		} else {
 			proto_item *pi;
-			checksum_ti = proto_tree_add_uint_format(lapd_tree, hf_lapd_checksum, tvb, checksum_offset, 2, 0,"Checksum: 0x%04x [incorrect, should be 0x%04x]", checksum, checksum_calculated);
+			checksum_ti = proto_tree_add_uint_format_value(lapd_tree, hf_lapd_checksum, tvb, checksum_offset, 2, 0,"0x%04x [incorrect, should be 0x%04x]", checksum, checksum_calculated);
 			checksum_tree = proto_item_add_subtree(checksum_ti, ett_lapd_checksum);
 			proto_tree_add_boolean(checksum_tree, hf_lapd_checksum_good, tvb, checksum_offset, 2, FALSE);
 			pi = proto_tree_add_boolean(checksum_tree, hf_lapd_checksum_bad, tvb, checksum_offset, 2, TRUE);
-			expert_add_info_format(pinfo, pi, PI_CHECKSUM, PI_WARN, "Bad FCS");
+			expert_add_info(pinfo, pi, &ei_lapd_checksum_bad);
 		}
 
 		next_tvb = tvb_new_subset(tvb, lapd_header_len, tvb_length_remaining(tvb,lapd_header_len) - 2, tvb_length_remaining(tvb,lapd_header_len) - 2);
@@ -565,7 +564,7 @@ dissect_lapd_full(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean
 	} else
 		next_tvb = tvb_new_subset_remaining(tvb, lapd_header_len);
 
-    /* Dissection done, append " | " to COL_INFO */
+	/* Dissection done, append " | " to COL_INFO */
 	col_append_fstr(pinfo->cinfo, COL_INFO, " | ");
 	col_set_fence(pinfo->cinfo, COL_INFO);
 
@@ -687,13 +686,7 @@ proto_register_lapd(void)
 	{ &hf_lapd_checksum_bad,
 	    { "Bad Checksum", "lapd.checksum_bad", FT_BOOLEAN, BASE_NONE,
 		NULL, 0x0, "True: checksum doesn't match packet content; False: matches content or not checked", HFILL }},
-
-	{ &hf_lapd_abort,
-	    { "Abort", "lapd.abort", FT_BOOLEAN, BASE_NONE,
-		NULL, 0x0, "True: there is an Abort sequence, 7 ones in a row, or 6 ones in a row that aren't equal to 0x7e", HFILL }}
-
     };
-
     static gint *ett[] = {
         &ett_lapd,
         &ett_lapd_address,
@@ -701,12 +694,20 @@ proto_register_lapd(void)
         &ett_lapd_checksum
     };
 
+	static ei_register_info ei[] = {
+		{ &ei_lapd_abort, { "lapd.abort.expert", PI_PROTOCOL, PI_ERROR, "Formatted message", EXPFILL }},
+		{ &ei_lapd_checksum_bad, { "lapd.checksum_bad.expert", PI_CHECKSUM, PI_WARN, "Bad FCS", EXPFILL }},
+	};
+
 	module_t *lapd_module;
+	expert_module_t* expert_lapd;
 
 	proto_lapd = proto_register_protocol("Link Access Procedure, Channel D (LAPD)",
 					 "LAPD", "lapd");
 	proto_register_field_array (proto_lapd, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	expert_lapd = expert_register_protocol(proto_lapd);
+	expert_register_field_array(expert_lapd, ei, array_length(ei));
 
 	register_dissector("lapd", dissect_lapd, proto_lapd);
 
