@@ -12,7 +12,7 @@
  * References:
  *  [1] ETSI TS 101 376-4-6 V1.2.1 - GMR-1 04.006
  *
- * $Id$
+ * $Id: packet-lapsat.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -38,6 +38,7 @@
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/reassemble.h>
+#include <epan/wmem/wmem.h>
 
 
 static int proto_lapsat = -1;
@@ -268,7 +269,7 @@ dissect_control(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, int is_
 	const char *frame_type;
 	char *info;
 
-	info = (char *)ep_alloc(80);
+	info = (char *)wmem_alloc(wmem_packet_scope(), 80);
 
 	/* Grab complete control field */
 	ctl = tvb_get_ntohs(tvb, 1) >> 4;
@@ -345,8 +346,7 @@ dissect_control(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, int is_
 	}
 
 	/* Add info */
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_add_str(pinfo->cinfo, COL_INFO, info);
+	col_add_str(pinfo->cinfo, COL_INFO, info);
 
 	/* Create item & subtree */
 	ctl_ti = proto_tree_add_uint_format_value(
@@ -505,7 +505,7 @@ dissect_lapsat(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	if ((plen + hlen) == tvb_length(tvb)) {
 		/* Need to integrate the last nibble */
-		guint8 *data = (guint8 *)tvb_memdup(tvb, hlen, plen);
+		guint8 *data = (guint8 *)tvb_memdup(NULL, tvb, hlen, plen);
 		data[plen-1] |= tvb_get_guint8(tvb, 2) << 4;
 		payload = tvb_new_child_real_data(tvb, data, plen, plen);
 		tvb_set_free_cb(payload, g_free);
@@ -521,7 +521,7 @@ dissect_lapsat(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		/*
 		 * Potentially fragmented I frames
 		 */
-		fragment_data *fd_m = NULL;
+		fragment_head *fd_m = NULL;
 		tvbuff_t *reassembled = NULL;
 		guint32 fragment_id;
 		gboolean save_fragmented = pinfo->fragmented;
