@@ -3,7 +3,7 @@
  * Copyright 2009, Vasantha Crabb <vcrabb@managesoft.com.au>
  *  and Chris Adams <cadams@managesoft.com.au>
  *
- * $Id$
+ * $Id: packet-ldss.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -50,6 +50,7 @@
 #include <epan/ipproto.h>
 #include <epan/prefs.h>
 #include <epan/strutil.h>
+#include <epan/wmem/wmem.h>
 #include <epan/dissectors/packet-tcp.h>
 
 /* The digest is up to 32 bytes long */
@@ -222,7 +223,7 @@ prepare_ldss_transfer_conv(ldss_broadcast_t *broadcast)
 	conversation_t *transfer_conv;
 	ldss_transfer_info_t *transfer_info;
 
-	transfer_info = se_new0(ldss_transfer_info_t);
+	transfer_info = wmem_new0(wmem_file_scope(), ldss_transfer_info_t);
 	transfer_info->broadcast = broadcast;
 
 	/* Preparation for later push/pull dissection */
@@ -287,7 +288,7 @@ dissect_ldss_broadcast(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	digest_type = tvb_get_guint8 (tvb,  2);
 	compression = tvb_get_guint8 (tvb,  3);
 	cookie      = tvb_get_ntohl  (tvb,  4);
-	digest      = (guint8 *)tvb_memdup (tvb,  8, DIGEST_LEN);
+	digest      = (guint8 *)tvb_memdup (NULL, tvb,  8, DIGEST_LEN);
 	size	    = tvb_get_ntoh64 (tvb, 40);
 	offset	    = tvb_get_ntoh64 (tvb, 48);
 	targetTime  = tvb_get_ntohl  (tvb, 56);
@@ -324,11 +325,9 @@ dissect_ldss_broadcast(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	packet_detail = val_to_str_const(messageDetail, ldss_inferred_info, "unknown");
 
 	/* Set the info column */
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_add_fstr(pinfo->cinfo, COL_INFO, "LDSS Broadcast (%s%s)",
+	col_add_fstr(pinfo->cinfo, COL_INFO, "LDSS Broadcast (%s%s)",
 			     packet_type,
 			     packet_detail);
-	}
 
 	/* If we have a non-null tree (ie we are building the proto_tree
 	 * instead of just filling out the columns), then give more detail. */
@@ -412,7 +411,7 @@ dissect_ldss_broadcast(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		ldss_broadcast_t *data;
 
 		/* Populate data from the broadcast */
-		data = se_new0(ldss_broadcast_t);
+		data = wmem_new0(wmem_file_scope(), ldss_broadcast_t);
 		data->num = pinfo->fd->num;
 		data->ts = pinfo->fd->abs_ts;
 		data->message_id = messageID;
@@ -422,11 +421,11 @@ dissect_ldss_broadcast(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		data->offset = offset;
 		data->compression = compression;
 
-		data->file = se_new0(ldss_file_t);
+		data->file = wmem_new0(wmem_file_scope(), ldss_file_t);
 		data->file->digest = digest;
 		data->file->digest_type = digest_type;
 
-		data->broadcaster = se_new0(ldss_broadcaster_t);
+		data->broadcaster = wmem_new0(wmem_file_scope(), ldss_broadcaster_t);
 		COPY_ADDRESS(&data->broadcaster->addr, &pinfo->src);
 		data->broadcaster->port = port;
 
@@ -495,8 +494,8 @@ dissect_ldss_transfer (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		    highest_num_seen < pinfo->fd->num) {
 
 			already_dissected = FALSE;
-			transfer_info->req = se_new0(ldss_file_request_t);
-			transfer_info->req->file = se_new0(ldss_file_t);
+			transfer_info->req = wmem_new0(wmem_file_scope(), ldss_file_request_t);
+			transfer_info->req->file = wmem_new0(wmem_file_scope(), ldss_file_t);
 			highest_num_seen = pinfo->fd->num;
 		}
 
@@ -523,7 +522,7 @@ dissect_ldss_transfer (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 						    FALSE);
 
 			/* Include new-line in line */
-			line = (guint8 *)tvb_memdup(tvb, offset, linelen+1); /* XXX - memory leak? */
+			line = (guint8 *)tvb_memdup(NULL, tvb, offset, linelen+1); /* XXX - memory leak? */
 
 			if (tree) {
 				ti = proto_tree_add_text(ldss_tree, tvb, offset, linelen,
@@ -609,7 +608,7 @@ dissect_ldss_transfer (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					if(digest_bytes->len >= DIGEST_LEN)
 						digest_bytes->len = (DIGEST_LEN-1);
 					/* Ensure the digest is zero-padded */
-					transfer_info->file->digest = (guint8 *)se_alloc0(DIGEST_LEN);
+					transfer_info->file->digest = (guint8 *)wmem_alloc0(wmem_file_scope(), DIGEST_LEN);
 					memcpy(transfer_info->file->digest, digest_bytes->data, digest_bytes->len);
 
 					g_byte_array_free(digest_bytes, TRUE);
@@ -680,12 +679,10 @@ dissect_ldss_transfer (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		transfer_info->resp_num = pinfo->fd->num;
 		transfer_info->resp_ts = pinfo->fd->abs_ts;
 
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_add_fstr(pinfo->cinfo, COL_INFO, "LDSS File Transfer (Sending file - %s)",
+		col_add_fstr(pinfo->cinfo, COL_INFO, "LDSS File Transfer (Sending file - %s)",
 				     transfer_info->broadcast->message_id == MESSAGE_ID_WILLSEND
 				     ? "pull"
 				     : "push");
-		}
 
 		if (tree) {
 			ti = proto_tree_add_item(tree, proto_ldss,
