@@ -2,7 +2,7 @@
  * Routines for Locator/ID Separation Protocol (LISP) Control Message dissection
  * Copyright 2011, Lorand Jakab <lj@lispmon.net>
  *
- * $Id$
+ * $Id: packet-lisp.c 52055 2013-09-15 13:46:13Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,6 +30,7 @@
 #include <epan/afn.h>
 #include <epan/ipv6-utils.h>
 #include <epan/expert.h>
+#include <epan/wmem/wmem.h>
 
 #define INET_ADDRLEN        4
 #define INET6_ADDRLEN       16
@@ -140,6 +141,7 @@ static int hf_lisp_xtrid = -1;
 static int hf_lisp_siteid = -1;
 
 /* Map-Request fields */
+static int hf_lisp_mreq_flags = -1;
 static int hf_lisp_mreq_flags_auth = -1;
 static int hf_lisp_mreq_flags_mrp = -1;
 static int hf_lisp_mreq_flags_probe = -1;
@@ -148,10 +150,21 @@ static int hf_lisp_mreq_flags_pitr = -1;
 static int hf_lisp_mreq_flags_smri = -1;
 static int hf_lisp_mreq_res = -1;
 static int hf_lisp_mreq_srceid_afi = -1;
-static int hf_lisp_mreq_srceid = -1;
-static int hf_lisp_mreq_srceidv6 = -1;
+static int hf_lisp_mreq_srceid_string = -1;
+static int hf_lisp_mreq_srceid_ipv4 = -1;
+static int hf_lisp_mreq_srceid_ipv6 = -1;
+static int hf_lisp_mreq_srceid_lacf = -1;
+static int hf_lisp_mreq_itr_rloc = -1;
+static int hf_lisp_mreq_itr_rloc_afi = -1;
 static int hf_lisp_mreq_srcitr = -1;
 static int hf_lisp_mreq_srcitrv6 = -1;
+static int hf_lisp_mreq_record = -1;
+static int hf_lisp_mreq_record_reserved = -1;
+static int hf_lisp_mreq_record_prefix_length = -1;
+static int hf_lisp_mreq_record_prefix_afi = -1;
+static int hf_lisp_mreq_record_prefix_ipv4 = -1;
+static int hf_lisp_mreq_record_prefix_ipv6 = -1;
+static int hf_lisp_mreq_record_prefix_lcaf = -1;
 
 /* Map-Reply fields */
 static int hf_lisp_mrep_flags_probe = -1;
@@ -185,6 +198,7 @@ static int hf_lisp_info_res2 = -1;
 static int hf_lisp_info_afi = -1;
 
 /* Mapping record fields */
+static int hf_lisp_mapping = -1;
 static int hf_lisp_mapping_ttl = -1;
 static int hf_lisp_mapping_loccnt = -1;
 static int hf_lisp_mapping_eid_masklen = -1;
@@ -196,6 +210,20 @@ static int hf_lisp_mapping_ver = -1;
 static int hf_lisp_mapping_eid_afi = -1;
 static int hf_lisp_mapping_eid = -1;
 
+/* Locator fields */
+static int hf_lisp_loc = -1;
+static int hf_lisp_loc_priority = -1;
+static int hf_lisp_loc_weight = -1;
+static int hf_lisp_loc_mpriority = -1;
+static int hf_lisp_loc_mweight = -1;
+static int hf_lisp_loc_flags = -1;
+static int hf_lisp_loc_flags_local = -1;
+static int hf_lisp_loc_flags_probe = -1;
+static int hf_lisp_loc_flags_reach = -1;
+static int hf_lisp_loc_flags_rsv = -1;
+static int hf_lisp_loc_afi = -1;
+static int hf_lisp_loc_locator = -1;
+
 /* LCAF fields */
 static int hf_lisp_lcaf_res1 = -1;
 static int hf_lisp_lcaf_flags = -1;
@@ -218,12 +246,22 @@ static int hf_lisp_ecm_res = -1;
 /* Initialize the subtree pointers */
 static gint ett_lisp = -1;
 static gint ett_lisp_mr = -1;
+static gint ett_lisp_mreq_flags = -1;
 static gint ett_lisp_mapping = -1;
 static gint ett_lisp_itr = -1;
 static gint ett_lisp_record = -1;
 static gint ett_lisp_lcaf = -1;
+static gint ett_lisp_loc = -1;
+static gint ett_lisp_loc_flags = -1;
 static gint ett_lisp_elp = -1;
 
+static expert_field ei_lisp_undecoded = EI_INIT;
+static expert_field ei_lisp_lcaf_type = EI_INIT;
+static expert_field ei_lisp_expected_field = EI_INIT;
+static expert_field ei_lisp_unexpected_field = EI_INIT;
+
+static dissector_handle_t lisp_handle;
+
 static dissector_handle_t ipv4_handle;
 static dissector_handle_t ipv6_handle;
 static dissector_handle_t data_handle;
@@ -336,7 +374,7 @@ get_addr_str(tvbuff_t *tvb, gint offset, guint16 afi, guint16 *addr_len)
                 iid = tvb_get_ntohl(tvb, offset + LCAF_HEADER_LEN);
                 afi = tvb_get_ntohs(tvb, offset + LCAF_HEADER_LEN + 4);
                 addr_str = get_addr_str(tvb, offset + LCAF_HEADER_LEN + 6, afi, &cur_len);
-                return ep_strdup_printf("[%d] %s", iid, addr_str);
+                return wmem_strdup_printf(wmem_packet_scope(), "[%d] %s", iid, addr_str);
             }
             return addr_str;
         default:
@@ -356,7 +394,7 @@ dissect_lcaf_natt_rloc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     rloc_str = get_addr_str(tvb, offset, rloc_afi, &addr_len);
 
     if (rloc_str == NULL) {
-        expert_add_info_format(pinfo, tree, PI_PROTOCOL, PI_ERROR,
+        expert_add_info_format(pinfo, tree, &ei_lisp_unexpected_field,
                 "Unexpected RLOC AFI (%d), cannot decode", rloc_afi);
         return offset;
     }
@@ -385,7 +423,7 @@ dissect_lcaf_elp_hop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     hop_str   = get_addr_str(tvb, offset, hop_afi, &addr_len);
 
     if (hop_str == NULL) {
-        expert_add_info_format(pinfo, tree, PI_PROTOCOL, PI_ERROR,
+        expert_add_info_format(pinfo, tree, &ei_lisp_unexpected_field,
                 "Unexpected reencap hop AFI (%d), cannot decode", hop_afi);
         return offset;
     }
@@ -456,7 +494,7 @@ dissect_lcaf_afi_list(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
                 remaining -= (offset - old_offset);
                 break;
             default:
-                expert_add_info_format(pinfo, tree, PI_PROTOCOL, PI_ERROR,
+                expert_add_info_format(pinfo, tree, &ei_lisp_unexpected_field,
                         "Unexpected AFI (%d), cannot decode", afi);
                 return -1;
         }
@@ -687,10 +725,9 @@ dissect_lcaf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gint offset)
             break;
         default:
             if (lcaf_type < 13)
-                expert_add_undecoded_item(tvb, pinfo, tree, offset,
-                        len, PI_WARN);
+                proto_tree_add_expert(tree, pinfo, &ei_lisp_undecoded, tvb, offset, len);
             else
-                expert_add_info_format(pinfo, tree, PI_PROTOCOL, PI_ERROR,
+                expert_add_info_format(pinfo, tree, &ei_lisp_lcaf_type,
                         "LCAF type %d is not defined in draft-farinacci-lisp-lcaf-%d",
                         lcaf_type, LCAF_DRAFT_VERSION);
             return offset + len;
@@ -726,31 +763,51 @@ dissect_lisp_locator(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_mapping
     guint16      flags;
     guint16      loc_afi;
     const gchar *locator;
-    proto_item  *tir;
-    proto_tree  *lisp_elp_tree;
+    proto_item  *tir, *ti_flags;
+    proto_tree  *lisp_elp_tree, *lisp_loc_tree, *lisp_flags_tree;
 
-    prio     = tvb_get_guint8(tvb, offset); offset += 1;
-    weight   = tvb_get_guint8(tvb, offset); offset += 1;
-    m_prio   = tvb_get_guint8(tvb, offset); offset += 1;
-    m_weight = tvb_get_guint8(tvb, offset); offset += 1;
-    flags    = tvb_get_ntohs(tvb, offset);  offset += 2;
-    loc_afi  = tvb_get_ntohs(tvb, offset);  offset += 2;
+    tir = proto_tree_add_item(lisp_mapping_tree, hf_lisp_loc, tvb, offset, 8, ENC_NA);
+
+    lisp_loc_tree = proto_item_add_subtree(tir, ett_lisp_loc);
+
+    proto_tree_add_item(lisp_loc_tree, hf_lisp_loc_priority, tvb, offset, 1, ENC_BIG_ENDIAN);
+    prio = tvb_get_guint8(tvb, offset);
+    offset += 1;
+
+    proto_tree_add_item(lisp_loc_tree, hf_lisp_loc_weight, tvb, offset, 1, ENC_BIG_ENDIAN);
+    weight = tvb_get_guint8(tvb, offset);
+    offset += 1;
+
+    proto_tree_add_item(lisp_loc_tree, hf_lisp_loc_mpriority, tvb, offset, 1, ENC_BIG_ENDIAN);
+    m_prio = tvb_get_guint8(tvb, offset);
+    offset += 1;
+
+    proto_tree_add_item(lisp_loc_tree, hf_lisp_loc_mweight, tvb, offset, 1, ENC_BIG_ENDIAN);
+    m_weight = tvb_get_guint8(tvb, offset);
+    offset += 1;
+
+    ti_flags = proto_tree_add_item(lisp_loc_tree, hf_lisp_loc_flags, tvb, offset, 2, ENC_BIG_ENDIAN);
+    lisp_flags_tree = proto_item_add_subtree(ti_flags, ett_lisp_loc_flags);
+    proto_tree_add_item(lisp_flags_tree, hf_lisp_loc_flags_reach, tvb, offset, 2, ENC_BIG_ENDIAN);
+    proto_tree_add_item(lisp_flags_tree, hf_lisp_loc_flags_probe, tvb, offset, 2, ENC_BIG_ENDIAN);
+    proto_tree_add_item(lisp_flags_tree, hf_lisp_loc_flags_local, tvb, offset, 2, ENC_BIG_ENDIAN);
+    proto_tree_add_item(lisp_flags_tree, hf_lisp_loc_flags_rsv, tvb, offset, 2, ENC_BIG_ENDIAN);
+    flags = tvb_get_ntohs(tvb, offset);
+    offset += 2;
+
+    proto_tree_add_item(lisp_loc_tree, hf_lisp_loc_afi, tvb, offset, 2, ENC_BIG_ENDIAN);
+    loc_afi  = tvb_get_ntohs(tvb, offset);
+    offset += 2;
 
     locator = get_addr_str(tvb, offset, loc_afi, &addr_len);
 
     if (locator == NULL) {
-        expert_add_info_format(pinfo, lisp_mapping_tree, PI_PROTOCOL, PI_ERROR,
+        expert_add_info_format(pinfo, lisp_mapping_tree, &ei_lisp_unexpected_field,
                 "Unexpected locator AFI (%d), cannot decode", loc_afi);
         return offset;
     }
 
-    tir = proto_tree_add_text(lisp_mapping_tree, tvb, 0, 8 + addr_len,
-            "%sRLOC: %s%s, %s, Priority/Weight: %d/%d, Multicast Priority/Weight: %d/%d",
-            (flags&LOCAL_BIT_MASK) ? "Local " : "",
-            locator,
-            (flags&PROBE_BIT_MASK) ? " (probed)" : "",
-            (flags&REACH_BIT_MASK) ? "Reachable" : "Unreachable",
-            prio, weight, m_prio, m_weight);
+    proto_tree_add_string(lisp_loc_tree, hf_lisp_loc_locator, tvb, offset, addr_len, locator);
 
     if (loc_afi == AFNUM_LCAF) {
         /* Create a sub-tree for the mapping */
@@ -760,6 +817,13 @@ dissect_lisp_locator(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_mapping
         offset += addr_len;
     }
 
+    proto_item_append_text(tir, " %s%s, %s, Priority/Weight: %d/%d, Multicast Priority/Weight: %d/%d",
+            locator,
+            (flags&PROBE_BIT_MASK) ? " (probed)" : "",
+            (flags&REACH_BIT_MASK) ? "Reachable" : "Unreachable",
+            prio, weight, m_prio, m_weight);
+    proto_item_set_len(tir, 8 + addr_len);
+
     return offset;
 }
 
@@ -787,11 +851,8 @@ dissect_lisp_mapping(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_tree,
 {
     int          i;
     gint         offset        = 0;
-    gint         offset_rec    = 0;
-    guint32      ttl;
     guint16      addr_len      = 0;
-    guint8       loc_cnt;
-    guint8       prefix_mask;
+    guint8       prefix_mask, loc_cnt;
     guint16      flags;
     guint16      act;
     guint16      prefix_afi;
@@ -799,31 +860,21 @@ dissect_lisp_mapping(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_tree,
     proto_item  *tir;
     proto_tree  *lisp_mapping_tree;
 
-    ttl           = tvb_get_ntohl(tvb, offset);  offset += 4;
-    loc_cnt       = tvb_get_guint8(tvb, offset); offset += 1;
-    prefix_mask   = tvb_get_guint8(tvb, offset); offset += 1;
-    flags         = tvb_get_ntohs(tvb, offset);  offset += 4;
-    prefix_afi    = tvb_get_ntohs(tvb, offset);  offset += 2;
+    prefix_mask   = tvb_get_guint8(tvb, 5);
+    flags         = tvb_get_ntohs(tvb, 6);
+    prefix_afi    = tvb_get_ntohs(tvb, 10);
 
     act = flags & LISP_MAP_ACT;
     act >>= 13;
 
-    prefix = get_addr_str(tvb, offset, prefix_afi, &addr_len);
+    prefix = get_addr_str(tvb, 12, prefix_afi, &addr_len);
 
     if (prefix == NULL) {
-        expert_add_info_format(pinfo, lisp_tree, PI_PROTOCOL, PI_ERROR,
+        expert_add_info_format(pinfo, lisp_tree, &ei_lisp_unexpected_field,
                 "Unexpected EID prefix AFI (%d), cannot decode", prefix_afi);
         return offset;
     }
-
-    tir = proto_tree_add_text(lisp_tree, tvb, 0, 12 + addr_len,
-            "EID prefix: %s/%d, TTL: %s, %sAuthoritative, %s%s",
-            prefix, prefix_mask,
-            (ttl == 0xFFFFFFFF) ? "Unlimited" : ep_strdup_printf("%d", ttl),
-            (flags&LISP_MAP_AUTH) ? "" : "Not ",
-            val_to_str(act, (referral) ? referral_actions : mapping_actions, "Invalid action code (%d)"),
-            (referral&&(flags&REFERRAL_INCOMPLETE)) ? " (Incomplete)" : "");
-    offset += addr_len;
+    tir = proto_tree_add_item(lisp_tree, hf_lisp_mapping, tvb, 0, 12 + addr_len, ENC_NA);
 
     /* Update the INFO column if there is only one record */
     if (rec_cnt == 1)
@@ -834,49 +885,62 @@ dissect_lisp_mapping(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_tree,
     lisp_mapping_tree = proto_item_add_subtree(tir, ett_lisp_mapping);
 
     /* TTL (32 bits) */
-    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_ttl, tvb, offset_rec, 4, ENC_BIG_ENDIAN);
-    offset_rec += 4;
+    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_ttl, tvb, offset, 4, ENC_BIG_ENDIAN);
+    if(tvb_get_ntohl(tvb, offset) == 0xFFFFFFFF){
+        proto_item_append_text(tir, " TTL: Unlimited");
+    }else{
+        proto_item_append_text(tir, " TTL: %d", tvb_get_ntohl(tvb, offset));
+    }
+    offset += 4;
 
     /* Locator count (8 bits) */
-    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_loccnt, tvb, offset_rec, 1, ENC_BIG_ENDIAN);
-    offset_rec += 1;
+    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_loccnt, tvb, offset, 1, ENC_BIG_ENDIAN);
+    loc_cnt = tvb_get_guint8(tvb, offset);
+    offset += 1;
 
     /* EID mask length (8 bits) */
-    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_eid_masklen, tvb, offset_rec, 1, ENC_BIG_ENDIAN);
-    offset_rec += 1;
+    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_eid_masklen, tvb, offset, 1, ENC_BIG_ENDIAN);
+    offset += 1;
 
     /* Action (3 bits) */
-    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_act, tvb, offset_rec, 2, ENC_BIG_ENDIAN);
+    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_act, tvb, offset, 2, ENC_BIG_ENDIAN);
+    proto_item_append_text(tir, " %s%s", val_to_str(act, (referral) ? referral_actions : mapping_actions, "Invalid action code (%d)"), (referral&&(flags&REFERRAL_INCOMPLETE)) ? " (Incomplete)" : "");
 
     /* Authoritative bit */
-    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_auth, tvb, offset_rec, 2, ENC_BIG_ENDIAN);
-
+    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_auth, tvb, offset, 2, ENC_BIG_ENDIAN);
+    if(flags&LISP_MAP_AUTH){
+        proto_item_append_text(tir, ", Authoritative");
+    }else{
+        proto_item_append_text(tir, ", Not Authoritative");
+    }
     /* Incomplete bit in Map-Referrals */
     if (referral)
-        proto_tree_add_item(lisp_mapping_tree, hf_lisp_referral_incomplete, tvb, offset_rec, 2, ENC_BIG_ENDIAN);
+        proto_tree_add_item(lisp_mapping_tree, hf_lisp_referral_incomplete, tvb, offset, 2, ENC_BIG_ENDIAN);
 
     /* Reserved (11 bits) */
-    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_res1, tvb, offset_rec, 2, ENC_BIG_ENDIAN);
-    offset_rec += 2;
+    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_res1, tvb, offset, 2, ENC_BIG_ENDIAN);
+    offset += 2;
 
     if (referral) {
         /* SigCnt (4 bits) */
-        proto_tree_add_item(lisp_mapping_tree, hf_lisp_referral_sigcnt, tvb, offset_rec, 2, ENC_BIG_ENDIAN);
+        proto_tree_add_item(lisp_mapping_tree, hf_lisp_referral_sigcnt, tvb, offset, 2, ENC_BIG_ENDIAN);
     } else {
         /* Reserved (4 bits) */
-        proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_res2, tvb, offset_rec, 2, ENC_BIG_ENDIAN);
+        proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_res2, tvb, offset, 2, ENC_BIG_ENDIAN);
     }
 
     /* Map-Version Number (12 bits) */
-    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_ver, tvb, offset_rec, 2, ENC_BIG_ENDIAN);
-    offset_rec += 2;
+    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_ver, tvb, offset, 2, ENC_BIG_ENDIAN);
+    offset += 2;
 
     /* EID prefix AFI (16 bits) */
-    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_eid_afi, tvb, offset_rec, 2, ENC_BIG_ENDIAN);
-    offset_rec += 2;
+    proto_tree_add_item(lisp_mapping_tree, hf_lisp_mapping_eid_afi, tvb, offset, 2, ENC_BIG_ENDIAN);
+    offset += 2;
 
     /* EID */
-    proto_tree_add_string(lisp_mapping_tree, hf_lisp_mapping_eid, tvb, offset_rec, offset - offset_rec, prefix);
+    proto_tree_add_string(lisp_mapping_tree, hf_lisp_mapping_eid, tvb, offset, addr_len, prefix);
+    proto_item_append_text(tir, ", EID Prefix: %s/%d", prefix, prefix_mask);
+    offset += addr_len;
 
     /* Locators */
     for(i=0; i < loc_cnt; i++) {
@@ -937,7 +1001,8 @@ dissect_lisp_map_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_tre
     guint8             rec_cnt     = 0;
     guint16            src_eid_afi;
     const gchar       *src_eid;
-    struct e_in6_addr  e_in6_addr;
+    proto_item        *ti_flags;
+    proto_tree        *flags_tree;
     tvbuff_t          *next_tvb;
 
     /* Flags (6 bits)*/
@@ -948,12 +1013,14 @@ dissect_lisp_map_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_tre
     pitr        = flags & (MAP_REQ_FLAG_p >> 8);
     smr_invoked = flags & (MAP_REQ_FLAG_s >> 8);
 
-    proto_tree_add_item(lisp_tree, hf_lisp_mreq_flags_auth, tvb, offset, 3, ENC_BIG_ENDIAN);
-    proto_tree_add_item(lisp_tree, hf_lisp_mreq_flags_mrp, tvb, offset, 3, ENC_BIG_ENDIAN);
-    proto_tree_add_item(lisp_tree, hf_lisp_mreq_flags_probe, tvb, offset, 3, ENC_BIG_ENDIAN);
-    proto_tree_add_item(lisp_tree, hf_lisp_mreq_flags_smr, tvb, offset, 3, ENC_BIG_ENDIAN);
-    proto_tree_add_item(lisp_tree, hf_lisp_mreq_flags_pitr, tvb, offset, 3, ENC_BIG_ENDIAN);
-    proto_tree_add_item(lisp_tree, hf_lisp_mreq_flags_smri, tvb, offset, 3, ENC_BIG_ENDIAN);
+    ti_flags = proto_tree_add_item(lisp_tree, hf_lisp_mreq_flags, tvb, offset, 3, ENC_BIG_ENDIAN);
+    flags_tree = proto_item_add_subtree(ti_flags, ett_lisp_mreq_flags);
+    proto_tree_add_item(flags_tree, hf_lisp_mreq_flags_auth, tvb, offset, 3, ENC_BIG_ENDIAN);
+    proto_tree_add_item(flags_tree, hf_lisp_mreq_flags_mrp, tvb, offset, 3, ENC_BIG_ENDIAN);
+    proto_tree_add_item(flags_tree, hf_lisp_mreq_flags_probe, tvb, offset, 3, ENC_BIG_ENDIAN);
+    proto_tree_add_item(flags_tree, hf_lisp_mreq_flags_smr, tvb, offset, 3, ENC_BIG_ENDIAN);
+    proto_tree_add_item(flags_tree, hf_lisp_mreq_flags_pitr, tvb, offset, 3, ENC_BIG_ENDIAN);
+    proto_tree_add_item(flags_tree, hf_lisp_mreq_flags_smri, tvb, offset, 3, ENC_BIG_ENDIAN);
 
     if (pitr)
         col_append_str(pinfo->cinfo, COL_INFO, " by P-ITR");
@@ -968,7 +1035,7 @@ dissect_lisp_map_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_tre
         col_append_str(pinfo->cinfo, COL_INFO, " (SMR-invoked)");
 
     /* Reserved bits (9 bits) */
-    proto_tree_add_item(lisp_tree, hf_lisp_mreq_res, tvb, offset, 3, ENC_BIG_ENDIAN);
+    proto_tree_add_item(flags_tree, hf_lisp_mreq_res, tvb, offset, 3, ENC_BIG_ENDIAN);
 
     /* ITR record count (5 bits) */
     itr_rec_cnt = tvb_get_guint8(tvb, offset + 2) & 0x1F;
@@ -992,26 +1059,25 @@ dissect_lisp_map_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_tre
     /* Source EID */
     switch (src_eid_afi) {
         case AFNUM_RESERVED:
-            proto_tree_add_text(lisp_tree, tvb, offset, 0, "Source EID: not set");
+            proto_tree_add_string(lisp_tree, hf_lisp_mreq_srceid_string, tvb, offset, 0, "not set");
             break;
         case AFNUM_INET:
-            proto_tree_add_ipv4(lisp_tree,
-                    hf_lisp_mreq_srceid, tvb, offset, INET_ADDRLEN, tvb_get_ipv4(tvb, offset));
+            proto_tree_add_item(lisp_tree,
+                    hf_lisp_mreq_srceid_ipv4, tvb, offset, INET_ADDRLEN, ENC_BIG_ENDIAN);
             offset += INET_ADDRLEN;
             break;
         case AFNUM_INET6:
-            tvb_get_ipv6(tvb, offset, &e_in6_addr);
-            proto_tree_add_ipv6(lisp_tree,
-                    hf_lisp_mreq_srceidv6, tvb, offset, INET6_ADDRLEN, (guint8 *)&e_in6_addr);
+            proto_tree_add_item(lisp_tree,
+                    hf_lisp_mreq_srceid_ipv6, tvb, offset, INET6_ADDRLEN, ENC_NA);
             offset += INET6_ADDRLEN;
             break;
         case AFNUM_LCAF:
             src_eid = get_addr_str(tvb, offset, src_eid_afi, &addr_len);
-            proto_tree_add_text(lisp_tree, tvb, offset, addr_len, "Source EID: %s", src_eid);
+            proto_tree_add_string(lisp_tree, hf_lisp_mreq_srceid_lacf, tvb, offset, addr_len, src_eid);
             offset += addr_len;
             break;
         default:
-            expert_add_info_format(pinfo, lisp_tree, PI_PROTOCOL, PI_ERROR,
+            expert_add_info_format(pinfo, lisp_tree, &ei_lisp_unexpected_field,
                     "Unexpected Source EID AFI (%d), cannot decode", src_eid_afi);
             next_tvb = tvb_new_subset_remaining(tvb, offset);
             call_dissector(data_handle, next_tvb, pinfo, lisp_tree);
@@ -1021,36 +1087,30 @@ dissect_lisp_map_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_tre
     /* ITR records */
     for(i=0; i < itr_rec_cnt+1; i++) {
         guint16 itr_afi;
-        guint32 itr_rloc_v4;
-        struct e_in6_addr itr_rloc_v6;
         proto_item *tir;
         proto_tree *lisp_itr_tree;
 
         itr_afi = tvb_get_ntohs(tvb, offset);
+        tir = proto_tree_add_item(lisp_tree, hf_lisp_mreq_itr_rloc, tvb, offset, 2, ENC_NA);
+        lisp_itr_tree = proto_item_add_subtree(tir, ett_lisp_itr);
+        proto_tree_add_item(lisp_itr_tree, hf_lisp_mreq_itr_rloc_afi, tvb, offset, 2, ENC_NA);
+        offset += 2;
 
         switch (itr_afi) {
             case AFNUM_INET:
-                itr_rloc_v4 = tvb_get_ipv4(tvb, offset + 2);
-                tir = proto_tree_add_text(lisp_tree, tvb, offset, INET_ADDRLEN + 2,
-                        "ITR-RLOC %d: %s", i + 1, ip_to_str((guint8 *)&itr_rloc_v4));
-                lisp_itr_tree = proto_item_add_subtree(tir, ett_lisp_itr);
-                proto_tree_add_text(lisp_itr_tree, tvb, offset, 2, "ITR-RLOC-AFI: %d", itr_afi);
-                proto_tree_add_ipv4(lisp_itr_tree, hf_lisp_mreq_srcitr, tvb, offset + 2,
-                        INET_ADDRLEN, itr_rloc_v4);
-                offset += INET_ADDRLEN + 2;
+                proto_tree_add_item(lisp_itr_tree, hf_lisp_mreq_srcitr, tvb, offset, 4, ENC_BIG_ENDIAN);
+                proto_item_append_text(tir, " %d: %s", i + 1, tvb_ip_to_str(tvb, offset));
+                proto_item_set_len(tir, 2 + 4);
+                offset += 4;
                 break;
             case AFNUM_INET6:
-                tvb_get_ipv6(tvb, offset + 2, &itr_rloc_v6);
-                tir = proto_tree_add_text(lisp_tree, tvb, offset, INET6_ADDRLEN + 2,
-                        "ITR-RLOC %d: %s", i + 1, ip6_to_str(&itr_rloc_v6));
-                lisp_itr_tree = proto_item_add_subtree(tir, ett_lisp_itr);
-                proto_tree_add_text(lisp_itr_tree, tvb, offset, 2, "ITR-RLOC-AFI: %d", itr_afi);
-                proto_tree_add_ipv6(lisp_itr_tree, hf_lisp_mreq_srcitrv6, tvb, offset + 2,
-                        INET6_ADDRLEN, (guint8 *)&itr_rloc_v6);
-                offset += INET6_ADDRLEN + 2;
+                proto_tree_add_item(lisp_itr_tree, hf_lisp_mreq_srcitrv6, tvb, offset, 16, ENC_NA);
+                proto_item_append_text(tir, " %d: %s", i + 1, tvb_ip6_to_str(tvb, offset));
+                proto_item_set_len(tir, 2 + 16);
+                offset += 16;
                 break;
             default:
-                expert_add_info_format(pinfo, lisp_tree, PI_PROTOCOL, PI_ERROR,
+                expert_add_info_format(pinfo, lisp_tree, &ei_lisp_unexpected_field,
                         "Unexpected ITR-RLOC-AFI (%d), cannot decode", itr_afi);
                 next_tvb = tvb_new_subset_remaining(tvb, offset);
                 call_dissector(data_handle, next_tvb, pinfo, lisp_tree);
@@ -1060,43 +1120,55 @@ dissect_lisp_map_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_tre
 
     /* Query records */
     for(i=0; i < rec_cnt; i++) {
-        guint16 reserved, prefix_mask;
+        guint16 prefix_mask;
         guint16 prefix_afi;
         const gchar *prefix;
         proto_item *tir;
         proto_tree *lisp_record_tree;
 
         addr_len = 0;
-        reserved = tvb_get_guint8(tvb, offset);
         prefix_mask = tvb_get_guint8(tvb, offset + 1);
         prefix_afi = tvb_get_ntohs(tvb, offset + 2);
         prefix = get_addr_str(tvb, offset + 4, prefix_afi, &addr_len);
 
         if (prefix == NULL) {
-            expert_add_info_format(pinfo, lisp_tree, PI_PROTOCOL, PI_ERROR,
+            expert_add_info_format(pinfo, lisp_tree, &ei_lisp_unexpected_field,
                     "Unexpected EID prefix AFI (%d), cannot decode", prefix_afi);
             next_tvb = tvb_new_subset_remaining(tvb, offset);
             call_dissector(data_handle, next_tvb, pinfo, lisp_tree);
             return;
         }
 
-        tir = proto_tree_add_text(lisp_tree, tvb, offset, 4 + addr_len,
-                "Record %d: %s/%d", i+1, prefix, prefix_mask);
+        tir = proto_tree_add_item(lisp_tree, hf_lisp_mreq_record, tvb, offset, 4+addr_len, ENC_NA);
 
         /* Update the INFO column if there is only one record */
         if (rec_cnt == 1)
             col_append_fstr(pinfo->cinfo, COL_INFO, " for %s/%d", prefix, prefix_mask);
 
         lisp_record_tree = proto_item_add_subtree(tir, ett_lisp_record);
-        proto_tree_add_text(lisp_record_tree, tvb, offset, 1, "Reserved bits: 0x%02X",
-                reserved);
-        proto_tree_add_text(lisp_record_tree, tvb, offset + 1, 1, "Prefix length: %d",
-                prefix_mask);
-        proto_tree_add_text(lisp_record_tree, tvb, offset + 2, 2, "Prefix AFI: %d",
-                prefix_afi);
-        proto_tree_add_text(lisp_record_tree, tvb, offset + 4, addr_len, "Prefix: %s",
-                prefix);
-        offset += 4 + addr_len;
+        proto_tree_add_item(lisp_record_tree, hf_lisp_mreq_record_reserved, tvb, offset, 1, ENC_NA);
+        offset += 1;
+
+        proto_tree_add_item(lisp_record_tree, hf_lisp_mreq_record_prefix_length, tvb, offset, 1, ENC_NA);
+        offset += 1;
+
+        proto_tree_add_item(lisp_record_tree, hf_lisp_mreq_record_prefix_afi, tvb, offset, 2, ENC_NA);
+        offset += 2;
+
+        switch(prefix_afi){
+            case AFNUM_INET:
+                proto_tree_add_item(lisp_record_tree, hf_lisp_mreq_record_prefix_ipv4, tvb, offset, 4, ENC_NA);
+                offset += 4;
+            break;
+            case AFNUM_INET6:
+                proto_tree_add_item(lisp_record_tree, hf_lisp_mreq_record_prefix_ipv6, tvb, offset, 16, ENC_NA);
+                offset += 16;
+            break;
+            case AFNUM_LCAF:
+                proto_tree_add_string(lisp_record_tree, hf_lisp_mreq_record_prefix_lcaf, tvb, offset, addr_len, prefix);
+                offset += addr_len;
+        }
+        proto_item_append_text(tir, " %d: %s/%d", i+1, prefix, prefix_mask);
     }
 
     /* If M bit is set, we also have a Map-Reply */
@@ -1106,7 +1178,7 @@ dissect_lisp_map_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_tre
         proto_item *tim;
         proto_tree *lisp_mr_tree;
 
-        tim = proto_tree_add_text(lisp_tree, tvb, offset, -1, "Map-Reply record");
+        tim = proto_tree_add_item(lisp_tree, hf_lisp_mreq_record, tvb, offset, -1, ENC_NA);
         lisp_mr_tree = proto_item_add_subtree(tim, ett_lisp_mr);
 
         rep_tvb = tvb_new_subset_remaining(tvb, offset);
@@ -1584,7 +1656,7 @@ dissect_lisp_info(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_tree)
     prefix      = get_addr_str(tvb, offset, prefix_afi, &addr_len);
 
     if (prefix == NULL) {
-        expert_add_info_format(pinfo, lisp_tree, PI_PROTOCOL, PI_ERROR,
+        expert_add_info_format(pinfo, lisp_tree, &ei_lisp_unexpected_field,
                 "Unexpected EID prefix AFI (%d), cannot decode", prefix_afi);
         next_tvb = tvb_new_subset_remaining(tvb, offset);
         call_dissector(data_handle, next_tvb, pinfo, lisp_tree);
@@ -1603,12 +1675,12 @@ dissect_lisp_info(tvbuff_t *tvb, packet_info *pinfo, proto_tree *lisp_tree)
 
     if (!reply) {
         if (afi != 0) {
-            expert_add_info_format(pinfo, tir, PI_PROTOCOL, PI_ERROR,
+            expert_add_info_format(pinfo, tir, &ei_lisp_expected_field,
                     "Expecting NULL AFI (0), found %d, incorrect packet!", afi);
         }
     } else {
         if (afi != AFNUM_LCAF) {
-            expert_add_info_format(pinfo, tir, PI_PROTOCOL, PI_ERROR,
+            expert_add_info_format(pinfo, tir, &ei_lisp_expected_field,
                     "Expecting LCAF AFI (%d), found %d, incorrect packet!",
                     AFNUM_LCAF, afi);
         } else {
@@ -1770,6 +1842,9 @@ proto_register_lisp(void)
         { &hf_lisp_nonce,
             { "Nonce", "lisp.nonce",
             FT_UINT64, BASE_HEX, NULL, 0x0, NULL, HFILL }},
+        { &hf_lisp_mreq_flags,
+            { "Flags", "lisp.mreq.flags",
+            FT_UINT24, BASE_HEX, NULL, 0x0, NULL, HFILL }},
         { &hf_lisp_mreq_flags_auth,
             { "A bit (Authoritative)", "lisp.mreq.flags.auth",
             FT_BOOLEAN, 24, TFS(&tfs_set_notset), MAP_REQ_FLAG_A, NULL, HFILL }},
@@ -1794,18 +1869,51 @@ proto_register_lisp(void)
         { &hf_lisp_mreq_srceid_afi,
             { "Source EID AFI", "lisp.mreq.srceid_afi",
             FT_UINT16, BASE_DEC, VALS(afn_vals), 0x0, "Source EID Address Family Indicator", HFILL }},
-        { &hf_lisp_mreq_srceid,
-            { "Source EID", "lisp.mreq.srceid",
+        { &hf_lisp_mreq_srceid_string,
+            { "Source EID", "lisp.mreq.srceid_string",
+            FT_STRING, BASE_NONE, NULL, 0x0, "Source EID Address", HFILL }},
+        { &hf_lisp_mreq_srceid_ipv4,
+            { "Source EID", "lisp.mreq.srceid_ipv4",
             FT_IPv4, BASE_NONE, NULL, 0x0, "Source EID Address", HFILL }},
-        { &hf_lisp_mreq_srceidv6,
-            { "Source EID", "lisp.mreq.srceidv6",
+        { &hf_lisp_mreq_srceid_ipv6,
+            { "Source EID", "lisp.mreq.srceid_ipv6",
             FT_IPv6, BASE_NONE, NULL, 0x0, "Source EID Address", HFILL }},
+        { &hf_lisp_mreq_srceid_lacf,
+            { "Source EID", "lisp.mreq.srceid_lacf",
+            FT_STRING, BASE_NONE, NULL, 0x0, "Source EID Address", HFILL }},
+        { &hf_lisp_mreq_itr_rloc,
+            { "ITR-RLOC", "lisp.mreq.itr_rloc",
+            FT_NONE, BASE_NONE, NULL, 0x0, "Originating ITR RLOC Address", HFILL }},
+        { &hf_lisp_mreq_itr_rloc_afi,
+            { "ITR-RLOC AFI", "lisp.mreq.itr_rloc.afi",
+            FT_UINT16, BASE_DEC, VALS(afn_vals), 0x0, "Originating ITR RLOC Address Family Indicator", HFILL }},
         { &hf_lisp_mreq_srcitr,
             { "ITR-RLOC Address", "lisp.mreq.srcitr",
             FT_IPv4, BASE_NONE, NULL, 0x0, "Originating ITR RLOC Address", HFILL }},
         { &hf_lisp_mreq_srcitrv6,
             { "ITR-RLOC Address", "lisp.mreq.srcitrv6",
             FT_IPv6, BASE_NONE, NULL, 0x0, "Originating ITR RLOC Address", HFILL }},
+        { &hf_lisp_mreq_record_reserved,
+            { "Reserved", "lisp.mreq.record.reserved",
+            FT_UINT8, BASE_HEX, NULL, 0x0, NULL, HFILL }},
+        { &hf_lisp_mreq_record_prefix_length,
+            { "Prefix Length", "lisp.mreq.record.prefix.length",
+            FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
+        { &hf_lisp_mreq_record_prefix_afi,
+            { "Prefix AFI", "lisp.mreq.record.prefix.afi",
+            FT_UINT16, BASE_DEC, VALS(afn_vals), 0x0, NULL, HFILL }},
+        { &hf_lisp_mreq_record_prefix_ipv4,
+            { "Prefix (IPv4)", "lisp.mreq.record.prefix.ipv4",
+            FT_IPv4, BASE_NONE, NULL, 0x0, NULL, HFILL }},
+        { &hf_lisp_mreq_record_prefix_ipv6,
+            { "Prefix (IPv6)", "lisp.mreq.record.prefix.ipv6",
+            FT_IPv6, BASE_NONE, NULL, 0x0, NULL, HFILL }},
+        { &hf_lisp_mreq_record_prefix_lcaf,
+            { "Prefix (LCAF)", "lisp.mreq.record.prefix.lcaf",
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }},
+        { &hf_lisp_mreq_record,
+            { "Map-Reply record", "lisp.mreq.record",
+            FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
         { &hf_lisp_mrep_flags_probe,
             { "P bit (Probe)", "lisp.mrep.flags.probe",
             FT_BOOLEAN, 24, TFS(&tfs_set_notset), MAP_REP_FLAG_P, NULL, HFILL }},
@@ -1887,6 +1995,45 @@ proto_register_lisp(void)
         { &hf_lisp_info_afi,
             { "AFI", "lisp.info.afi",
             FT_UINT16, BASE_DEC, VALS(afn_vals), 0x0, "Address Family Indicator", HFILL }},
+        { &hf_lisp_loc,
+            { "LOC", "lisp.loc",
+            FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
+        { &hf_lisp_loc_priority,
+            { "Priority", "lisp.loc.priority",
+            FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
+        { &hf_lisp_loc_weight,
+            { "Weight", "lisp.loc.weight",
+            FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
+        { &hf_lisp_loc_mpriority,
+            { "Multicast Priority", "lisp.loc.multicast_priority",
+            FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
+        { &hf_lisp_loc_mweight,
+            { "Multicast Weight", "lisp.loc.multicast_weight",
+            FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
+        { &hf_lisp_loc_flags,
+            { "Flags", "lisp.loc.flags",
+            FT_UINT16, BASE_HEX, NULL, 0x0, NULL, HFILL }},
+        { &hf_lisp_loc_flags_local,
+            { "Local", "lisp.loc.flags.local",
+            FT_BOOLEAN, 16, TFS(&tfs_set_notset), LOCAL_BIT_MASK, NULL, HFILL }},
+        { &hf_lisp_loc_flags_probe,
+            { "Probe", "lisp.loc.flags.probe",
+            FT_BOOLEAN, 16, TFS(&tfs_set_notset), PROBE_BIT_MASK, NULL, HFILL }},
+        { &hf_lisp_loc_flags_reach,
+            { "Reach", "lisp.loc.flags.reach",
+            FT_BOOLEAN, 16, TFS(&tfs_set_notset), REACH_BIT_MASK, NULL, HFILL }},
+        { &hf_lisp_loc_flags_rsv,
+            { "Reserved", "lisp.loc.flags.rsv",
+            FT_UINT16, BASE_HEX, NULL, 0xFFF8, "Must be zero", HFILL }},
+        { &hf_lisp_loc_afi,
+            { "AFI", "lisp.loc.afi",
+            FT_UINT16, BASE_DEC, VALS(lcaf_typevals), 0x0, NULL, HFILL }},
+        { &hf_lisp_loc_locator,
+            { "Locator", "lisp.loc.locator",
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }},
+        { &hf_lisp_mapping,
+            { "Mapping", "lisp.mapping",
+            FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
         { &hf_lisp_mapping_ttl,
             { "Record TTL", "lisp.mapping.ttl",
             FT_UINT32, BASE_DEC, NULL, 0x0, NULL, HFILL }},
@@ -1962,13 +2109,25 @@ proto_register_lisp(void)
     static gint *ett[] = {
         &ett_lisp,
         &ett_lisp_mr,
+        &ett_lisp_mreq_flags,
         &ett_lisp_mapping,
         &ett_lisp_itr,
         &ett_lisp_record,
         &ett_lisp_lcaf,
+        &ett_lisp_loc,
+        &ett_lisp_loc_flags,
         &ett_lisp_elp
     };
 
+    static ei_register_info ei[] = {
+        { &ei_lisp_undecoded, { "lisp.undecoded", PI_UNDECODED, PI_WARN, "Not dissected yet (report to wireshark.org)", EXPFILL }},
+        { &ei_lisp_unexpected_field, { "lisp.unexpected_field", PI_PROTOCOL, PI_ERROR, "Unexpected field", EXPFILL }},
+        { &ei_lisp_lcaf_type, { "lisp.lcaf.type.invalid", PI_PROTOCOL, PI_ERROR, "LCAF type is not defined in draft-farinacci-lisp-lcaf-X", EXPFILL }},
+        { &ei_lisp_expected_field, { "lisp.expected_field", PI_PROTOCOL, PI_ERROR, "Expecting field", EXPFILL }},
+    };
+
+    expert_module_t* expert_lisp;
+
     /* Register the protocol name and description */
     proto_lisp = proto_register_protocol("Locator/ID Separation Protocol",
         "LISP Control", "lisp");
@@ -1976,9 +2135,11 @@ proto_register_lisp(void)
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_lisp, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_lisp = expert_register_protocol(proto_lisp);
+    expert_register_field_array(expert_lisp, ei, array_length(ei));
 
     /* Register dissector so that other dissectors can call it */
-    new_register_dissector("lisp", dissect_lisp, proto_lisp);
+    lisp_handle = new_register_dissector("lisp", dissect_lisp, proto_lisp);
 }
 
 
@@ -1990,9 +2151,6 @@ proto_register_lisp(void)
 void
 proto_reg_handoff_lisp(void)
 {
-    dissector_handle_t lisp_handle;
-
-    lisp_handle = new_create_dissector_handle(dissect_lisp, proto_lisp);
     dissector_add_uint("udp.port", LISP_CONTROL_PORT, lisp_handle);
     ipv4_handle = find_dissector("ip");
     ipv6_handle = find_dissector("ipv6");
