@@ -3,7 +3,7 @@
  *
  * (c) Copyright Ashok Narayanan <ashokn@cisco.com>
  *
- * $Id$
+ * $Id: packet-lmp.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -53,7 +53,7 @@
 #include <epan/in_cksum.h>
 #include <epan/etypes.h>
 #include <epan/ipproto.h>
-#include <show_exception.h>
+#include <epan/expert.h>
 
 #include "packet-ip.h"
 #include "packet-rsvp.h"
@@ -374,6 +374,9 @@ enum hf_lmp_filter_keys {
   LMPF_VAL_REMOTE_INTERFACE_ID_IPV4,
   LMPF_VAL_REMOTE_INTERFACE_ID_IPV6,
   LMPF_VAL_REMOTE_INTERFACE_ID_UNNUM,
+  LMPF_VAL_CHANNEL_STATUS_INTERFACE_ID_IPV4,
+  LMPF_VAL_CHANNEL_STATUS_INTERFACE_ID_IPV6,
+  LMPF_VAL_CHANNEL_STATUS_INTERFACE_ID_UNNUM,
   LMPF_VAL_MESSAGE_ID,
   LMPF_VAL_MESSAGE_ID_ACK,
   LMPF_VAL_CONFIG_HELLO,
@@ -395,16 +398,20 @@ enum hf_lmp_filter_keys {
   LMPF_VAL_TE_LINK_FLAGS_FAULT_MGMT,
   LMPF_VAL_TE_LINK_FLAGS_LINK_VERIFY,
   LMPF_VAL_TE_LINK_LOCAL_IPV4,
+  LMPF_VAL_TE_LINK_LOCAL_IPV6,
   LMPF_VAL_TE_LINK_LOCAL_UNNUM,
   LMPF_VAL_TE_LINK_REMOTE_IPV4,
+  LMPF_VAL_TE_LINK_REMOTE_IPV6,
   LMPF_VAL_TE_LINK_REMOTE_UNNUM,
 
   LMPF_VAL_DATA_LINK_FLAGS,
   LMPF_VAL_DATA_LINK_FLAGS_PORT,
   LMPF_VAL_DATA_LINK_FLAGS_ALLOCATED,
   LMPF_VAL_DATA_LINK_LOCAL_IPV4,
+  LMPF_VAL_DATA_LINK_LOCAL_IPV6,
   LMPF_VAL_DATA_LINK_LOCAL_UNNUM,
   LMPF_VAL_DATA_LINK_REMOTE_IPV4,
+  LMPF_VAL_DATA_LINK_REMOTE_IPV6,
   LMPF_VAL_DATA_LINK_REMOTE_UNNUM,
   LMPF_VAL_DATA_LINK_SUBOBJ,
   LMPF_VAL_DATA_LINK_SUBOBJ_SWITCHING_TYPE,
@@ -488,11 +495,17 @@ enum hf_lmp_filter_keys {
   LMPF_VAL_LAD_INFO_SUBOBJ_SWITCHING_TYPE,
   LMPF_VAL_LAD_INFO_SUBOBJ_LSP_ENCODING,
 
+  LMPF_CHECKSUM,
+
   LMPF_MAX
 };
 
 static int hf_lmp_filter[LMPF_MAX];
 
+static expert_field ei_lmp_checksum_incorrect = EI_INIT;
+static expert_field ei_lmp_invalid_msg_type = EI_INIT;
+static expert_field ei_lmp_invalid_class = EI_INIT;
+
 static int
 lmp_valid_class(int lmp_class)
 {
@@ -660,7 +673,7 @@ dissect_lmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
     proto_tree *lmp_object_header_tree;
     proto_tree *lmp_flags_tree;
     proto_tree *lmp_subobj_tree;
-    proto_item *hidden_item;
+    proto_item *hidden_item, *msg_item;
 
     guint8 version;
     guint8 flags;
@@ -708,7 +721,7 @@ dissect_lmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 			       tvb, offset+2, 1, flags);
 	proto_tree_add_boolean(lmp_header_flags_tree, hf_lmp_filter[LMPF_HDR_FLAGS_REBOOT],
 			       tvb, offset+2, 1, flags);
-	proto_tree_add_uint(lmp_header_tree, hf_lmp_filter[LMPF_MSG], tvb,
+	msg_item = proto_tree_add_uint(lmp_header_tree, hf_lmp_filter[LMPF_MSG], tvb,
 			    offset+3, 1, message_type);
 	proto_tree_add_text(lmp_header_tree, tvb, offset+4, 2, "Length: %d bytes",
 			    msg_length);
@@ -722,34 +735,28 @@ dissect_lmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
                                           tvb, offset+3, 1, 1);
 	    PROTO_ITEM_SET_HIDDEN(hidden_item);
 	} else {
-	    proto_tree_add_protocol_format(lmp_header_tree, proto_malformed, tvb, offset+3, 1,
-					   "Invalid message type: %u", message_type);
+	    expert_add_info_format(pinfo, msg_item, &ei_lmp_invalid_msg_type,
+			    "Invalid message type: %u", message_type);
 		return tvb_length(tvb);
 	}
 
 	if (lmp_checksum_config) {
 		cksum = tvb_get_ntohs(tvb, offset+6);
+		ti = proto_tree_add_item(lmp_header_tree, hf_lmp_filter[LMPF_CHECKSUM], tvb,
+							offset+6, 2, ENC_BIG_ENDIAN);
 		if (!pinfo->fragmented && (int) tvb_length(tvb) >= msg_length) {
-		    /* The packet isn't part of a fragmented datagram and isn't
-		       truncated, so we can checksum it. */
-		    cksum_vec[0].ptr = tvb_get_ptr(tvb, 0, msg_length);
-		    cksum_vec[0].len = msg_length;
-		    computed_cksum = in_cksum(&cksum_vec[0], 1);
+			/* The packet isn't part of a fragmented datagram and isn't truncated, so we can checksum it. */
+			cksum_vec[0].ptr = tvb_get_ptr(tvb, 0, msg_length);
+			cksum_vec[0].len = msg_length;
+			computed_cksum = in_cksum(&cksum_vec[0], 1);
 
-		    if (computed_cksum == 0) {
-			proto_tree_add_text(lmp_header_tree, tvb, offset+6, 2,
-					    "Message Checksum: 0x%04x [correct]",
-					    cksum);
-		    } else {
-			proto_tree_add_text(lmp_header_tree, tvb, offset+6, 2,
-					    "Message Checksum: 0x%04x [incorrect, should be 0x%04x]",
-					    cksum,
-					    in_cksum_shouldbe(cksum, computed_cksum));
-		    }
-		} else {
-		    proto_tree_add_text(lmp_header_tree, tvb, offset+6, 2,
-					"Message Checksum: 0x%04x",
-					cksum);
+			if (computed_cksum == 0) {
+				proto_item_append_text( ti, " [correct]");
+			}
+			else {
+				expert_add_info_format(pinfo, ti, &ei_lmp_checksum_incorrect, "[incorrect, should be 0x%04x]",
+					in_cksum_shouldbe(cksum, computed_cksum));
+			}
 		}
 	} else {
 		proto_tree_add_text(lmp_header_tree, tvb, offset+6, 2, "No checksum");
@@ -770,16 +777,15 @@ dissect_lmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 	  object_type = val_to_str_const(lmp_class, lmp_class_vals, "Unknown");
 	  hidden_item = proto_tree_add_uint(lmp_tree, hf_lmp_filter[LMPF_OBJECT], tvb,
 				     offset, 1, lmp_class);
-	  PROTO_ITEM_SET_HIDDEN(hidden_item);
+	  PROTO_ITEM_SET_GENERATED(hidden_item);
 	  if (lmp_valid_class(lmp_class)) {
 
 	      ti = proto_tree_add_item(lmp_tree,
 				       hf_lmp_filter[lmp_class_to_filter_num(lmp_class)],
 				       tvb, offset, obj_length, ENC_NA);  /* all possibilities are FT_NONE */
 	  } else {
-	      proto_tree_add_protocol_format(lmp_tree, proto_malformed, tvb,
-					     offset+1, 1,
-					     "Invalid class: %u", lmp_class);
+	      expert_add_info_format(pinfo, hidden_item, &ei_lmp_invalid_class,
+			    "Invalid class: %u", lmp_class);
 	      return tvb_length(tvb);
 	  }
 	  lmp_object_tree = proto_item_add_subtree(ti, lmp_class_to_subtree(lmp_class));
@@ -874,8 +880,8 @@ dissect_lmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 		  l = (type == 3)? LMPF_VAL_LOCAL_LINK_ID_IPV6:
 		      LMPF_VAL_REMOTE_LINK_ID_IPV6;
 		  proto_item_append_text(ti, ": IPv6 %s", tvb_ip6_to_str(tvb, offset2));
-		  proto_tree_add_text(lmp_object_tree, tvb, offset2, 16, "IPv6: %s",
-				      tvb_ip6_to_str(tvb, offset2));
+		  proto_tree_add_item(lmp_object_tree, hf_lmp_filter[l], tvb,
+				      offset2, 16, ENC_NA);
 		  break;
 	      case 5:
 	      case 6:
@@ -912,8 +918,8 @@ dissect_lmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 		  l = (type == 3)? LMPF_VAL_LOCAL_INTERFACE_ID_IPV6:
 		      LMPF_VAL_REMOTE_INTERFACE_ID_IPV6;
 		  proto_item_append_text(ti, ": IPv6 %s", tvb_ip6_to_str(tvb, offset2));
-		  proto_tree_add_text(lmp_object_tree, tvb, offset2, 16, "IPv6: %s",
-				      tvb_ip6_to_str(tvb, offset2));
+		  proto_tree_add_item(lmp_object_tree, hf_lmp_filter[l], tvb,
+				      offset2, 16, ENC_NA);
 		  break;
 
 	      case 5:
@@ -1130,13 +1136,13 @@ dissect_lmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 	      case 2:
 		  proto_item_append_text(ti, ": IPv6: Local %s, Remote %s",
 					 tvb_ip6_to_str(tvb, offset2+4),
-					 tvb_ip6_to_str(tvb, offset2+8));
-		  proto_tree_add_text(lmp_object_tree, tvb, offset2+4, 16,
-				      "TE-Link Local ID - IPv6: %s",
-				      tvb_ip6_to_str(tvb, offset2));
-		  proto_tree_add_text(lmp_object_tree, tvb, offset2+20,16,
-				      "TE-Link Remote ID - IPv6: %s",
-				      tvb_ip6_to_str(tvb, offset2+4));
+					 tvb_ip6_to_str(tvb, offset2+20));
+		  proto_tree_add_item(lmp_object_tree,
+				      hf_lmp_filter[LMPF_VAL_TE_LINK_LOCAL_IPV6],
+				      tvb, offset2+4, 16, ENC_NA);
+		  proto_tree_add_item(lmp_object_tree,
+				      hf_lmp_filter[LMPF_VAL_TE_LINK_REMOTE_IPV6],
+				      tvb, offset2+20, 16, ENC_NA);
 		  break;
 
 	      case 3:
@@ -1380,22 +1386,20 @@ dissect_lmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 	      for (l=0; l<obj_length - 4; ) {
 		  switch(type) {
 		  case 1:
-		      proto_tree_add_text(lmp_object_tree, tvb, offset2+l, 4,
-					  "Interface ID: IPv4: %s",
-					  tvb_ip_to_str(tvb, offset2+l));
+		      proto_tree_add_item(lmp_object_tree, hf_lmp_filter[LMPF_VAL_CHANNEL_STATUS_INTERFACE_ID_IPV4],
+								  tvb, offset2+l, 4, ENC_BIG_ENDIAN);
 		      l += 4;
 		      break;
 
 		  case 2:
-		      proto_tree_add_text(lmp_object_tree, tvb, offset2+l, 16, "Interface ID: IPv6: %s",
-					  tvb_ip6_to_str(tvb, offset2+l));
+		      proto_tree_add_item(lmp_object_tree, hf_lmp_filter[LMPF_VAL_CHANNEL_STATUS_INTERFACE_ID_IPV6],
+								  tvb, offset2+l, 16, ENC_NA);
 		      l += 16;
 		      break;
 
 		  case 3:
-		      proto_tree_add_text(lmp_object_tree, tvb, offset2+l, 4,
-					  "Interface ID: Unnumbered: %d",
-					  tvb_get_ntohl(tvb, offset2+l));
+		      proto_tree_add_item(lmp_object_tree, hf_lmp_filter[LMPF_VAL_CHANNEL_STATUS_INTERFACE_ID_UNNUM],
+								  tvb, offset2+l, 4, ENC_BIG_ENDIAN);
 		      l += 4;
 		      break;
 
@@ -1732,15 +1736,13 @@ dissect_lmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 					 tvb_get_ntohs(tvb, offset2+8),
 					 tvb_get_ntohs(tvb, offset2+10));
 
-		  proto_tree_add_uint(lmp_object_tree,
+		  proto_tree_add_item(lmp_object_tree,
 				      hf_lmp_filter[LMPF_VAL_SERVICE_CONFIG_CPSA_MIN_NVC],
-				      tvb, offset2+8, 2,
-				      tvb_get_ntohs(tvb, offset2+8));
+				      tvb, offset2+8, 2, ENC_BIG_ENDIAN);
 
-		  proto_tree_add_uint(lmp_object_tree,
+		  proto_tree_add_item(lmp_object_tree,
 				      hf_lmp_filter[LMPF_VAL_SERVICE_CONFIG_CPSA_MAX_NVC],
-				      tvb, offset2+10, 2,
-				      tvb_get_ntohs(tvb, offset2+10));
+				      tvb, offset2+10, 2, ENC_BIG_ENDIAN);
 
 		  /* Local interface ID */
 		  proto_item_append_text(ti, ": Local Interface ID %s",
@@ -1836,16 +1838,14 @@ dissect_lmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 	      switch(type) {
 
 	      case 1:
-		  l = LMPF_VAL_LOCAL_DA_DCN_ADDR;
 		  proto_item_append_text(ti, ": %s", tvb_ip_to_str(tvb, offset2));
-		  proto_tree_add_item(lmp_object_tree, hf_lmp_filter[l], tvb,
+		  proto_tree_add_item(lmp_object_tree, hf_lmp_filter[LMPF_VAL_LOCAL_DA_DCN_ADDR], tvb,
 				      offset2, 4, ENC_BIG_ENDIAN);
 		  break;
 
 	      case 2:
-		  l = LMPF_VAL_REMOTE_DA_DCN_ADDR;
 		  proto_item_append_text(ti, ": %s", tvb_ip_to_str(tvb, offset2));
-		  proto_tree_add_item(lmp_object_tree, hf_lmp_filter[l], tvb,
+		  proto_tree_add_item(lmp_object_tree, hf_lmp_filter[LMPF_VAL_REMOTE_DA_DCN_ADDR], tvb,
 				      offset2, 4, ENC_BIG_ENDIAN);
 		  break;
 
@@ -2302,11 +2302,17 @@ proto_register_lmp(void)
 	   {&hf_lmp_filter[LMPF_VAL_LOCAL_LINK_ID_IPV4],
 		{ "Local Link ID - IPv4", "lmp.local_linkid_ipv4", FT_IPv4, BASE_NONE, NULL, 0x0,
 			NULL, HFILL }},
+	   {&hf_lmp_filter[LMPF_VAL_LOCAL_LINK_ID_IPV6],
+		{ "Local Link ID - IPv6", "lmp.local_linkid_ipv6", FT_IPv6, BASE_NONE, NULL, 0x0,
+			NULL, HFILL }},
 	   {&hf_lmp_filter[LMPF_VAL_LOCAL_LINK_ID_UNNUM],
 		{ "Local Link ID - Unnumbered", "lmp.local_linkid_unnum", FT_UINT32, BASE_DEC, NULL, 0x0,
 			NULL, HFILL }},
 	   {&hf_lmp_filter[LMPF_VAL_REMOTE_LINK_ID_IPV4],
-		{ "Remote Link ID - IPv4", "lmp.remote_linkid_ipv4", FT_UINT32, BASE_DEC, NULL, 0x0,
+		{ "Remote Link ID - IPv4", "lmp.remote_linkid_ipv4", FT_IPv4, BASE_NONE, NULL, 0x0,
+			NULL, HFILL }},
+	   {&hf_lmp_filter[LMPF_VAL_REMOTE_LINK_ID_IPV6],
+		{ "Remote Link ID - IPv6", "lmp.remote_linkid_ipv6", FT_IPv6, BASE_NONE, NULL, 0x0,
 			NULL, HFILL }},
 	   {&hf_lmp_filter[LMPF_VAL_REMOTE_LINK_ID_UNNUM],
 		{ "Remote Link ID - Unnumbered", "lmp.remote_linkid_unnum", FT_UINT32, BASE_DEC, NULL, 0x0,
@@ -2315,16 +2321,30 @@ proto_register_lmp(void)
 	   {&hf_lmp_filter[LMPF_VAL_LOCAL_INTERFACE_ID_IPV4],
 		{ "Local Interface ID - IPv4", "lmp.local_interfaceid_ipv4", FT_IPv4, BASE_NONE, NULL, 0x0,
 			NULL, HFILL }},
+	   {&hf_lmp_filter[LMPF_VAL_LOCAL_INTERFACE_ID_IPV6],
+		{ "Local Interface ID - IPv6", "lmp.local_interfaceid_ipv6", FT_IPv6, BASE_NONE, NULL, 0x0,
+			NULL, HFILL }},
 	   {&hf_lmp_filter[LMPF_VAL_LOCAL_INTERFACE_ID_UNNUM],
 		{ "Local Interface ID - Unnumbered", "lmp.local_interfaceid_unnum", FT_UINT32, BASE_DEC, NULL, 0x0,
 			NULL, HFILL }},
 	   {&hf_lmp_filter[LMPF_VAL_REMOTE_INTERFACE_ID_IPV4],
 		{ "Remote Interface ID - IPv4", "lmp.remote_interfaceid_ipv4", FT_IPv4, BASE_NONE, NULL, 0x0,
 			NULL, HFILL }},
+	   {&hf_lmp_filter[LMPF_VAL_REMOTE_INTERFACE_ID_IPV6],
+		{ "Remote Interface ID - IPv6", "lmp.remote_interfaceid_ipv6", FT_IPv6, BASE_NONE, NULL, 0x0,
+			NULL, HFILL }},
 	   {&hf_lmp_filter[LMPF_VAL_REMOTE_INTERFACE_ID_UNNUM],
 		{ "Remote Interface ID - Unnumbered", "lmp.remote_interfaceid_unnum", FT_UINT32, BASE_DEC, NULL, 0x0,
 			NULL, HFILL }},
-
+	   {&hf_lmp_filter[LMPF_VAL_CHANNEL_STATUS_INTERFACE_ID_IPV4],
+		{ "Interface ID: IPv4", "lmp.channel_status_interfaceid_ipv4", FT_IPv4, BASE_NONE, NULL, 0x0,
+			NULL, HFILL }},
+	   {&hf_lmp_filter[LMPF_VAL_CHANNEL_STATUS_INTERFACE_ID_IPV6],
+		{ "Interface ID: IPv6", "lmp.channel_status_interfaceid_ipv6", FT_IPv6, BASE_NONE, NULL, 0x0,
+			NULL, HFILL }},
+	   {&hf_lmp_filter[LMPF_VAL_CHANNEL_STATUS_INTERFACE_ID_UNNUM],
+		{ "Interface ID: Unnumbered", "lmp.channel_status_interfaceid_unnum", FT_UINT32, BASE_DEC, NULL, 0x0,
+			NULL, HFILL }},
 	   {&hf_lmp_filter[LMPF_VAL_MESSAGE_ID],
 		{ "Message-ID Value", "lmp.messageid", FT_UINT32, BASE_DEC, NULL, 0x0,
 			NULL, HFILL }},
@@ -2375,12 +2395,18 @@ proto_register_lmp(void)
 	   {&hf_lmp_filter[LMPF_VAL_TE_LINK_LOCAL_IPV4],
 		{ "TE-Link Local ID - IPv4", "lmp.te_link.local_ipv4", FT_IPv4, BASE_NONE, NULL, 0x0,
 			NULL, HFILL }},
+	   {&hf_lmp_filter[LMPF_VAL_TE_LINK_LOCAL_IPV6],
+		{ "TE-Link Local ID - IPv6", "lmp.te_link.local_ipv6", FT_IPv6, BASE_NONE, NULL, 0x0,
+			NULL, HFILL }},
 	   {&hf_lmp_filter[LMPF_VAL_TE_LINK_LOCAL_UNNUM],
 		{ "TE-Link Local ID - Unnumbered", "lmp.te_link.local_unnum", FT_UINT32, BASE_DEC, NULL, 0x0,
 			NULL, HFILL }},
 	   {&hf_lmp_filter[LMPF_VAL_TE_LINK_REMOTE_IPV4],
 		{ "TE-Link Remote ID - IPv4", "lmp.te_link.remote_ipv4", FT_IPv4, BASE_NONE, NULL, 0x0,
 			NULL, HFILL }},
+	   {&hf_lmp_filter[LMPF_VAL_TE_LINK_REMOTE_IPV6],
+		{ "TE-Link Remote ID - IPv6", "lmp.te_link.remote_ipv6", FT_IPv6, BASE_NONE, NULL, 0x0,
+			NULL, HFILL }},
 	   {&hf_lmp_filter[LMPF_VAL_TE_LINK_REMOTE_UNNUM],
 		{ "TE-Link Remote ID - Unnumbered", "lmp.te_link.remote_unnum", FT_UINT32, BASE_DEC, NULL, 0x0,
 			NULL, HFILL }},
@@ -2677,13 +2703,27 @@ proto_register_lmp(void)
 	   {&hf_lmp_filter[LMPF_VAL_LAD_INFO_SUBOBJ_LSP_ENCODING],
 		{ "LSP Encoding Type", "lmp.lad_encoding", FT_UINT8, BASE_DEC|BASE_RANGE_STRING,
 		  RVALS(gmpls_lsp_enc_rvals), 0x0, NULL, HFILL }},
+	   {&hf_lmp_filter[LMPF_CHECKSUM],
+		{ "Message Checksum", "lmp.checksum", FT_UINT16, BASE_HEX, NULL, 0x0,
+			NULL, HFILL }},
 	};
 
+    static ei_register_info ei[] = {
+        { &ei_lmp_checksum_incorrect, { "lmp.checksum.incorrect", PI_PROTOCOL, PI_WARN, "Incorrect checksum", EXPFILL }},
+        { &ei_lmp_invalid_msg_type, { "lmp.invalid_msg_type", PI_PROTOCOL, PI_WARN, "Invalid message type", EXPFILL }},
+        { &ei_lmp_invalid_class, { "lmp.invalid_class", PI_PROTOCOL, PI_WARN, "Invalid class", EXPFILL }},
+    };
+
+    expert_module_t* expert_lmp;
+
     for (i=0; i<NUM_LMP_SUBTREES; i++) {
 	lmp_subtree[i] = -1;
 	ett[i] = &lmp_subtree[i];
     }
 
+    expert_lmp = expert_register_protocol(proto_lmp);
+    expert_register_field_array(expert_lmp, ei, array_length(ei));
+
     proto_lmp = proto_register_protocol("Link Management Protocol (LMP)",
 					"LMP", "lmp");
     proto_register_field_array(proto_lmp, lmpf_info, array_length(lmpf_info));
