@@ -2,7 +2,7 @@
  * Routines for LTP dissection
  * Copyright 2009, Mithun Roy <mithunroy13@gmail.com>
  *
- * $Id$
+ * $Id: packet-ltp.c 51852 2013-09-09 00:44:09Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -103,6 +103,11 @@ static int hf_ltp_fragment_count = -1;
 static int hf_ltp_reassembled_in = -1;
 static int hf_ltp_reassembled_length = -1;
 
+static expert_field ei_ltp_neg_reception_claim_count = EI_INIT;
+static expert_field ei_ltp_mal_reception_claim = EI_INIT;
+
+static dissector_handle_t bundle_handle;
+
 static const value_string ltp_type_codes[] = {
 	{0x0, "Red data, NOT {Checkpoint, EORP or EOB}"},
 	{0x1, "Red data, Checkpoint, NOT {EORP or EOB}"},
@@ -230,7 +235,7 @@ dissect_data_segment(proto_tree *ltp_tree, tvbuff_t *tvb,packet_info *pinfo,int
 
 	tvbuff_t *datatvb;
 
-	fragment_data *frag_msg = NULL;
+	fragment_head *frag_msg = NULL;
 	gboolean more_frags = TRUE;
 
 	tvbuff_t *new_tvb = NULL;
@@ -357,7 +362,7 @@ dissect_data_segment(proto_tree *ltp_tree, tvbuff_t *tvb,packet_info *pinfo,int
 			ltp_data_data_tree = proto_item_add_subtree(ltp_data_data_item, ett_data_data_segm);
 
 			datatvb = tvb_new_subset(new_tvb, data_offset, (int)data_length - dissected_data_size, tvb_length(new_tvb));
-			bundle_size = dissect_complete_bundle(datatvb, pinfo, ltp_data_data_tree);
+			bundle_size = call_dissector(bundle_handle, datatvb, pinfo, ltp_data_data_tree);
 			if(bundle_size == 0) {  /*Couldn't parse bundle*/
 				col_set_str(pinfo->cinfo, COL_INFO, "Dissection Failed");
 				return 0;           /*Give up*/
@@ -435,7 +440,8 @@ dissect_report_segment(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ltp_tree,
 	rcpt_clm_cnt = evaluate_sdnv(tvb, frame_offset + segment_offset, &rcpt_clm_cnt_size);
 	if (rcpt_clm_cnt < 0){
 		proto_item_set_end(ltp_rpt_item, tvb, frame_offset + segment_offset);
-		expert_add_info_format(pinfo, ltp_tree, PI_UNDECODED, PI_ERROR, "Negative reception claim count: %d", rcpt_clm_cnt);
+		expert_add_info_format(pinfo, ltp_tree, &ei_ltp_neg_reception_claim_count,
+				"Negative reception claim count: %d", rcpt_clm_cnt);
 		return 0;
 	}
     /* Each reception claim is at least 2 bytes, so if the count is larger than the
@@ -444,7 +450,7 @@ dissect_report_segment(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ltp_tree,
      */
 	if (rcpt_clm_cnt > tvb_length_remaining(tvb, frame_offset + segment_offset) / 2) {
 		proto_item_set_end(ltp_rpt_item, tvb, frame_offset + segment_offset);
-		expert_add_info_format(pinfo, ltp_tree, PI_MALFORMED, PI_ERROR,
+		expert_add_info_format(pinfo, ltp_tree, &ei_ltp_mal_reception_claim,
 				"Reception claim count impossibly large: %d > %d", rcpt_clm_cnt,
 				tvb_length_remaining(tvb, frame_offset + segment_offset) / 2);
 		return 0;
@@ -963,12 +969,22 @@ proto_register_ltp(void)
 		&ett_ltp_fragments
 	};
 
-/* Register the protocol name and description */
+	static ei_register_info ei[] = {
+		{ &ei_ltp_neg_reception_claim_count, { "ltp.neg_reception_claim_count", PI_UNDECODED, PI_ERROR, "Negative reception claim count", EXPFILL }},
+		{ &ei_ltp_mal_reception_claim, { "ltp.mal_reception_claim", PI_MALFORMED, PI_ERROR, "Reception claim count impossibly large", EXPFILL }},
+	};
+
+	expert_module_t* expert_ltp;
+
+	/* Register the protocol name and description */
 	proto_ltp = proto_register_protocol("Licklider Transmission Protocol",
 		"LTP", "ltp");
 
 	proto_register_field_array(proto_ltp, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	expert_ltp = expert_register_protocol(proto_ltp);
+	expert_register_field_array(expert_ltp, ei, array_length(ei));
+
 	ltp_module = prefs_register_protocol(proto_ltp, proto_reg_handoff_ltp);
 
 	prefs_register_obsolete_preference(ltp_module, "udp.port");
@@ -987,6 +1003,7 @@ proto_reg_handoff_ltp(void)
 
 	if (!initialized) {
 		ltp_handle = new_create_dissector_handle(dissect_ltp, proto_ltp);
+        bundle_handle = find_dissector("bundle");
 		initialized = TRUE;
 	} else {
 		dissector_delete_uint("udp.port", currentPort, ltp_handle);
