@@ -1,7 +1,7 @@
 /* packet-mac-lte.h
  *
  * Martin Mathieson
- * $Id$
+ * $Id: packet-mac-lte.h 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -23,9 +23,9 @@
  *
  * This header file may also be distributed under
  * the terms of the BSD Licence as follows:
- * 
+ *
  * Copyright (C) 2009 Martin Mathieson. All rights reserved.
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
@@ -34,7 +34,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 
+ *
  * THIS SOFTWARE IS PROVIDED BY AUTHOR AND CONTRIBUTORS ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -94,7 +94,7 @@ typedef enum mac_lte_carrier_id {
     carrier_id_secondary_1,
     carrier_id_secondary_2,
     carrier_id_secondary_3,
-    carrier_id_secondary_4,
+    carrier_id_secondary_4
 } mac_lte_carrier_id;
 
 /* Context info attached to each LTE MAC frame */
@@ -136,7 +136,7 @@ typedef struct mac_lte_info
 
     /* Carrier ID */
     mac_lte_carrier_id   carrierId;
-    
+
     /* DL only.  Is this known to be a retransmission? */
     mac_lte_dl_retx dl_retx;
 
@@ -164,7 +164,7 @@ typedef struct mac_lte_info
             mac_lte_crc_status crc_status;
             guint8 harq_id;
             gboolean ndi;
-            guint8   transport_block;  /* 1..2 */
+            guint8   transport_block;  /* 0..1 */
         } dl_info;
     } detailed_phy_info;
 
@@ -200,6 +200,7 @@ typedef struct mac_lte_tap_info {
     guint32  bytes_for_lcid[11];
     guint32  sdus_for_lcid[11];
     guint8   number_of_rars;
+    guint8   number_of_paging_ids;
 
     /* Number of padding bytes includes padding subheaders and trailing padding */
     guint16  padding_bytes;
@@ -234,7 +235,7 @@ int is_mac_lte_frame_retx(packet_info *pinfo, guint8 direction);
 
 /* Fixed fields.  This is followed by the following 3 mandatory fields:
    - radioType (1 byte)
-   - direction (1 byte) 
+   - direction (1 byte)
    - rntiType (1 byte)
    (where the allowed values are defined above */
 
@@ -270,12 +271,53 @@ int is_mac_lte_frame_retx(packet_info *pinfo, guint8 direction);
 #define MAC_LTE_PAYLOAD_TAG 0x01
 
 
+/* Type to store parameters for configuring LCID->RLC channel settings for DRB */
+/* Some are optional, and may not be seen (e.g. on reestablishment) */
+typedef struct drb_mapping_t
+{
+    guint16    ueid;              /* Mandatory */
+    guint8     drbid;             /* Mandatory */
+    gboolean   lcid_present;
+    guint8     lcid;              /* Part of LogicalChannelConfig - optional */
+    gboolean   rlcMode_present;
+    guint8     rlcMode;           /* Part of RLC config - optional */
+    gboolean   um_sn_length_present;
+    guint8     um_sn_length;      /* Part of RLC config - optional */
+    gboolean   ul_priority_present;
+    guint8     ul_priority;       /* Part of LogicalChannelConfig - optional */
+    gboolean   pdcp_sn_size_present;
+    guint8     pdcp_sn_size;      /* Part of pdcp-Config - optional */
+} drb_mapping_t;
+
+
 /* Set details of an LCID -> drb channel mapping.  To be called from
    configuration protocol (e.g. RRC) */
-void set_mac_lte_channel_mapping(guint16 ueid, guint8 lcid,
-                                 guint8  srbid, guint8 drbid,
-                                 guint8  rlcMode, guint8 um_sn_length,
-                                 guint8  ul_priority);
+void set_mac_lte_channel_mapping(drb_mapping_t *drb_mapping);
+
+
+/* Dedicated DRX config. Used to verify that a sensible config is given.
+   Also, beginning to configure MAC with this config and (optionally) show
+   DRX config and state (cycles/timers) attached to each UL/DL PDU! */
+typedef struct drx_config_t {
+    gboolean    configured;
+    guint32     frameNum;
+    guint32     previousFrameNum;
+
+    guint32     onDurationTimer;
+    guint32     inactivityTimer;
+    guint32     retransmissionTimer;
+    guint32     longCycle;
+    guint32     cycleOffset;
+    /* Optional Short cycle */
+    gboolean    shortCycleConfigured;
+    guint32     shortCycle;
+    guint32     shortCycleTimer;
+} drx_config_t;
+
+/* Functions to set/release up dedicated DRX config */
+void set_mac_lte_drx_config(guint16 ueid, drx_config_t *drx_config, packet_info *pinfo);
+void set_mac_lte_drx_config_release(guint16 ueid,  packet_info *pinfo);
+
 
 /* Functions to be called from outside this module (e.g. in a plugin, where mac_lte_info
    isn't available) to get/set per-packet data */
