@@ -2,7 +2,7 @@
  * Routines for analyzing Cisco FabricPath MiM packets
  * Copyright 2011, Leonard Tracy <letracy@cisco.com>
  *
- * $Id$
+ * $Id: packet-mim.c 50362 2013-07-03 16:45:14Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -187,7 +187,7 @@ fp_add_hmac (tvbuff_t *tvb, proto_tree *tree, int offset) {
   offset += FP_SSWID_LEN;
 
   proto_tree_add_item (tree, hf_lid, tvb, offset, FP_LID_LEN, ENC_BIG_ENDIAN);
-  offset += FP_LID_LEN;
+  /*offset += FP_LID_LEN;*/
 
 }
 /* FabricPath MiM Dissector */
