@@ -4,7 +4,7 @@
  *
  * http://www.nasdaqtrader.com/content/technicalsupport/specifications/dataproducts/moldudp64.pdf
  *
- * $Id$
+ * $Id: packet-moldudp64.c 52034 2013-09-14 12:35:29Z eapache $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -60,6 +60,11 @@ static guint pf_moldudp64_port = 0;
 static gint ett_moldudp64        = -1;
 static gint ett_moldudp64_msgblk = -1;
 
+static expert_field ei_moldudp64_msglen_invalid = EI_INIT;
+static expert_field ei_moldudp64_end_of_session_extra = EI_INIT;
+static expert_field ei_moldudp64_count_invalid = EI_INIT;
+static expert_field ei_moldudp64_request = EI_INIT;
+
 /* Code to dissect a message block */
 guint
 dissect_moldudp64_msgblk(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
@@ -68,7 +73,7 @@ dissect_moldudp64_msgblk(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     proto_item *ti;
     proto_tree *blk_tree;
     guint16     msglen, real_msglen, whole_len;
-    guint       remaining;
+    gint        remaining;
 
     if (tvb_length_remaining(tvb, offset) < MOLDUDP64_MSGLEN_LEN)
         return 0;
@@ -76,7 +81,7 @@ dissect_moldudp64_msgblk(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     msglen = tvb_get_ntohs(tvb, offset);
     remaining = tvb_reported_length(tvb) - offset - MOLDUDP64_MSGLEN_LEN;
 
-    if (remaining < (offset + MOLDUDP64_MSGLEN_LEN))
+    if (remaining < 0)
         real_msglen = 0;
     else if (msglen <= remaining)
         real_msglen = msglen;
@@ -101,7 +106,7 @@ dissect_moldudp64_msgblk(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
             tvb, offset, MOLDUDP64_MSGLEN_LEN, ENC_BIG_ENDIAN);
 
     if (msglen != real_msglen)
-        expert_add_info_format(pinfo, ti, PI_MALFORMED, PI_ERROR,
+        expert_add_info_format(pinfo, ti, &ei_moldudp64_msglen_invalid,
                 "Invalid Message Length (claimed %u, found %u)",
                 msglen, real_msglen);
 
@@ -143,6 +148,10 @@ dissect_moldudp64(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *dat
         col_set_str(pinfo->cinfo, COL_INFO, "MoldUDP64 Heartbeat");
     else if (count == MOLDUDP64_ENDOFSESS)
         col_set_str(pinfo->cinfo, COL_INFO, "MoldUDP64 End Of Session");
+    else if (count > 0 && tvb_reported_length(tvb) == (MOLDUDP64_SESSION_LEN  +
+                                                       MOLDUDP64_SEQUENCE_LEN +
+                                                       MOLDUDP64_COUNT_LEN))
+        col_set_str(pinfo->cinfo, COL_INFO, "MoldUDP64 Request");
     else
         col_set_str(pinfo->cinfo, COL_INFO, "MoldUDP64 Messages");
 
@@ -171,17 +180,17 @@ dissect_moldudp64(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *dat
         real_count++;
     }
 
-    if (count == MOLDUDP64_ENDOFSESS)
+    if (count == MOLDUDP64_ENDOFSESS && real_count != 0)
     {
-        if (real_count != 0)
-        {
-            expert_add_info_format(pinfo, ti, PI_MALFORMED, PI_ERROR,
-                                   "End Of Session packet with extra data.");
-        }
+        expert_add_info(pinfo, ti, &ei_moldudp64_end_of_session_extra);
+    }
+    else if (count > 0 && real_count == 0)
+    {
+        expert_add_info(pinfo, ti, &ei_moldudp64_request);
     }
     else if (real_count != count)
     {
-        expert_add_info_format(pinfo, ti, PI_MALFORMED, PI_ERROR,
+        expert_add_info_format(pinfo, ti, &ei_moldudp64_count_invalid,
                                "Invalid Message Count (claimed %u, found %u)",
                                count, real_count);
     }
@@ -235,6 +244,15 @@ proto_register_moldudp64(void)
         &ett_moldudp64_msgblk
     };
 
+    static ei_register_info ei[] = {
+        { &ei_moldudp64_msglen_invalid, { "moldudp64.msglen.invalid", PI_MALFORMED, PI_ERROR, "Invalid Message Length", EXPFILL }},
+        { &ei_moldudp64_end_of_session_extra, { "moldudp64.end_of_session_extra", PI_MALFORMED, PI_ERROR, "End Of Session packet with extra data.", EXPFILL }},
+        { &ei_moldudp64_count_invalid, { "moldudp64.count.invalid", PI_MALFORMED, PI_ERROR, "Invalid Message Count", EXPFILL }},
+        { &ei_moldudp64_request, { "moldudp64.request", PI_COMMENTS_GROUP, PI_COMMENT, "Number of Requested Messages", EXPFILL }},
+    };
+
+    expert_module_t* expert_moldudp64;
+
     /* Register the protocol name and description */
     proto_moldudp64 = proto_register_protocol("MoldUDP64",
             "MoldUDP64", "moldudp64");
@@ -242,6 +260,8 @@ proto_register_moldudp64(void)
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_moldudp64, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_moldudp64 = expert_register_protocol(proto_moldudp64);
+    expert_register_field_array(expert_moldudp64, ei, array_length(ei));
 
     /* Register preferences module */
     moldudp64_module = prefs_register_protocol(proto_moldudp64,
