@@ -2,7 +2,7 @@
  *
  * Routines for RFC 2250 MPEG2 (ISO/IEC 13818-1) Transport Stream dissection
  *
- * $Id$
+ * $Id: packet-mp2t.c 51852 2013-09-09 00:44:09Z mmann $
  *
  * Copyright 2006, Erwin Rol <erwin@erwinrol.com>
  * Copyright 2012, Guy Martin <gmsoft@tuxicoman.be>
@@ -33,11 +33,13 @@
 
 #include <epan/rtp_pt.h>
 
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/conversation.h>
 #include <epan/expert.h>
 #include <epan/reassemble.h>
 
+#include <epan/tvbuff-int.h> /* XXX, for tvb_new_proxy() */
+
 /* The MPEG2 TS packet size */
 #define MP2T_PACKET_SIZE 188
 #define MP2T_SYNC_BYTE 0x47
@@ -45,6 +47,8 @@
 #define MP2T_PID_DOCSIS	0x1FFE
 #define MP2T_PID_NULL	0x1FFF
 
+static dissector_handle_t mp2t_handle;
+
 static dissector_handle_t docsis_handle;
 static dissector_handle_t mpeg_pes_handle;
 static dissector_handle_t mpeg_sect_handle;
@@ -68,7 +72,6 @@ static int hf_mp2t_pid = -1;
 static int hf_mp2t_tsc = -1;
 static int hf_mp2t_afc = -1;
 static int hf_mp2t_cc = -1;
-static int hf_mp2t_cc_drop = -1;
 
 /* static int hf_mp2t_analysis_flags = -1; */
 static int hf_mp2t_analysis_skips = -1;
@@ -218,6 +221,9 @@ static int hf_msg_fragment_count = -1;
 static int hf_msg_reassembled_in = -1;
 static int hf_msg_reassembled_length = -1;
 
+static expert_field ei_mp2t_pointer = EI_INIT;
+static expert_field ei_mp2t_cc_drop = EI_INIT;
+
 static const fragment_items mp2t_msg_frag_items = {
 	/* Fragment subtrees */
 	&ett_msg_fragment,
@@ -271,7 +277,7 @@ typedef struct mp2t_analysis_data {
 	 * individual pid's, this is only used when packets are
 	 * processed sequencially.
 	 */
-	emem_tree_t	*pid_table;
+	wmem_tree_t	*pid_table;
 
 	/* When detecting a CC drop, store that information for the
 	 * given frame.  This info is needed, when clicking around in
@@ -280,7 +286,7 @@ typedef struct mp2t_analysis_data {
 	 * used to tell the difference.
 	 *
 	 */
-	emem_tree_t	*frame_table;
+	wmem_tree_t	*frame_table;
 
 	/* Total counters per conversation / multicast stream */
 	guint32 total_skips;
@@ -293,7 +299,7 @@ enum pid_payload_type {
 	pid_pload_docsis,
 	pid_pload_pes,
 	pid_pload_sect,
-	pid_pload_null,
+	pid_pload_null
 };
 
 typedef struct subpacket_analysis_data {
@@ -306,7 +312,7 @@ typedef struct subpacket_analysis_data {
 typedef struct packet_analysis_data {
 
 	/* Contain information for each MPEG2-TS packet in the current big packet */
-	emem_tree_t *subpacket_table;
+	wmem_tree_t *subpacket_table;
 } packed_analysis_data_t;
 
 /* Analysis TS frame info needed during sequential processing */
@@ -335,7 +341,7 @@ typedef struct frame_analysis_data {
 	/* As each frame has several pid's, thus need a pid data
 	 * structure per TS frame.
 	 */
-	emem_tree_t	*ts_table;
+	wmem_tree_t	*ts_table;
 
 } frame_analysis_data_t;
 
@@ -344,14 +350,11 @@ init_mp2t_conversation_data(void)
 {
 	mp2t_analysis_data_t *mp2t_data = NULL;
 
-	mp2t_data = se_new0(struct mp2t_analysis_data);
+	mp2t_data = wmem_new0(wmem_file_scope(), struct mp2t_analysis_data);
 
-	mp2t_data->pid_table =
-		se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK,
-					      "mp2t_pid_table");
-	mp2t_data->frame_table =
-		se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK,
-					      "mp2t_frame_table");
+	mp2t_data->pid_table = wmem_tree_new(wmem_file_scope());
+
+	mp2t_data->frame_table = wmem_tree_new(wmem_file_scope());
 
 	mp2t_data->total_skips = 0;
 	mp2t_data->total_discontinuity = 0;
@@ -378,12 +381,10 @@ init_frame_analysis_data(mp2t_analysis_data_t *mp2t_data, packet_info *pinfo)
 {
 	frame_analysis_data_t *frame_analysis_data_p = NULL;
 
-	frame_analysis_data_p = se_new0(struct frame_analysis_data);
-	frame_analysis_data_p->ts_table =
-		se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK,
-					"mp2t_frame_pid_table");
+	frame_analysis_data_p = wmem_new0(wmem_file_scope(), struct frame_analysis_data);
+	frame_analysis_data_p->ts_table = wmem_tree_new(wmem_file_scope());
 	/* Insert into mp2t tree */
-	se_tree_insert32(mp2t_data->frame_table, pinfo->fd->num,
+	wmem_tree_insert32(mp2t_data->frame_table, pinfo->fd->num,
 			 (void *)frame_analysis_data_p);
 
 	return frame_analysis_data_p;
@@ -394,7 +395,7 @@ static frame_analysis_data_t *
 get_frame_analysis_data(mp2t_analysis_data_t *mp2t_data, packet_info *pinfo)
 {
 	frame_analysis_data_t *frame_analysis_data_p = NULL;
-	frame_analysis_data_p = (frame_analysis_data_t *)se_tree_lookup32(mp2t_data->frame_table, pinfo->fd->num);
+	frame_analysis_data_p = (frame_analysis_data_t *)wmem_tree_lookup32(mp2t_data->frame_table, pinfo->fd->num);
 	return frame_analysis_data_p;
 }
 
@@ -407,14 +408,14 @@ get_pid_analysis(guint32 pid, conversation_t *conv)
 
 	mp2t_data = get_mp2t_conversation_data(conv);
 
-	pid_data = (pid_analysis_data_t *)se_tree_lookup32(mp2t_data->pid_table, pid);
+	pid_data = (pid_analysis_data_t *)wmem_tree_lookup32(mp2t_data->pid_table, pid);
 	if (!pid_data) {
-		pid_data          = se_new0(struct pid_analysis_data);
+		pid_data          = wmem_new0(wmem_file_scope(), struct pid_analysis_data);
 		pid_data->cc_prev = -1;
 		pid_data->pid     = pid;
 		pid_data->frag_id = (pid << (32 - 13)) | 0x1;
 
-		se_tree_insert32(mp2t_data->pid_table, pid, (void *)pid_data);
+		wmem_tree_insert32(mp2t_data->pid_table, pid, (void *)pid_data);
 	}
 	return pid_data;
 }
@@ -459,7 +460,7 @@ mp2t_get_packet_length(tvbuff_t *tvb, guint offset, packet_info *pinfo,
 			guint32 frag_id, enum pid_payload_type pload_type)
 {
 
-	fragment_data *frag    = NULL;
+	fragment_head *frag    = NULL;
 	tvbuff_t      *len_tvb = NULL, *frag_tvb = NULL, *data_tvb = NULL;
 	gint           pkt_len = 0;
 	guint          remaining_len;
@@ -484,7 +485,7 @@ mp2t_get_packet_length(tvbuff_t *tvb, guint offset, packet_info *pinfo,
 
 	} else {
 		/* Create a composite tvb out of the two */
-		frag_tvb = tvb_new_real_data(frag->data, frag->len, frag->len);
+		frag_tvb = tvb_new_proxy(frag->tvb_data);
 		len_tvb = tvb_new_composite();
 		tvb_composite_append(len_tvb, frag_tvb);
 
@@ -528,7 +529,7 @@ mp2t_fragment_handle(tvbuff_t *tvb, guint offset, packet_info *pinfo,
 		     gboolean fragment_last, enum pid_payload_type pload_type)
 {
 	/* proto_item *ti; */
-	fragment_data *frag_msg = NULL;
+	fragment_head *frag_msg = NULL;
 	tvbuff_t      *new_tvb  = NULL;
 	gboolean       save_fragmented;
 
@@ -620,8 +621,7 @@ mp2t_process_fragmented_payload(tvbuff_t *tvb, gint offset, guint remaining_len,
 		remaining_len--;
 		if (pointer > remaining_len) {
 			/* Bogus pointer */
-			expert_add_info_format(pinfo, pi, PI_MALFORMED,
-			    PI_ERROR,
+			expert_add_info_format(pinfo, pi, &ei_mp2t_pointer,
 			    "Pointer value is too large (> remaining data length %u)",
 			    remaining_len);
 		}
@@ -636,22 +636,22 @@ mp2t_process_fragmented_payload(tvbuff_t *tvb, gint offset, guint remaining_len,
 		frag_id = pid_analysis->frag_id;
 		pdata = (packed_analysis_data_t *)p_get_proto_data(pinfo->fd, proto_mp2t, 0);
 		if (!pdata) {
-			pdata = se_new0(packed_analysis_data_t);
-			pdata->subpacket_table = se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK, "mp2t_frame_table");
+			pdata = wmem_new0(wmem_file_scope(), packed_analysis_data_t);
+			pdata->subpacket_table = wmem_tree_new(wmem_file_scope());
 			p_add_proto_data(pinfo->fd, proto_mp2t, 0, pdata);
 
 		} else {
-			spdata = (subpacket_analysis_data_t *)se_tree_lookup32(pdata->subpacket_table, offset);
+			spdata = (subpacket_analysis_data_t *)wmem_tree_lookup32(pdata->subpacket_table, offset);
 		}
 
 		if (!spdata) {
-			spdata = se_new0(subpacket_analysis_data_t);
+			spdata = wmem_new0(wmem_file_scope(), subpacket_analysis_data_t);
 			/* Save the info into pdata from pid_analysis */
 			spdata->frag_cur_pos = frag_cur_pos;
 			spdata->frag_tot_len = frag_tot_len;
 			spdata->fragmentation = fragmentation;
 			spdata->frag_id = frag_id;
-			se_tree_insert32(pdata->subpacket_table, offset, (void *)spdata);
+			wmem_tree_insert32(pdata->subpacket_table, offset, (void *)spdata);
 
 		}
 
@@ -663,7 +663,7 @@ mp2t_process_fragmented_payload(tvbuff_t *tvb, gint offset, guint remaining_len,
 			return;
 		}
 
-		spdata = (subpacket_analysis_data_t *)se_tree_lookup32(pdata->subpacket_table, offset);
+		spdata = (subpacket_analysis_data_t *)wmem_tree_lookup32(pdata->subpacket_table, offset);
 		if (!spdata) {
 			/* Occurs for the first sub packets in the capture which cannot be reassembled */
 			return;
@@ -734,7 +734,6 @@ mp2t_process_fragmented_payload(tvbuff_t *tvb, gint offset, guint remaining_len,
 				proto_tree_add_item(stuff_tree, hf_mp2t_stuff_bytes, tvb, offset, stuff_len, ENC_NA);
 				offset += stuff_len;
 				if (stuff_len >= remaining_len) {
-					remaining_len = 0;
 					goto save_state;
 				}
 				remaining_len -= stuff_len;
@@ -747,7 +746,7 @@ mp2t_process_fragmented_payload(tvbuff_t *tvb, gint offset, guint remaining_len,
 			if (frag_tot_len == (guint)-1 || !frag_tot_len) {
 				mp2t_fragment_handle(tvb, offset, pinfo, tree, frag_id, 0, remaining_len, FALSE, pid_analysis->pload_type);
 				fragmentation = TRUE;
-				offset += remaining_len;
+				/*offset += remaining_len;*/
 				frag_cur_pos += remaining_len;
 				goto save_state;
 			}
@@ -889,11 +888,11 @@ detect_cc_drops(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo,
 		/* Create and store a new TS frame pid_data object.
 		   This indicate that we have a drop
 		 */
-		ts_data = se_new0(struct ts_analysis_data);
+		ts_data = wmem_new0(wmem_file_scope(), struct ts_analysis_data);
 		ts_data->cc_prev = cc_prev;
 		ts_data->pid = pid;
 		ts_data->skips = skips;
-		se_tree_insert32(frame_analysis_data_p->ts_table, KEY(pid, cc_curr),
+		wmem_tree_insert32(frame_analysis_data_p->ts_table, KEY(pid, cc_curr),
 				 (void *)ts_data);
 	}
 
@@ -905,7 +904,7 @@ detect_cc_drops(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo,
 		if (!frame_analysis_data_p)
 			return 0; /* No stored frame data -> no drops*/
 		else {
-			ts_data = (struct ts_analysis_data *)se_tree_lookup32(frame_analysis_data_p->ts_table,
+			ts_data = (struct ts_analysis_data *)wmem_tree_lookup32(frame_analysis_data_p->ts_table,
 						   KEY(pid, cc_curr));
 
 			if (ts_data) {
@@ -921,27 +920,20 @@ detect_cc_drops(tvbuff_t *tvb, proto_tree *tree, packet_info *pinfo,
 
 	/* Add info to the proto tree about drops */
 	if (detected_drop) {
-
-		flags_item =
-			proto_tree_add_none_format(
-				tree, hf_mp2t_cc_drop, tvb, 0, 0,
-				"Detected %d missing TS frames before this"
-				" (last_cc:%d total skips:%d discontinuity:%d)",
+		expert_add_info_format(pinfo, tree, &ei_mp2t_cc_drop,
+				"Detected %d missing TS frames before this (last_cc:%d total skips:%d discontinuity:%d)",
 				skips, cc_prev,
 				mp2t_data->total_skips,
 				mp2t_data->total_discontinuity
 				);
 
-		PROTO_ITEM_SET_GENERATED(flags_item);
-		expert_add_info_format(pinfo, flags_item, PI_MALFORMED,
-				       PI_ERROR, "Detected TS frame loss");
-
 		flags_item = proto_tree_add_uint(tree, hf_mp2t_analysis_skips,
 					       tvb, 0, 0, skips);
 		PROTO_ITEM_SET_GENERATED(flags_item);
 
 		flags_item = proto_tree_add_uint(tree, hf_mp2t_analysis_drops,
-					       tvb, 0, 0, 1);
+
+            tvb, 0, 0, 1);
 		PROTO_ITEM_SET_GENERATED(flags_item);
 
 	}
@@ -1331,10 +1323,6 @@ proto_register_mp2t(void)
 			"Continuity Counter", "mp2t.cc",
 			FT_UINT32, BASE_DEC, NULL, MP2T_CC_MASK, NULL, HFILL
 		} } ,
-		{ &hf_mp2t_cc_drop, {
-			"Continuity Counter Drops", "mp2t.cc.drop",
-			FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL
-		} } ,
 #if 0
 		{ &hf_mp2t_analysis_flags, {
 			"MPEG2-TS Analysis Flags", "mp2t.analysis.flags",
@@ -1549,10 +1537,21 @@ proto_register_mp2t(void)
 		&ett_msg_fragments
 	};
 
+	static ei_register_info ei[] = {
+		{ &ei_mp2t_pointer, { "mp2t.pointer", PI_MALFORMED, PI_ERROR, "Pointer value is too large", EXPFILL }},
+		{ &ei_mp2t_cc_drop, { "mp2t.cc.drop", PI_MALFORMED, PI_ERROR, "Detected missing TS frames", EXPFILL }},
+	};
+
+	expert_module_t* expert_mp2t;
+
 	proto_mp2t = proto_register_protocol("ISO/IEC 13818-1", "MP2T", "mp2t");
-	register_dissector("mp2t", dissect_mp2t, proto_mp2t);
+
+	mp2t_handle = register_dissector("mp2t", dissect_mp2t, proto_mp2t);
+
 	proto_register_field_array(proto_mp2t, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	expert_mp2t = expert_register_protocol(proto_mp2t);
+	expert_register_field_array(expert_mp2t, ei, array_length(ei));
 
 	register_heur_dissector_list("mp2t.pid", &heur_subdissector_list);
 	/* Register init of processing of fragmented DEPI packets */
@@ -1564,11 +1563,8 @@ proto_register_mp2t(void)
 void
 proto_reg_handoff_mp2t(void)
 {
-	dissector_handle_t mp2t_handle;
-
 	heur_dissector_add("udp", heur_dissect_mp2t, proto_mp2t);
 
-	mp2t_handle = create_dissector_handle(dissect_mp2t, proto_mp2t);
 	dissector_add_uint("rtp.pt", PT_MP2T, mp2t_handle);
 	dissector_add_handle("udp.port", mp2t_handle);  /* for decode-as */
 	heur_dissector_add("usb.bulk", heur_dissect_mp2t, proto_mp2t);
