@@ -3,7 +3,7 @@
  * Routines for MPEG4 dissection
  * Copyright 2007-2008, Anders Broman <anders.broman[at]ericsson.com>
  *
- * $Id$
+ * $Id: packet-mp4ves.c 51669 2013-09-02 23:13:22Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -762,11 +762,11 @@ dissect_mp4ves(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			break;
 		case 0xb0:
 			/* VS start code */
-			bit_offset = dissect_mp4ves_VisualObjectSequence(tvb, pinfo, mp4ves_tree, 0);
+			/*bit_offset = */dissect_mp4ves_VisualObjectSequence(tvb, pinfo, mp4ves_tree, 0);
 			break;
 		default:
 			proto_tree_add_bits_item(mp4ves_tree, hf_mp4ves_start_code_prefix, tvb, bit_offset, 24, ENC_BIG_ENDIAN);
-			bit_offset = bit_offset+24;
+			/*bit_offset = bit_offset+24;*/
 			break;
 		}
 	}
