@@ -3,7 +3,7 @@
  * Routines for ISO/IEC 13818-6 DSM-CC
  * Copyright 2012, Weston Schmidt <weston_schmidt@alumni.purdue.edu>
  *
- * $Id$
+ * $Id: packet-mpeg-dsmcc.c 52366 2013-10-04 16:07:26Z martink $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -165,6 +165,9 @@ static gint ett_dsmcc_compat = -1;
 static gint ett_dsmcc_compat_sub_desc = -1;
 static gint ett_dsmcc_dii_module = -1;
 
+static expert_field ei_dsmcc_invalid_value = EI_INIT;
+static expert_field ei_dsmcc_crc_invalid = EI_INIT;
+
 #define DSMCC_TID_LLCSNAP         0x3a
 #define DSMCC_TID_UN_MSG          0x3b
 #define DSMCC_TID_DD_MSG          0x3c
@@ -224,11 +227,11 @@ static void
 dissect_dsmcc_adaptation_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     tvbuff_t   *sub_tvb;
-    guint		offset = 0;
+    guint       offset = 0;
     proto_item *pi;
     proto_tree *sub_tree;
-    guint8		type, tmp;
-    guint16		ca_len;
+    guint8      type, tmp;
+    guint16     ca_len;
 
     type = tvb_get_guint8(tvb, offset);
 
@@ -242,8 +245,7 @@ dissect_dsmcc_adaptation_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
         pi = proto_tree_add_item(sub_tree, hf_dsmcc_adaptation_ca_reserved, tvb,
             offset, 1, ENC_BIG_ENDIAN);
         if (0xff != tmp) {
-            PROTO_ITEM_SET_GENERATED(pi);
-            expert_add_info_format(pinfo, pi, PI_MALFORMED, PI_ERROR,
+            expert_add_info_format(pinfo, pi, &ei_dsmcc_invalid_value,
                         "Invalid value - should be 0xff");
         }
         offset +=1;
@@ -266,11 +268,10 @@ dissect_dsmcc_adaptation_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
         pi = proto_tree_add_item(sub_tree, hf_dsmcc_adaptation_user_id_reserved, tvb,
             offset, 1, ENC_BIG_ENDIAN);
         if (0xff != tmp) {
-            PROTO_ITEM_SET_GENERATED(pi);
-            expert_add_info_format(pinfo, pi, PI_MALFORMED, PI_ERROR,
+            expert_add_info_format(pinfo, pi, &ei_dsmcc_invalid_value,
                         "Invalid value - should be 0xff");
         }
-        offset +=1;
+        /*offset +=1;*/
         /* TODO: handle the userId */
     } else {
         pi = proto_tree_add_text(tree, tvb, offset, -1, "Unknown Adaptation Header");
@@ -287,11 +288,13 @@ dissect_dsmcc_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint
     tvbuff_t   *sub_tvb;
     proto_item *pi;
     proto_tree *sub_tree;
-    guint8		prot_disc;
-    guint		reserved;
-    guint8		adaptation_len;
-    guint		len = 0;
-    int			msg_id, tx_id;
+    guint8      prot_disc;
+    guint       reserved;
+    guint8      adaptation_len;
+    guint       offset_start;
+    int         msg_id, tx_id;
+
+    offset_start = offset;
 
     prot_disc = tvb_get_guint8(tvb, offset);
     reserved = tvb_get_guint8(tvb, 8+offset);
@@ -302,8 +305,7 @@ dissect_dsmcc_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint
     pi = proto_tree_add_item(sub_tree, hf_dsmcc_protocol_discriminator, tvb,
                  offset, 1, ENC_BIG_ENDIAN);
     if (0x11 != prot_disc) {
-        PROTO_ITEM_SET_GENERATED(pi);
-        expert_add_info_format(pinfo, pi, PI_MALFORMED, PI_ERROR,
+        expert_add_info_format(pinfo, pi, &ei_dsmcc_invalid_value,
                     "Invalid value - should be 0x11");
     }
     offset +=1;
@@ -326,8 +328,7 @@ dissect_dsmcc_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint
     pi = proto_tree_add_item(sub_tree, hf_dsmcc_header_reserved, tvb,
         offset, 1, ENC_BIG_ENDIAN);
     if (0xff != reserved) {
-        PROTO_ITEM_SET_GENERATED(pi);
-        expert_add_info_format(pinfo, pi, PI_MALFORMED, PI_ERROR,
+        expert_add_info_format(pinfo, pi, &ei_dsmcc_invalid_value,
                     "Invalid value - should be 0xff");
     }
     offset +=1;
@@ -339,14 +340,13 @@ dissect_dsmcc_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint
         offset, 2, ENC_BIG_ENDIAN);
     offset += 2;
 
-    len = 12;
     if (0 < adaptation_len) {
         sub_tvb = tvb_new_subset(tvb, offset, adaptation_len, adaptation_len);
         dissect_dsmcc_adaptation_header(sub_tvb, pinfo, sub_tree);
         offset += adaptation_len;
     }
 
-    return len;
+    return offset-offset_start;
 }
 
 
@@ -354,9 +354,9 @@ static guint
 dissect_dsmcc_dii_compat_desc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
                 guint offset)
 {
-    gint		i, j;
-    guint8		sub_count, sub_len;
-    guint16		len, count;
+    gint        i, j;
+    guint8      sub_count, sub_len;
+    guint16     len, count;
     proto_item *pi;
     proto_tree *compat_tree;
     proto_tree *desc_sub_tree;
@@ -416,8 +416,7 @@ dissect_dsmcc_dii_compat_desc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
         }
 
         if( 1000 == offset ) {
-            expert_add_info_format( pinfo, NULL, PI_MALFORMED,
-                        PI_ERROR, "Invalid CRC" );
+            expert_add_info( pinfo, NULL, &ei_dsmcc_crc_invalid);
         }
     }
 
@@ -428,12 +427,12 @@ static void
 dissect_dsmcc_dii(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
         guint offset)
 {
-    guint8		module_info_len;
-    guint16		modules, private_data_len;
-    guint16		module_id;
-    guint8		module_version;
-    guint		module_size;
-    guint		i;
+    guint8      module_info_len;
+    guint16     modules, private_data_len;
+    guint16     module_id;
+    guint8      module_version;
+    guint       module_size;
+    guint       i;
     proto_item *pi;
     proto_tree *mod_tree;
 
@@ -487,7 +486,7 @@ dissect_dsmcc_dii(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     if (0 < private_data_len) {
         proto_tree_add_item(tree, hf_etv_dii_authority, tvb, offset, 1,
             ENC_ASCII|ENC_NA);
-        offset += private_data_len;
+        /*offset += private_data_len;*/
     }
 }
 
@@ -498,7 +497,7 @@ dissect_dsmcc_ddb(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 {
     tvbuff_t   *sub_tvb;
     proto_item *pi;
-    guint8		reserved;
+    guint8      reserved;
 
     proto_tree_add_item(tree, hf_dsmcc_ddb_module_id, tvb, offset, 2, ENC_BIG_ENDIAN);
     offset += 2;
@@ -508,8 +507,7 @@ dissect_dsmcc_ddb(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     pi = proto_tree_add_item(tree, hf_dsmcc_ddb_reserved, tvb,
         offset, 1, ENC_BIG_ENDIAN);
     if (0xff != reserved) {
-        PROTO_ITEM_SET_GENERATED(pi);
-        expert_add_info_format(pinfo, pi, PI_MALFORMED, PI_ERROR,
+        expert_add_info_format(pinfo, pi, &ei_dsmcc_invalid_value,
                     "Invalid value - should be 0xff");
     }
     offset +=1;
@@ -527,8 +525,8 @@ dissect_dsmcc_un_download(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 {
     proto_item *pi;
     proto_tree *sub_tree;
-    guint16		msg_id;
-    guint		offset = 0;
+    guint16     msg_id;
+    guint       offset = 0;
 
     msg_id = tvb_get_ntohs(tvb, offset+2);
 
@@ -595,14 +593,14 @@ dissect_dsmcc_ts(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree_in, void *d
 {
     proto_item *pi;
     proto_tree *tree;
-    guint		crc_len;
-    guint8		tid;
-    guint16		sect_len;
-    guint32		crc, calculated_crc;
+    guint       crc_len;
+    guint8      tid;
+    guint16     sect_len;
+    guint32     crc, calculated_crc;
     const char *label;
     tvbuff_t   *sub_tvb;
-    guint16		ssi;
-    guint		offset = 0;
+    guint16     ssi;
+    guint       offset = 0;
 
     pi = proto_tree_add_item(tree_in, proto_dsmcc, tvb, 0, -1, ENC_NA);
     tree = proto_item_add_subtree(pi, ett_dsmcc);
@@ -676,15 +674,14 @@ dissect_dsmcc_ts(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree_in, void *d
             proto_tree_add_uint_format( tree, hf_dsmcc_crc, tvb,
                 crc_len, 4, crc, "CRC: 0x%08x [%s]", crc, label);
         } else {
-            proto_item *msg_error = NULL;
+            proto_item *msg_error;
 
             msg_error = proto_tree_add_uint_format( tree, hf_dsmcc_crc, tvb,
                                 crc_len, 4, crc,
                                 "CRC: 0x%08x [Failed Verification (Calculated: 0x%08x)]",
                                 crc, calculated_crc );
             PROTO_ITEM_SET_GENERATED(msg_error);
-            expert_add_info_format( pinfo, msg_error, PI_MALFORMED,
-                        PI_ERROR, "Invalid CRC" );
+            expert_add_info( pinfo, msg_error, &ei_dsmcc_crc_invalid);
         }
     } else {
         /* TODO: actually check the checksum */
@@ -1027,12 +1024,20 @@ proto_register_dsmcc(void)
         &ett_dsmcc_compat_sub_desc,
         &ett_dsmcc_dii_module
     };
+    static ei_register_info ei[] = {
+        { &ei_dsmcc_invalid_value, { "mpeg_dsmcc.invalid_value", PI_PROTOCOL, PI_WARN, "Invalid value", EXPFILL }},
+        { &ei_dsmcc_crc_invalid, { "mpeg_sect.crc.invalid", PI_CHECKSUM, PI_WARN, "Invalid CRC", EXPFILL }},
+    };
+
     module_t *dsmcc_module;
+    expert_module_t* expert_dsmcc;
 
     proto_dsmcc = proto_register_protocol("MPEG DSM-CC", "MPEG DSM-CC", "mpeg_dsmcc");
 
     proto_register_field_array(proto_dsmcc, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_dsmcc = expert_register_protocol(proto_dsmcc);
+    expert_register_field_array(expert_dsmcc, ei, array_length(ei));
     new_register_dissector("mp2t-dsmcc", dissect_dsmcc_ts, proto_dsmcc);
 
     dsmcc_module = prefs_register_protocol(proto_dsmcc, NULL);
