@@ -2,7 +2,7 @@
  * Declarations of exported routines from mpeg-sect dissector
  * Copyright 2012, Weston Schmidt <weston_schmidt@alumni.purdue.edu>
  *
- * $Id$
+ * $Id: packet-mpeg-sect.h 51283 2013-08-10 21:32:08Z alagoutte $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -23,7 +23,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __PACKET_MPEG_SECT_H_
+#ifndef __PACKET_MPEG_SECT_H__
 #define __PACKET_MPEG_SECT_H__
 
 #define PACKET_MPEG_SECT_PI__TABLE_ID	0
