@@ -2,7 +2,7 @@
  * Routines for Media Resource Control Protocol Version 2 (MRCPv2) dissection
  * Copyright 2012, Zeljko Ancimer  <zancimer[AT]gmail.com>
  *
- * $Id$
+ * $Id: packet-mrcpv2.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -40,6 +40,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
 
 #include <glib.h>
 
@@ -379,7 +380,7 @@ static gint ett_Event_Line = -1;
 static gint ett_Status_Code = -1;
 
 /* format status code description */
-static const string_string status_code_vals[] = { 
+static const string_string status_code_vals[] = {
     { "200", "Success" },
     { "201", "Success with some optional header fields ignored" },
     { "401", "Client Failure: Method not allowed" },
@@ -412,6 +413,7 @@ dissect_mrcpv2_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     gint offset;
     gint value_offset;
     gint str_len;
+    gchar helper_str[256];
     gchar *header_name;
     gchar *header_value;
     LINE_TYPE line_type = UNKNOWN_LINE;
@@ -456,37 +458,37 @@ dissect_mrcpv2_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         sp_end = tvb_find_guint8(tvb, 0, linelen, ' ');
         if ((sp_end == -1) || (sp_end > tvb_len) || (sp_end > linelen))
             return -1;
-        field1 = tvb_get_ephemeral_string(tvb, 0, sp_end);
+        field1 = tvb_get_string(wmem_packet_scope(), tvb, 0, sp_end);
         sp_start = sp_end + 1;
 
         /* length */
         sp_end = tvb_find_guint8(tvb, sp_start, linelen - sp_start, ' ');
         if ((sp_end == -1) || (sp_end > tvb_len) || (sp_end > linelen))
             return -1;
-        field2 = tvb_get_ephemeral_string(tvb, sp_start, sp_end - sp_start);
+        field2 = tvb_get_string(wmem_packet_scope(), tvb, sp_start, sp_end - sp_start);
         sp_start = sp_end + 1;
 
         /* method, request ID or event */
         sp_end = tvb_find_guint8(tvb, sp_start, linelen - sp_start, ' ');
         if ((sp_end == -1) || (sp_end > tvb_len) || (sp_end > linelen))
             return -1;
-        field3 = tvb_get_ephemeral_string(tvb, sp_start, sp_end - sp_start);
+        field3 = tvb_get_string(wmem_packet_scope(), tvb, sp_start, sp_end - sp_start);
         sp_start = sp_end + 1;
 
         /* request ID or status code */
         sp_end = tvb_find_guint8(tvb, sp_start, linelen - sp_start, ' ');
         if (sp_end == -1)
         {
-            field4 = tvb_get_ephemeral_string(tvb, sp_start, linelen - sp_start);
+            field4 = tvb_get_string(wmem_packet_scope(), tvb, sp_start, linelen - sp_start);
             line_type = REQUEST_LINE; /* only request line has 4 parameters */
         }
         else
         {
             if ((sp_end > tvb_len) || (sp_end > linelen))
                 return -1;
-            field4 = tvb_get_ephemeral_string(tvb, sp_start, sp_end - sp_start);
+            field4 = tvb_get_string(wmem_packet_scope(), tvb, sp_start, sp_end - sp_start);
 
-            if (g_ascii_isdigit(field3[0])) /* request ID is number, so it has to be response */
+            if (isdigit(field3[0])) /* request ID is number, so it has to be response */
                 line_type = RESPONSE_LINE;
             else
                 line_type = EVENT_LINE;
@@ -495,7 +497,7 @@ dissect_mrcpv2_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             sp_end = linelen;
             if ((sp_end > tvb_len) || (sp_end > linelen))
                 return -1;
-            field5 = tvb_get_ephemeral_string(tvb, sp_start, sp_end - sp_start);
+            field5 = tvb_get_string(wmem_packet_scope(), tvb, sp_start, sp_end - sp_start);
         }
 
         /* check pdu size */
@@ -610,7 +612,8 @@ dissect_mrcpv2_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 if (content_length > 0)
                 { /* content length > 0 and CRLF detected, this has to be msg body */
                     offset += 2; /* skip separating CRLF */
-                    proto_tree_add_item(mrcpv2_tree, hf_mrcpv2_Data, tvb, offset, tvb_len - offset, ENC_ASCII|ENC_NA);
+                    proto_tree_add_string_format(mrcpv2_tree, hf_mrcpv2_Data, tvb, offset, tvb_len - offset,
+                        helper_str, "Message data: %s", tvb_format_text(tvb, offset, tvb_len - offset));
                     next_offset = tvb_len; /* we are done */
                 }
                 continue;
@@ -623,10 +626,10 @@ dissect_mrcpv2_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 proto_tree_add_item(mrcpv2_tree, hf_mrcpv2_Unknown_Header, tvb, offset, linelen, ENC_UTF_8);
                 continue;
             }
-            header_name = tvb_get_ephemeral_string(tvb, offset, colon_offset - offset);
+            header_name = tvb_get_string(wmem_packet_scope(), tvb, offset, colon_offset - offset);
             ascii_strdown_inplace(header_name);
             value_offset = tvb_skip_wsp(tvb, colon_offset + 1, offset + linelen - (colon_offset + 1));
-            header_value = tvb_get_ephemeral_string(tvb, value_offset, offset + linelen - value_offset);
+            header_value = tvb_get_string(wmem_packet_scope(), tvb, value_offset, offset + linelen - value_offset);
 
             /* find out header type */
             header_type = UNKNOWN;
@@ -946,9 +949,9 @@ get_mrcpv2_pdu_len(packet_info *pinfo _U_, tvbuff_t *tvb, int offset)
     /* second string is message length */
     len_end = tvb_find_guint8(tvb, len_start, MRCPV2_MIN_PDU_LEN - len_start, ' ');
     if (len_end == -1)
-        msg_len = tvb_get_ephemeral_string(tvb, len_start, MRCPV2_MIN_PDU_LEN - len_start);
+        msg_len = tvb_get_string(wmem_packet_scope(), tvb, len_start, MRCPV2_MIN_PDU_LEN - len_start);
     else
-        msg_len = tvb_get_ephemeral_string(tvb, len_start, len_end - len_start);
+        msg_len = tvb_get_string(wmem_packet_scope(), tvb, len_start, len_end - len_start);
 
     num_msg_len = atoi(msg_len);
     return num_msg_len;
@@ -981,7 +984,7 @@ dissect_mrcpv2_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *da
     slash_offset = tvb_find_guint8(tvb, 0, MRCPV2_MIN_LENGTH, '/');
     if (slash_offset != 4)
         return 0;
-    version = tvb_get_ephemeral_string(tvb, 0, slash_offset);
+    version = tvb_get_string(wmem_packet_scope(), tvb, 0, slash_offset);
     if (strcmp(version, "MRCP") != 0)
         return 0;
 
@@ -992,7 +995,7 @@ dissect_mrcpv2_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *da
     value_size = dot_offset - slash_offset - 1;
     if ((value_size != 1) && (value_size != 2))
         return 0;
-    major = tvb_get_ephemeral_string(tvb, slash_offset + 1, dot_offset - 1);
+    major = tvb_get_string(wmem_packet_scope(), tvb, slash_offset + 1, dot_offset - 1);
     value = atoi(major);
     if (value != 2)
         return 0;
@@ -1001,12 +1004,12 @@ dissect_mrcpv2_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *da
     sp_offset = tvb_find_guint8(tvb, dot_offset + 1, MRCPV2_MIN_LENGTH - dot_offset - 1, ' ');
     if (sp_offset == -1)
     {
-        minor = tvb_get_ephemeral_string(tvb, dot_offset + 1, MRCPV2_MIN_LENGTH - dot_offset - 1);
+        minor = tvb_get_string(wmem_packet_scope(), tvb, dot_offset + 1, MRCPV2_MIN_LENGTH - dot_offset - 1);
         len = MRCPV2_MIN_LENGTH;
     }
     else
     {
-        minor = tvb_get_ephemeral_string(tvb, dot_offset + 1, MRCPV2_MIN_LENGTH - sp_offset - 1);
+        minor = tvb_get_string(wmem_packet_scope(), tvb, dot_offset + 1, MRCPV2_MIN_LENGTH - sp_offset - 1);
         len = sp_offset;
     }
     value = atoi(minor);
@@ -1047,7 +1050,7 @@ proto_register_mrcpv2(void)
             FT_STRING, BASE_NONE, NULL, 0, NULL, HFILL }
         },
         { &hf_mrcpv2_Data,
-            { "Message data", "mrcpv2.Data",
+            { "Data", "mrcpv2.Data",
             FT_STRING, BASE_NONE, NULL, 0, NULL, HFILL }
         },
         { &hf_mrcpv2_Method,
