@@ -5,7 +5,7 @@
  * Copyright 2005
  * Written by Martin Mathieson
  *
- * $Id$
+ * $Id: packet-ms-mms.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -435,7 +435,7 @@ static gint dissect_msmms_command(tvbuff_t *tvb, packet_info *pinfo, proto_tree
     offset += 4;
 
     /* Protocol name.  Must be "MMS"... */
-    if (strncmp((char*)tvb_get_ephemeral_string(tvb, offset, 3), "MMS", 3) != 0)
+    if (strncmp((char*)tvb_get_string(wmem_packet_scope(), tvb, offset, 3), "MMS", 3) != 0)
     {
         return 0;
     }
@@ -759,7 +759,7 @@ static void dissect_client_transport_info(tvbuff_t *tvb, packet_info *pinfo, pro
     offset += 4;
 
     /* Extract and show the string in tree and info column */
-    transport_info = tvb_get_ephemeral_unicode_string(tvb, offset, length_remaining - 20, ENC_LITTLE_ENDIAN);
+    transport_info = tvb_get_unicode_string(wmem_packet_scope(), tvb, offset, length_remaining - 20, ENC_LITTLE_ENDIAN);
 
     proto_tree_add_string_format(tree, hf_msmms_command_client_transport_info, tvb,
                                  offset, length_remaining-20,
@@ -867,7 +867,7 @@ static void dissect_server_info(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
         THROW(ReportedBoundsError);
     if (server_version_length > 1)
     {
-        server_version = tvb_get_ephemeral_unicode_string(tvb, offset, server_version_length*2, ENC_LITTLE_ENDIAN);
+        server_version = tvb_get_unicode_string(wmem_packet_scope(), tvb, offset, server_version_length*2, ENC_LITTLE_ENDIAN);
 
         /* Server version string */
         proto_tree_add_item(tree, hf_msmms_command_server_version, tvb,
@@ -933,7 +933,7 @@ static void dissect_client_player_info(tvbuff_t *tvb, packet_info *pinfo, proto_
     offset += 4;
 
     /* Extract and show the string in tree and info column */
-    player_info = tvb_get_ephemeral_unicode_string(tvb, offset, length_remaining - 12, ENC_LITTLE_ENDIAN);
+    player_info = tvb_get_unicode_string(wmem_packet_scope(), tvb, offset, length_remaining - 12, ENC_LITTLE_ENDIAN);
 
     proto_tree_add_item(tree, hf_msmms_command_client_player_info, tvb,
                         offset, length_remaining-12,
@@ -1010,7 +1010,7 @@ static void dissect_request_server_file(tvbuff_t *tvb, packet_info *pinfo, proto
     offset += 4;
 
     /* File path on server */
-    server_file = tvb_get_ephemeral_unicode_string(tvb, offset, length_remaining - 16, ENC_LITTLE_ENDIAN);
+    server_file = tvb_get_unicode_string(wmem_packet_scope(), tvb, offset, length_remaining - 16, ENC_LITTLE_ENDIAN);
 
     proto_tree_add_item(tree, hf_msmms_command_server_file, tvb,
                         offset, length_remaining-16,
