@@ -2,7 +2,7 @@
  * Routines for MSN Messenger Service packet dissection
  * Copyright 2003, Chris Waters <chris@waters.co.nz>
  *
- * $Id$
+ * $Id: packet-msn-messenger.c 49938 2013-06-14 17:49:53Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -84,13 +84,11 @@ dissect_msnms(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	line = tvb_get_ptr(tvb, offset, linelen);
 
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		/*
-		 * Put the first line from the buffer into the summary.
-		 */
-		col_add_str(pinfo->cinfo, COL_INFO,
+	/*
+	 * Put the first line from the buffer into the summary.
+	 */
+	col_add_str(pinfo->cinfo, COL_INFO,
 			    format_text(line, linelen));
-	}
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_msnms, tvb, offset, -1,
@@ -105,7 +103,7 @@ dissect_msnms(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			/*
 			 * Find the end of the line.
 			 */
-			linelen = tvb_find_line_end(tvb, offset, -1,
+			tvb_find_line_end(tvb, offset, -1,
 			    &next_offset, FALSE);
 
 			/*
