@@ -2,7 +2,7 @@
  * Routines for Microsoft Proxy packet dissection
  * Copyright 2000, Jeffrey C. Foster <jfoste@woodward.com>
  *
- * $Id$
+ * $Id: packet-msproxy.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,13 +29,13 @@
  */
 
 /************************************************************************
- *									*
- *  Notes: These are possible command values. User input is welcome 	*
- *									*
- *  Command = 0x040a - Remote host closed connection (maybe ?? )	*
- *  Command = 0x0411 - Remote host closed connection			*
- *  Command = 0x0413 - Local host closed connection or SYN worked	*
- *									*
+ *                                                                      *
+ *  Notes: These are possible command values. User input is welcome     *
+ *                                                                      *
+ *  Command = 0x040a - Remote host closed connection (maybe ?? )        *
+ *  Command = 0x0411 - Remote host closed connection                    *
+ *  Command = 0x0413 - Local host closed connection or SYN worked       *
+ *                                                                      *
  ************************************************************************/
 
 
@@ -49,7 +49,7 @@
 #include <epan/packet.h>
 #include <epan/addr_resolv.h>
 #include <epan/conversation.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/expert.h>
 
 #include "packet-tcp.h"
@@ -93,6 +93,9 @@ static int hf_msproxy_server_int_port = -1;
 static int hf_msproxy_server_ext_addr = -1;
 static int hf_msproxy_server_ext_port = -1;
 
+static expert_field ei_msproxy_unknown = EI_INIT;
+static expert_field ei_msproxy_unhandled = EI_INIT;
+
 static dissector_handle_t msproxy_sub_handle;
 
 
@@ -211,8 +214,7 @@ static void msproxy_sub_dissector( tvbuff_t *tvb, packet_info *pinfo,
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "MS Proxy");
 
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_set_str(pinfo->cinfo, COL_INFO,
+	col_set_str(pinfo->cinfo, COL_INFO,
 			(( redirect_info->proto == PT_TCP) ? "TCP stream" :
 			 "UDP packets"));
 
@@ -287,7 +289,7 @@ static void add_msproxy_conversation( packet_info *pinfo,
 	}
 	conversation_set_dissector(conversation, msproxy_sub_handle);
 
-	new_conv_info = se_new(redirect_entry_t);
+	new_conv_info = wmem_new(wmem_file_scope(), redirect_entry_t);
 
 	new_conv_info->remote_addr = hash_info->dst_addr;
 	new_conv_info->clnt_port = hash_info->clnt_port;
@@ -312,7 +314,7 @@ static int display_application_name(tvbuff_t *tvb, int offset,
 
 	length = tvb_strnlen( tvb, offset, 255);
 	proto_tree_add_text( tree, tvb, offset, length, "Application: %.*s",
-		length, tvb_get_ephemeral_string( tvb, offset, length));
+		length, tvb_get_string( wmem_packet_scope(),  tvb, offset, length));
 
 	return length;
 }
@@ -375,7 +377,7 @@ static void dissect_user_info_2(tvbuff_t *tvb, int offset,
 			return;
 		proto_tree_add_text( tree, tvb, offset, length + 1,
 			"User name: %.*s", length,
-			tvb_get_ephemeral_string( tvb, offset, length));
+			tvb_get_string( wmem_packet_scope(),  tvb, offset, length));
 		offset += length + 2;
 
 		length = tvb_strnlen( tvb, offset, 255);
@@ -383,7 +385,7 @@ static void dissect_user_info_2(tvbuff_t *tvb, int offset,
 			return;
 		proto_tree_add_text( tree, tvb, offset, length + 1,
 			"Application name: %.*s", length,
-			tvb_get_ephemeral_string( tvb, offset, length));
+			tvb_get_string( wmem_packet_scope(),  tvb, offset, length));
 		offset += length + 1;
 
 		length = tvb_strnlen( tvb, offset, 255);
@@ -391,7 +393,7 @@ static void dissect_user_info_2(tvbuff_t *tvb, int offset,
 			return;
 		proto_tree_add_text( tree, tvb, offset, length + 1,
 			"Client computer name: %.*s", length,
-			tvb_get_ephemeral_string( tvb, offset, length));
+			tvb_get_string( wmem_packet_scope(),  tvb, offset, length));
 	}
 }
 
@@ -580,7 +582,7 @@ static void dissect_request_resolve(tvbuff_t *tvb, int offset,
 	if ( tree){
   	 	ti = proto_tree_add_text(tree, tvb, offset, length + 1,
    		 	"Host Name: %.*s", length,
-   		 	tvb_get_ephemeral_string( tvb, offset + 18, length));
+   		 	tvb_get_string( wmem_packet_scope(),  tvb, offset + 18, length));
 
 		name_tree = proto_item_add_subtree(ti, ett_msproxy_name);
 
@@ -591,7 +593,7 @@ static void dissect_request_resolve(tvbuff_t *tvb, int offset,
 		offset += 17;
 
 		proto_tree_add_text( name_tree, tvb, offset, length, "String: %s",
-   		 	tvb_get_ephemeral_string( tvb, offset, length));
+   		 	tvb_get_string( wmem_packet_scope(),  tvb, offset, length));
 	}
 }
 
@@ -684,8 +686,8 @@ static void dissect_msproxy_request(tvbuff_t *tvb,
 	cmd = tvb_get_ntohs( tvb, offset);
 
 	if ( tree)
-		proto_tree_add_uint_format( tree, hf_msproxy_cmd, tvb, offset, 2,
-			cmd, "Command: %s (0x%02x)",
+		proto_tree_add_uint_format_value( tree, hf_msproxy_cmd, tvb, offset, 2,
+			cmd, "%s (0x%02x)",
 			get_msproxy_cmd_name( cmd, FROM_CLIENT),
 			cmd);
 
@@ -811,7 +813,7 @@ static void dissect_auth_1_ack(tvbuff_t *tvb, int offset,
 
 		/* XXX - always 255? */
 		proto_tree_add_text( tree, tvb, offset, 255, "NT domain: %.255s",
-			tvb_get_ephemeral_string( tvb, offset, 255));
+			tvb_get_string( wmem_packet_scope(),  tvb, offset, 255));
 	}
 }
 
@@ -1004,8 +1006,8 @@ static void dissect_msproxy_response(tvbuff_t *tvb, packet_info *pinfo,
 
 	cmd = tvb_get_ntohs( tvb, offset);
 
-	ti = proto_tree_add_uint_format( tree, hf_msproxy_cmd, tvb, offset, 2,
-			cmd, "Command: 0x%02x (%s)", cmd,
+	ti = proto_tree_add_uint_format_value( tree, hf_msproxy_cmd, tvb, offset, 2,
+			cmd, "0x%02x (%s)", cmd,
 			get_msproxy_cmd_name( cmd, FROM_SERVER));
 	offset += 2;
 
@@ -1052,16 +1054,16 @@ static void dissect_msproxy_response(tvbuff_t *tvb, packet_info *pinfo,
 
 		case MSPROXY_CONNECT_AUTHFAILED:
 		case MSPROXY_BIND_AUTHFAILED:
-			expert_add_info_format(pinfo, ti, PI_UNDECODED, PI_WARN, "No know information (help wanted)");
+			expert_add_info(pinfo, ti, &ei_msproxy_unknown);
 			break;
 
 		default:
 
 			if ((((cmd >> 8) ==  MSPROXY_CONNREFUSED) ||
 				((cmd >> 12) ==  MSPROXY_CONNREFUSED)))
-				expert_add_info_format(pinfo, ti, PI_UNDECODED, PI_WARN, "No know information (help wanted)");
+				expert_add_info(pinfo, ti, &ei_msproxy_unknown);
 			else
-				expert_add_info_format(pinfo, ti, PI_UNDECODED, PI_WARN, "Unhandled response command (report this, please)");                
+				expert_add_info(pinfo, ti, &ei_msproxy_unhandled);
 	}
 
 
@@ -1072,7 +1074,7 @@ static void dissect_msproxy_response(tvbuff_t *tvb, packet_info *pinfo,
 static void dissect_msproxy(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 
 
-	proto_tree      *msproxy_tree = NULL;
+	proto_tree      *msproxy_tree;
 	proto_item      *ti;
 	unsigned int	cmd;
 
@@ -1087,30 +1089,22 @@ static void dissect_msproxy(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	hash_info = (hash_entry_t *)conversation_get_proto_data(conversation, proto_msproxy);
 	if ( !hash_info) {
-    		hash_info = se_new(hash_entry_t);
+    		hash_info = wmem_new(wmem_file_scope(), hash_entry_t);
 		conversation_add_proto_data(conversation, proto_msproxy,
 			hash_info);
 	}
 
-	if (check_col(pinfo->cinfo, COL_INFO)){
+	cmd = tvb_get_ntohs( tvb, 36);
 
-		cmd = tvb_get_ntohs( tvb, 36);
+	if ( pinfo->srcport == UDP_PORT_MSPROXY)
+		col_add_fstr( pinfo->cinfo, COL_INFO, "Server message: %s",
+			get_msproxy_cmd_name( cmd, FROM_SERVER));
+	else
+		col_add_fstr(pinfo->cinfo, COL_INFO, "Client message: %s",
+			get_msproxy_cmd_name( cmd, FROM_CLIENT));
 
-		if ( pinfo->srcport == UDP_PORT_MSPROXY)
-			col_add_fstr( pinfo->cinfo, COL_INFO, "Server message: %s",
-				get_msproxy_cmd_name( cmd, FROM_SERVER));
-		else
-			col_add_fstr(pinfo->cinfo, COL_INFO, "Client message: %s",
-				get_msproxy_cmd_name( cmd, FROM_CLIENT));
-
-	}
-
-	if (tree) {				/* if proto tree, decode data */
-    		ti = proto_tree_add_item( tree, proto_msproxy, tvb, 0, -1,
-    				ENC_NA );
-
-		msproxy_tree = proto_item_add_subtree(ti, ett_msproxy);
-	}
+	ti = proto_tree_add_item( tree, proto_msproxy, tvb, 0, -1, ENC_NA );
+	msproxy_tree = proto_item_add_subtree(ti, ett_msproxy);
 
 	if ( pinfo->srcport == UDP_PORT_MSPROXY)
 		dissect_msproxy_response( tvb, pinfo, msproxy_tree, hash_info);
@@ -1270,11 +1264,20 @@ proto_register_msproxy( void){
 		},
 	};
 
+	static ei_register_info ei[] = {
+		{ &ei_msproxy_unknown, { "msproxy.unknown", PI_UNDECODED, PI_WARN, "No know information (help wanted)", EXPFILL }},
+		{ &ei_msproxy_unhandled, { "msproxy.command.unhandled", PI_UNDECODED, PI_WARN, "Unhandled response command (report this, please)", EXPFILL }},
+	};
+
+	expert_module_t* expert_msproxy;
+
 	proto_msproxy = proto_register_protocol( "MS Proxy Protocol",
 		"MS Proxy", "msproxy");
 
 	proto_register_field_array(proto_msproxy, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	expert_msproxy = expert_register_protocol(proto_msproxy);
+	expert_register_field_array(expert_msproxy, ei, array_length(ei));
 
 	register_init_routine( &msproxy_reinit);	/* register re-init routine */
 
