@@ -2,7 +2,7 @@
  * Routines for Message Session Relay Protocol(MSRP) dissection
  * Copyright 2005, Anders Broman <anders.broman[at]ericsson.com>
  *
- * $Id$
+ * $Id: packet-msrp.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,13 +29,14 @@
 #include "config.h"
 
 #include <stdlib.h>
+#include <ctype.h>
 
 #include <glib.h>
 
 #include <epan/packet.h>
 #include <epan/conversation.h>
 #include <epan/strutil.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/prefs.h>
 #include <wsutil/str_util.h>
 
@@ -198,7 +199,7 @@ msrp_add_address( packet_info *pinfo,
      */
     if (!p_conv_data) {
         /* Create conversation data */
-        p_conv_data = se_new0(struct _msrp_conversation_info);
+        p_conv_data = wmem_new0(wmem_file_scope(), struct _msrp_conversation_info);
         conversation_add_proto_data(p_conv, proto_msrp, p_conv_data);
     }
 
@@ -239,8 +240,8 @@ show_setup_info(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             if (p_conv_data)
             {
                 /* Save this conversation info into packet info */
-                p_conv_packet_data = (struct _msrp_conversation_info *)se_memdup(p_conv_data,
-                       sizeof(struct _msrp_conversation_info));
+                p_conv_packet_data = (struct _msrp_conversation_info *)wmem_memdup(wmem_file_scope(),
+                       p_conv_data, sizeof(struct _msrp_conversation_info));
 
                 p_add_proto_data(pinfo->fd, proto_msrp, 0, p_conv_packet_data);
             }
@@ -488,7 +489,6 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
      * is not longer than what's in the buffer, so the
      * "tvb_get_ptr()" calls below won't throw exceptions.   *
      */
-    offset = 0;
     linelen = tvb_find_line_end(tvb, 0, -1, &next_offset, FALSE);
 
     /* Find the first SP and skip the first token */
@@ -518,9 +518,9 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
      */
     is_msrp_response = FALSE;
     if (token_3_len == 3) {
-            if (g_ascii_isdigit(tvb_get_guint8(tvb, token_3_start)) &&
-                g_ascii_isdigit(tvb_get_guint8(tvb, token_3_start + 1)) &&
-                g_ascii_isdigit(tvb_get_guint8(tvb, token_3_start + 2))) {
+            if (isdigit(tvb_get_guint8(tvb, token_3_start)) &&
+                isdigit(tvb_get_guint8(tvb, token_3_start + 1)) &&
+                isdigit(tvb_get_guint8(tvb, token_3_start + 2))) {
                 is_msrp_response = TRUE;
             }
     }
@@ -568,7 +568,7 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
             reqresp_tree = proto_item_add_subtree(th, ett_msrp_reqresp);
             proto_tree_add_item(reqresp_tree,hf_msrp_transactionID,tvb,token_2_start,token_2_len,ENC_ASCII|ENC_NA);
             proto_tree_add_uint(reqresp_tree,hf_msrp_status_code,tvb,token_3_start,token_3_len,
-                                atoi(tvb_get_ephemeral_string(tvb, token_3_start, token_3_len)));
+                                atoi(tvb_get_string(wmem_packet_scope(), tvb, token_3_start, token_3_len)));
 
         }else{
             th = proto_tree_add_item(msrp_tree,hf_msrp_request_line,tvb,0,linelen,ENC_ASCII|ENC_NA);
@@ -632,7 +632,7 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
                      * Fetch the value.
                      */
                     value_len = line_end_offset - value_offset;
-                    value = tvb_get_ephemeral_string(tvb, value_offset,
+                    value = tvb_get_string(wmem_packet_scope(), tvb, value_offset,
                                        value_len);
 
                     /*
@@ -661,11 +661,11 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
                                     parameter_offset++;
                                 content_type_len = semi_colon_offset - value_offset;
                                 content_type_parameter_str_len = line_end_offset - parameter_offset;
-                                content_type_parameter_str = tvb_get_ephemeral_string(tvb,
+                                content_type_parameter_str = tvb_get_string(wmem_packet_scope(), tvb,
                                              parameter_offset, content_type_parameter_str_len);
                             }
                             media_type_str_lower_case = ascii_strdown_inplace(
-                                                            (gchar *)tvb_get_ephemeral_string(tvb, value_offset, content_type_len));
+                                                            (gchar *)tvb_get_string(wmem_packet_scope(), tvb, value_offset, content_type_len));
                             break;
 
                         default:
