@@ -14,7 +14,7 @@
  * Updated for ANSI, Chinese ITU, and Japan support by
  *  Jeff Morriss <jeff.morriss.ws [AT] gmail.com>
  *
- * $Id$
+ * $Id: packet-mtp3.c 52063 2013-09-15 15:11:11Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -45,7 +45,6 @@
 #include <epan/packet.h>
 #include <epan/tap.h>
 #include <epan/prefs.h>
-#include <epan/emem.h>
 #include <epan/wmem/wmem.h>
 #include "packet-q708.h"
 #include "packet-sccp.h"
@@ -133,8 +132,6 @@ static gboolean mtp3_use_ansi_5_bit_sls = FALSE;
 static gboolean mtp3_use_japan_5_bit_sls = FALSE;
 static gboolean mtp3_show_itu_priority = FALSE;
 static gint mtp3_addr_fmt = MTP3_ADDR_FMT_DASHED;
-static mtp3_addr_pc_t* mtp3_addr_dpc;
-static mtp3_addr_pc_t* mtp3_addr_opc;
 
 #define SIO_LENGTH                1
 #define SLS_LENGTH                1
@@ -289,7 +286,7 @@ mtp3_pc_to_str(const guint32 pc)
 {
   gchar *str;
 
-  str=(gchar *)ep_alloc(MAX_STRUCTURED_PC_LENGTH);
+  str=(gchar *)wmem_alloc(wmem_packet_scope(), MAX_STRUCTURED_PC_LENGTH);
   mtp3_pc_to_str_buf(pc, str, MAX_STRUCTURED_PC_LENGTH);
   return str;
 }
@@ -452,7 +449,8 @@ dissect_mtp3_3byte_pc(tvbuff_t *tvb, guint offset, proto_tree *tree, gint ett_pc
 }
 
 static void
-dissect_mtp3_sio(tvbuff_t *tvb, proto_tree *mtp3_tree)
+dissect_mtp3_sio(tvbuff_t *tvb, proto_tree *mtp3_tree,
+    mtp3_addr_pc_t *mtp3_addr_opc, mtp3_addr_pc_t *mtp3_addr_dpc)
 {
   guint8 sio;
   proto_item *sio_item;
@@ -490,7 +488,8 @@ dissect_mtp3_sio(tvbuff_t *tvb, proto_tree *mtp3_tree)
 }
 
 static void
-dissect_mtp3_routing_label(tvbuff_t *tvb, packet_info *pinfo, proto_tree *mtp3_tree)
+dissect_mtp3_routing_label(tvbuff_t *tvb, packet_info *pinfo, proto_tree *mtp3_tree,
+    mtp3_addr_pc_t *mtp3_addr_opc, mtp3_addr_pc_t *mtp3_addr_dpc)
 {
   guint32 label, dpc, opc;
   proto_item *label_item, *label_dpc_item, *label_opc_item;
@@ -698,9 +697,11 @@ reset_mtp3_standard(void)
 static void
 dissect_mtp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-    mtp3_tap_rec_t* tap_rec = ep_new0(mtp3_tap_rec_t);
+    mtp3_tap_rec_t* tap_rec = wmem_new0(wmem_packet_scope(), mtp3_tap_rec_t);
     gint heuristic_standard;
     guint8 si;
+    mtp3_addr_pc_t* mtp3_addr_dpc;
+    mtp3_addr_pc_t* mtp3_addr_opc;
 
     /* Set up structures needed to add the protocol subtree and manage it */
     proto_item *mtp3_item = NULL, *gen_item;
@@ -757,8 +758,8 @@ dissect_mtp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     /* Dissect the packet (even if !tree so can call sub-dissectors and update
      * the source and destination address columns) */
-    dissect_mtp3_sio(tvb, mtp3_tree);
-    dissect_mtp3_routing_label(tvb, pinfo, mtp3_tree);
+    dissect_mtp3_sio(tvb, mtp3_tree, mtp3_addr_opc, mtp3_addr_dpc);
+    dissect_mtp3_routing_label(tvb, pinfo, mtp3_tree, mtp3_addr_opc, mtp3_addr_dpc);
 
     memcpy(&(tap_rec->addr_opc), mtp3_addr_opc, sizeof(mtp3_addr_pc_t));
     memcpy(&(tap_rec->addr_dpc), mtp3_addr_dpc, sizeof(mtp3_addr_pc_t));
