@@ -3,7 +3,7 @@
  * Copyright 2004, Anders Broman.
  * Copyright 2004, Olivier Biot.
  *
- * $Id$
+ * $Id: packet-multipart.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Refer to the AUTHORS file or the AUTHORS section in the man page
  * for contacting the author(s) of this file.
@@ -59,13 +59,14 @@
 #include "config.h"
 
 #include <string.h>
+#include <ctype.h>
 
 #include <glib.h>
 
 #include <epan/packet.h>
 #include <epan/prefs.h>
 #include <epan/base64.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 
 #include "packet-imf.h"
 
@@ -174,7 +175,7 @@ base64_decode(packet_info *pinfo, tvbuff_t *b64_tvb, char *name)
 {
     char *data;
     tvbuff_t *tvb;
-    data = g_strdup(tvb_get_ephemeral_string(b64_tvb, 0, tvb_length(b64_tvb)));
+    data = tvb_get_string(wmem_packet_scope(), b64_tvb, 0, tvb_length(b64_tvb));
 
     tvb = base64_to_tvb(b64_tvb, data);
     add_new_data_source(pinfo, tvb, name);
@@ -204,7 +205,7 @@ unfold_and_compact_mime_header(const char *lines, gint *first_colon_offset)
     if (! lines) return NULL;
 
     c = *p;
-    ret = (char *)ep_alloc(strlen(lines) + 1);
+    ret = (char *)wmem_alloc(wmem_packet_scope(), strlen(lines) + 1);
     q = ret;
 
     while (c) {
@@ -268,11 +269,9 @@ unfold_and_compact_mime_header(const char *lines, gint *first_colon_offset)
         } else { /* Regular character */
             if (sep_seen) {
                 sep_seen = 0;
-                lws = FALSE;
             } else {
                 if (lws) {
                     *(q++) = ' ';
-                    lws = FALSE;
                 }
             }
             lws = FALSE;
@@ -324,7 +323,7 @@ static char *find_parameter(char *parameters, const char *key, int *retlen)
 
     while (*p) {
 
-        while ((*p) && g_ascii_isspace(*p))
+        while ((*p) && isspace((guchar)*p))
             p++; /* Skip white space */
 
         if (g_ascii_strncasecmp(p, key, keylen) == 0)
@@ -364,7 +363,7 @@ static char *find_parameter(char *parameters, const char *key, int *retlen)
          */
         p = start;
         while (*p) {
-            if (*p == ';' || g_ascii_isspace(*p))
+            if (*p == ';' || isspace((guchar)*p))
                 break;
             p++;
             len++;
@@ -616,7 +615,7 @@ process_body_part(proto_tree *tree, tvbuff_t *tvb, const guint8 *boundary,
             break;
         }
 
-        hdr_str = tvb_get_ephemeral_string(tvb, offset, next_offset - offset);
+        hdr_str = tvb_get_string(wmem_packet_scope(), tvb, offset, next_offset - offset);
 
         header_str = unfold_and_compact_mime_header(hdr_str, &colon_offset);
         if (colon_offset <= 0) {
@@ -659,7 +658,7 @@ process_body_part(proto_tree *tree, tvbuff_t *tvb, const guint8 *boundary,
 
                             if (semicolon_offset > 0) {
                                 value_str[semicolon_offset] = '\0';
-                                parameters = ep_strdup(value_str + semicolon_offset + 1);
+                                parameters = wmem_strdup(wmem_packet_scope(), value_str + semicolon_offset + 1);
                             } else {
                                 parameters = NULL;
                             }
