@@ -5,7 +5,7 @@
  *
  * MySQL 4.1+ protocol by Axel Schwenke <axel@mysql.com>
  *
- * $Id$
+ * $Id: packet-mysql.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -41,7 +41,7 @@
 
 #include <epan/packet.h>
 #include <epan/conversation.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 
 #include <epan/dissectors/packet-tcp.h>
 #include <epan/prefs.h>
@@ -516,6 +516,13 @@ static int hf_mysql_exec_field_time_length = -1;
 static int hf_mysql_exec_field_time_sign = -1;
 static int hf_mysql_exec_field_time_days = -1;
 
+static expert_field ei_mysql_eof = EI_INIT;
+static expert_field ei_mysql_dissector_incomplete = EI_INIT;
+static expert_field ei_mysql_streamed_param = EI_INIT;
+static expert_field ei_mysql_prepare_response_needed = EI_INIT;
+static expert_field ei_mysql_unknown_response = EI_INIT;
+static expert_field ei_mysql_command = EI_INIT;
+
 /* type constants */
 static const value_string type_constants[] = {
 	{0x00, "FIELD_TYPE_DECIMAL"    },
@@ -588,7 +595,7 @@ typedef struct mysql_conn_data {
 	mysql_state_t state;
 	guint16 stmt_num_params;
 	guint16 stmt_num_fields;
-	emem_tree_t* stmts;
+	wmem_tree_t* stmts;
 #ifdef CTDEBUG
 	guint32 generation;
 #endif
@@ -705,12 +712,12 @@ dissect_mysql_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	/* get associated state information, create if necessary */
 	conn_data= (mysql_conn_data_t *)conversation_get_proto_data(conversation, proto_mysql);
 	if (!conn_data) {
-		conn_data= se_new(mysql_conn_data_t);
+		conn_data= wmem_new(wmem_file_scope(), mysql_conn_data_t);
 		conn_data->srv_caps= 0;
 		conn_data->clnt_caps= 0;
 		conn_data->clnt_caps_ext= 0;
 		conn_data->state= UNDEFINED;
-		conn_data->stmts= se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK, "PROTO_mysql_stmts");
+		conn_data->stmts= wmem_tree_new(wmem_file_scope());
 #ifdef CTDEBUG
 		conn_data->generation= 0;
 #endif
@@ -724,7 +731,7 @@ dissect_mysql_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		 *  conversation now so if/when we dissect the frame again
 		 *  we'll start with the same state.
 		 */
-		mysql_frame_data_p = se_new(struct mysql_frame_data);
+		mysql_frame_data_p = wmem_new(wmem_file_scope(), struct mysql_frame_data);
 		mysql_frame_data_p->state = conn_data->state;
 		p_add_proto_data(pinfo->fd, proto_mysql, 0, mysql_frame_data_p);
 
@@ -816,7 +823,7 @@ dissect_mysql_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	/* remaining payload indicates an error */
 	if (tree && tvb_reported_length_remaining(tvb, offset) > 0) {
 		ti = proto_tree_add_item(mysql_tree, hf_mysql_payload, tvb, offset, -1, ENC_NA);
-		expert_add_info_format(pinfo, ti, PI_UNDECODED, PI_WARN, "FIXME - dissector is incomplete");
+		expert_add_info(pinfo, ti, &ei_mysql_dissector_incomplete);
 	}
 }
 
@@ -840,23 +847,19 @@ mysql_dissect_greeting(tvbuff_t *tvb, packet_info *pinfo, int offset,
 
 	conn_data->state= LOGIN;
 
-	if (tree) {
-		tf = proto_tree_add_item(tree, hf_mysql_server_greeting, tvb, offset, -1, ENC_NA);
-		greeting_tree = proto_item_add_subtree(tf, ett_server_greeting);
-	}
+	tf = proto_tree_add_item(tree, hf_mysql_server_greeting, tvb, offset, -1, ENC_NA);
+	greeting_tree = proto_item_add_subtree(tf, ett_server_greeting);
+
+	col_append_fstr(pinfo->cinfo, COL_INFO, " proto=%d", protocol) ;
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO, " proto=%d", protocol) ;
-	}
 	proto_tree_add_item(greeting_tree, hf_mysql_protocol, tvb, offset, 1, ENC_NA);
 
 	offset += 1;
 
 	/* version string */
 	lenstr = tvb_strsize(tvb,offset);
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO, " version=%s", tvb_get_ephemeral_string(tvb, offset, lenstr));
-	}
+	col_append_fstr(pinfo->cinfo, COL_INFO, " version=%s", tvb_get_string(wmem_packet_scope(), tvb, offset, lenstr));
+
 	proto_tree_add_item(greeting_tree, hf_mysql_version, tvb, offset, lenstr, ENC_ASCII|ENC_NA);
 	conn_data->major_version = 0;
 	for (ver_offset = 0; ver_offset < lenstr; ver_offset++) {
@@ -942,9 +945,7 @@ mysql_dissect_login(tvbuff_t *tvb, packet_info *pinfo, int offset,
 
 	/* User name */
 	lenstr = my_tvb_strsize(tvb, offset);
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO, " user=%s", tvb_get_ephemeral_string(tvb, offset, lenstr));
-	}
+	col_append_fstr(pinfo->cinfo, COL_INFO, " user=%s", tvb_get_string(wmem_packet_scope(), tvb, offset, lenstr));
 	proto_tree_add_item(login_tree, hf_mysql_user, tvb, offset, lenstr, ENC_ASCII|ENC_NA);
 	offset += lenstr;
 
@@ -971,9 +972,8 @@ mysql_dissect_login(tvbuff_t *tvb, packet_info *pinfo, int offset,
 			return offset;
 		}
 
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_append_fstr(pinfo->cinfo, COL_INFO, " db=%s", tvb_get_ephemeral_string(tvb, offset, lenstr));
-		}
+		col_append_fstr(pinfo->cinfo, COL_INFO, " db=%s", tvb_get_string(wmem_packet_scope(), tvb, offset, lenstr));
+
 		proto_tree_add_item(login_tree, hf_mysql_schema, tvb, offset, lenstr, ENC_ASCII|ENC_NA);
 		offset += lenstr;
 	}
@@ -1148,9 +1148,7 @@ mysql_dissect_exec_param(proto_item *req_tree, tvbuff_t *tvb, int *offset,
 	param_unsigned = tvb_get_guint8(tvb, *offset);
 	*offset += 1; /* signedness */
 	if ((param_flags & MYSQL_PARAM_FLAG_STREAMED) == MYSQL_PARAM_FLAG_STREAMED) {
-		expert_add_info_format(pinfo, field_tree, PI_SEQUENCE, PI_CHAT,
-				       "This parameter was streamed, its value "
-				       "can be found in Send BLOB packets");
+		expert_add_info(pinfo, field_tree, &ei_mysql_streamed_param);
 		return 1;
 	}
 	while (mysql_exec_dissectors[dissector_index].dissector != NULL) {
@@ -1182,9 +1180,8 @@ mysql_dissect_request(tvbuff_t *tvb,packet_info *pinfo, int offset,
 	}
 
 	opcode = tvb_get_guint8(tvb, offset);
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO, " %s", val_to_str(opcode, mysql_command_vals, "Unknown (%u)"));
-	}
+	col_append_fstr(pinfo->cinfo, COL_INFO, " %s", val_to_str(opcode, mysql_command_vals, "Unknown (%u)"));
+
 	proto_tree_add_item(req_tree, hf_mysql_command, tvb, offset, 1, ENC_NA);
 	proto_item_append_text(tf, " %s", val_to_str(opcode, mysql_command_vals, "Unknown (%u)"));
 	offset += 1;
@@ -1221,8 +1218,7 @@ mysql_dissect_request(tvbuff_t *tvb,packet_info *pinfo, int offset,
 		lenstr = my_tvb_strsize(tvb, offset);
 		proto_tree_add_item(req_tree, hf_mysql_query, tvb, offset, lenstr, ENC_ASCII|ENC_NA);
 		if (mysql_showquery) {
-		        if (check_col(pinfo->cinfo, COL_INFO))
-		                col_append_fstr(pinfo->cinfo, COL_INFO, " { %s } ", tvb_get_ephemeral_string(tvb, offset, lenstr));
+			col_append_fstr(pinfo->cinfo, COL_INFO, " { %s } ", tvb_get_string(wmem_packet_scope(), tvb, offset, lenstr));
 		}
 		offset += lenstr;
 		conn_data->state = RESPONSE_TABULAR;
@@ -1323,7 +1319,7 @@ mysql_dissect_request(tvbuff_t *tvb,packet_info *pinfo, int offset,
 		stmt_id = tvb_get_letohl(tvb, offset);
 		offset += 4;
 
-		stmt_data = (my_stmt_data_t *)se_tree_lookup32(conn_data->stmts, stmt_id);
+		stmt_data = (my_stmt_data_t *)wmem_tree_lookup32(conn_data->stmts, stmt_id);
 		if (stmt_data != NULL) {
 			guint16 data_param = tvb_get_letohs(tvb, offset);
 			if (stmt_data->nparam > data_param) {
@@ -1358,7 +1354,7 @@ mysql_dissect_request(tvbuff_t *tvb,packet_info *pinfo, int offset,
 		proto_tree_add_item(req_tree, hf_mysql_exec_iter, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 		offset += 4;
 
-		stmt_data = (my_stmt_data_t *)se_tree_lookup32(conn_data->stmts, stmt_id);
+		stmt_data = (my_stmt_data_t *)wmem_tree_lookup32(conn_data->stmts, stmt_id);
 		if (stmt_data != NULL) {
 			if (stmt_data->nparam != 0) {
 				guint8 stmt_bound;
@@ -1380,8 +1376,7 @@ mysql_dissect_request(tvbuff_t *tvb,packet_info *pinfo, int offset,
 			lenstr = tvb_reported_length_remaining(tvb, offset);
 			if (tree &&  lenstr > 0) {
 				ti = proto_tree_add_item(req_tree, hf_mysql_payload, tvb, offset, lenstr, ENC_NA);
-				expert_add_info_format(pinfo, ti, PI_UNDECODED, PI_WARN,
-						       "PREPARE Response packet is needed to dissect the payload");
+				expert_add_info(pinfo, ti, &ei_mysql_prepare_response_needed);
 			}
 			offset += lenstr;
 		}
@@ -1391,7 +1386,7 @@ mysql_dissect_request(tvbuff_t *tvb,packet_info *pinfo, int offset,
 		lenstr = tvb_reported_length_remaining(tvb, offset);
 		if (tree &&  lenstr > 0) {
 			ti = proto_tree_add_item(req_tree, hf_mysql_payload, tvb, offset, lenstr, ENC_NA);
-			expert_add_info_format(pinfo, ti, PI_UNDECODED, PI_WARN, "FIXME: execute dissector incomplete");
+			expert_add_info_format(pinfo, ti, &ei_mysql_dissector_incomplete, "FIXME: execute dissector incomplete");
 		}
 		offset += lenstr;
 #endif
@@ -1422,14 +1417,14 @@ mysql_dissect_request(tvbuff_t *tvb,packet_info *pinfo, int offset,
 	case MYSQL_CONNECT_OUT:
 	case MYSQL_REGISTER_SLAVE:
 		ti = proto_tree_add_item(req_tree, hf_mysql_payload, tvb, offset, -1, ENC_NA);
-		expert_add_info_format(pinfo, ti, PI_UNDECODED, PI_WARN, "FIXME: implement replication packets");
+		expert_add_info_format(pinfo, ti, &ei_mysql_dissector_incomplete, "FIXME: implement replication packets");
 		offset += tvb_reported_length_remaining(tvb, offset);
 		conn_data->state = REQUEST;
 		break;
 
 	default:
 		ti = proto_tree_add_item(req_tree, hf_mysql_payload, tvb, offset, -1, ENC_NA);
-		expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN, "Unknown/invalid command code");
+		expert_add_info(pinfo, ti, &ei_mysql_command);
 		offset += tvb_reported_length_remaining(tvb, offset);
 		conn_data->state = UNDEFINED;
 	}
@@ -1486,8 +1481,7 @@ mysql_dissect_response(tvbuff_t *tvb, packet_info *pinfo, int offset,
 		} else {
 			/* This should be an unreachable case */
 			conn_data->state= REQUEST;
-			expert_add_info_format(pinfo, ti, PI_PROTOCOL, PI_WARN,
-				"EOF Marker found while connection in wrong state.");
+			expert_add_info(pinfo, ti, &ei_mysql_eof);
 		}
 	}
 
@@ -1532,7 +1526,7 @@ mysql_dissect_response(tvbuff_t *tvb, packet_info *pinfo, int offset,
 
 		default:
 			ti = proto_tree_add_item(tree, hf_mysql_payload, tvb, offset, -1, ENC_NA);
-			expert_add_info_format(pinfo, ti, PI_UNDECODED, PI_WARN, "unknown/invalid response");
+			expert_add_info(pinfo, ti, &ei_mysql_unknown_response);
 			offset += tvb_reported_length_remaining(tvb, offset);
 			conn_data->state = UNDEFINED;
 		}
@@ -1546,9 +1540,8 @@ static int
 mysql_dissect_error_packet(tvbuff_t *tvb, packet_info *pinfo,
 			   int offset, proto_tree *tree)
 {
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO, " Error %d", tvb_get_letohs(tvb, offset));
-	}
+	col_append_fstr(pinfo->cinfo, COL_INFO, " Error %d", tvb_get_letohs(tvb, offset));
+
 	proto_tree_add_item(tree, hf_mysql_error_code, tvb, offset, 2, ENC_LITTLE_ENDIAN);
 	offset += 2;
 
@@ -1854,12 +1847,12 @@ mysql_dissect_response_prepare(tvbuff_t *tvb, int offset, proto_tree *tree, mysq
 	offset += 2;
 	proto_tree_add_item(tree, hf_mysql_num_params, tvb, offset, 2, ENC_LITTLE_ENDIAN);
 	conn_data->stmt_num_params = tvb_get_letohs(tvb, offset);
-	stmt_data = se_new(struct my_stmt_data);
+	stmt_data = wmem_new(wmem_file_scope(), struct my_stmt_data);
 	stmt_data->nparam = conn_data->stmt_num_params;
 	flagsize = (int)(sizeof(guint8) * stmt_data->nparam);
-	stmt_data->param_flags = (guint8 *)se_alloc(flagsize);
+	stmt_data->param_flags = (guint8 *)wmem_alloc(wmem_file_scope(), flagsize);
 	memset(stmt_data->param_flags, 0, flagsize);
-	se_tree_insert32(conn_data->stmts, stmt_id, stmt_data);
+	wmem_tree_insert32(conn_data->stmts, stmt_id, stmt_data);
 	offset += 2;
 	/* Filler */
 	offset += 1;
@@ -2639,11 +2632,23 @@ void proto_register_mysql(void)
 		&ett_exec_param
 	};
 
+	static ei_register_info ei[] = {
+		{ &ei_mysql_dissector_incomplete, { "mysql.dissector_incomplete", PI_UNDECODED, PI_WARN, "FIXME - dissector is incomplete", EXPFILL }},
+		{ &ei_mysql_streamed_param, { "mysql.streamed_param", PI_SEQUENCE, PI_CHAT, "This parameter was streamed, its value can be found in Send BLOB packets", EXPFILL }},
+		{ &ei_mysql_prepare_response_needed, { "mysql.prepare_response_needed", PI_UNDECODED, PI_WARN, "PREPARE Response packet is needed to dissect the payload", EXPFILL }},
+		{ &ei_mysql_command, { "mysql.command.invalid", PI_PROTOCOL, PI_WARN, "Unknown/invalid command code", EXPFILL }},
+		{ &ei_mysql_eof, { "mysql.eof.wrong_state", PI_PROTOCOL, PI_WARN, "EOF Marker found while connection in wrong state.", EXPFILL }},
+		{ &ei_mysql_unknown_response, { "mysql.unknown_response", PI_UNDECODED, PI_WARN, "unknown/invalid response", EXPFILL }},
+	};
+
 	module_t *mysql_module;
+	expert_module_t* expert_mysql;
 
 	proto_mysql = proto_register_protocol("MySQL Protocol", "MySQL", "mysql");
 	proto_register_field_array(proto_mysql, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	expert_mysql = expert_register_protocol(proto_mysql);
+	expert_register_field_array(expert_mysql, ei, array_length(ei));
 
 	mysql_module = prefs_register_protocol(proto_mysql, NULL);
 	prefs_register_bool_preference(mysql_module, "desegment_buffers",
