@@ -2,7 +2,7 @@
  * Routines for NASDAQ TotalView-ITCH version 2.00/3.00 (with Chi-X extension) Protocol dissection
  * Copyright 2007,2008 Didier Gautheron <dgautheron@magic.fr>
  *
- * $Id$
+ * $Id: packet-nasdaq-itch.c 52172 2013-09-22 15:50:55Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -42,6 +42,7 @@
 
 #include <epan/packet.h>
 #include <epan/prefs.h>
+#include <epan/wmem/wmem.h>
 #include <wsutil/type_util.h>
 
 /* Chi-X version */
@@ -147,23 +148,16 @@ static int hf_nasdaq_itch_execution_price = -1;
 static int hf_nasdaq_itch_canceled = -1;
 static int hf_nasdaq_itch_cross = -1;
 
-#define PINFO_COL(a) (check_col((a)->cinfo, COL_INFO))
-
 /* ---------------------- */
 static int
 order_ref_number(tvbuff_t *tvb, packet_info *pinfo, proto_tree *nasdaq_itch_tree, int offset)
 {
-  gint col_info = PINFO_COL(pinfo);
+  const char *str_value = tvb_get_string(wmem_packet_scope(), tvb, offset, 9);
+  guint32 value = (guint32)strtoul(str_value, NULL, 10);
 
-  if (nasdaq_itch_tree || col_info) {
-      const char *str_value = tvb_get_ephemeral_string(tvb, offset, 9);
-      guint32 value = (guint32)strtoul(str_value, NULL, 10);
+  proto_tree_add_uint(nasdaq_itch_tree, hf_nasdaq_itch_order_reference, tvb, offset, 9, value);
+  col_append_fstr(pinfo->cinfo, COL_INFO, "%u ", value);
 
-      proto_tree_add_uint(nasdaq_itch_tree, hf_nasdaq_itch_order_reference, tvb, offset, 9, value);
-      if (col_info) {
-          col_append_fstr(pinfo->cinfo, COL_INFO, "%u ", value);
-      }
-  }
   return offset+9;
 }
 
@@ -175,17 +169,17 @@ time_stamp(tvbuff_t *tvb, proto_tree *nasdaq_itch_tree, int id, int offset, int
   if (nasdaq_itch_tree) {
       guint32 ms, val;
       const char *display = "";
-      const char *str_value = tvb_get_ephemeral_string(tvb, offset, size);
+      const char *str_value = tvb_get_string(wmem_packet_scope(), tvb, offset, size);
 
       ms = val = (guint32)strtoul(str_value, NULL, 10);
       switch (size) {
       case 3:
-          display = ep_strdup_printf(" %03u" , val);
+          display = wmem_strdup_printf(wmem_packet_scope(), " %03u" , val);
           break;
       case 5:
           ms = val *1000;
       case 8: /* 0 86 400 000 */
-          display = ep_strdup_printf(" %u (%02u:%02u:%02u.%03u)", val,
+          display = wmem_strdup_printf(wmem_packet_scope(), " %u (%02u:%02u:%02u.%03u)", val,
               ms/3600000, (ms % 3600000)/60000, (ms % 60000)/1000, ms %1000);
           break;
       }
@@ -198,18 +192,14 @@ time_stamp(tvbuff_t *tvb, proto_tree *nasdaq_itch_tree, int id, int offset, int
 static int
 number_of_shares(tvbuff_t *tvb, packet_info *pinfo, proto_tree *nasdaq_itch_tree, int id, int offset, int big)
 {
-  gint col_info = PINFO_COL(pinfo);
   gint size = (big)?10:6;
+  const char *str_value = tvb_get_string(wmem_packet_scope(), tvb, offset, size);
 
-  if (nasdaq_itch_tree || col_info) {
-      const char *str_value = tvb_get_ephemeral_string(tvb, offset, size);
-      guint32 value = (guint32)strtoul(str_value, NULL, 10);
+  guint32 value = (guint32)strtoul(str_value, NULL, 10);
+
+  proto_tree_add_uint(nasdaq_itch_tree, id, tvb, offset, size, value);
+  col_append_fstr(pinfo->cinfo, COL_INFO, "qty %u ", value);
 
-      proto_tree_add_uint(nasdaq_itch_tree, id, tvb, offset, size, value);
-      if (col_info) {
-          col_append_fstr(pinfo->cinfo, COL_INFO, "qty %u ", value);
-      }
-  }
   return offset +size;
 }
 
@@ -217,18 +207,14 @@ number_of_shares(tvbuff_t *tvb, packet_info *pinfo, proto_tree *nasdaq_itch_tree
 static int
 price(tvbuff_t *tvb, packet_info *pinfo, proto_tree *nasdaq_itch_tree, int id, int offset, int big)
 {
-  gint col_info = PINFO_COL(pinfo);
   gint size = (big)?19:10;
 
-  if (nasdaq_itch_tree || col_info) {
-      const char *str_value = tvb_get_ephemeral_string(tvb, offset, size);
-      gdouble value = guint64_to_gdouble(g_ascii_strtoull(str_value, NULL, 10))/((big)?1000000.0:10000.0);
+  const char *str_value = tvb_get_string(wmem_packet_scope(), tvb, offset, size);
+  gdouble value = guint64_to_gdouble(g_ascii_strtoull(str_value, NULL, 10))/((big)?1000000.0:10000.0);
+
+  proto_tree_add_double(nasdaq_itch_tree, id, tvb, offset, size, value);
+  col_append_fstr(pinfo->cinfo, COL_INFO, "price %g ", value);
 
-      proto_tree_add_double(nasdaq_itch_tree, id, tvb, offset, size, value);
-      if (col_info) {
-          col_append_fstr(pinfo->cinfo, COL_INFO, "price %g ", value);
-      }
-  }
   return offset+size;
 }
 
@@ -236,15 +222,11 @@ price(tvbuff_t *tvb, packet_info *pinfo, proto_tree *nasdaq_itch_tree, int id, i
 static int
 stock(tvbuff_t *tvb, packet_info *pinfo, proto_tree *nasdaq_itch_tree, int offset)
 {
-  gint col_info = PINFO_COL(pinfo);
-  if (nasdaq_itch_tree || col_info) {
-      char *stock_p = tvb_get_ephemeral_string(tvb, offset, 6);
+  char *stock_p = tvb_get_string(wmem_packet_scope(), tvb, offset, 6);
+
+  proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_stock, tvb, offset, 6, ENC_ASCII|ENC_NA);
+  col_append_fstr(pinfo->cinfo, COL_INFO, "<%s> ", stock_p);
 
-      proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_stock, tvb, offset, 6, ENC_ASCII|ENC_NA);
-      if (col_info) {
-          col_append_fstr(pinfo->cinfo, COL_INFO, "<%s> ", stock_p);
-      }
-  }
   return offset+6;
 }
 
@@ -252,15 +234,13 @@ stock(tvbuff_t *tvb, packet_info *pinfo, proto_tree *nasdaq_itch_tree, int offse
 static int
 order(tvbuff_t *tvb, packet_info *pinfo, proto_tree *nasdaq_itch_tree, int offset, int big)
 {
-  gint col_info = PINFO_COL(pinfo);
   guint8 value;
 
   offset = order_ref_number(tvb, pinfo, nasdaq_itch_tree, offset);
 
   value = tvb_get_guint8(tvb, offset);
-  if (col_info) {
-      col_append_fstr(pinfo->cinfo, COL_INFO, "%c ", value);
-  }
+
+  col_append_fstr(pinfo->cinfo, COL_INFO, "%c ", value);
   proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_buy_sell, tvb, offset, 1, ENC_ASCII|ENC_NA);
   offset += 1;
 
@@ -293,11 +273,9 @@ dissect_nasdaq_itch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     proto_tree *nasdaq_itch_tree = NULL;
     guint8 nasdaq_itch_type;
     int  offset = 0;
-    gint col_info;
     int version = 3;
     int big = 0;
-
-    col_info = PINFO_COL(pinfo);
+    const gchar *rep;
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "Nasdaq-ITCH");
 
@@ -310,23 +288,21 @@ dissect_nasdaq_itch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     if ((!nasdaq_itch_chi_x || version == 3) && strchr(chix_msg, nasdaq_itch_type)) {
         nasdaq_itch_type = 0; /* unknown */
     }
-    if (col_info || tree) {
-        const gchar *rep = val_to_str(nasdaq_itch_type, message_types_val, "Unknown packet type (0x%02x) ");
-        if (col_info ) {
-            col_clear(pinfo->cinfo, COL_INFO);
-            col_add_str(pinfo->cinfo, COL_INFO, rep);
-        }
-        if (tree) {
-            proto_item *item;
 
-            ti = proto_tree_add_protocol_format(tree, proto_nasdaq_itch, tvb, offset, -1, "Nasdaq TotalView-ITCH %s, %s",
-                    version == 2?"2.0":"3.0", rep);
+    rep = val_to_str(nasdaq_itch_type, message_types_val, "Unknown packet type (0x%02x) ");
+    col_clear(pinfo->cinfo, COL_INFO);
+    col_add_str(pinfo->cinfo, COL_INFO, rep);
 
-            nasdaq_itch_tree = proto_item_add_subtree(ti, ett_nasdaq_itch);
+    if (tree) {
+        proto_item *item;
 
-            item=proto_tree_add_uint(nasdaq_itch_tree, hf_nasdaq_itch_version, tvb, 0, 0, version);
-            PROTO_ITEM_SET_GENERATED(item);
-        }
+        ti = proto_tree_add_protocol_format(tree, proto_nasdaq_itch, tvb, offset, -1, "Nasdaq TotalView-ITCH %s, %s",
+                version == 2?"2.0":"3.0", rep);
+
+        nasdaq_itch_tree = proto_item_add_subtree(ti, ett_nasdaq_itch);
+
+        item=proto_tree_add_uint(nasdaq_itch_tree, hf_nasdaq_itch_version, tvb, 0, 0, version);
+        PROTO_ITEM_SET_GENERATED(item);
     }
 
     if (version == 2) {
@@ -339,11 +315,11 @@ dissect_nasdaq_itch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     if (version == 3) {
       switch (nasdaq_itch_type) {
       case 'T': /* seconds */
-          offset = time_stamp (tvb, nasdaq_itch_tree, hf_nasdaq_itch_second, offset, 5);
+          /*offset =*/ time_stamp (tvb, nasdaq_itch_tree, hf_nasdaq_itch_second, offset, 5);
           return;
 
       case 'M': /* milliseconds */
-          offset = time_stamp (tvb, nasdaq_itch_tree, hf_nasdaq_itch_millisecond, offset, 3);
+          /*offset =*/ time_stamp (tvb, nasdaq_itch_tree, hf_nasdaq_itch_millisecond, offset, 3);
           return;
       }
     }
@@ -364,7 +340,7 @@ dissect_nasdaq_itch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_round_lot_size, tvb, offset, 6, ENC_ASCII|ENC_NA);
         offset += 6;
         proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_round_lots_only, tvb, offset, 1, ENC_BIG_ENDIAN);
-        offset += 1;
+        /*offset += 1;*/
         break;
 
     case 'H': /* Stock trading action */
@@ -375,7 +351,7 @@ dissect_nasdaq_itch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_reserved, tvb, offset, 1, ENC_ASCII|ENC_NA);
         offset += 1;
         proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_reason, tvb, offset, 4, ENC_ASCII|ENC_NA);
-        offset += 4;
+        /*offset += 4;*/
         break;
 
     case 'a' :
@@ -384,20 +360,20 @@ dissect_nasdaq_itch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         offset = order(tvb, pinfo, nasdaq_itch_tree, offset, big);
         if (version == 2) {
             proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_printable, tvb, offset, 1, ENC_ASCII|ENC_NA);
-            offset += 1;
+            /*offset += 1;*/
         }
         break;
 
     case 'F': /* Add order, MPID */
         offset = order(tvb, pinfo, nasdaq_itch_tree, offset, big);
         proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_attribution, tvb, offset, 4, ENC_ASCII|ENC_NA);
-        offset += 4;
+        /*offset += 4;*/
         break;
 
     case 'e' :
         big = 1;
     case 'E' : /* Order executed */
-        offset = executed(tvb, pinfo, nasdaq_itch_tree, offset, big);
+        /*offset =*/ executed(tvb, pinfo, nasdaq_itch_tree, offset, big);
         break;
 
     case 'C' : /* Order executed with price */
@@ -405,19 +381,19 @@ dissect_nasdaq_itch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_printable, tvb, offset, 1, ENC_ASCII|ENC_NA);
         offset += 1;
 
-        offset = price(tvb, pinfo, nasdaq_itch_tree, hf_nasdaq_itch_execution_price, offset, big);
+        /*offset = */price(tvb, pinfo, nasdaq_itch_tree, hf_nasdaq_itch_execution_price, offset, big);
         break;
 
     case 'x' :
         big = 1;
     case 'X' : /* Order cancel */
         offset = order_ref_number(tvb, pinfo, nasdaq_itch_tree, offset);
-        offset = number_of_shares(tvb, pinfo, nasdaq_itch_tree, hf_nasdaq_itch_canceled, offset, big);
+        /*offset = */number_of_shares(tvb, pinfo, nasdaq_itch_tree, hf_nasdaq_itch_canceled, offset, big);
         break;
 
     case 'D' : /* Order delete */
-        offset = order_ref_number(tvb, pinfo, nasdaq_itch_tree, offset);
-        offset += 9;
+        /*offset = */order_ref_number(tvb, pinfo, nasdaq_itch_tree, offset);
+        /*offset += 9;*/
         break;
 
     case 'p' :
@@ -425,7 +401,7 @@ dissect_nasdaq_itch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     case 'P' : /* Trade identifier */
         offset = order(tvb, pinfo, nasdaq_itch_tree, offset, big);
         proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_match, tvb, offset, 9, ENC_ASCII|ENC_NA);
-        offset += 9;
+        /*offset += 9;*/
         break;
 
     case 'Q' : /* Cross Trade */
@@ -438,25 +414,25 @@ dissect_nasdaq_itch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_match, tvb, offset, 9, ENC_ASCII|ENC_NA);
         offset += 9;
         proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_cross, tvb, offset, 1, ENC_ASCII|ENC_NA);
-        offset += 1;
+        /*offset += 1;*/
         break;
 
     case 'B' : /* Broken Trade */
         proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_match, tvb, offset, 9, ENC_ASCII|ENC_NA);
-        offset += 9;
+        /*offset += 9;*/
         break;
 
     case 'I': /* NOII, FIXME */
         offset = stock(tvb, pinfo, nasdaq_itch_tree, offset);
 
         proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_cross, tvb, offset, 1, ENC_ASCII|ENC_NA);
-        offset += 1;
+        /*offset += 1;*/
         break;
 
     default:
         /* unknown */
         proto_tree_add_item(nasdaq_itch_tree, hf_nasdaq_itch_message, tvb, offset, -1, ENC_ASCII|ENC_NA);
-        offset += 5-1;
+        /*offset += 5-1;*/
         break;
     }
 }
