@@ -3,7 +3,7 @@
  *
  * Ronnie sahlberg 2006
  *
- * $Id$
+ * $Id: packet-nbd.c 51512 2013-08-25 14:23:13Z eapache $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,7 +31,7 @@
 #include <epan/packet.h>
 #include <epan/prefs.h>
 #include <epan/conversation.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include "packet-tcp.h"
 
 static gint proto_nbd = -1;
@@ -59,8 +59,8 @@ typedef struct _nbd_transaction_t {
 	guint8 type;
 } nbd_transaction_t;
 typedef struct _nbd_conv_info_t {
-        emem_tree_t *unacked_pdus;    /* indexed by handle, whichs wraps quite frequently  */
-        emem_tree_t *acked_pdus;    /* indexed by packet# and handle */
+        wmem_tree_t *unacked_pdus;    /* indexed by handle, whichs wraps quite frequently  */
+        wmem_tree_t *acked_pdus;    /* indexed by packet# and handle */
 } nbd_conv_info_t;
 
 
@@ -88,7 +88,7 @@ get_nbd_tcp_pdu_len(packet_info *pinfo, tvbuff_t *tvb, int offset)
 	conversation_t *conversation;
 	nbd_conv_info_t *nbd_info;
 	nbd_transaction_t *nbd_trans=NULL;
-	emem_tree_key_t hkey[3];
+	wmem_tree_key_t hkey[3];
 	guint32 handle[2];
 
 	magic=tvb_get_ntohl(tvb, offset);
@@ -131,7 +131,7 @@ get_nbd_tcp_pdu_len(packet_info *pinfo, tvbuff_t *tvb, int offset)
 			hkey[0].length=2;
 			hkey[0].key=handle;
 			hkey[1].length=0;
-			nbd_trans=(nbd_transaction_t *)se_tree_lookup32_array(nbd_info->unacked_pdus, hkey);
+			nbd_trans=(nbd_transaction_t *)wmem_tree_lookup32_array(nbd_info->unacked_pdus, hkey);
 			if(!nbd_trans){
 				/* No, so just return the rest of the current packet */
 				return tvb_length(tvb);
@@ -148,7 +148,7 @@ get_nbd_tcp_pdu_len(packet_info *pinfo, tvbuff_t *tvb, int offset)
 			hkey[1].length=2;
 			hkey[1].key=handle;
 			hkey[2].length=0;
-			nbd_trans=(nbd_transaction_t *)se_tree_lookup32_array(nbd_info->acked_pdus, hkey);
+			nbd_trans=(nbd_transaction_t *)wmem_tree_lookup32_array(nbd_info->acked_pdus, hkey);
 			if(!nbd_trans){
 				/* No, so just return the rest of the current packet */
 				return tvb_length(tvb);
@@ -182,7 +182,7 @@ dissect_nbd_tcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	conversation_t *conversation;
 	nbd_conv_info_t *nbd_info;
 	nbd_transaction_t *nbd_trans=NULL;
-	emem_tree_key_t hkey[3];
+	wmem_tree_key_t hkey[3];
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "NBD");
 
@@ -218,16 +218,16 @@ dissect_nbd_tcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		/* No.  Attach that information to the conversation, and add
 		 * it to the list of information structures.
 		 */
-		nbd_info = se_new(nbd_conv_info_t);
-		nbd_info->unacked_pdus=se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK, "nbd_unacked_pdus");
-		nbd_info->acked_pdus=se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK, "nbd_acked_pdus");
+		nbd_info = wmem_new(wmem_file_scope(), nbd_conv_info_t);
+		nbd_info->unacked_pdus = wmem_tree_new(wmem_file_scope());
+		nbd_info->acked_pdus   = wmem_tree_new(wmem_file_scope());
 
 		conversation_add_proto_data(conversation, proto_nbd, nbd_info);
 	}
 	if(!pinfo->fd->flags.visited){
 		if(magic==NBD_REQUEST_MAGIC){
 			/* This is a request */
-			nbd_trans=se_new(nbd_transaction_t);
+			nbd_trans=wmem_new(wmem_file_scope(), nbd_transaction_t);
 			nbd_trans->req_frame=pinfo->fd->num;
 			nbd_trans->rep_frame=0;
 			nbd_trans->req_time=pinfo->fd->abs_ts;
@@ -238,13 +238,13 @@ dissect_nbd_tcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 			hkey[0].key=handle;
 			hkey[1].length=0;
 
-			se_tree_insert32_array(nbd_info->unacked_pdus, hkey, (void *)nbd_trans);
+			wmem_tree_insert32_array(nbd_info->unacked_pdus, hkey, (void *)nbd_trans);
 		} else if(magic==NBD_RESPONSE_MAGIC){
 			hkey[0].length=2;
 			hkey[0].key=handle;
 			hkey[1].length=0;
 
-			nbd_trans=(nbd_transaction_t *)se_tree_lookup32_array(nbd_info->unacked_pdus, hkey);
+			nbd_trans=(nbd_transaction_t *)wmem_tree_lookup32_array(nbd_info->unacked_pdus, hkey);
 			if(nbd_trans){
 				nbd_trans->rep_frame=pinfo->fd->num;
 
@@ -253,13 +253,13 @@ dissect_nbd_tcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 				hkey[1].length=2;
 				hkey[1].key=handle;
 				hkey[2].length=0;
-				se_tree_insert32_array(nbd_info->acked_pdus, hkey, (void *)nbd_trans);
+				wmem_tree_insert32_array(nbd_info->acked_pdus, hkey, (void *)nbd_trans);
 				hkey[0].length=1;
 				hkey[0].key=&nbd_trans->req_frame;
 				hkey[1].length=2;
 				hkey[1].key=handle;
 				hkey[2].length=0;
-				se_tree_insert32_array(nbd_info->acked_pdus, hkey, (void *)nbd_trans);
+				wmem_tree_insert32_array(nbd_info->acked_pdus, hkey, (void *)nbd_trans);
 			}
 		}
 	} else {
@@ -270,7 +270,7 @@ dissect_nbd_tcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		hkey[1].key=handle;
 		hkey[2].length=0;
 
-		nbd_trans=(nbd_transaction_t *)se_tree_lookup32_array(nbd_info->acked_pdus, hkey);
+		nbd_trans=(nbd_transaction_t *)wmem_tree_lookup32_array(nbd_info->acked_pdus, hkey);
 	}
 	/* The bloody handles are reused !!! eventhough they are 64 bits.
 	 * So we must verify we got the "correct" one
@@ -284,7 +284,7 @@ dissect_nbd_tcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 
 	if(!nbd_trans){
 		/* create a "fake" nbd_trans structure */
-		nbd_trans=ep_new(nbd_transaction_t);
+		nbd_trans=wmem_new(wmem_packet_scope(), nbd_transaction_t);
 		nbd_trans->req_frame=0;
 		nbd_trans->rep_frame=0;
 		nbd_trans->req_time=pinfo->fd->abs_ts;
@@ -332,18 +332,16 @@ dissect_nbd_tcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		proto_tree_add_item(tree, hf_nbd_len, tvb, offset, 4, ENC_BIG_ENDIAN);
 		offset+=4;
 
-		if(check_col(pinfo->cinfo, COL_INFO)){
-			switch(nbd_trans->type){
-			case NBD_CMD_WRITE:
-				col_add_fstr(pinfo->cinfo, COL_INFO, "Write Request  Offset:0x%" G_GINT64_MODIFIER "x Length:%d", from, nbd_trans->datalen);
-				break;
-			case NBD_CMD_READ:
-				col_add_fstr(pinfo->cinfo, COL_INFO, "Read Request  Offset:0x%" G_GINT64_MODIFIER "x Length:%d", from, nbd_trans->datalen);
-				break;
-			case NBD_CMD_DISC:
-				col_set_str(pinfo->cinfo, COL_INFO, "Disconnect Request");
-				break;
-			}
+		switch(nbd_trans->type){
+		case NBD_CMD_WRITE:
+			col_add_fstr(pinfo->cinfo, COL_INFO, "Write Request  Offset:0x%" G_GINT64_MODIFIER "x Length:%d", from, nbd_trans->datalen);
+			break;
+		case NBD_CMD_READ:
+			col_add_fstr(pinfo->cinfo, COL_INFO, "Read Request  Offset:0x%" G_GINT64_MODIFIER "x Length:%d", from, nbd_trans->datalen);
+			break;
+		case NBD_CMD_DISC:
+			col_set_str(pinfo->cinfo, COL_INFO, "Disconnect Request");
+			break;
 		}
 
 		if(nbd_trans->type==NBD_CMD_WRITE){
@@ -361,9 +359,7 @@ dissect_nbd_tcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		proto_tree_add_item(tree, hf_nbd_handle, tvb, offset, 8, ENC_BIG_ENDIAN);
 		offset+=8;
 
-		if(check_col(pinfo->cinfo, COL_INFO)){
-			col_add_fstr(pinfo->cinfo, COL_INFO, "%s Response  Error:%d", (nbd_trans->type==NBD_CMD_WRITE)?"Write":"Read", error);
-		}
+		col_add_fstr(pinfo->cinfo, COL_INFO, "%s Response  Error:%d", (nbd_trans->type==NBD_CMD_WRITE)?"Write":"Read", error);
 
 		if(nbd_trans->type==NBD_CMD_READ){
 			proto_tree_add_item(tree, hf_nbd_data, tvb, offset, nbd_trans->datalen, ENC_NA);
