@@ -3,7 +3,7 @@
  * to when it had only NBNS)
  * Guy Harris <guy@alum.mit.edu>
  *
- * $Id$
+ * $Id: packet-nbns.c 52045 2013-09-15 01:48:30Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,7 +30,7 @@
 #include <glib.h>
 
 #include <epan/packet.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/prefs.h>
 #include <epan/strutil.h>
 #include <epan/show_exception.h>
@@ -172,8 +172,8 @@ static const true_false_string tfs_flags_broadcast = {
     "Not a broadcast packet"
 };
 
-static const true_false_string tfs_nbss_flags_e = { 
-    "Add 65536 to length", 
+static const true_false_string tfs_nbss_flags_e = {
+    "Add 65536 to length",
     "Add 0 to length"
 };
 
@@ -316,7 +316,7 @@ get_nbns_name(tvbuff_t *tvb, int offset, int nbns_data_offset,
     char         *pname_ret;
     size_t        idx = 0;
 
-    nbname_buf = (char *)ep_alloc(NBNAME_BUF_LEN);
+    nbname_buf = (char *)wmem_alloc(wmem_packet_scope(), NBNAME_BUF_LEN);
     nbname = nbname_buf;
     /* XXX Fix data len */
     name_len = get_dns_name(tvb, offset, 0, nbns_data_offset, &name);
@@ -453,7 +453,7 @@ dissect_nbns_query(tvbuff_t *tvb, int offset, int nbns_data_offset,
     proto_tree *q_tree;
     proto_item *tq;
 
-    name = (char *)ep_alloc(MAX_NAME_LEN);
+    name = (char *)wmem_alloc(wmem_packet_scope(), MAX_NAME_LEN);
     data_start = data_offset = offset;
 
     name_len = MAX_NAME_LEN;
@@ -510,7 +510,7 @@ nbns_add_nbns_flags(column_info *cinfo, proto_tree *nbns_tree, tvbuff_t *tvb, in
     if (!nbns_tree)
         return;
 
-    buf = (char *)ep_alloc(MAX_BUF_SIZE);
+    buf = (char *)wmem_alloc(wmem_packet_scope(), MAX_BUF_SIZE);
     opcode = (guint16) ((flags & F_OPCODE) >> OPCODE_SHIFT);
     g_snprintf(buf, MAX_BUF_SIZE, "%s", val_to_str_const(opcode, opcode_vals, "Unknown operation"));
     if (flags & F_RESPONSE && !is_wack) {
@@ -519,8 +519,8 @@ nbns_add_nbns_flags(column_info *cinfo, proto_tree *nbns_tree, tvbuff_t *tvb, in
         g_strlcat(buf, val_to_str_const(flags & F_RCODE, rcode_vals, "Unknown error"), MAX_BUF_SIZE);
         buf[MAX_BUF_SIZE-1] = '\0';
     }
-    tf = proto_tree_add_uint_format(nbns_tree, hf_nbns_flags,
-                                    tvb, offset, 2, flags, "Flags: 0x%04x (%s)", flags, buf);
+    tf = proto_tree_add_uint_format_value(nbns_tree, hf_nbns_flags,
+                                    tvb, offset, 2, flags, "0x%04x (%s)", flags, buf);
     field_tree = proto_item_add_subtree(tf, ett_nbns_flags);
     proto_tree_add_item(field_tree, hf_nbns_flags_response,
                         tvb, offset, 2, ENC_BIG_ENDIAN);
@@ -562,7 +562,7 @@ nbns_add_nb_flags(proto_tree *rr_tree, tvbuff_t *tvb, int offset)
     proto_tree_add_item(field_tree, hf_nbns_nb_flags_group, tvb, offset, 2, ENC_BIG_ENDIAN);
     proto_tree_add_item(field_tree, hf_nbns_nb_flags_ont, tvb, offset, 2, ENC_BIG_ENDIAN);
 
-    proto_item_append_text(tf, "(%s, %s", 
+    proto_item_append_text(tf, "(%s, %s",
                 val_to_str_const(flags & NB_FLAGS_ONT, nb_flags_ont_vals, "Unknown"),
                 (flags & NB_FLAGS_G) ? "group" : "unique");
 }
@@ -587,18 +587,18 @@ nbns_add_name_flags(proto_tree *rr_tree, tvbuff_t *tvb, int offset)
     proto_tree_add_item(field_tree, hf_nbns_name_flags_act, tvb, offset, 2, ENC_BIG_ENDIAN);
     proto_tree_add_item(field_tree, hf_nbns_name_flags_prm, tvb, offset, 2, ENC_BIG_ENDIAN);
 
-    proto_item_append_text(tf, "(%s, %s", 
+    proto_item_append_text(tf, "(%s, %s",
                 val_to_str_const(flags & NAME_FLAGS_ONT, name_flags_ont_vals, "Unknown"),
                 (flags & NAME_FLAGS_G) ? "group" : "unique");
     if (flags & NAME_FLAGS_DRG)
-        proto_item_append_text(tf, ", being deregistered"); 
+        proto_item_append_text(tf, ", being deregistered");
     if (flags & NAME_FLAGS_CNF)
-        proto_item_append_text(tf, ", in conflict"); 
+        proto_item_append_text(tf, ", in conflict");
     if (flags & NAME_FLAGS_ACT)
-        proto_item_append_text(tf, ", active"); 
+        proto_item_append_text(tf, ", active");
     if (flags & NAME_FLAGS_PRM)
-        proto_item_append_text(tf, ", permanent node name"); 
-    proto_item_append_text(tf, ")"); 
+        proto_item_append_text(tf, ", permanent node name");
+    proto_item_append_text(tf, ")");
 }
 
 static int
@@ -625,9 +625,9 @@ dissect_nbns_answer(tvbuff_t *tvb, int offset, int nbns_data_offset,
 
     cur_offset = offset;
 
-    name     = (char *)ep_alloc(MAX_NAME_LEN);
-    name_str = (char *)ep_alloc(MAX_NAME_LEN);
-    nbname   = (char *)ep_alloc(16+4+1); /* 4 for [<last char>] */
+    name     = (char *)wmem_alloc(wmem_packet_scope(), MAX_NAME_LEN);
+    name_str = (char *)wmem_alloc(wmem_packet_scope(), MAX_NAME_LEN);
+    nbname   = (char *)wmem_alloc(wmem_packet_scope(), 16+4+1); /* 4 for [<last char>] */
 
     name_len = MAX_NAME_LEN;
     len      = get_nbns_name_type_class(tvb, offset, nbns_data_offset, name,
@@ -1064,7 +1064,6 @@ dissect_nbns(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     int		 offset    = 0;
     int		 nbns_data_offset;
-    column_info	*cinfo;
     proto_tree	*nbns_tree = NULL;
     proto_item	*ti;
     guint16	 id, flags, opcode, quest, ans, auth, add;
@@ -1080,19 +1079,9 @@ dissect_nbns(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     flags  = tvb_get_ntohs(tvb, offset + NBNS_FLAGS);
     opcode = (guint16) ((flags & F_OPCODE) >> OPCODE_SHIFT);
 
-    if (check_col(pinfo->cinfo, COL_INFO)) {
-        col_add_fstr(pinfo->cinfo, COL_INFO, "%s%s",
-                     val_to_str(opcode, opcode_vals, "Unknown operation (%u)"),
-                     (flags & F_RESPONSE) ? " response" : "");
-        cinfo = pinfo->cinfo;
-    } else {
-        /* Set "cinfo" to NULL; we pass a NULL "cinfo" to the query
-           and answer dissectors, as a way of saying that they
-           shouldn't add stuff to the COL_INFO column (a call to
-           "check_col(cinfo, COL_INFO)" is more expensive than
-           a check that a pointer isn't NULL). */
-        cinfo = NULL;
-    }
+    col_add_fstr(pinfo->cinfo, COL_INFO, "%s%s",
+                    val_to_str(opcode, opcode_vals, "Unknown operation (%u)"),
+                    (flags & F_RESPONSE) ? " response" : "");
 
     if (tree) {
         ti = proto_tree_add_item(tree, proto_nbns, tvb, offset, -1,
@@ -1135,7 +1124,7 @@ dissect_nbns(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
            answers. */
         cur_off += dissect_query_records(tvb, cur_off,
                                          nbns_data_offset, quest,
-                                         (!(flags & F_RESPONSE) ? cinfo : NULL), nbns_tree);
+                                         (!(flags & F_RESPONSE) ? pinfo->cinfo : NULL), nbns_tree);
     }
 
     if (ans > 0) {
@@ -1144,7 +1133,7 @@ dissect_nbns(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
            queries. */
         cur_off += dissect_answer_records(tvb, cur_off,
                                           nbns_data_offset, ans,
-                                          ((flags & F_RESPONSE) ? cinfo : NULL), nbns_tree,
+                                          ((flags & F_RESPONSE) ? pinfo->cinfo : NULL), nbns_tree,
                                           opcode, "Answers");
     }
 
@@ -1234,7 +1223,7 @@ dissect_nbdgm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     int name_type;
     int len;
 
-    name = (char *)ep_alloc(MAX_NAME_LEN);
+    name = (char *)wmem_alloc(wmem_packet_scope(), MAX_NAME_LEN);
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "NBDS");
     col_clear(pinfo->cinfo, COL_INFO);
@@ -1441,7 +1430,7 @@ dissect_nbss_packet(tvbuff_t *tvb, int offset, packet_info *pinfo,
     const char   *saved_proto;
     void	 *pd_save;
 
-    name = (char *)ep_alloc(MAX_NAME_LEN);
+    name = (char *)wmem_alloc(wmem_packet_scope(), MAX_NAME_LEN);
 
     /* Desegmentation */
     length_remaining = tvb_length_remaining(tvb, offset);
@@ -1511,19 +1500,15 @@ dissect_nbss_packet(tvbuff_t *tvb, int offset, packet_info *pinfo,
 
     msg_type = tvb_get_guint8(tvb, offset);
 
-    if (tree) {
-        ti = proto_tree_add_item(tree, proto_nbss, tvb, offset, length + 4, ENC_NA);
-        nbss_tree = proto_item_add_subtree(ti, ett_nbss);
+    ti = proto_tree_add_item(tree, proto_nbss, tvb, offset, length + 4, ENC_NA);
+    nbss_tree = proto_item_add_subtree(ti, ett_nbss);
 
-        proto_tree_add_item(nbss_tree, hf_nbss_type, tvb, offset, 1, ENC_NA);
-    }
+    proto_tree_add_item(nbss_tree, hf_nbss_type, tvb, offset, 1, ENC_NA);
 
     offset += 1;
 
     if (is_cifs) {
-        if (tree) {
-            proto_tree_add_item(nbss_tree, hf_nbss_cifs_length, tvb, offset, 3, ENC_BIG_ENDIAN);
-        }
+        proto_tree_add_item(nbss_tree, hf_nbss_cifs_length, tvb, offset, 3, ENC_BIG_ENDIAN);
         offset += 3;
     } else {
         if (tree) {
@@ -1533,10 +1518,7 @@ dissect_nbss_packet(tvbuff_t *tvb, int offset, packet_info *pinfo,
         }
         offset += 1;
 
-        if (tree) {
-            proto_tree_add_uint_format(nbss_tree, hf_nbss_length, tvb, offset, 2,
-                                       length, "Length: %u", length);
-        }
+        proto_tree_add_uint(nbss_tree, hf_nbss_length, tvb, offset, 2, length);
 
         offset += 2;
     }
