@@ -5,7 +5,7 @@
  *
  * derived from the packet-nbns.c
  *
- * $Id$
+ * $Id: packet-netbios.c 50708 2013-07-17 21:12:24Z darkjames $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1070,7 +1070,7 @@ dissect_netbios(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint16			session_id;
 	gboolean		save_fragmented;
 	int			len;
-	fragment_data		*fd_head;
+	fragment_head		*fd_head;
 	tvbuff_t		*next_tvb;
 
 	int offset = 0;
@@ -1099,28 +1099,24 @@ dissect_netbios(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					/* limit command so no table overflows */
 	command = MIN( command, sizeof( dissect_netb)/ sizeof(void *));
 
-        if (check_col( pinfo->cinfo, COL_INFO)) {              /* print command name */
-		command_name = val_to_str(command, cmd_vals, "Unknown (0x%02x)");
-                switch ( command ) {
-                case NB_NAME_QUERY:
-                        name_type = get_netbios_name( tvb, offset + 12, name, (NETBIOS_NAME_LEN - 1)*4 + 1);
-                        col_add_fstr( pinfo->cinfo, COL_INFO, "%s for %s<%02x>",
-                            command_name, name, name_type);
-                        break;
+		/* print command name */
+	command_name = val_to_str(command, cmd_vals, "Unknown (0x%02x)");
+	switch ( command ) {
+		case NB_NAME_QUERY:
+			name_type = get_netbios_name( tvb, offset + 12, name, (NETBIOS_NAME_LEN - 1)*4 + 1);
+			col_add_fstr( pinfo->cinfo, COL_INFO, "%s for %s<%02x>", command_name, name, name_type);
+			break;
 
-                case NB_NAME_RESP:
-                case NB_ADD_NAME:
-                case NB_ADD_GROUP:
-                        name_type = get_netbios_name( tvb, offset + 28, name, (NETBIOS_NAME_LEN - 1)*4 + 1);
-                        col_add_fstr( pinfo->cinfo, COL_INFO, "%s - %s<%02x>",
-                            command_name, name, name_type);
-                        break;
+		case NB_NAME_RESP:
+		case NB_ADD_NAME:
+		case NB_ADD_GROUP:
+			name_type = get_netbios_name( tvb, offset + 28, name, (NETBIOS_NAME_LEN - 1)*4 + 1);
+			col_add_fstr( pinfo->cinfo, COL_INFO, "%s - %s<%02x>", command_name, name, name_type);
+		break;
 
 		default:
-			col_add_str( pinfo->cinfo, COL_INFO,
-			    command_name);
+			col_add_str( pinfo->cinfo, COL_INFO, command_name);
 			break;
-		}
 	}
 
 	if ( tree) {
@@ -1174,8 +1170,7 @@ dissect_netbios(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				    len, command == NB_DATA_FIRST_MIDDLE);
 				if (fd_head != NULL) {
 					if (fd_head->next != NULL) {
-						next_tvb = tvb_new_child_real_data(tvb, fd_head->data,
-						    fd_head->len, fd_head->len);
+						next_tvb = tvb_new_chain(tvb, fd_head->tvb_data);
 						add_new_data_source(pinfo,
 						    next_tvb,
 						    "Reassembled NetBIOS");
