@@ -1,7 +1,7 @@
 /* packet-netsync.c
  * Routines for Monotone Netsync packet disassembly
  *
- * $Id$
+ * $Id: packet-netsync.c 52126 2013-09-17 19:23:11Z wmeier $
  *
  * Copyright (c) 2005 by Erwin Rol <erwin@erwinrol.com>
  *
@@ -31,9 +31,7 @@
 #include <glib.h>
 
 #include <epan/packet.h>
-#include <epan/addr_resolv.h>
 #include <epan/prefs.h>
-#include <epan/strutil.h>
 #include "packet-tcp.h"
 
 /*
