@@ -4,7 +4,7 @@
  *     RFC 2520: NHRP with Mobile NHCs
  *     RFC 2735: NHRP Support for Virtual Private Networks
  *
- * $Id$
+ * $Id: packet-nhrp.c 52272 2013-09-29 18:19:29Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -139,6 +139,11 @@ static gint ett_nhrp_devcap_ext = -1;
 static gint ett_nhrp_devcap_ext_srccap = -1;
 static gint ett_nhrp_devcap_ext_dstcap = -1;
 
+static expert_field ei_nhrp_ext_not_allowed = EI_INIT;
+static expert_field ei_nhrp_hdr_extoff = EI_INIT;
+static expert_field ei_nhrp_ext_malformed = EI_INIT;
+static expert_field ei_nhrp_ext_extra = EI_INIT;
+
 /* NHRP Packet Types */
 #define NHRP_RESOLUTION_REQ     1
 #define NHRP_RESOLUTION_REPLY   2
@@ -248,7 +253,7 @@ static const value_string nhrp_cie_code_vals[] = {
     { 0,                                NULL }
 };
 
-static dissector_table_t osinl_subdissector_table;
+static dissector_table_t osinl_incl_subdissector_table;
 static dissector_table_t osinl_excl_subdissector_table;
 static dissector_table_t ethertype_subdissector_table;
 
@@ -330,8 +335,8 @@ void dissect_nhrp_hdr(tvbuff_t     *tvb,
         pro_type_str = val_to_str_const(hdr->ar_pro_type, etype_vals,
             "Unknown Ethertype");
     }
-    proto_tree_add_uint_format(nhrp_tree, hf_nhrp_hdr_pro_type, tvb, offset, 2,
-        hdr->ar_pro_type, "Protocol Type (short form): %s (0x%04x)",
+    proto_tree_add_uint_format_value(nhrp_tree, hf_nhrp_hdr_pro_type, tvb, offset, 2,
+        hdr->ar_pro_type, "%s (0x%04x)",
         pro_type_str, hdr->ar_pro_type);
     offset += 2;
 
@@ -376,38 +381,37 @@ void dissect_nhrp_hdr(tvbuff_t     *tvb,
         ipcsum = nhrp_checksum(tvb_get_ptr(tvb, 0, total_len),
             total_len);
         if (ipcsum == 0) {
-            proto_tree_add_uint_format(nhrp_tree, hf_nhrp_hdr_chksum, tvb, offset, 2, rx_chksum,
-                "NHRP Packet checksum: 0x%04x [correct]", rx_chksum);
+            proto_tree_add_uint_format_value(nhrp_tree, hf_nhrp_hdr_chksum, tvb, offset, 2, rx_chksum,
+                "0x%04x [correct]", rx_chksum);
         } else {
-            proto_tree_add_uint_format(nhrp_tree, hf_nhrp_hdr_chksum, tvb, offset, 2, rx_chksum,
-                "NHRP Packet checksum: 0x%04x [incorrect, should be 0x%04x]", rx_chksum,
+            proto_tree_add_uint_format_value(nhrp_tree, hf_nhrp_hdr_chksum, tvb, offset, 2, rx_chksum,
+                "0x%04x [incorrect, should be 0x%04x]", rx_chksum,
                 in_cksum_shouldbe(rx_chksum, ipcsum));
         }
     } else {
-        proto_tree_add_uint_format(nhrp_tree, hf_nhrp_hdr_chksum, tvb, offset, 2, rx_chksum,
-            "NHRP Packet checksum: 0x%04x [not all data available]", rx_chksum);
+        proto_tree_add_uint_format_value(nhrp_tree, hf_nhrp_hdr_chksum, tvb, offset, 2, rx_chksum,
+            "0x%04x [not all data available]", rx_chksum);
     }
     offset += 2;
 
     hdr->ar_extoff = tvb_get_ntohs(tvb, offset);
     ti = proto_tree_add_item(nhrp_tree, hf_nhrp_hdr_extoff, tvb, offset, 2, ENC_BIG_ENDIAN);
     if (hdr->ar_extoff != 0 && hdr->ar_extoff < 20) {
-        expert_add_info_format(pinfo, ti, PI_MALFORMED, PI_ERROR,
-            "Extension offset is less than the fixed header length");
+        expert_add_info(pinfo, ti, &ei_nhrp_hdr_extoff);
     }
     offset += 2;
 
     hdr->ar_op_version = tvb_get_guint8(tvb, offset);
-    proto_tree_add_uint_format(nhrp_tree, hf_nhrp_hdr_version, tvb, offset, 1,
-        hdr->ar_op_version, "Version : %u (%s)", hdr->ar_op_version,
+    proto_tree_add_uint_format_value(nhrp_tree, hf_nhrp_hdr_version, tvb, offset, 1,
+        hdr->ar_op_version, "%u (%s)", hdr->ar_op_version,
         (hdr->ar_op_version == 1) ? "NHRP - rfc2332" : "Unknown");
     offset += 1;
     proto_tree_add_item(nhrp_tree, hf_nhrp_hdr_op_type, tvb, offset, 1, ENC_BIG_ENDIAN);
     offset += 1;
 
     hdr->ar_shtl = tvb_get_guint8(tvb, offset);
-    shtl_tree_item = proto_tree_add_uint_format(nhrp_tree, hf_nhrp_hdr_shtl,
-        tvb, offset, 1, hdr->ar_shtl, "Source Address Type/Len: %s/%u",
+    shtl_tree_item = proto_tree_add_uint_format_value(nhrp_tree, hf_nhrp_hdr_shtl,
+        tvb, offset, 1, hdr->ar_shtl, "%s/%u",
         val_to_str_const(NHRP_SHTL_TYPE(hdr->ar_shtl), nhrp_shtl_type_vals, "Unknown Type"),
         NHRP_SHTL_LEN(hdr->ar_shtl));
     shtl_tree = proto_item_add_subtree(shtl_tree_item, ett_nhrp_hdr_shtl);
@@ -416,8 +420,8 @@ void dissect_nhrp_hdr(tvbuff_t     *tvb,
     offset += 1;
 
     hdr->ar_sstl = tvb_get_guint8(tvb, offset);
-    sstl_tree_item = proto_tree_add_uint_format(nhrp_tree, hf_nhrp_hdr_sstl,
-        tvb, offset, 1, hdr->ar_sstl, "Source SubAddress Type/Len: %s/%u",
+    sstl_tree_item = proto_tree_add_uint_format_value(nhrp_tree, hf_nhrp_hdr_sstl,
+        tvb, offset, 1, hdr->ar_sstl, "%s/%u",
         val_to_str_const(NHRP_SHTL_TYPE(hdr->ar_sstl), nhrp_shtl_type_vals, "Unknown Type"),
         NHRP_SHTL_LEN(hdr->ar_sstl));
     sstl_tree = proto_item_add_subtree(sstl_tree_item, ett_nhrp_hdr_sstl);
@@ -497,9 +501,8 @@ void dissect_cie_list(tvbuff_t    *tvb,
         offset += 2;
 
         val = tvb_get_guint8(tvb, offset);
-        cli_addr_tree_item = proto_tree_add_uint_format(cie_tree,
-            hf_nhrp_cli_addr_tl, tvb, offset, 1, val,
-            "Client Address Type/Len: %s/%u",
+        cli_addr_tree_item = proto_tree_add_uint_format_value(cie_tree,
+            hf_nhrp_cli_addr_tl, tvb, offset, 1, val, "%s/%u",
             val_to_str_const(NHRP_SHTL_TYPE(val), nhrp_shtl_type_vals, "Unknown Type"),
             NHRP_SHTL_LEN(val));
         cli_addr_tree = proto_item_add_subtree(cli_addr_tree_item, ett_nhrp_cie_cli_addr_tl);
@@ -508,9 +511,8 @@ void dissect_cie_list(tvbuff_t    *tvb,
         offset += 1;
 
         val = tvb_get_guint8(tvb, offset);
-        cli_saddr_tree_item = proto_tree_add_uint_format(cie_tree,
-            hf_nhrp_cli_saddr_tl, tvb, offset, 1, val,
-            "Client Sub Address Type/Len: %s/%u",
+        cli_saddr_tree_item = proto_tree_add_uint_format_value(cie_tree,
+            hf_nhrp_cli_saddr_tl, tvb, offset, 1, val, "%s/%u",
             val_to_str_const(NHRP_SHTL_TYPE(val), nhrp_shtl_type_vals, "Unknown Type"),
             NHRP_SHTL_LEN(val));
         cli_saddr_tree = proto_item_add_subtree(cli_saddr_tree_item, ett_nhrp_cie_cli_saddr_tl);
@@ -774,7 +776,7 @@ void dissect_nhrp_mand(tvbuff_t    *tvb,
                      * Dissect based on the NLPID.
                      */
                     dissected = dissector_try_uint(
-                        osinl_subdissector_table,
+                        osinl_incl_subdissector_table,
                         hdr->ar_pro_type, sub_tvb, pinfo,
                         ind_tree) ||
                                 dissector_try_uint(
@@ -808,8 +810,7 @@ void dissect_nhrp_mand(tvbuff_t    *tvb,
     /* According to RFC 2332, section 5.2.7, there shouldn't be any extensions
      * in the Error Indication packet. */
     if (isErr && tvb_reported_length_remaining(tvb, offset)) {
-        expert_add_info_format(pinfo, tree, PI_MALFORMED, PI_ERROR,
-            "Extensions not allowed per RFC2332 section 5.2.7");
+        expert_add_info(pinfo, tree, &ei_nhrp_ext_not_allowed);
     }
 
     dissect_cie_list(tvb, pinfo, nhrp_tree, offset, mandEnd, hdr, isReq, codeinfo);
@@ -900,8 +901,7 @@ void dissect_nhrp_ext(tvbuff_t    *tvb,
                     ti = proto_tree_add_text(nhrp_tree, tvb, offset, len,
                         "Malformed Extension: %s",
                         tvb_bytes_to_str(tvb, offset, len));
-                    expert_add_info_format(pinfo, ti, PI_MALFORMED, PI_ERROR,
-                        "Incomplete Authentication Extension");
+                    expert_add_info_format(pinfo, ti, &ei_nhrp_ext_malformed, "Incomplete Authentication Extension");
                 }
                 else {
                     proto_item *auth_item;
@@ -932,8 +932,7 @@ void dissect_nhrp_ext(tvbuff_t    *tvb,
                     ti = proto_tree_add_text(nhrp_tree, tvb, offset, len,
                         "Malformed Extension: %s",
                         tvb_bytes_to_str(tvb, offset, len));
-                    expert_add_info_format(pinfo, ti, PI_MALFORMED, PI_ERROR,
-                        "Incomplete Vendor-Private Extension");
+                    expert_add_info_format(pinfo, ti, &ei_nhrp_ext_malformed, "Incomplete Vendor-Private Extension");
                 }
                 else {
                     proto_item *vendor_item;
@@ -945,8 +944,8 @@ void dissect_nhrp_ext(tvbuff_t    *tvb,
                         "Extension Data: Vendor ID=%s, Data=%s", get_manuf_name(manuf),
                         tvb_bytes_to_str(tvb, offset + 3, len - 3));
                     vendor_tree = proto_item_add_subtree(vendor_item, ett_nhrp_vendor_ext);
-                    proto_tree_add_bytes_format(vendor_tree, hf_nhrp_vendor_ext_id, tvb,
-                        offset, 3, manuf, "Vendor ID: %s", get_manuf_name(manuf));
+                    proto_tree_add_bytes_format_value(vendor_tree, hf_nhrp_vendor_ext_id, tvb,
+                        offset, 3, manuf, "%s", get_manuf_name(manuf));
                     if (len > 3) {
                         proto_tree_add_text(vendor_tree, tvb, offset + 3, len - 3,
                             "Data: %s", tvb_bytes_to_str(tvb, offset + 3, len - 3));
@@ -968,8 +967,7 @@ skip_switch:
             if ((extType == NHRP_EXT_NULL) && len) {
                 ti = proto_tree_add_text(tree, tvb, offset, len,
                     "Unknown Data (%d bytes)", len);
-                expert_add_info_format(pinfo, ti, PI_MALFORMED, PI_ERROR,
-                    "Superfluous data follows End Extension");
+                expert_add_info(pinfo, ti, &ei_nhrp_ext_extra);
                 break;
             }
         }
@@ -1062,7 +1060,7 @@ proto_register_nhrp(void)
             NULL, HFILL }
         },
         { &hf_nhrp_hdr_chksum,
-          { "Packet Checksum", "nhrp.hdr.chksum",
+          { "NHRP Packet Checksum", "nhrp.hdr.chksum",
             FT_UINT16, BASE_HEX, NULL, 0x0,
             NULL, HFILL }
         },
@@ -1384,12 +1382,20 @@ proto_register_nhrp(void)
         &ett_nhrp_devcap_ext_dstcap
     };
 
-    proto_nhrp = proto_register_protocol(
-        "NBMA Next Hop Resolution Protocol",
-        "NHRP",
-        "nhrp");
+    static ei_register_info ei[] = {
+        { &ei_nhrp_hdr_extoff, { "nhrp.hdr.extoff.invalid", PI_MALFORMED, PI_ERROR, "Extension offset is less than the fixed header length", EXPFILL }},
+        { &ei_nhrp_ext_not_allowed, { "nhrp.ext.not_allowed", PI_MALFORMED, PI_ERROR, "Extensions not allowed per RFC2332 section 5.2.7", EXPFILL }},
+        { &ei_nhrp_ext_malformed, { "nhrp.ext.malformed", PI_MALFORMED, PI_ERROR, "Incomplete Authentication Extension", EXPFILL }},
+        { &ei_nhrp_ext_extra, { "nhrp.ext.extra", PI_MALFORMED, PI_ERROR, "Superfluous data follows End Extension", EXPFILL }},
+    };
+
+    expert_module_t* expert_nhrp;
+
+    proto_nhrp = proto_register_protocol("NBMA Next Hop Resolution Protocol", "NHRP", "nhrp");
     proto_register_field_array(proto_nhrp, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_nhrp = expert_register_protocol(proto_nhrp);
+    expert_register_field_array(expert_nhrp, ei, array_length(ei));
 }
 
 void
@@ -1399,7 +1405,7 @@ proto_reg_handoff_nhrp(void)
 
     data_handle = find_dissector("data");
 
-    osinl_subdissector_table      = find_dissector_table("osinl");
+    osinl_incl_subdissector_table = find_dissector_table("osinl.incl");
     osinl_excl_subdissector_table = find_dissector_table("osinl.excl");
     ethertype_subdissector_table  = find_dissector_table("ethertype");
 
