@@ -2,7 +2,7 @@
 * Routines for Transparent Proxy Cache Protocol packet disassembly
 * (c) Copyright Giles Scott <giles.scott1 [AT] btinternet.com>
 *
-* $Id$
+* $Id: packet-nt-tpcp.c 52098 2013-09-16 10:39:06Z mmann $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
@@ -130,8 +130,7 @@ dissect_tpcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	tpcph.cport     = g_ntohs(tpcph.cport);
 	tpcph.signature = g_ntohl(tpcph.signature);
 
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_add_fstr(pinfo->cinfo, COL_INFO,"%s id %d CPort %s CIP %s SIP %s",
+	col_add_fstr(pinfo->cinfo, COL_INFO,"%s id %d CPort %s CIP %s SIP %s",
 		val_to_str_const(tpcph.type, type_vals, "Unknown"),
 		tpcph.id,
 		get_udp_port(tpcph.cport),
@@ -145,10 +144,7 @@ dissect_tpcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		tpcp_tree = proto_item_add_subtree(ti, ett_tpcp);
 
 		proto_tree_add_uint(tpcp_tree, hf_tpcp_version, tvb, 0, 1, tpcph.version);
-
-		proto_tree_add_uint_format(tpcp_tree, hf_tpcp_type, tvb, 1, 1, tpcph.type,
-			"Type: %s (%d)",
-			val_to_str_const(tpcph.type, type_vals, "Unknown"), tpcph.type);
+		proto_tree_add_uint(tpcp_tree, hf_tpcp_type, tvb, 1, 1, tpcph.type);
 
 		/* flags next , i'll do that when I can work out how to do it :-(   */
 		tf = proto_tree_add_text(tpcp_tree, tvb, 2, 2, "Flags: 0x%04x",tpcph.flags);
@@ -161,8 +157,8 @@ dissect_tpcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		proto_tree_add_uint(tpcp_tree, hf_tpcp_id, tvb, 4, 2, tpcph.id);
 
-		proto_tree_add_uint_format(tpcp_tree, hf_tpcp_cport, tvb, 6, 2, tpcph.cport,
-			"Client Source port: %s", get_udp_port(tpcph.cport));
+		proto_tree_add_uint_format_value(tpcp_tree, hf_tpcp_cport, tvb, 6, 2, tpcph.cport,
+			"%s", get_udp_port(tpcph.cport));
 
 		proto_tree_add_ipv4(tpcp_tree, hf_tpcp_caddr, tvb, 8, 4, tpcph.caddr);
 
@@ -186,7 +182,7 @@ proto_register_tpcp(void)
 		"TPCP version", HFILL }},
 
 		{ &hf_tpcp_type,
-		{ "Type",		"tpcp.type", FT_UINT8, BASE_DEC,NULL, 0x0,
+		{ "Type",		"tpcp.type", FT_UINT8, BASE_DEC, VALS(type_vals), 0x0,
 		"PDU type", HFILL }},
 
 		{ &hf_tpcp_flags_tcp,
