@@ -2,7 +2,7 @@
  * Routines for NTP packet dissection
  * Copyright 1999, Nathan Neulinger <nneul@umr.edu>
  *
- * $Id$
+ * $Id: packet-ntp.c 52301 2013-09-30 16:10:40Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -33,7 +33,7 @@
 
 #include <epan/packet.h>
 #include <epan/addr_resolv.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 
 #include <epan/tvbparse.h>
 
@@ -613,7 +613,7 @@ tvb_mip6_fmt_ts(tvbuff_t *tvb, gint offset)
 	}
 
 	fractime = bd->tm_sec + tempfrac / NTP_FLOAT_DENOM;
-	buff=(char *)ep_alloc(NTP_TS_SIZE);
+	buff=(char *)wmem_alloc(wmem_packet_scope(), NTP_TS_SIZE);
 	g_snprintf(buff, NTP_TS_SIZE,
 		 "%s %2d, %d %02d:%02d:%07.4f UTC",
 		 mon_names[bd->tm_mon],
@@ -655,7 +655,7 @@ tvb_ntp_fmt_ts(tvbuff_t *tvb, gint offset)
 	}
 
 	fractime = bd->tm_sec + tempfrac / NTP_FLOAT_DENOM;
-	buff=(char *)ep_alloc(NTP_TS_SIZE);
+	buff=(char *)wmem_alloc(wmem_packet_scope(), NTP_TS_SIZE);
 	g_snprintf(buff, NTP_TS_SIZE,
 		 "%s %2d, %d %02d:%02d:%09.6f UTC",
 		 mon_names[bd->tm_mon],
@@ -763,17 +763,17 @@ dissect_ntp_std(tvbuff_t *tvb, proto_tree *ntp_tree, guint8 flags)
 	 */
 	stratum = tvb_get_guint8(tvb, 1);
 	if (stratum == 0) {
-		buffc="Peer Clock Stratum: unspecified or invalid (%u)";
+		buffc="unspecified or invalid (%u)";
 	} else if (stratum == 1) {
-		buffc="Peer Clock Stratum: primary reference (%u)";
+		buffc="primary reference (%u)";
 	} else if ((stratum >= 2) && (stratum <= 15)) {
-		buffc="Peer Clock Stratum: secondary reference (%u)";
+		buffc="secondary reference (%u)";
 	} else if (stratum == 16) {
-		buffc="Peer Clock Stratum: unsynchronized (%u)";
+		buffc="unsynchronized (%u)";
 	} else {
-		buffc="Peer Clock Stratum: reserved: %u";
+		buffc="reserved: %u";
 	}
-	proto_tree_add_uint_format(ntp_tree, hf_ntp_stratum, tvb, 1, 1,
+	proto_tree_add_uint_format_value(ntp_tree, hf_ntp_stratum, tvb, 1, 1,
 				   stratum, buffc, stratum);
 	/* Poll interval, 1byte field indicating the maximum interval
 	 * between successive messages, in seconds to the nearest
@@ -781,15 +781,15 @@ dissect_ntp_std(tvbuff_t *tvb, proto_tree *ntp_tree, guint8 flags)
 	 */
 	ppoll = tvb_get_guint8(tvb, 2);
 	if ((ppoll >= 4) && (ppoll <= 17)) {
-		proto_tree_add_uint_format(ntp_tree, hf_ntp_ppoll, tvb, 2, 1,
+		proto_tree_add_uint_format_value(ntp_tree, hf_ntp_ppoll, tvb, 2, 1,
 				   ppoll,
-				   "Peer Polling Interval: %u (%u sec)",
+				   "%u (%u sec)",
 				   ppoll,
 				   1 << ppoll);
 	} else {
-		proto_tree_add_uint_format(ntp_tree, hf_ntp_ppoll, tvb, 2, 1,
+		proto_tree_add_uint_format_value(ntp_tree, hf_ntp_ppoll, tvb, 2, 1,
 				   ppoll,
-				   "Peer Polling Interval: invalid (%u)",
+				   "invalid (%u)",
 				   ppoll);
 	}
 
@@ -797,9 +797,9 @@ dissect_ntp_std(tvbuff_t *tvb, proto_tree *ntp_tree, guint8 flags)
 	 * local clock, in seconds to the nearest power of two.
 	 */
 	precision = tvb_get_guint8(tvb, 3);
-	proto_tree_add_int_format(ntp_tree, hf_ntp_precision, tvb, 3, 1,
+	proto_tree_add_int_format_value(ntp_tree, hf_ntp_precision, tvb, 3, 1,
 				   precision,
-				   "Peer Clock Precision: %8.6f sec",
+				   "%8.6f sec",
 				   pow(2, precision));
 
 	/* Root Delay is a 32-bit signed fixed-point number indicating
@@ -808,9 +808,9 @@ dissect_ntp_std(tvbuff_t *tvb, proto_tree *ntp_tree, guint8 flags)
 	 */
 	rootdelay = ((gint16)tvb_get_ntohs(tvb, 4)) +
 			(tvb_get_ntohs(tvb, 6) / 65536.0);
-	proto_tree_add_double_format(ntp_tree, hf_ntp_rootdelay, tvb, 4, 4,
+	proto_tree_add_double_format_value(ntp_tree, hf_ntp_rootdelay, tvb, 4, 4,
 				   rootdelay,
-				   "Root Delay: %9.4f sec",
+				   "%9.4f sec",
 				   rootdelay);
 
 	/* Root Dispersion, 32-bit unsigned fixed-point number indicating
@@ -819,9 +819,9 @@ dissect_ntp_std(tvbuff_t *tvb, proto_tree *ntp_tree, guint8 flags)
 	 */
 	rootdispersion = ((gint16)tvb_get_ntohs(tvb, 8)) +
 				(tvb_get_ntohs(tvb, 10) / 65536.0);
-	proto_tree_add_double_format(ntp_tree, hf_ntp_rootdispersion, tvb, 8, 4,
+	proto_tree_add_double_format_value(ntp_tree, hf_ntp_rootdispersion, tvb, 8, 4,
 				   rootdispersion,
-				   "Root Dispersion: %9.4f sec",
+				   "%9.4f sec",
 				   rootdispersion);
 
 	/* Now, there is a problem with secondary servers.  Standards
@@ -831,10 +831,10 @@ dissect_ntp_std(tvbuff_t *tvb, proto_tree *ntp_tree, guint8 flags)
 	 * But, all V3 and V4 servers set this to IP address of their
 	 * higher level server. My decision was to resolve this address.
 	 */
-	buff = (gchar *)ep_alloc(NTP_TS_SIZE);
+	buff = (gchar *)wmem_alloc(wmem_packet_scope(), NTP_TS_SIZE);
 	if (stratum <= 1) {
 		g_snprintf (buff, NTP_TS_SIZE, "Unidentified reference source '%.4s'",
-			tvb_get_ephemeral_string(tvb, 12, 4));
+			tvb_get_string(wmem_packet_scope(), tvb, 12, 4));
 		for (i = 0; primary_sources[i].id; i++) {
 			if (tvb_memeql(tvb, 12, primary_sources[i].id, 4) == 0) {
 				g_snprintf(buff, NTP_TS_SIZE, "%s",
@@ -853,8 +853,8 @@ dissect_ntp_std(tvbuff_t *tvb, proto_tree *ntp_tree, guint8 flags)
 			buff[NTP_TS_SIZE-1]=0;
 		}
 	}
-	proto_tree_add_bytes_format(ntp_tree, hf_ntp_refid, tvb, 12, 4,
-				    NULL, "Reference ID: %s", buff);
+	proto_tree_add_bytes_format_value(ntp_tree, hf_ntp_refid, tvb, 12, 4,
+					NULL, "%s", buff);
 
 	/* Reference Timestamp: This is the time at which the local clock was
 	 * last set or corrected.
@@ -1226,25 +1226,22 @@ init_parser(void)
 	tvbparse_wanted_t* want_identifier = tvbparse_chars(-1, 1, 0,
 		"abcdefghijklmnopqrstuvwxyz-_ABCDEFGHIJKLMNOPQRSTUVWXYZ.0123456789", NULL, NULL, NULL);
 	/* this is the equal sign used in assignments */
-	tvbparse_wanted_t* want_equalsign = tvbparse_char(-1, "=", NULL, NULL, NULL);
+	tvbparse_wanted_t* want_equalsign = tvbparse_chars(-1, 1, 0, "=", NULL, NULL, NULL);
 	/* possible characters allowed for values */
 	tvbparse_wanted_t* want_value = tvbparse_set_oneof(0, NULL, NULL, NULL,
 		tvbparse_quoted(-1, NULL, NULL, tvbparse_shrink_token_cb, '\"', '\\'),
 		tvbparse_quoted(-1, NULL, NULL, tvbparse_shrink_token_cb, '\'', '\\'),
 		tvbparse_chars(-1, 1, 0, "abcdefghijklmnopqrstuvwxyz-_ABCDEFGHIJKLMNOPQRSTUVWXYZ.0123456789 ", NULL, NULL, NULL),
 		NULL);
-	tvbparse_wanted_t* want_comma = tvbparse_until(-1, NULL, NULL, NULL,
-		tvbparse_char(-1, ",", NULL, NULL, NULL), TP_UNTIL_SPEND);
 	/* the following specifies an assignment of the form identifier=value */
 	tvbparse_wanted_t* want_assignment = tvbparse_set_seq(-1, NULL, NULL, NULL,
 		want_identifier,
 		want_equalsign,
-		tvbparse_some(-1, 0, 1, NULL, NULL, NULL, want_value),
-		tvbparse_some(-1, 0, 1, NULL, NULL, NULL, want_comma),
+		want_value,
 		NULL);
 
 	/* we ignore white space characters */
-	want_ignore = tvbparse_chars(-1, 1, 0, " \t\r\n", NULL, NULL, NULL);
+	want_ignore = tvbparse_chars(-1, 1, 0, ", \t\r\n", NULL, NULL, NULL);
 	/* data part of control messages consists of either identifiers or assignments */
 	want = tvbparse_set_oneof(-1, NULL, NULL, NULL,
 		want_assignment,
