@@ -1,7 +1,7 @@
 /* packet-null.c
  * Routines for null packet disassembly
  *
- * $Id$
+ * $Id: packet-null.c 51907 2013-09-09 22:30:40Z cmaynard $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -474,7 +474,7 @@ proto_register_null(void)
 
 	/* subdissector code */
 	null_dissector_table = register_dissector_table("null.type",
-	   "BSD AF_ type", FT_UINT32, BASE_DEC);
+	   "Null type", FT_UINT32, BASE_DEC);
 }
 
 void
