@@ -2,7 +2,7 @@
  * ISC OMAPI (Object Management API) dissector
  * Copyright 2006, Jaap Keuter <jaap.keuter@xs4all.nl>
  *
- * $Id$
+ * $Id: packet-omapi.c 49921 2013-06-14 01:56:28Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -117,7 +117,6 @@ dissect_omapi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   if (tvb_reported_length_remaining(tvb, 0) < 8)
   {
     /* Payload too small for OMAPI */
-    ptvcursor_free(cursor);
     DISSECTOR_ASSERT_NOT_REACHED();
   }
   else if (tvb_reported_length_remaining(tvb, 0) < 24)
@@ -129,7 +128,6 @@ dissect_omapi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     col_set_str(pinfo->cinfo, COL_INFO, "Status message");
     proto_item_append_text(ti, ", Status message");
 
-    ptvcursor_free(cursor);
     return;
   }
   else if ( !(tvb_get_ntohl(tvb, 8) || tvb_get_ntohl(tvb, 12)) )
@@ -138,10 +136,8 @@ dissect_omapi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     ptvcursor_add(cursor, hf_omapi_version, 4, ENC_BIG_ENDIAN);
     ptvcursor_add(cursor, hf_omapi_hlength, 4, ENC_BIG_ENDIAN);
 
-    if (check_col(pinfo->cinfo, COL_INFO))
-    {
-      col_append_str(pinfo->cinfo, COL_INFO, "Status message");
-    }
+    col_append_str(pinfo->cinfo, COL_INFO, "Status message");
+
     proto_item_append_text(ti, ", Status message");
   }
 
@@ -149,11 +145,9 @@ dissect_omapi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   authlength = tvb_get_ntohl(tvb, ptvcursor_current_offset(cursor));
   ptvcursor_add(cursor, hf_omapi_auth_len, 4, ENC_BIG_ENDIAN);
 
-  if (check_col(pinfo->cinfo, COL_INFO))
-  {
-    col_append_sep_str(pinfo->cinfo, COL_INFO, NULL,
+  col_append_sep_str(pinfo->cinfo, COL_INFO, NULL,
       val_to_str(tvb_get_ntohl(tvb, ptvcursor_current_offset(cursor)), omapi_opcode_vals, "Unknown opcode (0x%04x)"));
-  }
+
   proto_item_append_text(ti, ", Opcode: %s",
     val_to_str(tvb_get_ntohl(tvb, ptvcursor_current_offset(cursor)), omapi_opcode_vals, "Unknown opcode (0x%04x)"));
 
@@ -219,8 +213,6 @@ dissect_omapi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   if (authlength > 0) {
     ptvcursor_add(cursor, hf_omapi_signature, authlength, ENC_NA);
   }
-
-  ptvcursor_free(cursor);
 }
 
 void
