@@ -13,7 +13,7 @@
  *   Stiftinger Thomas
  *   Werner Sebastian
  *
- * $Id$
+ * $Id: packet-openvpn.c 51156 2013-08-05 18:09:43Z darkjames $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -60,8 +60,6 @@
 #define P_CONTROL_HARD_RESET_CLIENT_V2  7
 #define P_CONTROL_HARD_RESET_SERVER_V2  8
 
-static dissector_handle_t ssl_handle;
-
 static gint ett_openvpn = -1;
 static gint ett_openvpn_data = -1;
 static gint ett_openvpn_packetarray = -1;
@@ -82,6 +80,10 @@ static gint hf_openvpn_rsessionid = -1;
 static gint hf_openvpn_sessionid = -1;
 static gint proto_openvpn = -1;
 
+static dissector_handle_t openvpn_handle;
+
+static dissector_handle_t ssl_handle;
+
 /* Preferences */
 static gboolean pref_long_format       = TRUE;
 static gboolean pref_tls_auth          = FALSE;
@@ -197,7 +199,7 @@ dissect_openvpn_msg(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   proto_tree    *type_tree;
   guint32        msg_length_remaining;
   gboolean       msg_lastframe;
-  fragment_data *frag_msg;
+  fragment_head *frag_msg;
   tvbuff_t      *new_tvb;
   gboolean       save_fragmented;
 
@@ -595,7 +597,7 @@ proto_register_openvpn(void)
   proto_register_field_array(proto_openvpn, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
 
-  register_dissector(PFNAME, dissect_openvpn, proto_openvpn);
+  openvpn_handle = register_dissector(PFNAME, dissect_openvpn, proto_openvpn);
 
   register_init_routine(&openvpn_reassemble_init);
 
@@ -644,13 +646,11 @@ proto_register_openvpn(void)
 void
 proto_reg_handoff_openvpn(void)
 {
-  static dissector_handle_t openvpn_handle;
   static guint    tcp_port;
   static guint    udp_port;
   static gboolean initialized = FALSE;
 
   if (! initialized) {
-    openvpn_handle = find_dissector(PFNAME);
     ssl_handle     = find_dissector("ssl");
     initialized    = TRUE;
   } else {
