@@ -2,7 +2,7 @@
  * Routines for OUCH 4.x protocol dissection
  * Copyright 2013 David Arnold <davida@pobox.com>
  *
- * $Id$
+ * $Id: packet-ouch.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -19,7 +19,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the 
+ * along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
  *   51 Franklin Street, Fifth Floor,
  *   Boston, MA 02110-1301 USA.
@@ -194,7 +194,7 @@ static const value_string ouch_liquidity_flag_val[] = {
     { 'r', "Retail Order removes RPI liquidity" },
     { 't', "Retail Order removes price improving non-displayed liquidity "
       "other than RPI liquidity" },
-    { '6', "Liquidity Removing Order in designated securities" },    
+    { '6', "Liquidity Removing Order in designated securities" },
     { 0, NULL }
 };
 
@@ -238,7 +238,7 @@ static const value_string ouch_reject_reason_val[] = {
     { 'k', "On Close order restriction" },
     { 'l', "Two sided quote reject" },
     { 'm', "Exceeded shares limit" },
-    { 'n', "Exceeded dollar value limit" },    
+    { 'n', "Exceeded dollar value limit" },
     { 0, NULL}
 };
 
@@ -318,7 +318,7 @@ ouch_tree_add_timestamp(
 
     proto_tree_add_string(tree, hf, tvb, offset, 8, buf);
 }
-                          
+
 
 /** BASE_CUSTOM formatter for BBO weight indicator code
  *
@@ -1268,29 +1268,14 @@ dissect_ouch(
 
 
 /* Register the protocol with Wireshark */
-static void
-range_add_ouch_callback(
-    guint32 port)
-{
-    dissector_add_uint("tcp.port", port, ouch_handle);
-}
-
-static void
-range_delete_ouch_callback(
-    guint32 port)
-{
-    dissector_delete_uint("tcp.port", port, ouch_handle);
-}
 
 static void
 ouch_prefs(void)
 {
-    range_foreach(ouch_range,
-                  range_delete_ouch_callback);
+    dissector_delete_uint_range("tcp.port", ouch_range, ouch_handle);
     g_free(ouch_range);
     ouch_range = range_copy(global_ouch_range);
-    range_foreach(ouch_range,
-                  range_add_ouch_callback);
+    dissector_add_uint_range("tcp.port", ouch_range, ouch_handle);
 }
 
 
