@@ -6,7 +6,7 @@
  *
  * Copyright 2005, Stig Bjorlykke <stig@bjorlykke.org>, Thales Norway AS
  *
- * $Id$
+ * $Id: packet-p_mul.c 52299 2013-09-30 15:52:24Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -43,6 +43,7 @@
 #include <epan/reassemble.h>
 #include <epan/expert.h>
 #include <epan/asn1.h>
+#include <epan/wmem/wmem.h>
 #include <string.h>
 
 #include "packet-cdt.h"
@@ -134,10 +135,8 @@ static int hf_analysis_total_retrans_time = -1;
 static int hf_analysis_last_pdu_num = -1;
 static int hf_analysis_addr_pdu_num = -1;
 static int hf_analysis_addr_pdu_time = -1;
-static int hf_analysis_addr_pdu_missing = -1;
 static int hf_analysis_prev_pdu_num = -1;
 static int hf_analysis_prev_pdu_time = -1;
-static int hf_analysis_prev_pdu_missing = -1;
 static int hf_analysis_retrans_no = -1;
 static int hf_analysis_ack_num = -1;
 static int hf_analysis_ack_missing = -1;
@@ -158,7 +157,22 @@ static gint ett_seq_ack_analysis = -1;
 static gint ett_msg_fragment = -1;
 static gint ett_msg_fragments = -1;
 
+static expert_field ei_more_data = EI_INIT;
+static expert_field ei_checksum_bad = EI_INIT;
+static expert_field ei_tot_miss_seq_no = EI_INIT;
+static expert_field ei_miss_seq_no = EI_INIT;
+static expert_field ei_analysis_ack_missing = EI_INIT;
+static expert_field ei_miss_seq_range = EI_INIT;
+static expert_field ei_address_pdu_missing = EI_INIT;
+static expert_field ei_analysis_ack_dup_no = EI_INIT;
+static expert_field ei_length = EI_INIT;
+static expert_field ei_analysis_prev_pdu_missing = EI_INIT;
+static expert_field ei_message_discarded = EI_INIT;
+static expert_field ei_ack_length = EI_INIT;
+static expert_field ei_analysis_retrans_no = EI_INIT;
+
 static dissector_handle_t p_mul_handle = NULL;
+
 static dissector_handle_t data_handle = NULL;
 
 typedef struct _p_mul_id_key {
@@ -317,7 +331,7 @@ static p_mul_seq_val *lookup_seq_val (guint32 message_id, guint16 seq_no,
                                       address *addr)
 {
   p_mul_seq_val *pkg_data;
-  p_mul_id_key  *p_mul_key = se_new(p_mul_id_key);
+  p_mul_id_key  *p_mul_key = wmem_new(wmem_file_scope(), p_mul_id_key);
 
   p_mul_key->id = message_id;
   p_mul_key->seq = seq_no;
@@ -345,7 +359,7 @@ static void copy_hashtable_data (gpointer key, p_mul_ack_data *ack_data1, GHashT
 {
   p_mul_ack_data *ack_data2;
 
-  ack_data2 = se_new(p_mul_ack_data);
+  ack_data2 = wmem_new(wmem_file_scope(), p_mul_ack_data);
   ack_data2->ack_id = ack_data1->ack_id;
   ack_data2->ack_resend_count = ack_data1->ack_resend_count;
 
@@ -362,7 +376,7 @@ static p_mul_seq_val *register_p_mul_id (packet_info *pinfo, address *addr, guin
   nstime_t        addr_time, prev_time;
   guint           addr_id = 0, prev_id = 0;
   guint16         last_found_pdu = 0;
-  gboolean        missing_pdu = FALSE, set_address = FALSE;
+  gboolean        missing_pdu = FALSE, need_set_address = FALSE;
   GHashTable     *pkg_list;
 
   if (pinfo->flags.in_error_pkt) {
@@ -373,7 +387,7 @@ static p_mul_seq_val *register_p_mul_id (packet_info *pinfo, address *addr, guin
   nstime_set_zero(&addr_time);
   nstime_set_zero(&prev_time);
 
-  p_mul_key = se_new(p_mul_id_key);
+  p_mul_key = wmem_new(wmem_file_scope(), p_mul_id_key);
 
   if (!pinfo->fd->flags.visited &&
       (pdu_type == Address_PDU || pdu_type == Data_PDU || pdu_type == Discard_Message_PDU))
@@ -382,7 +396,7 @@ static p_mul_seq_val *register_p_mul_id (packet_info *pinfo, address *addr, guin
     p_mul_key->id = message_id;
     p_mul_key->seq = 0;
     SE_COPY_ADDRESS(&p_mul_key->addr, addr);
-    set_address = TRUE;
+    need_set_address = TRUE;
 
     p_mul_data = (p_mul_seq_val *) g_hash_table_lookup (p_mul_id_hash_table, p_mul_key);
 
@@ -434,7 +448,7 @@ static p_mul_seq_val *register_p_mul_id (packet_info *pinfo, address *addr, guin
   if (!pinfo->fd->flags.visited) {
     p_mul_key->id = message_id;
     p_mul_key->seq = seq_no;
-    if (!set_address) {
+    if (!need_set_address) {
       SE_COPY_ADDRESS(&p_mul_key->addr, addr);
     }
     p_mul_data = (p_mul_seq_val *) g_hash_table_lookup (p_mul_id_hash_table, p_mul_key);
@@ -446,7 +460,7 @@ static p_mul_seq_val *register_p_mul_id (packet_info *pinfo, address *addr, guin
           ack_data = (p_mul_ack_data *)g_hash_table_lookup (p_mul_data->ack_data, GUINT_TO_POINTER(dstIP));
           if (!ack_data) {
             /* Only save reference to first ACK */
-            ack_data = se_new0(p_mul_ack_data);
+            ack_data = wmem_new0(wmem_file_scope(), p_mul_ack_data);
             ack_data->ack_id = pinfo->fd->num;
             g_hash_table_insert (p_mul_data->ack_data, GUINT_TO_POINTER(dstIP), ack_data);
           } else {
@@ -469,7 +483,7 @@ static p_mul_seq_val *register_p_mul_id (packet_info *pinfo, address *addr, guin
     } else {
       /* New message */
       if (pdu_type == Ack_PDU) {
-        p_mul_data = se_new0(p_mul_seq_val);
+        p_mul_data = wmem_new0(wmem_file_scope(), p_mul_seq_val);
       } else {
         p_mul_data = (p_mul_seq_val *)g_malloc0(sizeof (p_mul_seq_val));
       }
@@ -480,7 +494,7 @@ static p_mul_seq_val *register_p_mul_id (packet_info *pinfo, address *addr, guin
 
       if (pdu_type == Ack_PDU) {
         /* No matching message for this ack */
-        ack_data = se_new0(p_mul_ack_data);
+        ack_data = wmem_new0(wmem_file_scope(), p_mul_ack_data);
         ack_data->ack_id = pinfo->fd->num;
         g_hash_table_insert (p_mul_data->ack_data, GUINT_TO_POINTER(dstIP), ack_data);
       } else {
@@ -500,7 +514,7 @@ static p_mul_seq_val *register_p_mul_id (packet_info *pinfo, address *addr, guin
     }
 
     /* Copy the current package data to the frame */
-    pkg_data = se_new(p_mul_seq_val);
+    pkg_data = wmem_new(wmem_file_scope(), p_mul_seq_val);
     *pkg_data = *p_mul_data;
     if (p_mul_data->ack_data) {
       /* Copy the hash table for ack data */
@@ -558,12 +572,7 @@ static void add_ack_analysis (tvbuff_t *tvb, packet_info *pinfo, proto_tree *p_m
                                   tvb, 0, 0, &ns);
         PROTO_ITEM_SET_GENERATED (en);
       } else {
-        en = proto_tree_add_item (analysis_tree,
-                                  hf_analysis_addr_pdu_missing,
-                                  tvb, offset, 0, ENC_NA);
-        expert_add_info_format (pinfo, en, PI_SEQUENCE, PI_NOTE,
-                                "Address PDU missing");
-        PROTO_ITEM_SET_GENERATED (en);
+        proto_tree_add_expert(analysis_tree, pinfo, &ei_address_pdu_missing, tvb, offset, 0);
       }
       item_added = TRUE;
     } else {
@@ -585,8 +594,7 @@ static void add_ack_analysis (tvbuff_t *tvb, packet_info *pinfo, proto_tree *p_m
         if (pinfo->fd->flags.visited) {
           /* We do not know this on first visit and we do not want to
              add a entry in the "Expert Severity Info" for this note */
-          expert_add_info_format (pinfo, en, PI_SEQUENCE, PI_NOTE,
-                                  "Ack PDU missing");
+          expert_add_info(pinfo, en, &ei_analysis_ack_missing);
           PROTO_ITEM_SET_GENERATED (en);
         }
         item_added = TRUE;
@@ -624,12 +632,7 @@ static void add_ack_analysis (tvbuff_t *tvb, packet_info *pinfo, proto_tree *p_m
         PROTO_ITEM_SET_GENERATED (en);
       }
     } else {
-      en = proto_tree_add_item (analysis_tree,
-                                hf_analysis_addr_pdu_missing,
-                                tvb, offset, 0, ENC_NA);
-      expert_add_info_format (pinfo, en, PI_SEQUENCE, PI_NOTE,
-                              "Address PDU missing");
-      PROTO_ITEM_SET_GENERATED (en);
+      proto_tree_add_expert(analysis_tree, pinfo, &ei_address_pdu_missing, tvb, offset, 0);
     }
 
     if (pkg_data->msg_type != Ack_PDU && pkg_data->prev_pdu_id) {
@@ -650,8 +653,7 @@ static void add_ack_analysis (tvbuff_t *tvb, packet_info *pinfo, proto_tree *p_m
                                 tvb, 0, 0, ack_data->ack_resend_count);
       PROTO_ITEM_SET_GENERATED (en);
 
-      expert_add_info_format (pinfo, en, PI_SEQUENCE, PI_NOTE,
-                              "Dup ACK #%d", ack_data->ack_resend_count);
+      expert_add_info_format(pinfo, en, &ei_analysis_ack_dup_no, "Dup ACK #%d", ack_data->ack_resend_count);
 
       en = proto_tree_add_uint (analysis_tree, hf_analysis_ack_resend_from,
                                 tvb, 0, 0, ack_data->ack_id);
@@ -707,12 +709,7 @@ static p_mul_seq_val *add_seq_analysis (tvbuff_t *tvb, packet_info *pinfo,
       }
       item_added = TRUE;
     } else if (!pkg_data->msg_resend_count) {
-      en = proto_tree_add_item (analysis_tree,
-                                hf_analysis_addr_pdu_missing,
-                                tvb, offset, 0, ENC_NA);
-      expert_add_info_format (pinfo, en, PI_SEQUENCE, PI_NOTE,
-                              "Address PDU missing");
-      PROTO_ITEM_SET_GENERATED (en);
+      proto_tree_add_expert(analysis_tree, pinfo, &ei_address_pdu_missing, tvb, offset, 0);
       item_added = TRUE;
     }
   }
@@ -730,12 +727,7 @@ static p_mul_seq_val *add_seq_analysis (tvbuff_t *tvb, packet_info *pinfo,
       PROTO_ITEM_SET_GENERATED (en);
       item_added = TRUE;
     } else if (!pkg_data->msg_resend_count) {
-      en = proto_tree_add_item (analysis_tree,
-                                hf_analysis_prev_pdu_missing,
-                                tvb, offset, 0, ENC_NA);
-      expert_add_info_format (pinfo, en, PI_SEQUENCE, PI_NOTE,
-                              "Previous PDU missing");
-      PROTO_ITEM_SET_GENERATED (en);
+      proto_tree_add_expert(analysis_tree, pinfo, &ei_analysis_prev_pdu_missing, tvb, offset, 0);
       item_added = TRUE;
     }
   }
@@ -752,9 +744,7 @@ static p_mul_seq_val *add_seq_analysis (tvbuff_t *tvb, packet_info *pinfo,
                                 tvb, 0, 0, pkg_data->pdu_id);
       PROTO_ITEM_SET_GENERATED (en);
 
-      expert_add_info_format (pinfo, en, PI_SEQUENCE, PI_NOTE,
-                              "Retransmission #%d",
-                              pkg_data->msg_resend_count);
+      expert_add_info_format(pinfo, en, &ei_analysis_retrans_no, "Retransmission #%d", pkg_data->msg_resend_count);
 
       nstime_delta (&ns, &pinfo->fd->abs_ts, &pkg_data->prev_msg_time);
       en = proto_tree_add_time (analysis_tree, hf_analysis_retrans_time,
@@ -815,7 +805,7 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   guint8         pdu_type, *value, map = 0, fec_len;
   gint           i, tot_no_missing = 0, no_missing = 0, offset = 0;
   address        src, dst;
-  emem_strbuf_t *message_id_list = NULL;
+  wmem_strbuf_t *message_id_list = NULL;
   nstime_t       ts;
 
   col_set_str (pinfo->cinfo, COL_PROTOCOL, "P_MUL");
@@ -853,14 +843,13 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   offset += 1;
 
   /* MAP / PDU_Type */
-  en = proto_tree_add_uint_format (p_mul_tree, hf_pdu_type, tvb, offset, 1,
-                                   pdu_type, "PDU Type: %s (0x%02x)",
+  en = proto_tree_add_uint_format_value(p_mul_tree, hf_pdu_type, tvb, offset, 1,
+                                   pdu_type, "%s (0x%02x)",
                                    get_type (pdu_type), pdu_type);
   field_tree = proto_item_add_subtree (en, ett_pdu_type);
 
   if (pdu_type == Discard_Message_PDU) {
-    expert_add_info_format (pinfo, en, PI_RESPONSE_CODE, PI_NOTE,
-                            "Message discarded");
+    expert_add_info(pinfo, en, &ei_message_discarded);
   }
 
   switch (pdu_type) {
@@ -926,7 +915,7 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   en = proto_tree_add_item (p_mul_tree, hf_checksum, tvb, offset, 2, ENC_BIG_ENDIAN);
   checksum_tree = proto_item_add_subtree (en, ett_checksum);
   len = tvb_length (tvb);
-  value = tvb_get_ephemeral_string (tvb, 0, len);
+  value = tvb_get_string (wmem_packet_scope(), tvb, 0, len);
   checksum1 = checksum (value, len, offset);
   checksum2 = tvb_get_ntohs (tvb, offset);
   if (checksum1 == checksum2) {
@@ -939,7 +928,7 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     PROTO_ITEM_SET_GENERATED (en);
   } else {
     proto_item_append_text (en, " (incorrect, should be 0x%04x)", checksum1);
-    expert_add_info_format (pinfo, en, PI_CHECKSUM, PI_WARN, "Bad checksum");
+    expert_add_info(pinfo, en, &ei_checksum_bad);
     en = proto_tree_add_boolean (checksum_tree, hf_checksum_good, tvb,
                                  offset, 2, FALSE);
     PROTO_ITEM_SET_GENERATED (en);
@@ -952,7 +941,7 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   if (pdu_type == Ack_PDU) {
     /* Source ID of Ack Sender */
     ip = tvb_get_ipv4 (tvb, offset);
-    SET_ADDRESS (&dst, AT_IPv4, sizeof(ip), ep_memdup (&ip, 4));
+    SET_ADDRESS (&dst, AT_IPv4, sizeof(ip), wmem_memdup (wmem_packet_scope(), &ip, 4));
     proto_tree_add_item (p_mul_tree, hf_source_id_ack, tvb, offset, 4, ENC_BIG_ENDIAN);
     offset += 4;
 
@@ -963,7 +952,7 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   } else {
     /* Source Id */
     ip = tvb_get_ipv4 (tvb, offset);
-    SET_ADDRESS (&src, AT_IPv4, sizeof(ip), ep_memdup (&ip, 4));
+    SET_ADDRESS (&src, AT_IPv4, sizeof(ip), wmem_memdup (wmem_packet_scope(), &ip, 4));
     proto_tree_add_item (p_mul_tree, hf_source_id, tvb, offset, 4, ENC_BIG_ENDIAN);
     offset += 4;
 
@@ -975,9 +964,8 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         message_id_offset = message_id;
       }
       message_id -= message_id_offset;
-      proto_tree_add_uint_format (p_mul_tree, hf_message_id, tvb, offset, 4,
-                                  message_id, "Message ID (MSID): %u"
-                                  "    (relative message id)", message_id);
+      proto_tree_add_uint_format_value(p_mul_tree, hf_message_id, tvb, offset, 4,
+                                  message_id, "%u    (relative message id)", message_id);
     } else {
       proto_tree_add_item (p_mul_tree, hf_message_id, tvb, offset, 4, ENC_BIG_ENDIAN);
     }
@@ -1040,7 +1028,7 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
       /* Destination Id */
       ip = tvb_get_ipv4 (tvb, offset);
-      SET_ADDRESS (&dst, AT_IPv4, sizeof(ip), ep_memdup(&ip, 4));
+      SET_ADDRESS (&dst, AT_IPv4, sizeof(ip), wmem_memdup(wmem_packet_scope(), &ip, 4));
       proto_tree_add_item (field_tree, hf_dest_id, tvb, offset, 4, ENC_BIG_ENDIAN);
       offset += 4;
 
@@ -1080,9 +1068,8 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     break;
 
   case Ack_PDU:
-    if (check_col (pinfo->cinfo, COL_INFO)) {
-      message_id_list = ep_strbuf_new_label("");
-    }
+    message_id_list = wmem_strbuf_new_label(wmem_packet_scope());
+
     for (i = 0; i < count; i++) {
       /* Ack Info Entry */
       len = tvb_get_ntohs (tvb, offset);
@@ -1098,13 +1085,12 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
       if (len < 10) {
         proto_item_append_text (en, "    (invalid length)");
-        expert_add_info_format (pinfo, en, PI_MALFORMED, PI_WARN,
-                                "Invalid ack info length");
+        expert_add_info(pinfo, en, &ei_ack_length);
       }
 
       /* Source Id */
       ip = tvb_get_ipv4 (tvb, offset);
-      SET_ADDRESS (&src, AT_IPv4, sizeof(ip), ep_memdup (&ip, 4));
+      SET_ADDRESS (&src, AT_IPv4, sizeof(ip), wmem_memdup (wmem_packet_scope(), &ip, 4));
       proto_tree_add_item (field_tree, hf_source_id, tvb, offset, 4, ENC_BIG_ENDIAN);
       offset += 4;
 
@@ -1116,20 +1102,17 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
           message_id_offset = message_id;
         }
         message_id -= message_id_offset;
-        proto_tree_add_uint_format (field_tree, hf_message_id, tvb, offset, 4,
-                                    message_id, "Message ID (MSID): %u"
-                                    "    (relative message id)", message_id);
+        proto_tree_add_uint_format_value(field_tree, hf_message_id, tvb, offset, 4,
+                                    message_id, "%u    (relative message id)", message_id);
       } else {
         proto_tree_add_item (field_tree, hf_message_id, tvb, offset, 4, ENC_BIG_ENDIAN);
       }
       offset += 4;
 
-      if (check_col (pinfo->cinfo, COL_INFO)) {
-        if (i == 0) {
-          ep_strbuf_printf (message_id_list, "%u", message_id);
-        } else {
-          ep_strbuf_append_printf (message_id_list, ",%u", message_id);
-        }
+      if (i == 0) {
+        wmem_strbuf_append_printf (message_id_list, "%u", message_id);
+      } else {
+        wmem_strbuf_append_printf (message_id_list, ",%u", message_id);
       }
 
       if (len > 10) {
@@ -1142,14 +1125,13 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             /* We are handling a range */
             guint16 end_seq_no = tvb_get_ntohs (tvb, offset + 4);
 
-            en = proto_tree_add_bytes_format (field_tree, hf_miss_seq_range,
+            en = proto_tree_add_bytes_format_value(field_tree, hf_miss_seq_range,
                                               tvb, offset, 6, NULL,
-                                             "Missing Data PDU Seq Range: %d - %d",
+                                             "%d - %d",
                                              ack_seq_no, end_seq_no);
             if (ack_seq_no >= end_seq_no) {
               proto_item_append_text (en, "    (invalid)");
-              expert_add_info_format (pinfo, en, PI_UNDECODED, PI_WARN,
-                                      "Invalid missing sequence range");
+              expert_add_info(pinfo, en, &ei_miss_seq_range);
             } else {
               proto_tree *missing_tree;
               guint16 sno;
@@ -1157,9 +1139,9 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
               missing_tree = proto_item_add_subtree (en, ett_range_entry);
 
               for (sno = ack_seq_no; sno <= end_seq_no; sno++) {
-                en = proto_tree_add_uint_format (missing_tree, hf_miss_seq_no,
+                en = proto_tree_add_uint_format_value(missing_tree, hf_miss_seq_no,
                                                  tvb, offset, 6, sno,
-                                                 "Missing Data PDU Seq Number: %d", sno);
+                                                 "%d", sno);
                 PROTO_ITEM_SET_GENERATED (en);
               }
               tot_no_missing += (end_seq_no - ack_seq_no + 1);
@@ -1175,8 +1157,7 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
             if (ack_seq_no == 0) {
               proto_item_append_text (en, "    (invalid)");
-              expert_add_info_format (pinfo, en, PI_UNDECODED, PI_WARN,
-                                      "Invalid missing seq number");
+              expert_add_info(pinfo, en, &ei_miss_seq_no);
             } else if (ack_seq_no <= prev_ack_seq_no) {
               proto_item_append_text (en, "    (end of list indicator)");
             } else {
@@ -1199,9 +1180,9 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       guint64 timestamp;
 
       timestamp = tvb_get_ntoh64 (tvb, offset);
-      proto_tree_add_uint64_format (p_mul_tree, hf_timestamp_option, tvb,
+      proto_tree_add_uint64_format_value(p_mul_tree, hf_timestamp_option, tvb,
                                     offset, 8, timestamp,
-                                    "Timestamp: %" G_GINT64_MODIFIER "d.%d second%s (%" G_GINT64_MODIFIER "u)",
+                                    "%" G_GINT64_MODIFIER "d.%d second%s (%" G_GINT64_MODIFIER "u)",
                                     timestamp / 10, (int) timestamp % 10,
                                     (timestamp == 10) ? "" : "s", timestamp);
       offset += 8;
@@ -1212,8 +1193,7 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       en = proto_tree_add_uint (p_mul_tree, hf_tot_miss_seq_no, tvb, 0, 0,
                                 tot_no_missing);
       PROTO_ITEM_SET_GENERATED (en);
-      expert_add_info_format (pinfo, en, PI_RESPONSE_CODE, PI_NOTE,
-                              "Missing seq numbers: %d", tot_no_missing);
+      expert_add_info_format(pinfo, en, &ei_tot_miss_seq_no, "Missing seq numbers: %d", tot_no_missing);
     }
     break;
 
@@ -1254,37 +1234,35 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                                  message_id, seq_no, tot_no_missing);
   }
 
-  if (check_col (pinfo->cinfo, COL_INFO)) {
-    /* Check if printing Ack-Ack */
-    if (pdu_type == Address_PDU && no_dest == 0) {
-      col_append_str (pinfo->cinfo, COL_INFO, get_type (Ack_Ack_PDU));
-    } else {
-      col_append_str (pinfo->cinfo, COL_INFO, get_type (pdu_type));
+  /* Check if printing Ack-Ack */
+  if (pdu_type == Address_PDU && no_dest == 0) {
+    col_append_str (pinfo->cinfo, COL_INFO, get_type (Ack_Ack_PDU));
+  } else {
+    col_append_str (pinfo->cinfo, COL_INFO, get_type (pdu_type));
+  }
+  if (pdu_type == Address_PDU || pdu_type == Extra_Address_PDU ||
+      pdu_type == FEC_Address_PDU || pdu_type == Extra_FEC_Address_PDU) {
+    col_append_fstr (pinfo->cinfo, COL_INFO, ", No PDUs: %u", no_pdus);
+  } else if (pdu_type == Data_PDU) {
+    col_append_fstr (pinfo->cinfo, COL_INFO, ", Seq no: %u", seq_no);
+  }
+  if (pdu_type == Address_PDU || pdu_type == Extra_Address_PDU ||
+      pdu_type == FEC_Address_PDU || pdu_type == Extra_FEC_Address_PDU) {
+    if (no_dest > 0) {
+      col_append_fstr (pinfo->cinfo, COL_INFO, ", Count of Dest: %u", no_dest);
     }
-    if (pdu_type == Address_PDU || pdu_type == Extra_Address_PDU ||
-        pdu_type == FEC_Address_PDU || pdu_type == Extra_FEC_Address_PDU) {
-      col_append_fstr (pinfo->cinfo, COL_INFO, ", No PDUs: %u", no_pdus);
-    } else if (pdu_type == Data_PDU) {
-      col_append_fstr (pinfo->cinfo, COL_INFO, ", Seq no: %u", seq_no);
+  } else if (pdu_type == Ack_PDU) {
+    if (tot_no_missing) {
+      col_append_fstr (pinfo->cinfo, COL_INFO, ", Missing seq numbers: %u",
+                       tot_no_missing);
     }
-    if (pdu_type == Address_PDU || pdu_type == Extra_Address_PDU ||
-        pdu_type == FEC_Address_PDU || pdu_type == Extra_FEC_Address_PDU) {
-      if (no_dest > 0) {
-        col_append_fstr (pinfo->cinfo, COL_INFO, ", Count of Dest: %u", no_dest);
-      }
-    } else if (pdu_type == Ack_PDU) {
-      if (tot_no_missing) {
-        col_append_fstr (pinfo->cinfo, COL_INFO, ", Missing seq numbers: %u",
-                         tot_no_missing);
-      }
-      col_append_fstr (pinfo->cinfo, COL_INFO, ", Count of Ack: %u", count);
-    }
-    if (pdu_type != Ack_PDU) {
-      col_append_fstr (pinfo->cinfo, COL_INFO, ", MSID: %u", message_id);
-    } else {
-      if (message_id_list && message_id_list->len > 0) {
-        col_append_fstr (pinfo->cinfo, COL_INFO, ", MSID: %s", message_id_list->str);
-      }
+    col_append_fstr (pinfo->cinfo, COL_INFO, ", Count of Ack: %u", count);
+  }
+  if (pdu_type != Ack_PDU) {
+    col_append_fstr (pinfo->cinfo, COL_INFO, ", MSID: %u", message_id);
+  } else {
+    if (message_id_list && wmem_strbuf_get_len(message_id_list) > 0) {
+      col_append_fstr (pinfo->cinfo, COL_INFO, ", MSID: %s", wmem_strbuf_get_str(message_id_list));
     }
   }
 
@@ -1296,7 +1274,7 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       fragment_start_seq_check (&p_mul_reassembly_table,
                                 pinfo, message_id, NULL, no_pdus - 1);
     } else if (pdu_type == Data_PDU) {
-      fragment_data *frag_msg;
+      fragment_head *frag_msg;
       tvbuff_t      *new_tvb;
 
       pinfo->fragmented = TRUE;
@@ -1325,12 +1303,10 @@ static void dissect_p_mul (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   if (pdu_length != (offset + data_len)) {
     proto_item_append_text (len_en, " (incorrect, should be: %d)",
                             offset + data_len);
-    expert_add_info_format (pinfo, len_en, PI_MALFORMED, PI_WARN,
-                            "Incorrect length field");
+    expert_add_info(pinfo, len_en, &ei_length);
   } else if ((len = tvb_length_remaining (tvb, pdu_length)) > 0) {
     proto_item_append_text (len_en, " (more data in packet: %d)", len);
-    expert_add_info_format (pinfo, len_en, PI_MALFORMED, PI_WARN,
-                            "More data in packet");
+    expert_add_info(pinfo, len_en, &ei_more_data);
   }
 }
 
@@ -1451,7 +1427,7 @@ void proto_register_p_mul (void)
         "p_mul.no_missing_seq_no", FT_UINT16, BASE_DEC, NULL, 0x0,
         NULL, HFILL } },
     { &hf_timestamp_option,
-      { "Timestamp Option", "p_mul.timestamp", FT_UINT64, BASE_DEC,
+      { "Timestamp", "p_mul.timestamp", FT_UINT64, BASE_DEC,
         NULL, 0x0, "Timestamp Option (in units of 100ms)", HFILL } },
     { &hf_dest_entry,
       { "Destination Entry", "p_mul.dest_entry", FT_NONE, BASE_NONE,
@@ -1537,12 +1513,6 @@ void proto_register_p_mul (void)
     { &hf_analysis_ack_num,
       { "Ack PDU in", "p_mul.analysis.ack_in", FT_FRAMENUM, BASE_NONE,
         NULL, 0x0, "This packet has an Ack in this frame", HFILL } },
-    { &hf_analysis_addr_pdu_missing,
-      { "Address PDU missing", "p_mul.analysis.addr_pdu_missing", FT_NONE, BASE_NONE,
-        NULL, 0x0, "The Address PDU for this packet is missing", HFILL } },
-    { &hf_analysis_prev_pdu_missing,
-      { "Previous PDU missing", "p_mul.analysis.prev_pdu_missing", FT_NONE, BASE_NONE,
-        NULL, 0x0, "The previous PDU for this packet is missing", HFILL } },
     { &hf_analysis_ack_missing,
       { "Ack PDU missing", "p_mul.analysis.ack_missing", FT_NONE, BASE_NONE,
         NULL, 0x0, "The acknowledgement for this packet is missing", HFILL } },
@@ -1578,14 +1548,33 @@ void proto_register_p_mul (void)
     &ett_msg_fragment,
     &ett_msg_fragments
   };
+  static ei_register_info ei[] = {
+      { &ei_address_pdu_missing, { "p_mul.analysis.addr_pdu_missing", PI_SEQUENCE, PI_NOTE, "Address PDU missing", EXPFILL }},
+      { &ei_analysis_ack_missing, { "p_mul.analysis.ack_missing.expert", PI_SEQUENCE, PI_NOTE, "Ack PDU missing", EXPFILL }},
+      { &ei_analysis_ack_dup_no, { "p_mul.analysis.dup_ack_no.expert", PI_SEQUENCE, PI_NOTE, "Dup ACK #", EXPFILL }},
+      { &ei_analysis_prev_pdu_missing, { "p_mul.analysis.prev_pdu_missing", PI_SEQUENCE, PI_NOTE, "Previous PDU missing", EXPFILL }},
+      { &ei_analysis_retrans_no, { "p_mul.analysis.retrans_no.expert", PI_SEQUENCE, PI_NOTE, "Retransmission #", EXPFILL }},
+      { &ei_message_discarded, { "p_mul.message_discarded", PI_RESPONSE_CODE, PI_NOTE, "Message discarded", EXPFILL }},
+      { &ei_checksum_bad, { "p_mul.checksum_bad.expert", PI_CHECKSUM, PI_WARN, "Bad checksum", EXPFILL }},
+      { &ei_ack_length, { "p_mul.ack_length.invalid", PI_MALFORMED, PI_WARN, "Invalid ack info length", EXPFILL }},
+      { &ei_miss_seq_range, { "p_mul.missing_seq_range.invalid", PI_UNDECODED, PI_WARN, "Invalid missing sequence range", EXPFILL }},
+      { &ei_miss_seq_no, { "p_mul.missing_seq_no.invalid", PI_UNDECODED, PI_WARN, "Invalid missing seq number", EXPFILL }},
+      { &ei_tot_miss_seq_no, { "p_mul.no_missing_seq_no.expert", PI_RESPONSE_CODE, PI_NOTE, "Missing seq numbers", EXPFILL }},
+      { &ei_length, { "p_mul.length.invalid", PI_MALFORMED, PI_WARN, "Incorrect length field", EXPFILL }},
+      { &ei_more_data, { "p_mul.more_data", PI_MALFORMED, PI_WARN, "More data in packet", EXPFILL }},
+  };
 
   module_t *p_mul_module;
+  expert_module_t* expert_p_mul;
 
   proto_p_mul = proto_register_protocol (PNAME, PSNAME, PFNAME);
-  register_dissector(PFNAME, dissect_p_mul, proto_p_mul);
+
+  p_mul_handle = register_dissector(PFNAME, dissect_p_mul, proto_p_mul);
 
   proto_register_field_array (proto_p_mul, hf, array_length (hf));
   proto_register_subtree_array (ett, array_length (ett));
+  expert_p_mul = expert_register_protocol(proto_p_mul);
+  expert_register_field_array(expert_p_mul, ei, array_length(ei));
   register_init_routine (&p_mul_init_routine);
 
   /* Set default UDP ports */
@@ -1624,34 +1613,23 @@ void proto_register_p_mul (void)
                                   &decode_option, decode_options, FALSE);
 }
 
-static void range_delete_callback (guint32 port)
-{
-    dissector_delete_uint ("udp.port", port, p_mul_handle);
-}
-
-static void range_add_callback (guint32 port)
-{
-    dissector_add_uint ("udp.port", port, p_mul_handle);
-}
-
 void proto_reg_handoff_p_mul (void)
 {
   static gboolean p_mul_prefs_initialized = FALSE;
   static range_t *p_mul_port_range;
 
   if (!p_mul_prefs_initialized) {
-    p_mul_handle = find_dissector(PFNAME);
     p_mul_prefs_initialized = TRUE;
     data_handle = find_dissector ("data");
   } else {
-    range_foreach (p_mul_port_range, range_delete_callback);
+	dissector_delete_uint_range ("udp.port", p_mul_port_range, p_mul_handle);
     g_free (p_mul_port_range);
   }
 
   /* Save port number for later deletion */
   p_mul_port_range = range_copy (global_p_mul_port_range);
 
-  range_foreach (p_mul_port_range, range_add_callback);
+  dissector_add_uint_range ("udp.port", p_mul_port_range, p_mul_handle);
 }
 
 /*
