@@ -3,7 +3,7 @@
  *
  * Copyright 2009, Stig Bjorlykke <stig@bjorlykke.org>
  *
- * $Id$
+ * $Id: packet-packetlogger.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,9 +32,6 @@
 #define PSNAME "PKTLOG"
 #define PFNAME "packetlogger"
 
-static dissector_table_t hci_h1_table;
-static dissector_handle_t data_handle;
-
 static int proto_packetlogger = -1;
 
 static int hf_type = -1;
@@ -42,6 +39,11 @@ static int hf_info = -1;
 
 static gint ett_packetlogger = -1;
 
+static dissector_handle_t packetlogger_handle;
+static dissector_table_t hci_h1_table;
+
+static dissector_handle_t data_handle;
+
 #define PKT_HCI_COMMAND     0x00
 #define PKT_HCI_EVENT       0x01
 #define PKT_SENT_ACL_DATA   0x02
@@ -148,17 +150,15 @@ void proto_register_packetlogger (void)
   };
 
   proto_packetlogger = proto_register_protocol (PNAME, PSNAME, PFNAME);
-  register_dissector (PFNAME, dissect_packetlogger, proto_packetlogger);
-  
+
+  packetlogger_handle = register_dissector (PFNAME, dissect_packetlogger, proto_packetlogger);
+
   proto_register_field_array (proto_packetlogger, hf, array_length (hf));
   proto_register_subtree_array (ett, array_length (ett));
 }
 
 void proto_reg_handoff_packetlogger (void)
 {
-  dissector_handle_t packetlogger_handle;
-
-  packetlogger_handle = find_dissector (PFNAME);
   hci_h1_table = find_dissector_table("hci_h1.type");
   data_handle = find_dissector("data");
   dissector_add_uint ("wtap_encap", WTAP_ENCAP_PACKETLOGGER, packetlogger_handle);
