@@ -2,7 +2,7 @@
  * Routines for Protocol for carrying Authentication for Network Access dissection
  * Copyright 2006, Peter Racz <racz@ifi.unizh.ch>
  *
- * $Id$
+ * $Id: packet-pana.c 52468 2013-10-09 16:20:54Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,7 +34,7 @@
 
 #include <epan/packet.h>
 #include <epan/conversation.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 
 #if 0
 #define PANA_UDP_PORT 3001
@@ -207,7 +207,7 @@ typedef struct _pana_transaction_t {
 } pana_transaction_t;
 
 typedef struct _pana_conv_info_t {
-        emem_tree_t *pdus;
+        wmem_tree_t *pdus;
 } pana_conv_info_t;
 
 static void
@@ -518,11 +518,9 @@ dissect_pana_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
        seq_num    = tvb_get_ntohl(tvb, 12);
        avp_length = msg_length - 16;
 
-       if (check_col(pinfo->cinfo, COL_INFO)) {
-               col_add_fstr(pinfo->cinfo, COL_INFO, "Type %s-%s",
+       col_add_fstr(pinfo->cinfo, COL_INFO, "Type %s-%s",
                             val_to_str(msg_type, msg_type_names, "Unknown (%d)"),
                             val_to_str(flags & PANA_FLAG_R, msg_subtype_names, "Unknown (%d)"));
-       }
 
        /* Make the protocol tree */
        if (tree) {
@@ -546,8 +544,8 @@ dissect_pana_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                /* No.  Attach that information to the conversation, and add
                 * it to the list of information structures.
                 */
-               pana_info = se_new(pana_conv_info_t);
-               pana_info->pdus=se_tree_create_non_persistent(EMEM_TREE_TYPE_RED_BLACK, "pana_pdus");
+               pana_info = wmem_new(wmem_file_scope(), pana_conv_info_t);
+               pana_info->pdus=wmem_tree_new(wmem_file_scope());
 
                conversation_add_proto_data(conversation, proto_pana, pana_info);
        }
@@ -555,24 +553,24 @@ dissect_pana_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
        if(!pinfo->fd->flags.visited){
                if(flags&PANA_FLAG_R){
                       /* This is a request */
-                      pana_trans=se_new(pana_transaction_t);
+                      pana_trans=wmem_new(wmem_file_scope(), pana_transaction_t);
                       pana_trans->req_frame=pinfo->fd->num;
                       pana_trans->rep_frame=0;
                       pana_trans->req_time=pinfo->fd->abs_ts;
-                      se_tree_insert32(pana_info->pdus, seq_num, (void *)pana_trans);
+                      wmem_tree_insert32(pana_info->pdus, seq_num, (void *)pana_trans);
                } else {
-                      pana_trans=(pana_transaction_t *)se_tree_lookup32(pana_info->pdus, seq_num);
+                      pana_trans=(pana_transaction_t *)wmem_tree_lookup32(pana_info->pdus, seq_num);
                       if(pana_trans){
                               pana_trans->rep_frame=pinfo->fd->num;
                       }
                }
        } else {
-               pana_trans=(pana_transaction_t *)se_tree_lookup32(pana_info->pdus, seq_num);
+               pana_trans=(pana_transaction_t *)wmem_tree_lookup32(pana_info->pdus, seq_num);
        }
 
        if(!pana_trans){
                /* create a "fake" pana_trans structure */
-               pana_trans=ep_new(pana_transaction_t);
+               pana_trans=wmem_new(wmem_packet_scope(), pana_transaction_t);
                pana_trans->req_frame=0;
                pana_trans->rep_frame=0;
                pana_trans->req_time=pinfo->fd->abs_ts;
@@ -670,13 +668,8 @@ dissect_pana(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
                return 0;
        }
 
-       /* Get header fields */
-       pana_res   = tvb_get_ntohs(tvb, 0);
+	   /* Check minimum packet length */
        msg_length = tvb_get_ntohs(tvb, 2);
-       flags      = tvb_get_ntohs(tvb, 4);
-       msg_type   = tvb_get_ntohs(tvb, 6);
-
-       /* Check minimum packet length */
        if(msg_length < 16) {
                return 0;
        }
@@ -687,16 +680,19 @@ dissect_pana(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
        }
 
        /* check that the reserved field is zero */
+       pana_res   = tvb_get_ntohs(tvb, 0);
        if (pana_res != 0) {
                return 0;
        }
 
        /* verify that none of the reserved bits are set */
+       flags      = tvb_get_ntohs(tvb, 4);
        if (flags & PANA_FLAG_RESERVED) {
                return 0;
        }
 
        /* verify that we recognize the message type */
+       msg_type   = tvb_get_ntohs(tvb, 6);
        if ((msg_type > MSG_TYPE_MAX) || (msg_type == 0)) {
                return 0;
        }
