@@ -2,7 +2,7 @@
  *
  * Martin Mathieson
  *
- * $Id$
+ * $Id: packet-pdcp-lte.c 51852 2013-09-09 00:44:09Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,7 +32,7 @@
 #include <epan/prefs.h>
 #include <epan/expert.h>
 #include <epan/addr_resolv.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 
 #include "packet-rlc-lte.h"
 #include "packet-pdcp-lte.h"
@@ -90,7 +90,6 @@ static int hf_pdcp_lte_fms = -1;
 static int hf_pdcp_lte_reserved4 = -1;
 static int hf_pdcp_lte_fms2 = -1;
 static int hf_pdcp_lte_bitmap = -1;
-static int hf_pdcp_lte_bitmap_not_received = -1;
 
 
 /* Sequence Analysis */
@@ -113,6 +112,10 @@ static int ett_pdcp_packet = -1;
 static int ett_pdcp_lte_sequence_analysis = -1;
 static int ett_pdcp_report_bitmap = -1;
 
+static expert_field ei_pdcp_lte_sequence_analysis_wrong_sequence_number = EI_INIT;
+static expert_field ei_pdcp_lte_reserved_bits_not_zero = EI_INIT;
+static expert_field ei_pdcp_lte_sequence_analysis_sn_repeated = EI_INIT;
+static expert_field ei_pdcp_lte_sequence_analysis_sn_missing = EI_INIT;
 
 static const value_string direction_vals[] =
 {
@@ -219,9 +222,9 @@ static dissector_handle_t data_handle;
 #define SEQUENCE_ANALYSIS_PDCP_ONLY 2
 
 /* Preference variables */
-static gboolean global_pdcp_dissect_user_plane_as_ip = FALSE;
-static gboolean global_pdcp_dissect_signalling_plane_as_rrc = FALSE;
-static gint     global_pdcp_check_sequence_numbers = FALSE;
+static gboolean global_pdcp_dissect_user_plane_as_ip = TRUE;
+static gboolean global_pdcp_dissect_signalling_plane_as_rrc = TRUE;
+static gint     global_pdcp_check_sequence_numbers = TRUE;
 static gboolean global_pdcp_dissect_rohc = FALSE;
 
 /* Which layer info to show in the info column */
@@ -325,7 +328,7 @@ static gpointer get_report_hash_key(guint16 SN, guint32 frameNumber,
 
     /* Only allocate a struct when will be adding entry */
     if (do_persist) {
-        p_key = se_new(pdcp_result_hash_key);
+        p_key = wmem_new(wmem_file_scope(), pdcp_result_hash_key);
     }
     else {
         memset(&key, 0, sizeof(pdcp_result_hash_key));
@@ -434,7 +437,7 @@ static void addChannelSequenceInfo(pdcp_sequence_report_in_frame *p,
                                         tvb, 0, 0, TRUE);
             PROTO_ITEM_SET_GENERATED(ti);
             if (p->lastSN != p->firstSN) {
-                expert_add_info_format(pinfo, ti, PI_SEQUENCE, PI_WARN,
+                expert_add_info_format(pinfo, ti, &ei_pdcp_lte_sequence_analysis_sn_missing,
                                        "PDCP SNs (%u to %u) missing for %s on UE %u (%s-%u)",
                                        p->firstSN, p->lastSN,
                                        val_to_str_const(p_pdcp_lte_info->direction, direction_vals, "Unknown"),
@@ -445,7 +448,7 @@ static void addChannelSequenceInfo(pdcp_sequence_report_in_frame *p,
                                        p->firstSN, p->lastSN);
             }
             else {
-                expert_add_info_format(pinfo, ti, PI_SEQUENCE, PI_WARN,
+                expert_add_info_format(pinfo, ti, &ei_pdcp_lte_sequence_analysis_sn_missing,
                                        "PDCP SN (%u) missing for %s on UE %u (%s-%u)",
                                        p->firstSN,
                                        val_to_str_const(p_pdcp_lte_info->direction, direction_vals, "Unknown"),
@@ -464,7 +467,7 @@ static void addChannelSequenceInfo(pdcp_sequence_report_in_frame *p,
             ti = proto_tree_add_boolean(seqnum_tree, hf_pdcp_lte_sequence_analysis_repeated,
                                         tvb, 0, 0, TRUE);
             PROTO_ITEM_SET_GENERATED(ti);
-            expert_add_info_format(pinfo, ti, PI_SEQUENCE, PI_WARN,
+            expert_add_info_format(pinfo, ti, &ei_pdcp_lte_sequence_analysis_sn_repeated,
                                    "PDCP SN (%u) repeated for %s for UE %u (%s-%u)",
                                    p->firstSN,
                                    val_to_str_const(p_pdcp_lte_info->direction, direction_vals, "Unknown"),
@@ -477,7 +480,7 @@ static void addChannelSequenceInfo(pdcp_sequence_report_in_frame *p,
 
         default:
             /* Incorrect sequence number */
-            expert_add_info_format(pinfo, ti_expected_sn, PI_SEQUENCE, PI_WARN,
+            expert_add_info_format(pinfo, ti_expected_sn, &ei_pdcp_lte_sequence_analysis_wrong_sequence_number,
                                    "Wrong Sequence Number for %s on UE %u (%s-%u) - got %u, expected %u",
                                    val_to_str_const(p_pdcp_lte_info->direction, direction_vals, "Unknown"),
                                    p_pdcp_lte_info->ueid,
@@ -539,7 +542,7 @@ static void checkChannelSequenceInfo(packet_info *pinfo, tvbuff_t *tvb,
         createdChannel = TRUE;
 
         /* Allocate a new value and duplicate key contents */
-        p_channel_status = se_new0(pdcp_channel_status);
+        p_channel_status = wmem_new0(wmem_file_scope(), pdcp_channel_status);
 
         /* Add entry */
         g_hash_table_insert(pdcp_sequence_analysis_channel_hash,
@@ -547,7 +550,7 @@ static void checkChannelSequenceInfo(packet_info *pinfo, tvbuff_t *tvb,
     }
 
     /* Create space for frame state_report */
-    p_report_in_frame = se_new(pdcp_sequence_report_in_frame);
+    p_report_in_frame = wmem_new(wmem_file_scope(), pdcp_sequence_report_in_frame);
     p_report_in_frame->nextFrameNum = 0;
 
     switch (p_pdcp_lte_info->seqnum_length) {
@@ -880,7 +883,7 @@ static gboolean dissect_pdcp_lte_heur(tvbuff_t *tvb, packet_info *pinfo,
     p_pdcp_lte_info = (pdcp_lte_info *)p_get_proto_data(pinfo->fd, proto_pdcp_lte, 0);
     if (p_pdcp_lte_info == NULL) {
         /* Allocate new info struct for this frame */
-        p_pdcp_lte_info = se_new0(pdcp_lte_info);
+        p_pdcp_lte_info = wmem_new0(wmem_file_scope(), pdcp_lte_info);
         infoAlreadySet = FALSE;
     }
     else {
@@ -943,6 +946,14 @@ static gboolean dissect_pdcp_lte_heur(tvbuff_t *tvb, packet_info *pinfo,
                 p_pdcp_lte_info->profile = tvb_get_ntohs(tvb, offset);
                 offset += 2;
                 break;
+            case PDCP_LTE_CHANNEL_ID_TAG:
+                p_pdcp_lte_info->channelId = tvb_get_ntohs(tvb, offset);
+                offset += 2;
+                break;
+            case PDCP_LTE_UEID_TAG:
+                p_pdcp_lte_info->ueid = tvb_get_ntohs(tvb, offset);
+                offset += 2;
+                break;
 
             case PDCP_LTE_PAYLOAD_TAG:
                 /* Have reached data, so get out of loop */
@@ -1049,7 +1060,7 @@ static void dissect_pdcp_lte(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
             proto_item *ti = proto_tree_add_item(pdcp_tree, hf_pdcp_lte_control_plane_reserved,
                                                  tvb, offset, 1, ENC_BIG_ENDIAN);
             if (reserved != 0) {
-                expert_add_info_format(pinfo, ti, PI_MALFORMED, PI_ERROR,
+                expert_add_info_format(pinfo, ti, &ei_pdcp_lte_reserved_bits_not_zero,
                                        "PDCP signalling header reserved bits not zero");
             }
 
@@ -1060,6 +1071,11 @@ static void dissect_pdcp_lte(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
             write_pdu_label_and_info(root_ti, pinfo, " sn=%-2u ", seqnum);
             offset++;
 
+            if (tvb_length_remaining(tvb, offset) == 0) {
+                /* Only PDCP header was captured, stop dissection here */
+                return;
+            }
+
             /* RRC data is all but last 4 bytes.
                Call lte-rrc dissector (according to direction and channel type) */
             if (global_pdcp_dissect_signalling_plane_as_rrc) {
@@ -1137,7 +1153,7 @@ static void dissect_pdcp_lte(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
 
                             /* Complain if not 0 */
                             if (reserved_value != 0) {
-                                expert_add_info_format(pinfo, ti, PI_MALFORMED, PI_ERROR,
+                                expert_add_info_format(pinfo, ti, &ei_pdcp_lte_reserved_bits_not_zero,
                                                        "Reserved bits have value 0x%x - should be 0x0",
                                                        reserved_value);
                             }
@@ -1171,12 +1187,16 @@ static void dissect_pdcp_lte(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
                 switch (control_pdu_type) {
                     case 0:    /* PDCP status report */
                         {
+                            guint8  bits;
                             guint16 fms;
                             guint16 modulo;
                             guint   not_received = 0;
-                            guint   sn;
+                            guint   sn, i, j, l;
+                            guint32 len, bit_offset;
                             proto_tree *bitmap_tree;
                             proto_item *bitmap_ti = NULL;
+                            gchar  *buff = NULL;
+                            #define BUFF_SIZE 49
 
                             if (p_pdcp_info->seqnum_length == PDCP_SN_LENGTH_12_BITS) {
                                 /* First-Missing-Sequence SN */
@@ -1197,7 +1217,7 @@ static void dissect_pdcp_lte(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
 
                                 /* Complain if not 0 */
                                 if (reserved_value != 0) {
-                                    expert_add_info_format(pinfo, ti, PI_MALFORMED, PI_ERROR,
+                                    expert_add_info_format(pinfo, ti, &ei_pdcp_lte_reserved_bits_not_zero,
                                                            "Reserved bits have value 0x%x - should be 0x0",
                                                            reserved_value);
                                 }
@@ -1217,19 +1237,22 @@ static void dissect_pdcp_lte(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
                                                                 offset, -1, ENC_NA);
                                 bitmap_tree = proto_item_add_subtree(bitmap_ti, ett_pdcp_report_bitmap);
 
-
+                                 buff = (gchar *)wmem_alloc(wmem_packet_scope(), BUFF_SIZE);
+                                 len = tvb_length_remaining(tvb, offset);
+                                 bit_offset = offset<<3;
                                 /* For each byte... */
-                                for ( ; tvb_length_remaining(tvb, offset); offset++) {
-                                    guint bit_offset = 0;
-                                    /* .. look for error (0) in each bit */
-                                    for ( ; bit_offset < 8; bit_offset++) {
-                                        if ((tvb_get_guint8(tvb, offset) >> (7-bit_offset) & 0x1) == 0) {
-                                            proto_tree_add_boolean_bits_format_value(bitmap_tree, hf_pdcp_lte_bitmap_not_received, tvb, offset*8 + bit_offset,
-                                                                                     1, 0, " (SN=%u)", sn);
+                                for (i=0; i<len; i++) {
+                                    bits = tvb_get_bits8(tvb, bit_offset, 8);
+                                    for (l=0, j=0; l<8; l++) {
+                                        if ((bits << l) & 0x80) {
+                                            j += g_snprintf(&buff[j], BUFF_SIZE-j, "%5u,", (unsigned)(sn+(8*i)+l)%modulo);
+                                        } else {
+                                            j += g_snprintf(&buff[j], BUFF_SIZE-j, "     ,");
                                             not_received++;
                                         }
-                                        sn = (sn + 1) % modulo;
                                     }
+                                    proto_tree_add_text(bitmap_tree, tvb, bit_offset/8, 1, "%s", buff);
+                                    bit_offset += 8;
                                 }
                             }
 
@@ -1374,7 +1397,7 @@ static void dissect_pdcp_lte(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
     rohc_tvb = tvb_new_subset_remaining(tvb, rohc_offset);
 
     /* RoHC settings */
-    p_rohc_info = ep_new(rohc_info);
+    p_rohc_info = wmem_new(wmem_packet_scope(), rohc_info);
 
     p_rohc_info->rohc_compression     = p_pdcp_info->rohc_compression;
     p_rohc_info->rohc_ip_version      = p_pdcp_info->rohc_ip_version;
@@ -1611,12 +1634,6 @@ void proto_register_pdcp(void)
               "Status report bitmap (0=error, 1=OK)", HFILL
             }
         },
-        { &hf_pdcp_lte_bitmap_not_received,
-            { "Not Received",
-              "pdcp-lte.bitmap.error", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
-              "Status report PDU error", HFILL
-            }
-        },
 
 
         { &hf_pdcp_lte_sequence_analysis,
@@ -1674,6 +1691,13 @@ void proto_register_pdcp(void)
         &ett_pdcp_report_bitmap
     };
 
+    static ei_register_info ei[] = {
+        { &ei_pdcp_lte_sequence_analysis_sn_missing, { "pdcp-lte.sequence-analysis.sn_missing", PI_SEQUENCE, PI_WARN, "PDCP SN missing", EXPFILL }},
+        { &ei_pdcp_lte_sequence_analysis_sn_repeated, { "pdcp-lte.sequence-analysis.sn_repeated", PI_SEQUENCE, PI_WARN, "PDCP SN repeated", EXPFILL }},
+        { &ei_pdcp_lte_sequence_analysis_wrong_sequence_number, { "pdcp-lte.sequence-analysis.wrong_sequence_number", PI_SEQUENCE, PI_WARN, "Wrong Sequence Number", EXPFILL }},
+        { &ei_pdcp_lte_reserved_bits_not_zero, { "pdcp_lte.reserved_bits_not_zero", PI_MALFORMED, PI_ERROR, "Reserved bits not zero", EXPFILL }},
+    };
+
     static const enum_val_t sequence_analysis_vals[] = {
         {"no-analysis", "No-Analysis",      FALSE},
         {"rlc-only",    "Only-RLC-frames",  SEQUENCE_ANALYSIS_RLC_ONLY},
@@ -1689,12 +1713,14 @@ void proto_register_pdcp(void)
     };
 
     module_t *pdcp_lte_module;
-
+    expert_module_t* expert_pdcp_lte;
 
     /* Register protocol. */
     proto_pdcp_lte = proto_register_protocol("PDCP-LTE", "PDCP-LTE", "pdcp-lte");
     proto_register_field_array(proto_pdcp_lte, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+    expert_pdcp_lte = expert_register_protocol(proto_pdcp_lte);
+    expert_register_field_array(expert_pdcp_lte, ei, array_length(ei));
 
     /* Allow other dissectors to find this one by name. */
     register_dissector("pdcp-lte", dissect_pdcp_lte, proto_pdcp_lte);
