@@ -1,7 +1,7 @@
 /* packet-pdcp-lte.h
  *
  * Martin Mathieson
- * $Id$
+ * $Id: packet-pdcp-lte.h 50422 2013-07-06 21:43:44Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -161,6 +161,11 @@ typedef struct pdcp_lte_info
 #define PDCP_LTE_ROHC_PROFILE_TAG           0x0C
 /* 2 bytes, network order */
 
+#define PDCP_LTE_CHANNEL_ID_TAG             0x0D
+/* 2 bytes, network order */
+
+#define PDCP_LTE_UEID_TAG                   0x0E
+/* 2 bytes, network order */
 
 /* PDCP PDU. Following this tag comes the actual PDCP PDU (there is no length, the PDU
    continues until the end of the frame) */
