@@ -7,7 +7,7 @@ proper helper routines
  * Routines for dissection of ASN.1 Aligned PER
  * 2003  Ronnie Sahlberg
  *
- * $Id$
+ * $Id: packet-per.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,7 +39,7 @@ proper helper routines
 #include <epan/oids.h>
 #include <epan/to_str.h>
 #include <epan/prefs.h>
-#include <epan/emem.h>
+#include <epan/wmem/wmem.h>
 #include <epan/asn1.h>
 #include <epan/strutil.h>
 #include <epan/expert.h>
@@ -81,6 +81,13 @@ static gint ett_per_sequence_of_item = -1;
 static gint ett_per_External = -1;
 static gint ett_per_External_encoding = -1;
 
+static expert_field ei_per_size_constraint_value = EI_INIT;
+static expert_field ei_per_size_constraint_too_few = EI_INIT;
+static expert_field ei_per_size_constraint_too_many = EI_INIT;
+static expert_field ei_per_choice_extension_unknown = EI_INIT;
+static expert_field ei_per_sequence_extension_unknown = EI_INIT;
+static expert_field ei_per_encoding_error = EI_INIT;
+
 /*
 #define DEBUG_ENTRY(x) \
 printf("#%u  %s   tvb:0x%08x\n",actx->pinfo->fd->num,x,(int)tvb);
@@ -122,27 +129,27 @@ static const true_false_string tfs_optional_field_bit = {
 static void per_check_value(guint32 value, guint32 min_len, guint32 max_len, asn1_ctx_t *actx, proto_item *item, gboolean is_signed)
 {
 	if ((is_signed == FALSE) && (value > max_len)) {
-		expert_add_info_format(actx->pinfo, item, PI_PROTOCOL, PI_WARN, "Size constraint: value too big: %u (%u .. %u)", value, min_len, max_len);
+		expert_add_info_format(actx->pinfo, item, &ei_per_size_constraint_value, "Size constraint: value too big: %u (%u .. %u)", value, min_len, max_len);
 	} else if ((is_signed == TRUE) && ((gint32)value > (gint32)max_len)) {
-		expert_add_info_format(actx->pinfo, item, PI_PROTOCOL, PI_WARN, "Size constraint: value too big: %d (%d .. %d)", (gint32)value, (gint32)min_len, (gint32)max_len);
+		expert_add_info_format(actx->pinfo, item, &ei_per_size_constraint_value, "Size constraint: value too big: %d (%d .. %d)", (gint32)value, (gint32)min_len, (gint32)max_len);
 	}
 }
 
 static void per_check_value64(guint64 value, guint64 min_len, guint64 max_len, asn1_ctx_t *actx, proto_item *item, gboolean is_signed)
 {
 	if ((is_signed == FALSE) && (value > max_len)) {
-		expert_add_info_format(actx->pinfo, item, PI_PROTOCOL, PI_WARN, "Size constraint: value too big: %" G_GINT64_MODIFIER "u (%" G_GINT64_MODIFIER "u .. %" G_GINT64_MODIFIER "u)", value, min_len, max_len);
+		expert_add_info_format(actx->pinfo, item, &ei_per_size_constraint_value, "Size constraint: value too big: %" G_GINT64_MODIFIER "u (%" G_GINT64_MODIFIER "u .. %" G_GINT64_MODIFIER "u)", value, min_len, max_len);
 	} else if ((is_signed == TRUE) && ((gint64)value > (gint64)max_len)) {
-		expert_add_info_format(actx->pinfo, item, PI_PROTOCOL, PI_WARN, "Size constraint: value too big: %" G_GINT64_MODIFIER "d (%" G_GINT64_MODIFIER "d .. %" G_GINT64_MODIFIER "d)", (gint64)value, (gint64)min_len, (gint64)max_len);
+		expert_add_info_format(actx->pinfo, item, &ei_per_size_constraint_value, "Size constraint: value too big: %" G_GINT64_MODIFIER "d (%" G_GINT64_MODIFIER "d .. %" G_GINT64_MODIFIER "d)", (gint64)value, (gint64)min_len, (gint64)max_len);
 	}
 }
 
 static void per_check_items(guint32 cnt, int min_len, int max_len, asn1_ctx_t *actx, proto_item *item)
 {
 	if (min_len != NO_BOUND && cnt < (guint32)min_len) {
-		expert_add_info_format(actx->pinfo, item, PI_PROTOCOL, PI_WARN, "Size constraint: too few items: %d (%d .. %d)", cnt, min_len, max_len);
+		expert_add_info_format(actx->pinfo, item, &ei_per_size_constraint_too_few, "Size constraint: too few items: %d (%d .. %d)", cnt, min_len, max_len);
 	} else if (max_len != NO_BOUND && cnt > (guint32)max_len) {
-		expert_add_info_format(actx->pinfo, item, PI_PROTOCOL, PI_WARN, "Size constraint: too many items: %d (%d .. %d)", cnt, min_len, max_len);
+		expert_add_info_format(actx->pinfo, item, &ei_per_size_constraint_too_many, "Size constraint: too many items: %d (%d .. %d)", cnt, min_len, max_len);
 	}
 }
 
@@ -164,7 +171,7 @@ static tvbuff_t *new_octet_aligned_subset(tvbuff_t *tvb, guint32 offset, asn1_ct
   if (offset & 0x07) {  /* unaligned */
     shift1 = offset & 0x07;
     shift0 = 8 - shift1;
-    buf = (guint8 *)g_malloc(actual_length);
+    buf = (guint8 *)wmem_alloc(actx->pinfo->pool, actual_length);
     octet0 = tvb_get_guint8(tvb, boffset);
     for (i=0; i<actual_length; i++) {
       octet1 = octet0;
@@ -172,7 +179,6 @@ static tvbuff_t *new_octet_aligned_subset(tvbuff_t *tvb, guint32 offset, asn1_ct
       buf[i] = (octet1 << shift1) | (octet0 >> shift0);
     }
     sub_tvb = tvb_new_child_real_data(tvb, buf, actual_length, length);
-    tvb_set_free_cb(sub_tvb, g_free);
     add_new_data_source(actx->pinfo, sub_tvb, "Unaligned OCTET STRING");
   } else {  /* aligned */
     sub_tvb = tvb_new_subset(tvb, boffset, actual_length, length);
@@ -305,7 +311,7 @@ dissect_per_length_determinant(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx _
 
 		/* prepare the string (max number of bits + quartet separators + prepended space) */
 		str_length = 256+64+1;
-		str=(char *)ep_alloc(str_length+1);
+		str=(char *)wmem_alloc(wmem_packet_scope(), str_length+1);
 		str_index = 0;
 
 		str_length = g_snprintf(str, str_length+1, " ");
@@ -559,11 +565,10 @@ DEBUG_ENTRY("dissect_per_sequence_of");
 
 /* XXX we don't do >64k length strings   yet */
 static guint32
-dissect_per_restricted_character_string_sorted(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len,
-                                               gboolean has_extension _U_, guint16 lb _U_, guint16 ub, const char *alphabet, int alphabet_length, tvbuff_t **value_tvb)
+dissect_per_restricted_character_string_sorted(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, gboolean has_extension _U_,const char *alphabet, int alphabet_length, tvbuff_t **value_tvb)
 {
 	guint32 length;
-	gboolean byte_aligned, use_canonical_order;
+	gboolean byte_aligned;
 	guint8 *buf;
 	guint char_pos;
 	int bits_per_char;
@@ -669,13 +674,8 @@ DEBUG_ENTRY("dissect_per_restricted_character_string");
 		BYTE_ALIGN_OFFSET(offset);
 	}
 
-	/* 30.5: if "ub" is less than or equal to 2^b-1, then "v" is the value specified in above , else
-	   the characters are placed in the canonical order defined in ITU-T Rec. X.680 | ISO/IEC 8824-1,
-	   clause 43. The first is assigned the value zero and the next in canonical order is assigned a value
-	   that is one greater than the value assigned to the previous character in the canonical order. These are the values "v" */
-	use_canonical_order = (ub <= ((guint16)(1<<bits_per_char)-1)) ? FALSE : TRUE;
 
-	buf = (guint8 *)g_malloc(length+1);
+	buf = (guint8 *)wmem_alloc(actx->pinfo->pool, length+1);
 	old_offset=offset;
 	for(char_pos=0;char_pos<length;char_pos++){
 		guchar val;
@@ -687,7 +687,11 @@ DEBUG_ENTRY("dissect_per_restricted_character_string");
 			offset=dissect_per_boolean(tvb, offset, actx, tree, -1, &bit);
 			val=(val<<1)|bit;
 		}
-		if(use_canonical_order == FALSE){
+		/* ALIGNED PER does not do any remapping of chars if
+		   bitsperchar is 8
+		*/
+		/* If alphabet is not provided, do not do any remapping either */
+		if((bits_per_char==8) || (alphabet==NULL)){
 			buf[char_pos]=val;
 		} else {
 			if (val < alphabet_length){
@@ -701,9 +705,6 @@ DEBUG_ENTRY("dissect_per_restricted_character_string");
 	proto_tree_add_string(tree, hf_index, tvb, (old_offset>>3), (offset>>3)-(old_offset>>3), (char*)buf);
 	if (value_tvb) {
 		*value_tvb = tvb_new_child_real_data(tvb, buf, length, length);
-		tvb_set_free_cb(*value_tvb, g_free);
-	} else {
-		g_free(buf);
 	}
 	return offset;
 }
@@ -712,19 +713,15 @@ static const char*
 sort_alphabet(char *sorted_alphabet, const char *alphabet, int alphabet_length)
 {
   int i, j;
-  guchar c, c_max, c_min;
+  char c, c_max, c_min;
   char tmp_buf[256];
 
-  /*
-   * XXX - presumably all members of alphabet will be in the
-   * range 0 to 127.
-   */
   if (!alphabet_length) return sorted_alphabet;
   memset(tmp_buf, 0, 256);
-  c_min = c_max = (guchar)alphabet[0];
+  c_min = c_max = alphabet[0];
   for (i=0; i<alphabet_length; i++) {
-    c = (guchar)alphabet[i];
-    tmp_buf[c] = 1;
+    c = alphabet[i];
+    tmp_buf[(int)c] = 1;
     if (c > c_max) c_max = c;
     else if (c < c_min) c_min = c;
   }
@@ -745,15 +742,17 @@ dissect_per_restricted_character_string(tvbuff_t *tvb, guint32 offset, asn1_ctx_
   } else {
     alphabet_ptr = sort_alphabet(sorted_alphabet, alphabet, alphabet_length);
   }
-  /* Not a known-multiplier character string: enforce lb and ub to max values */
-  return dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree, hf_index, min_len, max_len, has_extension, 0, 65535, alphabet_ptr, alphabet_length, value_tvb);
+  return dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree, hf_index, min_len, max_len, has_extension, alphabet_ptr, alphabet_length, value_tvb);
 }
 
+/* dissect a constrained IA5String that consists of the full ASCII set,
+   i.e. no FROM stuff limiting the alphabet
+*/
 guint32
 dissect_per_IA5String(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, gboolean has_extension)
 {
 	offset=dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree, hf_index, min_len, max_len, has_extension,
-		0, 127, NULL, 128, NULL);
+		NULL, 128, NULL);
 
 	return offset;
 }
@@ -762,7 +761,7 @@ guint32
 dissect_per_NumericString(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, gboolean has_extension)
 {
 	offset=dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree, hf_index, min_len, max_len, has_extension,
-		32, 57, " 0123456789", 11, NULL);
+		" 0123456789", 11, NULL);
 
 	return offset;
 }
@@ -770,14 +769,14 @@ guint32
 dissect_per_PrintableString(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, gboolean has_extension)
 {
 	offset=dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree, hf_index, min_len, max_len, has_extension,
-		32, 122, " '()+,-.*0123456789:=?ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz", 74, NULL);
+		" '()+,-.*0123456789:=?ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz", 74, NULL);
 	return offset;
 }
 guint32
 dissect_per_VisibleString(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, gboolean has_extension)
 {
 	offset=dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree, hf_index, min_len, max_len, has_extension,
-		32, 126, " !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~", 95, NULL);
+		" !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~", 95, NULL);
 	return offset;
 }
 guint32
@@ -815,7 +814,7 @@ dissect_per_BMPString(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tre
 		length=1024;
 	}
 
-	str = tvb_get_ephemeral_unicode_string(tvb, offset>>3, length*2, ENC_BIG_ENDIAN);
+	str = tvb_get_unicode_string(wmem_packet_scope(), tvb, offset>>3, length*2, ENC_BIG_ENDIAN);
 
 	proto_tree_add_string(tree, hf_index, tvb, offset>>3, length*2, str);
 
@@ -827,7 +826,7 @@ guint32
 dissect_per_UTF8String(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, int min_len, int max_len, gboolean has_extension _U_)
 {
 	offset=dissect_per_restricted_character_string_sorted(tvb, offset, actx, tree,
-		hf_index, min_len, max_len, has_extension, 0, 255, NULL, 256, NULL);
+		hf_index, min_len, max_len, has_extension, NULL, 256, NULL);
 	return offset;
 }
 
@@ -942,21 +941,22 @@ DEBUG_ENTRY("dissect_per_set_of");
 
 /* 23 Encoding the object identifier type */
 guint32
-dissect_per_object_identifier(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, tvbuff_t **value_tvb)
+dissect_per_any_oid(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, tvbuff_t **value_tvb,
+                    gboolean is_absolute)
 {
   guint length;
   const char *str;
   tvbuff_t *val_tvb = NULL;
   header_field_info *hfi;
 
-DEBUG_ENTRY("dissect_per_object_identifier");
+DEBUG_ENTRY("dissect_per_any_oid");
 
   offset = dissect_per_length_determinant(tvb, offset, actx, tree, hf_per_object_identifier_length, &length);
   if (actx->aligned) BYTE_ALIGN_OFFSET(offset);
   val_tvb = new_octet_aligned_subset(tvb, offset, actx, length);
 
   hfi = proto_registrar_get_nth(hf_index);
-  if (hfi->type == FT_OID) {
+  if ((is_absolute && hfi->type == FT_OID) || (is_absolute && hfi->type == FT_REL_OID)) {
     actx->created_item = proto_tree_add_item(tree, hf_index, val_tvb, 0, length, ENC_BIG_ENDIAN);
   } else if (IS_FT_STRING(hfi->type)) {
     str = oid_encoded2string(tvb_get_ptr(val_tvb, 0, length), length);
@@ -973,12 +973,25 @@ DEBUG_ENTRY("dissect_per_object_identifier");
 }
 
 guint32
-dissect_per_object_identifier_str(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, const char **value_stringx)
+dissect_per_object_identifier(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, tvbuff_t **value_tvb)
+{
+  return dissect_per_any_oid(tvb, offset, actx, tree, hf_index, value_tvb, TRUE);
+}
+
+guint32
+dissect_per_relative_oid(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, tvbuff_t **value_tvb)
+{
+  return dissect_per_any_oid(tvb, offset, actx, tree, hf_index, value_tvb, FALSE);
+}
+
+guint32
+dissect_per_any_oid_str(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, const char **value_stringx,
+                        gboolean is_absolute)
 {
   tvbuff_t *value_tvb = NULL;
   guint length;
 
-  offset = dissect_per_object_identifier(tvb, offset, actx, tree, hf_index, (value_stringx) ? &value_tvb : NULL);
+  offset = dissect_per_any_oid(tvb, offset, actx, tree, hf_index, (value_stringx) ? &value_tvb : NULL, is_absolute);
 
   if (value_stringx) {
     if (value_tvb && (length = tvb_length(value_tvb))) {
@@ -991,6 +1004,17 @@ dissect_per_object_identifier_str(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *act
   return offset;
 }
 
+guint32
+dissect_per_object_identifier_str(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, const char **value_stringx)
+{
+  return dissect_per_any_oid_str(tvb, offset, actx, tree, hf_index, value_stringx, TRUE);
+}
+
+guint32
+dissect_per_relative_oid_str(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index, const char **value_stringx)
+{
+  return dissect_per_any_oid_str(tvb, offset, actx, tree, hf_index, value_stringx, FALSE);
+}
 
 
 /* this function reads a single bit */
@@ -1251,7 +1275,7 @@ DEBUG_ENTRY("dissect_per_constrained_integer");
 			num_bits=1;
 		}
 
-		val_start = (offset)>>3; 
+		val_start = (offset)>>3;
 		val_length = length;
 		val = (guint32)tvb_get_bits64(tvb,offset,num_bits, ENC_BIG_ENDIAN);
 
@@ -1420,8 +1444,7 @@ DEBUG_ENTRY("dissect_per_constrained_integer_64b");
 
 		/* prepare the string (max number of bits + quartet separators + field name + ": ") */
 		str_length = 512+128+(int)strlen(hfi->name)+2;
-		str = (char *)ep_alloc(str_length+1);
-		str_index = 0;
+		str = (char *)wmem_alloc(wmem_packet_scope(), str_length+1);
 		str_index = g_snprintf(str, str_length+1, "%s: ", hfi->name);
 		for(bit=0;bit<((int)(offset&0x07));bit++){
 			if(bit&&(!(bit%4))){
@@ -1688,8 +1711,9 @@ DEBUG_ENTRY("dissect_per_choice");
 			PER_NOT_DECODED_YET("unknown extension root index in choice");
 		} else {
 			offset += ext_length * 8;
-			proto_tree_add_text(tree, tvb, old_offset>>3, BLEN(old_offset, offset), "Choice no. %d in extension", choice_index);
-			expert_add_info_format(actx->pinfo, choice_item, PI_UNDECODED, PI_NOTE, "unknown choice extension");
+			proto_tree_add_expert_format(tree, actx->pinfo, &ei_per_choice_extension_unknown,
+										tvb, old_offset>>3, BLEN(old_offset, offset),
+										"Choice no. %d in extension", choice_index);
 		}
 	}
 
@@ -1886,7 +1910,6 @@ DEBUG_ENTRY("dissect_per_sequence");
 
 		/* decode the extensions one by one */
 		for(i=0;i<num_extensions;i++){
-			proto_item *cause;
 			guint32 length;
 			guint32 new_offset;
 			guint32 difference;
@@ -1903,7 +1926,7 @@ DEBUG_ENTRY("dissect_per_sequence");
 			if(i>=num_known_extensions){
 				/* we don't know how to decode this extension */
 				offset+=length*8;
-				expert_add_info_format(actx->pinfo, item, PI_UNDECODED, PI_NOTE, "unknown sequence extension");
+				expert_add_info(actx->pinfo, item, &ei_per_sequence_extension_unknown);
 				continue;
 			}
 
@@ -1925,10 +1948,7 @@ DEBUG_ENTRY("dissect_per_sequence");
 				/* A difference of 7 or less might be byte aligning */
                 /* Difference could be 8 if open type has no bits and the length is 1 */
 				if ((length > 1) && (difference > 7)) {
-					cause=proto_tree_add_text(tree, tvb, new_offset>>3, (offset-new_offset)>>3,
-						"[Possible encoding error full length not decoded. Open type length %u ,decoded %u]",length, length - (difference>>3));
-					proto_item_set_expert_flags(cause, PI_MALFORMED, PI_WARN);
-					expert_add_info_format(actx->pinfo, cause, PI_MALFORMED, PI_WARN,
+					proto_tree_add_expert_format(tree, actx->pinfo, &ei_per_encoding_error, tvb, new_offset>>3, (offset-new_offset)>>3,
 						"Possible encoding error full length not decoded. Open type length %u ,decoded %u",length, length - (difference>>3));
 				}
 			} else {
@@ -2071,6 +2091,8 @@ dissect_per_bit_string(tvbuff_t *tvb, guint32 offset, asn1_ctx_t *actx, proto_tr
 DEBUG_ENTRY("dissect_per_bit_string");
 	/* 15.8 if the length is 0 bytes there will be no encoding */
 	if(max_len==0) {
+		if (value_tvb)
+			*value_tvb = out_tvb;
 		return offset;
 	}
 
@@ -2428,11 +2450,13 @@ dissect_per_T_octet_aligned(tvbuff_t *tvb, int offset, asn1_ctx_t *actx, proto_t
   offset = dissect_per_octet_string(tvb, offset, actx, tree, hf_index,
                                        NO_BOUND, NO_BOUND, FALSE, &actx->external.octet_aligned);
 
-  if (actx->external.u.per.type_cb) {
-    actx->external.u.per.type_cb(actx->external.octet_aligned, 0, actx, tree, actx->external.hf_index);
+  if (actx->external.octet_aligned) {
+    if (actx->external.u.per.type_cb) {
+      actx->external.u.per.type_cb(actx->external.octet_aligned, 0, actx, tree, actx->external.hf_index);
     } else {
-        actx->created_item = proto_tree_add_text(tree, actx->external.octet_aligned, 0, -1, "Unknown EXTERNAL Type");
+      actx->created_item = proto_tree_add_text(tree, actx->external.octet_aligned, 0, -1, "Unknown EXTERNAL Type");
     }
+  }
   return offset;
 }
 
@@ -2443,11 +2467,13 @@ dissect_per_T_arbitrary(tvbuff_t *tvb, int offset, asn1_ctx_t *actx, proto_tree
   offset = dissect_per_bit_string(tvb, offset, actx, tree, hf_index,
                                      NO_BOUND, NO_BOUND, FALSE, &actx->external.arbitrary);
 
-  if (actx->external.u.per.type_cb) {
-    actx->external.u.per.type_cb(actx->external.arbitrary, 0, actx, tree, actx->external.hf_index);
+  if (actx->external.arbitrary) {
+    if (actx->external.u.per.type_cb) {
+      actx->external.u.per.type_cb(actx->external.arbitrary, 0, actx, tree, actx->external.hf_index);
     } else {
-        actx->created_item = proto_tree_add_text(tree, actx->external.arbitrary, 0, -1, "Unknown EXTERNAL Type");
+      actx->created_item = proto_tree_add_text(tree, actx->external.arbitrary, 0, -1, "Unknown EXTERNAL Type");
     }
+  }
   return offset;
 }
 
@@ -2610,11 +2636,23 @@ proto_register_per(void)
 		&ett_per_External,
 		&ett_per_External_encoding,
 	};
+	static ei_register_info ei[] = {
+		{ &ei_per_size_constraint_value, { "per.size_constraint.value", PI_PROTOCOL, PI_WARN, "Size constraint: value too big", EXPFILL }},
+		{ &ei_per_size_constraint_too_few, { "per.size_constraint.too_few", PI_PROTOCOL, PI_WARN, "Size constraint: too few items", EXPFILL }},
+		{ &ei_per_size_constraint_too_many, { "per.size_constraint.too_many", PI_PROTOCOL, PI_WARN, "Size constraint: too many items", EXPFILL }},
+		{ &ei_per_choice_extension_unknown, { "per.choice_extension_unknown", PI_UNDECODED, PI_NOTE, "unknown choice extension", EXPFILL }},
+		{ &ei_per_sequence_extension_unknown, { "per.sequence_extension_unknown", PI_UNDECODED, PI_NOTE, "unknown sequence extension", EXPFILL }},
+		{ &ei_per_encoding_error, { "per.encoding_error", PI_MALFORMED, PI_WARN, "Encoding error", EXPFILL }},
+	};
+
 	module_t *per_module;
+	expert_module_t* expert_per;
 
 	proto_per = proto_register_protocol("Packed Encoding Rules (ASN.1 X.691)", "PER", "per");
 	proto_register_field_array(proto_per, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	expert_per = expert_register_protocol(proto_per);
+	expert_register_field_array(expert_per, ei, array_length(ei));
 
 	proto_set_cant_toggle(proto_per);
 
@@ -2631,3 +2669,15 @@ proto_reg_handoff_per(void)
 {
 }
 
+/*
+ * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ *
+ * Local variables:
+ * c-basic-offset: 8
+ * tab-width: 8
+ * indent-tabs-mode: t
+ * End:
+ *
+ * vi: set shiftwidth=8 tabstop=8 noexpandtab:
+ * :indentSize=8:tabSize=8:noTabs=false:
+ */
