@@ -3,7 +3,7 @@
  * <http://www.postgresql.org/docs/current/static/protocol.html>
  * Copyright 2004 Abhijit Menon-Sen <ams@oryx.com>
  *
- * $Id$
+ * $Id: packet-pgsql.c 52180 2013-09-22 20:04:35Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -172,8 +172,7 @@ dissect_pgsql(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     /* cv = find_or_create_conversation(pinfo); */
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "PGSQL");
-    if (check_col(pinfo->cinfo, COL_INFO))
-        col_set_str(pinfo->cinfo, COL_INFO,
+    col_set_str(pinfo->cinfo, COL_INFO,
                     (pinfo->match_uint == pinfo->destport) ?
                      ">" : "<");
 
@@ -214,7 +213,6 @@ dissect_pgsql_msg(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     guchar type;
     const char *typestr;
     guint length;
-    gboolean info = check_col(pinfo->cinfo, COL_INFO);
     gboolean fe = (pinfo->match_uint == pinfo->destport);
 
     n = 0;
@@ -248,14 +246,12 @@ dissect_pgsql_msg(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         typestr = val_to_str_const(type, be_messages, "Unknown");
     }
 
-    if (info) {
-        /* This is a terrible hack. It makes the "Info" column reflect
-           the contents of every message in a TCP packet. Could it be
-           done any better? */
-        col_append_fstr(pinfo->cinfo, COL_INFO, "%s%c",
-                        ( first_message ? "" : "/" ), type);
-        first_message = FALSE;
-    }
+    /* This is a terrible hack. It makes the "Info" column reflect
+        the contents of every message in a TCP packet. Could it be
+        done any better? */
+    col_append_fstr(pinfo->cinfo, COL_INFO, "%s%c",
+                    ( first_message ? "" : "/" ), type);
+    first_message = FALSE;
 
     if (tree) {
         ti = proto_tree_add_item(tree, proto_pgsql, tvb, 0, -1, ENC_NA);
@@ -391,7 +387,7 @@ static void dissect_pgsql_fe_msg(guchar type, guint length, tvbuff_t *tvb,
 
         if (i != 0) {
             n += 1;
-            s = tvb_get_ephemeral_stringz(tvb, n, &siz);
+            s = tvb_get_stringz(wmem_packet_scope(), tvb, n, &siz);
             hidden_item = proto_tree_add_string(tree, i, tvb, n, siz, s);
             PROTO_ITEM_SET_HIDDEN(hidden_item);
             proto_tree_add_text(
@@ -515,11 +511,11 @@ static void dissect_pgsql_be_msg(guchar type, guint length, tvbuff_t *tvb,
 
     /* Parameter status */
     case 'S':
-        s = tvb_get_ephemeral_stringz(tvb, n, &siz);
+        s = tvb_get_stringz(wmem_packet_scope(), tvb, n, &siz);
         hidden_item = proto_tree_add_string(tree, hf_parameter_name, tvb, n, siz, s);
         PROTO_ITEM_SET_HIDDEN(hidden_item);
         n += siz;
-        t = tvb_get_ephemeral_stringz(tvb, n, &i);
+        t = tvb_get_stringz(wmem_packet_scope(), tvb, n, &i);
         hidden_item = proto_tree_add_string(tree, hf_parameter_value, tvb, n, i, t);
         PROTO_ITEM_SET_HIDDEN(hidden_item);
         proto_tree_add_text(tree, tvb, n-siz, siz+i, "%s: %s", s, t);
@@ -599,7 +595,7 @@ static void dissect_pgsql_be_msg(guchar type, guint length, tvbuff_t *tvb,
             c = tvb_get_guint8(tvb, n);
             if (c == '\0')
                 break;
-            s = tvb_get_ephemeral_stringz(tvb, n+1, &siz);
+            s = tvb_get_stringz(wmem_packet_scope(), tvb, n+1, &siz);
             i = hf_text;
             switch (c) {
             case 'S': i = hf_severity; break;
