@@ -2,7 +2,7 @@
  * Routines for PIM disassembly
  * (c) Copyright Jun-ichiro itojun Hagino <itojun@itojun.org>
  *
- * $Id$
+ * $Id: packet-pim.c 52591 2013-10-13 19:56:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,6 +32,7 @@
 #include <epan/afn.h>
 #include <epan/prefs.h>
 #include <epan/in_cksum.h>
+#include <epan/wmem/wmem.h>
 #include "packet-pim.h"
 
 #define PIM_TYPE(x)     ((x) & 0x0f)
@@ -133,13 +134,13 @@ dissect_pimv1_addr(tvbuff_t *tvb, int offset) {
 
     flags_masklen = tvb_get_ntohs(tvb, offset);
     if (flags_masklen & 0x0180) {
-        return ep_strdup_printf("(%s%s%s) ",
-                                flags_masklen & 0x0100 ? "S" : "",
-                                flags_masklen & 0x0080 ? "W" : "",
-                                flags_masklen & 0x0040 ? "R" : "");
+        return wmem_strdup_printf(wmem_packet_scope(), "(%s%s%s) ",
+                                  flags_masklen & 0x0100 ? "S" : "",
+                                  flags_masklen & 0x0080 ? "W" : "",
+                                  flags_masklen & 0x0040 ? "R" : "");
     } else {
-        return ep_strdup_printf("%s/%u",
-                                tvb_ip_to_str(tvb, offset + 2), flags_masklen & 0x3f);
+        return wmem_strdup_printf(wmem_packet_scope(), "%s/%u",
+                                  tvb_ip_to_str(tvb, offset + 2), flags_masklen & 0x3f);
     }
 }
 
@@ -196,8 +197,7 @@ dissect_pimv1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     offset += 1;
 
     pim_type = tvb_get_guint8(tvb, offset);
-    if (check_col(pinfo->cinfo, COL_INFO))
-        col_add_str(pinfo->cinfo, COL_INFO,
+    col_add_str(pinfo->cinfo, COL_INFO,
                     val_to_str(pim_type, type1vals, "Unknown (%u)"));
 
     proto_tree_add_uint(pim_tree, hf_pim_code, tvb, offset, 1, pim_type);
@@ -248,14 +248,14 @@ dissect_pimv1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
         cksum_vec[0].len = pim_length;
         computed_cksum = in_cksum(&cksum_vec[0], 1);
         if (computed_cksum == 0) {
-            proto_tree_add_uint_format(pim_tree, hf_pim_cksum, tvb,
+            proto_tree_add_uint_format_value(pim_tree, hf_pim_cksum, tvb,
                                        offset, 2, pim_cksum,
-                                       "Checksum: 0x%04x [correct]",
+                                       "0x%04x [correct]",
                                        pim_cksum);
         } else {
-            proto_tree_add_uint_format(pim_tree, hf_pim_cksum, tvb,
+            proto_tree_add_uint_format_value(pim_tree, hf_pim_cksum, tvb,
                                        offset, 2, pim_cksum,
-                                       "Checksum: 0x%04x [incorrect, should be 0x%04x]",
+                                       "0x%04x [incorrect, should be 0x%04x]",
                                        pim_cksum, in_cksum_shouldbe(pim_cksum, computed_cksum));
         }
     } else {
@@ -465,7 +465,6 @@ dissect_pimv1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
     case 5:     /* assert */
     {
-        guint32 pref;
 
         proto_tree_add_item(pimopt_tree, hf_pim_group_address_ip4, tvb, offset, 4, ENC_BIG_ENDIAN);
         offset += 4;
@@ -474,10 +473,8 @@ dissect_pimv1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
         offset += 4;
 
         proto_tree_add_item(pimopt_tree, hf_pim_rpt, tvb, offset, 1, ENC_BIG_ENDIAN);
-        pref = tvb_get_ntohl(tvb, offset) & 0x7fffffff;
-        proto_tree_add_uint_format(pimopt_tree, hf_pim_metric_pref, tvb,
-                                   offset, 4, pref,
-                                   "Metric Preference: %u", pref);
+        proto_tree_add_item(pimopt_tree, hf_pim_metric_pref, tvb,
+                                   offset, 4, ENC_BIG_ENDIAN);
         offset += 4;
 
         proto_tree_add_item(pimopt_tree, hf_pim_metric, tvb, offset, 4, ENC_BIG_ENDIAN);
@@ -708,12 +705,9 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
         break;
     }
 
-    if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-        col_add_fstr(pinfo->cinfo, COL_PROTOCOL, "PIMv%d",
+    col_add_fstr(pinfo->cinfo, COL_PROTOCOL, "PIMv%d",
                      PIM_VER(pim_typever));
-    }
-    if (check_col(pinfo->cinfo, COL_INFO))
-        col_add_str(pinfo->cinfo, COL_INFO, typestr);
+    col_add_str(pinfo->cinfo, COL_INFO, typestr);
 
     ti = proto_tree_add_item(tree, proto_pim, tvb, offset, -1, ENC_NA);
     pim_tree = proto_item_add_subtree(ti, ett_pim);
@@ -784,14 +778,14 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
         }
 
         if (computed_cksum == 0) {
-            proto_tree_add_uint_format(pim_tree, hf_pim_cksum, tvb,
+            proto_tree_add_uint_format_value(pim_tree, hf_pim_cksum, tvb,
                                        offset + 2, 2, pim_cksum,
-                                       "Checksum: 0x%04x [correct]",
+                                       "0x%04x [correct]",
                                        pim_cksum);
         } else {
-            proto_tree_add_uint_format(pim_tree, hf_pim_cksum, tvb,
+            proto_tree_add_uint_format_value(pim_tree, hf_pim_cksum, tvb,
                                        offset + 2, 2, pim_cksum,
-                                       "Checksum: 0x%04x [incorrect, should be 0x%04x]",
+                                       "0x%04x [incorrect, should be 0x%04x]",
                                        pim_cksum, in_cksum_shouldbe(pim_cksum, computed_cksum));
         }
     } else {
@@ -1017,8 +1011,8 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
         offset += 2;
 
         for (i = 0; i < ngroup; i++) {
-            if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_group, 
-                                   ep_strdup_printf("Group %d", i), &tigroup,
+            if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_group,
+                                   wmem_strdup_printf(wmem_packet_scope(), "Group %d", i), &tigroup,
                                    hf_pim_group_ip4, hf_pim_group_ip6, &advance))
                 goto breakbreak3;
 
@@ -1079,8 +1073,8 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
         offset += advance;
 
         for (i = 0; tvb_reported_length_remaining(tvb, offset) > 0; i++) {
-            if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_group, 
-                                   ep_strdup_printf("Group %d", i), &tigroup,
+            if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_group,
+                                   wmem_strdup_printf(wmem_packet_scope(), "Group %d", i), &tigroup,
                                    hf_pim_group_ip4, hf_pim_group_ip6, &advance))
                 goto breakbreak4;
 
@@ -1094,8 +1088,8 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
             offset += 3;
 
             for (j = 0; j < frpcnt; j++) {
-                if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_unicast, 
-                                       ep_strdup_printf("RP %d", j), NULL,
+                if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_unicast,
+                                       wmem_strdup_printf(wmem_packet_scope(), "RP %d", j), NULL,
                                        hf_pim_rp_ip4, hf_pim_rp_ip6, &advance))
 
                     goto breakbreak4;
@@ -1119,25 +1113,22 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
     case 5:     /* assert */
     {
         int advance;
-        guint32 pref;
 
-        if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_group, 
+        if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_group,
                                 NULL, NULL,
                                 hf_pim_group_ip4, hf_pim_group_ip6, &advance))
             break;
         offset += advance;
 
-        if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_unicast, 
+        if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_unicast,
                                 NULL, NULL,
                                 hf_pim_source_ip4, hf_pim_source_ip6, &advance))
             break;
         offset += advance;
 
         proto_tree_add_item(pimopt_tree, hf_pim_rpt, tvb, offset, 1, ENC_BIG_ENDIAN);
-        pref = tvb_get_ntohl(tvb, offset) & 0x7fffffff;
-        proto_tree_add_uint_format(pimopt_tree, hf_pim_metric_pref, tvb,
-                                   offset, 4, pref,
-                                   "Metric Preference: %u", pref);
+        proto_tree_add_item(pimopt_tree, hf_pim_metric_pref, tvb,
+                                   offset, 4, ENC_BIG_ENDIAN);
         offset += 4;
 
         proto_tree_add_item(pimopt_tree, hf_pim_metric, tvb, offset, 4, ENC_BIG_ENDIAN);
@@ -1164,15 +1155,15 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
                                    holdtime == 0xffff ? "(infinity)": "");
         offset += 2;
 
-        if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_unicast, 
+        if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_unicast,
                                 NULL, NULL,
                                 hf_pim_rp_ip4, hf_pim_rp_ip6, &advance))
             break;
         offset += advance;
 
         for (i = 0; i < pfxcnt; i++) {
-            if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_group, 
-                                   ep_strdup_printf("Group %d", i), NULL,
+            if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_group,
+                                   wmem_strdup_printf(wmem_packet_scope(), "Group %d", i), NULL,
                                    hf_pim_group_ip4, hf_pim_group_ip6, &advance))
                 goto breakbreak8;
             offset += advance;
@@ -1184,31 +1175,28 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
     case 9:     /* State-Refresh */
     {
         int advance;
-        guint32 pref;
 
-        if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_group, 
+        if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_group,
                                 NULL, NULL,
                                 hf_pim_group_ip4, hf_pim_group_ip6, &advance))
             break;
         offset += advance;
 
-        if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_unicast, 
+        if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_unicast,
                                 NULL, NULL,
                                 hf_pim_source_ip4, hf_pim_source_ip6, &advance))
             break;
         offset += advance;
 
-        if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_unicast, 
+        if (!dissect_pim_addr(pimopt_tree, tvb, offset, pimv2_unicast,
                                 NULL, NULL,
                                 hf_pim_originator_ip4, hf_pim_originator_ip6, &advance))
             break;
         offset += advance;
 
         proto_tree_add_item(pimopt_tree, hf_pim_rpt, tvb, offset, 1, ENC_BIG_ENDIAN);
-        pref = tvb_get_ntohl(tvb, offset) & 0x7fffffff;
-        proto_tree_add_uint_format(pimopt_tree, hf_pim_metric_pref, tvb,
-                                   offset, 4, pref,
-                                   "Metric Preference: %u", pref);
+        proto_tree_add_item(pimopt_tree, hf_pim_metric_pref, tvb,
+                                   offset, 4, ENC_BIG_ENDIAN);
         offset += 4;
 
         proto_tree_add_item(pimopt_tree, hf_pim_metric, tvb, offset, 4, ENC_BIG_ENDIAN);
