@@ -3,7 +3,7 @@
  * RFC 1939
  * Copyright 1999, Richard Sharpe <rsharpe@ns.aus.com>
  *
- * $Id$
+ * $Id: packet-pop.c 51968 2013-09-12 12:37:27Z eapache $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -37,6 +37,7 @@
 #include <epan/conversation.h>
 #include <epan/prefs.h>
 #include <epan/reassemble.h>
+#include <epan/wmem/wmem.h>
 #include "packet-ssl.h"
 
 static int proto_pop = -1;
@@ -134,7 +135,7 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   int                    linelen;
   int                    tokenlen;
   const guchar           *next_token;
-  fragment_data          *frag_msg = NULL;
+  fragment_head          *frag_msg = NULL;
   tvbuff_t               *next_tvb = NULL;
   conversation_t         *conversation = NULL;
   struct pop_data_val    *data_val = NULL;
@@ -151,7 +152,7 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
      /*
       * No conversation - create one and attach it.
       */
-     data_val = se_new0(struct pop_data_val);
+     data_val = wmem_new0(wmem_file_scope(), struct pop_data_val);
 
      conversation_add_proto_data(conversation, proto_pop, data_val);
   }
@@ -194,22 +195,20 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     is_continuation = response_is_continuation(line);
   }
 
-  if (check_col(pinfo->cinfo, COL_INFO)) {
-    /*
-     * Put the first line from the buffer into the summary
-     * if it's a POP request or reply (but leave out the
-     * line terminator).
-     * Otherwise, just call it a continuation.
-     */
-    if (is_continuation) {
-      length_remaining = tvb_length_remaining(tvb, offset);
-      col_add_fstr(pinfo->cinfo, COL_INFO, "S: DATA fragment, %d byte%s",
+  /*
+   * Put the first line from the buffer into the summary
+   * if it's a POP request or reply (but leave out the
+   * line terminator).
+   * Otherwise, just call it a continuation.
+   */
+  if (is_continuation) {
+    length_remaining = tvb_length_remaining(tvb, offset);
+    col_add_fstr(pinfo->cinfo, COL_INFO, "S: DATA fragment, %d byte%s",
                    length_remaining, plurality (length_remaining, "", "s"));
-    }
-    else
-      col_add_fstr(pinfo->cinfo, COL_INFO, "%s: %s", is_request ? "C" : "S",
-                   format_text(line, linelen));
   }
+  else
+    col_add_fstr(pinfo->cinfo, COL_INFO, "%s: %s", is_request ? "C" : "S",
+                   format_text(line, linelen));
 
   ti = proto_tree_add_item(tree, proto_pop, tvb, offset, -1, ENC_NA);
   pop_tree = proto_item_add_subtree(ti, ett_pop);
@@ -222,7 +221,7 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
         data_val->msg_read_len += tvb_length(tvb);
 
-        frame_data_p = se_new(struct pop_proto_data);
+        frame_data_p = wmem_new(wmem_file_scope(), struct pop_proto_data);
 
         frame_data_p->conversation_id = conversation->index;
         frame_data_p->more_frags = data_val->msg_read_len < data_val->msg_tot_len;
