@@ -1,7 +1,7 @@
 /* packet-portmap.c
  * Routines for portmap dissection
  *
- * $Id$
+ * $Id: packet-portmap.c 52045 2013-09-15 01:48:30Z mmann $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -92,23 +92,20 @@ dissect_getport_call(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
 	/* program */
 	prog = tvb_get_ntohl(tvb, offset+0);
 	prog_name = rpc_prog_name(prog);
-	proto_tree_add_uint_format(tree, hf_portmap_prog, tvb,
-		offset, 4, prog, "Program: %s (%u)",
+	proto_tree_add_uint_format_value(tree, hf_portmap_prog, tvb,
+		offset, 4, prog, "%s (%u)",
 		prog_name, prog);
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO,  " %s(%u)", prog_name, prog);
+	col_append_fstr(pinfo->cinfo, COL_INFO,  " %s(%u)", prog_name, prog);
 
-	}
 	proto_item_append_text(tree, " GETPORT Call %s(%u)", prog_name, prog);
 
 	/* version */
 	version = tvb_get_ntohl(tvb, offset+4);
 	proto_tree_add_item(tree, hf_portmap_version, tvb,
 		offset+4, 4, ENC_BIG_ENDIAN);
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO,  " V:%d", version);
+	col_append_fstr(pinfo->cinfo, COL_INFO,  " V:%d", version);
+
 
-	}
 	proto_item_append_text(tree, " Version:%d", version);
 
 
@@ -117,10 +114,8 @@ dissect_getport_call(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
 	proto_name = ipprotostr(proto);
 	proto_tree_add_uint_format(tree, hf_portmap_proto, tvb,
 		offset+8, 4, proto, "Proto: %s (%u)", proto_name, proto);
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO,  " %s", proto_name);
+	col_append_fstr(pinfo->cinfo, COL_INFO,  " %s", proto_name);
 
-	}
 	proto_item_append_text(tree, " %s", proto_name);
 
 	/* port */
@@ -159,9 +154,7 @@ dissect_getport_reply(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
 	    offset);
 	proto_item_append_text(tree, " GETPORT Reply Port:%d", portx);
 	if(portx){
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_append_fstr(pinfo->cinfo, COL_INFO,  " Port:%d", portx);
-		}
+		col_append_fstr(pinfo->cinfo, COL_INFO,  " Port:%d", portx);
 		proto_item_append_text(tree, " Port:%d", portx);
 	} else {
 		col_append_str(pinfo->cinfo, COL_INFO,  " PROGRAM_NOT_AVAILABLE");
@@ -182,8 +175,8 @@ dissect_set_call(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
 	if ( tree )
 	{
 		prog = tvb_get_ntohl(tvb, offset+0);
-		proto_tree_add_uint_format(tree, hf_portmap_prog, tvb,
-			offset, 4, prog, "Program: %s (%d)",
+		proto_tree_add_uint_format_value(tree, hf_portmap_prog, tvb,
+			offset, 4, prog, "%s (%d)",
 			rpc_prog_name(prog), prog);
 		proto_tree_add_item(tree, hf_portmap_version, tvb,
 			offset+4, 4, ENC_BIG_ENDIAN);
@@ -210,8 +203,8 @@ dissect_unset_call(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
 	if ( tree )
 	{
 		prog = tvb_get_ntohl(tvb, offset+0);
-		proto_tree_add_uint_format(tree, hf_portmap_prog, tvb,
-			offset, 4, prog, "Program: %s (%d)",
+		proto_tree_add_uint_format_value(tree, hf_portmap_prog, tvb,
+			offset, 4, prog, "%s (%d)",
 			rpc_prog_name(prog), prog);
 		proto_tree_add_item(tree, hf_portmap_version, tvb,
 			offset+4, 4, ENC_BIG_ENDIAN);
@@ -254,14 +247,14 @@ dissect_dump_entry(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
 			rpc_prog_name(prog), prog, version);
 		subtree = proto_item_add_subtree(ti, ett_portmap_entry);
 
-		proto_tree_add_uint_format(subtree, hf_portmap_prog, tvb,
+		proto_tree_add_uint_format_value(subtree, hf_portmap_prog, tvb,
 			offset+0, 4, prog,
-			"Program: %s (%u)", rpc_prog_name(prog), prog);
+			"%s (%u)", rpc_prog_name(prog), prog);
 		proto_tree_add_uint(subtree, hf_portmap_version, tvb,
 			offset+4, 4, version);
-		proto_tree_add_uint_format(subtree, hf_portmap_proto, tvb,
+		proto_tree_add_uint_format_value(subtree, hf_portmap_proto, tvb,
 			offset+8, 4, proto,
-			"Protocol: %s (0x%02x)", ipprotostr(proto), proto);
+			"%s (0x%02x)", ipprotostr(proto), proto);
 		proto_tree_add_uint(subtree, hf_portmap_port, tvb,
 			offset+12, 4, port);
 	}
@@ -288,8 +281,8 @@ dissect_callit_call(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	prog = tvb_get_ntohl(tvb, offset+0);
 	if ( tree )
 	{
-		proto_tree_add_uint_format(tree, hf_portmap_prog, tvb,
-			offset, 4, prog, "Program: %s (%u)",
+		proto_tree_add_uint_format_value(tree, hf_portmap_prog, tvb,
+			offset, 4, prog, "%s (%u)",
 			rpc_prog_name(prog), prog);
 	}
 
@@ -303,8 +296,8 @@ dissect_callit_call(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proc = tvb_get_ntohl(tvb, offset+8);
 	if ( tree )
 	{
-		proto_tree_add_uint_format(tree, hf_portmap_proc, tvb,
-			offset+8, 4, proc, "Procedure: %s (%u)",
+		proto_tree_add_uint_format_value(tree, hf_portmap_proc, tvb,
+			offset+8, 4, proc, "%s (%u)",
 			rpc_proc_name(prog, vers, proc), proc);
 	}
 
@@ -410,9 +403,9 @@ dissect_rpcb(tvbuff_t *tvb, int offset, packet_info *pinfo _U_, proto_tree *tree
 
 	prog = tvb_get_ntohl(tvb, offset);
 	if (rpcb_tree)
-		proto_tree_add_uint_format(rpcb_tree, hf_portmap_rpcb_prog, tvb,
+		proto_tree_add_uint_format_value(rpcb_tree, hf_portmap_rpcb_prog, tvb,
 			offset, 4, prog,
-			"Program: %s (%u)", rpc_prog_name(prog), prog);
+			"%s (%u)", rpc_prog_name(prog), prog);
 	offset += 4;
 
 	offset = dissect_rpc_uint32(tvb, rpcb_tree,
