@@ -2,7 +2,7 @@
  * packet-ppi.c
  * Routines for PPI Packet Header dissection
  *
- * $Id$
+ * $Id: packet-ppi.c 52074 2013-09-15 18:18:08Z pascal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -52,8 +52,10 @@
 #include <epan/packet.h>
 #include <epan/ptvcursor.h>
 #include <epan/prefs.h>
+#include <epan/expert.h>
 #include <epan/reassemble.h>
 #include <epan/frequency-utils.h>
+#include <epan/wmem/wmem.h>
 
 /* Needed for wtap_pcap_encap_to_wtap_encap(). */
 #include <wiretap/pcap-encap.h>
@@ -252,9 +254,9 @@ static int hf_80211n_mac_phy_rssi_ant3_ext = -1;
 static int hf_80211n_mac_phy_ext_chan_freq = -1;
 static int hf_80211n_mac_phy_ext_chan_flags = -1;
 static int hf_80211n_mac_phy_ext_chan_flags_turbo = -1;
-static int hhf_80211n_mac_phy_ext_chan_flags_cck = -1;
+static int hf_80211n_mac_phy_ext_chan_flags_cck = -1;
 static int hf_80211n_mac_phy_ext_chan_flags_ofdm = -1;
-static int hhf_80211n_mac_phy_ext_chan_flags_2ghz = -1;
+static int hf_80211n_mac_phy_ext_chan_flags_2ghz = -1;
 static int hf_80211n_mac_phy_ext_chan_flags_5ghz = -1;
 static int hf_80211n_mac_phy_ext_chan_flags_passive = -1;
 static int hf_80211n_mac_phy_ext_chan_flags_dynamic = -1;
@@ -299,6 +301,13 @@ static int hf_8023_extension_errors_sequence = -1;
 static int hf_8023_extension_errors_symbol = -1;
 static int hf_8023_extension_errors_data = -1;
 
+/* Generated from convert_proto_tree_add_text.pl */
+static int hf_ppi_antenna = -1;
+static int hf_ppi_harris = -1;
+static int hf_ppi_reserved = -1;
+static int hf_ppi_vector = -1;
+static int hf_ppi_gps = -1;
+
 static gint ett_ppi_pph = -1;
 static gint ett_ppi_flags = -1;
 static gint ett_dot11_common = -1;
@@ -316,11 +325,15 @@ static gint ett_8023_extension = -1;
 static gint ett_8023_extension_flags = -1;
 static gint ett_8023_extension_errors = -1;
 
+/* Generated from convert_proto_tree_add_text.pl */
+static expert_field ei_ppi_invalid_length = EI_INIT;
+
+static dissector_handle_t ppi_handle;
+
 static dissector_handle_t data_handle;
 static dissector_handle_t ieee80211_ht_handle;
 static dissector_handle_t ppi_gps_handle, ppi_vector_handle, ppi_sensor_handle, ppi_antenna_handle;
 
-
 static const true_false_string tfs_ppi_head_flag_alignment = { "32-bit aligned", "Not aligned" };
 static const true_false_string tfs_tsft_ms = { "milliseconds", "microseconds" };
 static const true_false_string tfs_ht20_40 = { "HT40", "HT20" };
@@ -476,7 +489,7 @@ dissect_80211_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int of
     data_len -= 4; /* Subtract field header length */
 
     if (data_len != PPI_80211_COMMON_LEN) {
-        proto_tree_add_text(ftree, tvb, offset, data_len, "Invalid length: %u", data_len);
+        proto_tree_add_expert_format(ftree, pinfo, &ei_ppi_invalid_length, tvb, offset, data_len, "Invalid length: %u", data_len);
         THROW(ReportedBoundsError);
     }
 
@@ -504,18 +517,14 @@ dissect_80211_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int of
                                     rate_kbps / 1000.0);
     if (rate_kbps == 0)
         proto_item_append_text(ti, " [invalid]");
-    if (check_col(pinfo->cinfo, COL_TX_RATE)) {
-        col_add_fstr(pinfo->cinfo, COL_TX_RATE, "%.1f Mbps", rate_kbps / 1000.0);
-    }
+    col_add_fstr(pinfo->cinfo, COL_TX_RATE, "%.1f Mbps", rate_kbps / 1000.0);
     ptvcursor_advance(csr, 2);
 
     common_frequency = tvb_get_letohs(ptvcursor_tvbuff(csr), ptvcursor_current_offset(csr));
     chan_str = ieee80211_mhz_to_str(common_frequency);
-    proto_tree_add_uint_format(ptvcursor_tree(csr), hf_80211_common_chan_freq, ptvcursor_tvbuff(csr),
-                               ptvcursor_current_offset(csr), 2, common_frequency, "Channel frequency: %s", chan_str);
-    if (check_col(pinfo->cinfo, COL_FREQ_CHAN)) {
-        col_add_fstr(pinfo->cinfo, COL_FREQ_CHAN, "%s", chan_str);
-    }
+    proto_tree_add_uint_format_value(ptvcursor_tree(csr), hf_80211_common_chan_freq, ptvcursor_tvbuff(csr),
+                               ptvcursor_current_offset(csr), 2, common_frequency, "%s", chan_str);
+    col_add_fstr(pinfo->cinfo, COL_FREQ_CHAN, "%s", chan_str);
     g_free(chan_str);
     ptvcursor_advance(csr, 2);
 
@@ -535,10 +544,9 @@ dissect_80211_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int of
     ptvcursor_add(csr, hf_80211_common_fhss_hopset, 1, ENC_LITTLE_ENDIAN);
     ptvcursor_add(csr, hf_80211_common_fhss_pattern, 1, ENC_LITTLE_ENDIAN);
 
-    if (check_col(pinfo->cinfo, COL_RSSI)) {
-        col_add_fstr(pinfo->cinfo, COL_RSSI, "%d dBm",
+    col_add_fstr(pinfo->cinfo, COL_RSSI, "%d dBm",
             (gint8) tvb_get_guint8(tvb, ptvcursor_current_offset(csr)));
-    }
+
     ptvcursor_add_invalid_check(csr, hf_80211_common_dbm_antsignal, 1, 0x80); /* -128 */
     ptvcursor_add_invalid_check(csr, hf_80211_common_dbm_antnoise, 1, 0x80);
 
@@ -564,7 +572,7 @@ dissect_80211n_mac(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, int
     }
 
     if (data_len != PPI_80211N_MAC_LEN) {
-        proto_tree_add_text(ftree, tvb, offset, data_len, "Invalid length: %u", data_len);
+        proto_tree_add_expert_format(ftree, pinfo, &ei_ppi_invalid_length, tvb, offset, data_len, "Invalid length: %u", data_len);
         THROW(ReportedBoundsError);
     }
 
@@ -606,7 +614,7 @@ dissect_80211n_mac_phy(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int
     data_len -= 4; /* Subtract field header length */
 
     if (data_len != PPI_80211N_MAC_PHY_LEN) {
-        proto_tree_add_text(ftree, tvb, offset, data_len, "Invalid length: %u", data_len);
+        proto_tree_add_expert_format(ftree, pinfo, &ei_ppi_invalid_length, tvb, offset, data_len, "Invalid length: %u", data_len);
         THROW(ReportedBoundsError);
     }
 
@@ -640,9 +648,9 @@ dissect_80211n_mac_phy(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int
     ptvcursor_add_with_subtree(csr, hf_80211n_mac_phy_ext_chan_flags, 2, ENC_LITTLE_ENDIAN,
                                ett_dot11n_mac_phy_ext_channel_flags);
     ptvcursor_add_no_advance(csr, hf_80211n_mac_phy_ext_chan_flags_turbo, 2, ENC_LITTLE_ENDIAN);
-    ptvcursor_add_no_advance(csr, hhf_80211n_mac_phy_ext_chan_flags_cck, 2, ENC_LITTLE_ENDIAN);
+    ptvcursor_add_no_advance(csr, hf_80211n_mac_phy_ext_chan_flags_cck, 2, ENC_LITTLE_ENDIAN);
     ptvcursor_add_no_advance(csr, hf_80211n_mac_phy_ext_chan_flags_ofdm, 2, ENC_LITTLE_ENDIAN);
-    ptvcursor_add_no_advance(csr, hhf_80211n_mac_phy_ext_chan_flags_2ghz, 2, ENC_LITTLE_ENDIAN);
+    ptvcursor_add_no_advance(csr, hf_80211n_mac_phy_ext_chan_flags_2ghz, 2, ENC_LITTLE_ENDIAN);
     ptvcursor_add_no_advance(csr, hf_80211n_mac_phy_ext_chan_flags_5ghz, 2, ENC_LITTLE_ENDIAN);
     ptvcursor_add_no_advance(csr, hf_80211n_mac_phy_ext_chan_flags_passive, 2, ENC_LITTLE_ENDIAN);
     ptvcursor_add_no_advance(csr, hf_80211n_mac_phy_ext_chan_flags_dynamic, 2, ENC_LITTLE_ENDIAN);
@@ -678,7 +686,7 @@ dissect_aggregation_extension(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree
     data_len -= 4; /* Subtract field header length */
 
     if (data_len != PPI_AGGREGATION_EXTENSION_LEN) {
-        proto_tree_add_text(ftree, tvb, offset, data_len, "Invalid length: %u", data_len);
+        proto_tree_add_expert_format(ftree, pinfo, &ei_ppi_invalid_length, tvb, offset, data_len, "Invalid length: %u", data_len);
         THROW(ReportedBoundsError);
     }
 
@@ -701,7 +709,7 @@ dissect_8023_extension(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree,
     data_len -= 4; /* Subtract field header length */
 
     if (data_len != PPI_8023_EXTENSION_LEN) {
-        proto_tree_add_text(ftree, tvb, offset, data_len, "Invalid length: %u", data_len);
+        proto_tree_add_expert_format(ftree, pinfo, &ei_ppi_invalid_length, tvb, offset, data_len, "Invalid length: %u", data_len);
         THROW(ReportedBoundsError);
     }
 
@@ -741,7 +749,8 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     guint32        dlt;
     guint32        n_ext_flags = 0;
     guint32        ampdu_id    = 0;
-    fragment_data *fd_head     = NULL, *ft_fdh = NULL;
+    fragment_head *fd_head     = NULL;
+    fragment_item *ft_fdh      = NULL;
     gint           mpdu_count  = 0;
     gchar         *mpdu_str;
     gboolean       first_mpdu  = TRUE;
@@ -830,8 +839,7 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         case PPI_GPS_INFO:
             if (ppi_gps_handle == NULL)
             {
-                proto_tree_add_text(ppi_tree, tvb, offset, data_len,
-                                    "%s (%u bytes)", val_to_str_const(data_type, vs_ppi_field_type, "GPS: "), data_len);
+                proto_tree_add_item(ppi_tree, hf_ppi_gps, tvb, offset, data_len, ENC_NA);
             }
             else /* we found a suitable dissector */
             {
@@ -843,8 +851,7 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         case PPI_VECTOR_INFO:
             if (ppi_vector_handle == NULL)
             {
-                proto_tree_add_text(ppi_tree, tvb, offset, data_len,
-                                    "%s (%u bytes)", val_to_str_const(data_type, vs_ppi_field_type, "VECTOR: "), data_len);
+                proto_tree_add_item(ppi_tree, hf_ppi_vector, tvb, offset, data_len, ENC_NA);
             }
             else /* we found a suitable dissector */
             {
@@ -856,8 +863,7 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         case PPI_SENSOR_INFO:
             if (ppi_sensor_handle == NULL)
             {
-                proto_tree_add_text(ppi_tree, tvb, offset, data_len,
-                                    "%s (%u bytes)", val_to_str_const(data_type, vs_ppi_field_type, "HARRIS: "), data_len);
+                proto_tree_add_item(ppi_tree, hf_ppi_harris, tvb, offset, data_len, ENC_NA);
             }
             else /* we found a suitable dissector */
             {
@@ -869,8 +875,7 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         case PPI_ANTENNA_INFO:
             if (ppi_antenna_handle == NULL)
             {
-                proto_tree_add_text(ppi_tree, tvb, offset, data_len,
-                                    "%s (%u bytes)", val_to_str_const(data_type, vs_ppi_field_type, "ANTENNA: "), data_len);
+                proto_tree_add_item(ppi_tree, hf_ppi_antenna, tvb, offset, data_len, ENC_NA);
             }
             else /* we found a suitable dissector */
             {
@@ -881,9 +886,7 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             break;
 
         default:
-            if (tree)
-                proto_tree_add_text(ppi_tree, tvb, offset, data_len,
-                                    "%s (%u bytes)", val_to_str_const(data_type, vs_ppi_field_type, "Reserved"), data_len);
+            proto_tree_add_item(ppi_tree, hf_ppi_reserved, tvb, offset, data_len, ENC_NA);
         }
 
         offset += data_len;
@@ -910,8 +913,7 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         }
         if (ampdu_len > AGGREGATE_MAX) {
             if (tree) {
-                proto_tree_add_text(ppi_tree, tvb, offset, -1,
-                    "[Aggregate length greater than maximum (%u)]", AGGREGATE_MAX);
+                proto_tree_add_expert_format(ppi_tree, pinfo, &ei_ppi_invalid_length, tvb, offset, -1, "Aggregate length greater than maximum (%u)", AGGREGATE_MAX);
                 THROW(ReportedBoundsError);
             } else {
                 return;
@@ -941,7 +943,7 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             seg_tree = proto_item_add_subtree(ti, ett_ampdu_segments);
 
             while (ft_fdh) {
-                if (ft_fdh->data && ft_fdh->len) {
+                if (ft_fdh->tvb_data && ft_fdh->len) {
                     last_frame = ft_fdh->frame;
                     if (!first_mpdu)
                         proto_item_append_text(ti, ",");
@@ -971,12 +973,11 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             }
 
             while (fd_head) {
-                if (fd_head->data && fd_head->len) {
+                if (fd_head->tvb_data && fd_head->len) {
                     mpdu_count++;
-                    mpdu_str = ep_strdup_printf("MPDU #%d", mpdu_count);
+                    mpdu_str = wmem_strdup_printf(wmem_packet_scope(), "MPDU #%d", mpdu_count);
 
-                    next_tvb = tvb_new_child_real_data(tvb, fd_head->data,
-                        fd_head->len, fd_head->len);
+                    next_tvb = tvb_new_chain(tvb, fd_head->tvb_data);
                     add_new_data_source(pinfo, next_tvb, mpdu_str);
 
                     if (agg_tree) {
@@ -1197,13 +1198,13 @@ proto_register_ppi(void)
     { &hf_80211n_mac_phy_ext_chan_flags_turbo,
        { "Turbo", "ppi.80211-mac-phy.ext-chan.type.turbo",
          FT_BOOLEAN, 16, NULL, 0x0010, "PPI 802.11n MAC+PHY Channel Type Turbo", HFILL } },
-    { &hhf_80211n_mac_phy_ext_chan_flags_cck,
+    { &hf_80211n_mac_phy_ext_chan_flags_cck,
        { "Complementary Code Keying (CCK)", "ppi.80211-mac-phy.ext-chan.type.cck",
          FT_BOOLEAN, 16, NULL, 0x0020, "PPI 802.11n MAC+PHY Channel Type Complementary Code Keying (CCK) Modulation", HFILL } },
     { &hf_80211n_mac_phy_ext_chan_flags_ofdm,
        { "Orthogonal Frequency-Division Multiplexing (OFDM)", "ppi.80211-mac-phy.ext-chan.type.ofdm",
          FT_BOOLEAN, 16, NULL, 0x0040, "PPI 802.11n MAC+PHY Channel Type Orthogonal Frequency-Division Multiplexing (OFDM)", HFILL } },
-    { &hhf_80211n_mac_phy_ext_chan_flags_2ghz,
+    { &hf_80211n_mac_phy_ext_chan_flags_2ghz,
        { "2 GHz spectrum", "ppi.80211-mac-phy.ext-chan.type.2ghz",
          FT_BOOLEAN, 16, NULL, 0x0080, "PPI 802.11n MAC+PHY Channel Type 2 GHz spectrum", HFILL } },
     { &hf_80211n_mac_phy_ext_chan_flags_5ghz,
@@ -1314,6 +1315,12 @@ proto_register_ppi(void)
             FT_BOOLEAN, 32, TFS(&tfs_true_false), 0x0008,
             "PPI 802.3 Extension Data Error", HFILL } },
 
+      /* Generated from convert_proto_tree_add_text.pl */
+      { &hf_ppi_gps, { "GPS", "ppi.gps", FT_BYTES, BASE_NONE, NULL, 0x0, NULL, HFILL }},
+      { &hf_ppi_vector, { "VECTOR", "ppi.vector", FT_BYTES, BASE_NONE, NULL, 0x0, NULL, HFILL }},
+      { &hf_ppi_harris, { "HARRIS", "ppi.harris", FT_BYTES, BASE_NONE, NULL, 0x0, NULL, HFILL }},
+      { &hf_ppi_antenna, { "ANTENNA", "ppi.antenna", FT_BYTES, BASE_NONE, NULL, 0x0, NULL, HFILL }},
+      { &hf_ppi_reserved, { "Reserved", "ppi.reserved", FT_BYTES, BASE_NONE, NULL, 0x0, NULL, HFILL }},
     };
 
     static gint *ett[] = {
@@ -1335,12 +1342,20 @@ proto_register_ppi(void)
         &ett_8023_extension_errors
     };
 
+    static ei_register_info ei[] = {
+        { &ei_ppi_invalid_length, { "ppi.invalid_length", PI_MALFORMED, PI_ERROR, "Invalid length", EXPFILL }},
+    };
+
     module_t *ppi_module;
+    expert_module_t* expert_ppi;
 
     proto_ppi = proto_register_protocol("PPI Packet Header", "PPI", "ppi");
     proto_register_field_array(proto_ppi, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
-    register_dissector("ppi", dissect_ppi, proto_ppi);
+    expert_ppi = expert_register_protocol(proto_ppi);
+    expert_register_field_array(expert_ppi, ei, array_length(ei));
+
+    ppi_handle = register_dissector("ppi", dissect_ppi, proto_ppi);
 
     register_init_routine(ampdu_reassemble_init);
 
@@ -1355,9 +1370,6 @@ proto_register_ppi(void)
 void
 proto_reg_handoff_ppi(void)
 {
-    dissector_handle_t ppi_handle;
-
-    ppi_handle = create_dissector_handle(dissect_ppi, proto_ppi);
     data_handle = find_dissector("data");
     ieee80211_ht_handle = find_dissector("wlan_ht");
     ppi_gps_handle = find_dissector("ppi_gps");
